#| -*-Scheme-*-

Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
    1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
    2017, 2018 Massachusetts Institute of Technology

This file is part of MIT/GNU Scheme.

MIT/GNU Scheme is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

MIT/GNU Scheme is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with MIT/GNU Scheme; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
USA.

|#

;;;; UCD property: na (name)

;;; Generated from Unicode 9.0.0

((0 . 32) . #f)
(32 . "SPACE")
(33 . "EXCLAMATION MARK")
(34 . "QUOTATION MARK")
(35 . "NUMBER SIGN")
(36 . "DOLLAR SIGN")
(37 . "PERCENT SIGN")
(38 . "AMPERSAND")
(39 . "APOSTROPHE")
(40 . "LEFT PARENTHESIS")
(41 . "RIGHT PARENTHESIS")
(42 . "ASTERISK")
(43 . "PLUS SIGN")
(44 . "COMMA")
(45 . "HYPHEN-MINUS")
(46 . "FULL STOP")
(47 . "SOLIDUS")
(48 . "DIGIT ZERO")
(49 . "DIGIT ONE")
(50 . "DIGIT TWO")
(51 . "DIGIT THREE")
(52 . "DIGIT FOUR")
(53 . "DIGIT FIVE")
(54 . "DIGIT SIX")
(55 . "DIGIT SEVEN")
(56 . "DIGIT EIGHT")
(57 . "DIGIT NINE")
(58 . "COLON")
(59 . "SEMICOLON")
(60 . "LESS-THAN SIGN")
(61 . "EQUALS SIGN")
(62 . "GREATER-THAN SIGN")
(63 . "QUESTION MARK")
(64 . "COMMERCIAL AT")
(65 . "LATIN CAPITAL LETTER A")
(66 . "LATIN CAPITAL LETTER B")
(67 . "LATIN CAPITAL LETTER C")
(68 . "LATIN CAPITAL LETTER D")
(69 . "LATIN CAPITAL LETTER E")
(70 . "LATIN CAPITAL LETTER F")
(71 . "LATIN CAPITAL LETTER G")
(72 . "LATIN CAPITAL LETTER H")
(73 . "LATIN CAPITAL LETTER I")
(74 . "LATIN CAPITAL LETTER J")
(75 . "LATIN CAPITAL LETTER K")
(76 . "LATIN CAPITAL LETTER L")
(77 . "LATIN CAPITAL LETTER M")
(78 . "LATIN CAPITAL LETTER N")
(79 . "LATIN CAPITAL LETTER O")
(80 . "LATIN CAPITAL LETTER P")
(81 . "LATIN CAPITAL LETTER Q")
(82 . "LATIN CAPITAL LETTER R")
(83 . "LATIN CAPITAL LETTER S")
(84 . "LATIN CAPITAL LETTER T")
(85 . "LATIN CAPITAL LETTER U")
(86 . "LATIN CAPITAL LETTER V")
(87 . "LATIN CAPITAL LETTER W")
(88 . "LATIN CAPITAL LETTER X")
(89 . "LATIN CAPITAL LETTER Y")
(90 . "LATIN CAPITAL LETTER Z")
(91 . "LEFT SQUARE BRACKET")
(92 . "REVERSE SOLIDUS")
(93 . "RIGHT SQUARE BRACKET")
(94 . "CIRCUMFLEX ACCENT")
(95 . "LOW LINE")
(96 . "GRAVE ACCENT")
(97 . "LATIN SMALL LETTER A")
(98 . "LATIN SMALL LETTER B")
(99 . "LATIN SMALL LETTER C")
(100 . "LATIN SMALL LETTER D")
(101 . "LATIN SMALL LETTER E")
(102 . "LATIN SMALL LETTER F")
(103 . "LATIN SMALL LETTER G")
(104 . "LATIN SMALL LETTER H")
(105 . "LATIN SMALL LETTER I")
(106 . "LATIN SMALL LETTER J")
(107 . "LATIN SMALL LETTER K")
(108 . "LATIN SMALL LETTER L")
(109 . "LATIN SMALL LETTER M")
(110 . "LATIN SMALL LETTER N")
(111 . "LATIN SMALL LETTER O")
(112 . "LATIN SMALL LETTER P")
(113 . "LATIN SMALL LETTER Q")
(114 . "LATIN SMALL LETTER R")
(115 . "LATIN SMALL LETTER S")
(116 . "LATIN SMALL LETTER T")
(117 . "LATIN SMALL LETTER U")
(118 . "LATIN SMALL LETTER V")
(119 . "LATIN SMALL LETTER W")
(120 . "LATIN SMALL LETTER X")
(121 . "LATIN SMALL LETTER Y")
(122 . "LATIN SMALL LETTER Z")
(123 . "LEFT CURLY BRACKET")
(124 . "VERTICAL LINE")
(125 . "RIGHT CURLY BRACKET")
(126 . "TILDE")
((127 . 160) . #f)
(160 . "NO-BREAK SPACE")
(161 . "INVERTED EXCLAMATION MARK")
(162 . "CENT SIGN")
(163 . "POUND SIGN")
(164 . "CURRENCY SIGN")
(165 . "YEN SIGN")
(166 . "BROKEN BAR")
(167 . "SECTION SIGN")
(168 . "DIAERESIS")
(169 . "COPYRIGHT SIGN")
(170 . "FEMININE ORDINAL INDICATOR")
(171 . "LEFT-POINTING DOUBLE ANGLE QUOTATION MARK")
(172 . "NOT SIGN")
(173 . "SOFT HYPHEN")
(174 . "REGISTERED SIGN")
(175 . "MACRON")
(176 . "DEGREE SIGN")
(177 . "PLUS-MINUS SIGN")
(178 . "SUPERSCRIPT TWO")
(179 . "SUPERSCRIPT THREE")
(180 . "ACUTE ACCENT")
(181 . "MICRO SIGN")
(182 . "PILCROW SIGN")
(183 . "MIDDLE DOT")
(184 . "CEDILLA")
(185 . "SUPERSCRIPT ONE")
(186 . "MASCULINE ORDINAL INDICATOR")
(187 . "RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK")
(188 . "VULGAR FRACTION ONE QUARTER")
(189 . "VULGAR FRACTION ONE HALF")
(190 . "VULGAR FRACTION THREE QUARTERS")
(191 . "INVERTED QUESTION MARK")
(192 . "LATIN CAPITAL LETTER A WITH GRAVE")
(193 . "LATIN CAPITAL LETTER A WITH ACUTE")
(194 . "LATIN CAPITAL LETTER A WITH CIRCUMFLEX")
(195 . "LATIN CAPITAL LETTER A WITH TILDE")
(196 . "LATIN CAPITAL LETTER A WITH DIAERESIS")
(197 . "LATIN CAPITAL LETTER A WITH RING ABOVE")
(198 . "LATIN CAPITAL LETTER AE")
(199 . "LATIN CAPITAL LETTER C WITH CEDILLA")
(200 . "LATIN CAPITAL LETTER E WITH GRAVE")
(201 . "LATIN CAPITAL LETTER E WITH ACUTE")
(202 . "LATIN CAPITAL LETTER E WITH CIRCUMFLEX")
(203 . "LATIN CAPITAL LETTER E WITH DIAERESIS")
(204 . "LATIN CAPITAL LETTER I WITH GRAVE")
(205 . "LATIN CAPITAL LETTER I WITH ACUTE")
(206 . "LATIN CAPITAL LETTER I WITH CIRCUMFLEX")
(207 . "LATIN CAPITAL LETTER I WITH DIAERESIS")
(208 . "LATIN CAPITAL LETTER ETH")
(209 . "LATIN CAPITAL LETTER N WITH TILDE")
(210 . "LATIN CAPITAL LETTER O WITH GRAVE")
(211 . "LATIN CAPITAL LETTER O WITH ACUTE")
(212 . "LATIN CAPITAL LETTER O WITH CIRCUMFLEX")
(213 . "LATIN CAPITAL LETTER O WITH TILDE")
(214 . "LATIN CAPITAL LETTER O WITH DIAERESIS")
(215 . "MULTIPLICATION SIGN")
(216 . "LATIN CAPITAL LETTER O WITH STROKE")
(217 . "LATIN CAPITAL LETTER U WITH GRAVE")
(218 . "LATIN CAPITAL LETTER U WITH ACUTE")
(219 . "LATIN CAPITAL LETTER U WITH CIRCUMFLEX")
(220 . "LATIN CAPITAL LETTER U WITH DIAERESIS")
(221 . "LATIN CAPITAL LETTER Y WITH ACUTE")
(222 . "LATIN CAPITAL LETTER THORN")
(223 . "LATIN SMALL LETTER SHARP S")
(224 . "LATIN SMALL LETTER A WITH GRAVE")
(225 . "LATIN SMALL LETTER A WITH ACUTE")
(226 . "LATIN SMALL LETTER A WITH CIRCUMFLEX")
(227 . "LATIN SMALL LETTER A WITH TILDE")
(228 . "LATIN SMALL LETTER A WITH DIAERESIS")
(229 . "LATIN SMALL LETTER A WITH RING ABOVE")
(230 . "LATIN SMALL LETTER AE")
(231 . "LATIN SMALL LETTER C WITH CEDILLA")
(232 . "LATIN SMALL LETTER E WITH GRAVE")
(233 . "LATIN SMALL LETTER E WITH ACUTE")
(234 . "LATIN SMALL LETTER E WITH CIRCUMFLEX")
(235 . "LATIN SMALL LETTER E WITH DIAERESIS")
(236 . "LATIN SMALL LETTER I WITH GRAVE")
(237 . "LATIN SMALL LETTER I WITH ACUTE")
(238 . "LATIN SMALL LETTER I WITH CIRCUMFLEX")
(239 . "LATIN SMALL LETTER I WITH DIAERESIS")
(240 . "LATIN SMALL LETTER ETH")
(241 . "LATIN SMALL LETTER N WITH TILDE")
(242 . "LATIN SMALL LETTER O WITH GRAVE")
(243 . "LATIN SMALL LETTER O WITH ACUTE")
(244 . "LATIN SMALL LETTER O WITH CIRCUMFLEX")
(245 . "LATIN SMALL LETTER O WITH TILDE")
(246 . "LATIN SMALL LETTER O WITH DIAERESIS")
(247 . "DIVISION SIGN")
(248 . "LATIN SMALL LETTER O WITH STROKE")
(249 . "LATIN SMALL LETTER U WITH GRAVE")
(250 . "LATIN SMALL LETTER U WITH ACUTE")
(251 . "LATIN SMALL LETTER U WITH CIRCUMFLEX")
(252 . "LATIN SMALL LETTER U WITH DIAERESIS")
(253 . "LATIN SMALL LETTER Y WITH ACUTE")
(254 . "LATIN SMALL LETTER THORN")
(255 . "LATIN SMALL LETTER Y WITH DIAERESIS")
(256 . "LATIN CAPITAL LETTER A WITH MACRON")
(257 . "LATIN SMALL LETTER A WITH MACRON")
(258 . "LATIN CAPITAL LETTER A WITH BREVE")
(259 . "LATIN SMALL LETTER A WITH BREVE")
(260 . "LATIN CAPITAL LETTER A WITH OGONEK")
(261 . "LATIN SMALL LETTER A WITH OGONEK")
(262 . "LATIN CAPITAL LETTER C WITH ACUTE")
(263 . "LATIN SMALL LETTER C WITH ACUTE")
(264 . "LATIN CAPITAL LETTER C WITH CIRCUMFLEX")
(265 . "LATIN SMALL LETTER C WITH CIRCUMFLEX")
(266 . "LATIN CAPITAL LETTER C WITH DOT ABOVE")
(267 . "LATIN SMALL LETTER C WITH DOT ABOVE")
(268 . "LATIN CAPITAL LETTER C WITH CARON")
(269 . "LATIN SMALL LETTER C WITH CARON")
(270 . "LATIN CAPITAL LETTER D WITH CARON")
(271 . "LATIN SMALL LETTER D WITH CARON")
(272 . "LATIN CAPITAL LETTER D WITH STROKE")
(273 . "LATIN SMALL LETTER D WITH STROKE")
(274 . "LATIN CAPITAL LETTER E WITH MACRON")
(275 . "LATIN SMALL LETTER E WITH MACRON")
(276 . "LATIN CAPITAL LETTER E WITH BREVE")
(277 . "LATIN SMALL LETTER E WITH BREVE")
(278 . "LATIN CAPITAL LETTER E WITH DOT ABOVE")
(279 . "LATIN SMALL LETTER E WITH DOT ABOVE")
(280 . "LATIN CAPITAL LETTER E WITH OGONEK")
(281 . "LATIN SMALL LETTER E WITH OGONEK")
(282 . "LATIN CAPITAL LETTER E WITH CARON")
(283 . "LATIN SMALL LETTER E WITH CARON")
(284 . "LATIN CAPITAL LETTER G WITH CIRCUMFLEX")
(285 . "LATIN SMALL LETTER G WITH CIRCUMFLEX")
(286 . "LATIN CAPITAL LETTER G WITH BREVE")
(287 . "LATIN SMALL LETTER G WITH BREVE")
(288 . "LATIN CAPITAL LETTER G WITH DOT ABOVE")
(289 . "LATIN SMALL LETTER G WITH DOT ABOVE")
(290 . "LATIN CAPITAL LETTER G WITH CEDILLA")
(291 . "LATIN SMALL LETTER G WITH CEDILLA")
(292 . "LATIN CAPITAL LETTER H WITH CIRCUMFLEX")
(293 . "LATIN SMALL LETTER H WITH CIRCUMFLEX")
(294 . "LATIN CAPITAL LETTER H WITH STROKE")
(295 . "LATIN SMALL LETTER H WITH STROKE")
(296 . "LATIN CAPITAL LETTER I WITH TILDE")
(297 . "LATIN SMALL LETTER I WITH TILDE")
(298 . "LATIN CAPITAL LETTER I WITH MACRON")
(299 . "LATIN SMALL LETTER I WITH MACRON")
(300 . "LATIN CAPITAL LETTER I WITH BREVE")
(301 . "LATIN SMALL LETTER I WITH BREVE")
(302 . "LATIN CAPITAL LETTER I WITH OGONEK")
(303 . "LATIN SMALL LETTER I WITH OGONEK")
(304 . "LATIN CAPITAL LETTER I WITH DOT ABOVE")
(305 . "LATIN SMALL LETTER DOTLESS I")
(306 . "LATIN CAPITAL LIGATURE IJ")
(307 . "LATIN SMALL LIGATURE IJ")
(308 . "LATIN CAPITAL LETTER J WITH CIRCUMFLEX")
(309 . "LATIN SMALL LETTER J WITH CIRCUMFLEX")
(310 . "LATIN CAPITAL LETTER K WITH CEDILLA")
(311 . "LATIN SMALL LETTER K WITH CEDILLA")
(312 . "LATIN SMALL LETTER KRA")
(313 . "LATIN CAPITAL LETTER L WITH ACUTE")
(314 . "LATIN SMALL LETTER L WITH ACUTE")
(315 . "LATIN CAPITAL LETTER L WITH CEDILLA")
(316 . "LATIN SMALL LETTER L WITH CEDILLA")
(317 . "LATIN CAPITAL LETTER L WITH CARON")
(318 . "LATIN SMALL LETTER L WITH CARON")
(319 . "LATIN CAPITAL LETTER L WITH MIDDLE DOT")
(320 . "LATIN SMALL LETTER L WITH MIDDLE DOT")
(321 . "LATIN CAPITAL LETTER L WITH STROKE")
(322 . "LATIN SMALL LETTER L WITH STROKE")
(323 . "LATIN CAPITAL LETTER N WITH ACUTE")
(324 . "LATIN SMALL LETTER N WITH ACUTE")
(325 . "LATIN CAPITAL LETTER N WITH CEDILLA")
(326 . "LATIN SMALL LETTER N WITH CEDILLA")
(327 . "LATIN CAPITAL LETTER N WITH CARON")
(328 . "LATIN SMALL LETTER N WITH CARON")
(329 . "LATIN SMALL LETTER N PRECEDED BY APOSTROPHE")
(330 . "LATIN CAPITAL LETTER ENG")
(331 . "LATIN SMALL LETTER ENG")
(332 . "LATIN CAPITAL LETTER O WITH MACRON")
(333 . "LATIN SMALL LETTER O WITH MACRON")
(334 . "LATIN CAPITAL LETTER O WITH BREVE")
(335 . "LATIN SMALL LETTER O WITH BREVE")
(336 . "LATIN CAPITAL LETTER O WITH DOUBLE ACUTE")
(337 . "LATIN SMALL LETTER O WITH DOUBLE ACUTE")
(338 . "LATIN CAPITAL LIGATURE OE")
(339 . "LATIN SMALL LIGATURE OE")
(340 . "LATIN CAPITAL LETTER R WITH ACUTE")
(341 . "LATIN SMALL LETTER R WITH ACUTE")
(342 . "LATIN CAPITAL LETTER R WITH CEDILLA")
(343 . "LATIN SMALL LETTER R WITH CEDILLA")
(344 . "LATIN CAPITAL LETTER R WITH CARON")
(345 . "LATIN SMALL LETTER R WITH CARON")
(346 . "LATIN CAPITAL LETTER S WITH ACUTE")
(347 . "LATIN SMALL LETTER S WITH ACUTE")
(348 . "LATIN CAPITAL LETTER S WITH CIRCUMFLEX")
(349 . "LATIN SMALL LETTER S WITH CIRCUMFLEX")
(350 . "LATIN CAPITAL LETTER S WITH CEDILLA")
(351 . "LATIN SMALL LETTER S WITH CEDILLA")
(352 . "LATIN CAPITAL LETTER S WITH CARON")
(353 . "LATIN SMALL LETTER S WITH CARON")
(354 . "LATIN CAPITAL LETTER T WITH CEDILLA")
(355 . "LATIN SMALL LETTER T WITH CEDILLA")
(356 . "LATIN CAPITAL LETTER T WITH CARON")
(357 . "LATIN SMALL LETTER T WITH CARON")
(358 . "LATIN CAPITAL LETTER T WITH STROKE")
(359 . "LATIN SMALL LETTER T WITH STROKE")
(360 . "LATIN CAPITAL LETTER U WITH TILDE")
(361 . "LATIN SMALL LETTER U WITH TILDE")
(362 . "LATIN CAPITAL LETTER U WITH MACRON")
(363 . "LATIN SMALL LETTER U WITH MACRON")
(364 . "LATIN CAPITAL LETTER U WITH BREVE")
(365 . "LATIN SMALL LETTER U WITH BREVE")
(366 . "LATIN CAPITAL LETTER U WITH RING ABOVE")
(367 . "LATIN SMALL LETTER U WITH RING ABOVE")
(368 . "LATIN CAPITAL LETTER U WITH DOUBLE ACUTE")
(369 . "LATIN SMALL LETTER U WITH DOUBLE ACUTE")
(370 . "LATIN CAPITAL LETTER U WITH OGONEK")
(371 . "LATIN SMALL LETTER U WITH OGONEK")
(372 . "LATIN CAPITAL LETTER W WITH CIRCUMFLEX")
(373 . "LATIN SMALL LETTER W WITH CIRCUMFLEX")
(374 . "LATIN CAPITAL LETTER Y WITH CIRCUMFLEX")
(375 . "LATIN SMALL LETTER Y WITH CIRCUMFLEX")
(376 . "LATIN CAPITAL LETTER Y WITH DIAERESIS")
(377 . "LATIN CAPITAL LETTER Z WITH ACUTE")
(378 . "LATIN SMALL LETTER Z WITH ACUTE")
(379 . "LATIN CAPITAL LETTER Z WITH DOT ABOVE")
(380 . "LATIN SMALL LETTER Z WITH DOT ABOVE")
(381 . "LATIN CAPITAL LETTER Z WITH CARON")
(382 . "LATIN SMALL LETTER Z WITH CARON")
(383 . "LATIN SMALL LETTER LONG S")
(384 . "LATIN SMALL LETTER B WITH STROKE")
(385 . "LATIN CAPITAL LETTER B WITH HOOK")
(386 . "LATIN CAPITAL LETTER B WITH TOPBAR")
(387 . "LATIN SMALL LETTER B WITH TOPBAR")
(388 . "LATIN CAPITAL LETTER TONE SIX")
(389 . "LATIN SMALL LETTER TONE SIX")
(390 . "LATIN CAPITAL LETTER OPEN O")
(391 . "LATIN CAPITAL LETTER C WITH HOOK")
(392 . "LATIN SMALL LETTER C WITH HOOK")
(393 . "LATIN CAPITAL LETTER AFRICAN D")
(394 . "LATIN CAPITAL LETTER D WITH HOOK")
(395 . "LATIN CAPITAL LETTER D WITH TOPBAR")
(396 . "LATIN SMALL LETTER D WITH TOPBAR")
(397 . "LATIN SMALL LETTER TURNED DELTA")
(398 . "LATIN CAPITAL LETTER REVERSED E")
(399 . "LATIN CAPITAL LETTER SCHWA")
(400 . "LATIN CAPITAL LETTER OPEN E")
(401 . "LATIN CAPITAL LETTER F WITH HOOK")
(402 . "LATIN SMALL LETTER F WITH HOOK")
(403 . "LATIN CAPITAL LETTER G WITH HOOK")
(404 . "LATIN CAPITAL LETTER GAMMA")
(405 . "LATIN SMALL LETTER HV")
(406 . "LATIN CAPITAL LETTER IOTA")
(407 . "LATIN CAPITAL LETTER I WITH STROKE")
(408 . "LATIN CAPITAL LETTER K WITH HOOK")
(409 . "LATIN SMALL LETTER K WITH HOOK")
(410 . "LATIN SMALL LETTER L WITH BAR")
(411 . "LATIN SMALL LETTER LAMBDA WITH STROKE")
(412 . "LATIN CAPITAL LETTER TURNED M")
(413 . "LATIN CAPITAL LETTER N WITH LEFT HOOK")
(414 . "LATIN SMALL LETTER N WITH LONG RIGHT LEG")
(415 . "LATIN CAPITAL LETTER O WITH MIDDLE TILDE")
(416 . "LATIN CAPITAL LETTER O WITH HORN")
(417 . "LATIN SMALL LETTER O WITH HORN")
(418 . "LATIN CAPITAL LETTER OI")
(419 . "LATIN SMALL LETTER OI")
(420 . "LATIN CAPITAL LETTER P WITH HOOK")
(421 . "LATIN SMALL LETTER P WITH HOOK")
(422 . "LATIN LETTER YR")
(423 . "LATIN CAPITAL LETTER TONE TWO")
(424 . "LATIN SMALL LETTER TONE TWO")
(425 . "LATIN CAPITAL LETTER ESH")
(426 . "LATIN LETTER REVERSED ESH LOOP")
(427 . "LATIN SMALL LETTER T WITH PALATAL HOOK")
(428 . "LATIN CAPITAL LETTER T WITH HOOK")
(429 . "LATIN SMALL LETTER T WITH HOOK")
(430 . "LATIN CAPITAL LETTER T WITH RETROFLEX HOOK")
(431 . "LATIN CAPITAL LETTER U WITH HORN")
(432 . "LATIN SMALL LETTER U WITH HORN")
(433 . "LATIN CAPITAL LETTER UPSILON")
(434 . "LATIN CAPITAL LETTER V WITH HOOK")
(435 . "LATIN CAPITAL LETTER Y WITH HOOK")
(436 . "LATIN SMALL LETTER Y WITH HOOK")
(437 . "LATIN CAPITAL LETTER Z WITH STROKE")
(438 . "LATIN SMALL LETTER Z WITH STROKE")
(439 . "LATIN CAPITAL LETTER EZH")
(440 . "LATIN CAPITAL LETTER EZH REVERSED")
(441 . "LATIN SMALL LETTER EZH REVERSED")
(442 . "LATIN SMALL LETTER EZH WITH TAIL")
(443 . "LATIN LETTER TWO WITH STROKE")
(444 . "LATIN CAPITAL LETTER TONE FIVE")
(445 . "LATIN SMALL LETTER TONE FIVE")
(446 . "LATIN LETTER INVERTED GLOTTAL STOP WITH STROKE")
(447 . "LATIN LETTER WYNN")
(448 . "LATIN LETTER DENTAL CLICK")
(449 . "LATIN LETTER LATERAL CLICK")
(450 . "LATIN LETTER ALVEOLAR CLICK")
(451 . "LATIN LETTER RETROFLEX CLICK")
(452 . "LATIN CAPITAL LETTER DZ WITH CARON")
(453 . "LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON")
(454 . "LATIN SMALL LETTER DZ WITH CARON")
(455 . "LATIN CAPITAL LETTER LJ")
(456 . "LATIN CAPITAL LETTER L WITH SMALL LETTER J")
(457 . "LATIN SMALL LETTER LJ")
(458 . "LATIN CAPITAL LETTER NJ")
(459 . "LATIN CAPITAL LETTER N WITH SMALL LETTER J")
(460 . "LATIN SMALL LETTER NJ")
(461 . "LATIN CAPITAL LETTER A WITH CARON")
(462 . "LATIN SMALL LETTER A WITH CARON")
(463 . "LATIN CAPITAL LETTER I WITH CARON")
(464 . "LATIN SMALL LETTER I WITH CARON")
(465 . "LATIN CAPITAL LETTER O WITH CARON")
(466 . "LATIN SMALL LETTER O WITH CARON")
(467 . "LATIN CAPITAL LETTER U WITH CARON")
(468 . "LATIN SMALL LETTER U WITH CARON")
(469 . "LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON")
(470 . "LATIN SMALL LETTER U WITH DIAERESIS AND MACRON")
(471 . "LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE")
(472 . "LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE")
(473 . "LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON")
(474 . "LATIN SMALL LETTER U WITH DIAERESIS AND CARON")
(475 . "LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE")
(476 . "LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE")
(477 . "LATIN SMALL LETTER TURNED E")
(478 . "LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON")
(479 . "LATIN SMALL LETTER A WITH DIAERESIS AND MACRON")
(480 . "LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON")
(481 . "LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON")
(482 . "LATIN CAPITAL LETTER AE WITH MACRON")
(483 . "LATIN SMALL LETTER AE WITH MACRON")
(484 . "LATIN CAPITAL LETTER G WITH STROKE")
(485 . "LATIN SMALL LETTER G WITH STROKE")
(486 . "LATIN CAPITAL LETTER G WITH CARON")
(487 . "LATIN SMALL LETTER G WITH CARON")
(488 . "LATIN CAPITAL LETTER K WITH CARON")
(489 . "LATIN SMALL LETTER K WITH CARON")
(490 . "LATIN CAPITAL LETTER O WITH OGONEK")
(491 . "LATIN SMALL LETTER O WITH OGONEK")
(492 . "LATIN CAPITAL LETTER O WITH OGONEK AND MACRON")
(493 . "LATIN SMALL LETTER O WITH OGONEK AND MACRON")
(494 . "LATIN CAPITAL LETTER EZH WITH CARON")
(495 . "LATIN SMALL LETTER EZH WITH CARON")
(496 . "LATIN SMALL LETTER J WITH CARON")
(497 . "LATIN CAPITAL LETTER DZ")
(498 . "LATIN CAPITAL LETTER D WITH SMALL LETTER Z")
(499 . "LATIN SMALL LETTER DZ")
(500 . "LATIN CAPITAL LETTER G WITH ACUTE")
(501 . "LATIN SMALL LETTER G WITH ACUTE")
(502 . "LATIN CAPITAL LETTER HWAIR")
(503 . "LATIN CAPITAL LETTER WYNN")
(504 . "LATIN CAPITAL LETTER N WITH GRAVE")
(505 . "LATIN SMALL LETTER N WITH GRAVE")
(506 . "LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE")
(507 . "LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE")
(508 . "LATIN CAPITAL LETTER AE WITH ACUTE")
(509 . "LATIN SMALL LETTER AE WITH ACUTE")
(510 . "LATIN CAPITAL LETTER O WITH STROKE AND ACUTE")
(511 . "LATIN SMALL LETTER O WITH STROKE AND ACUTE")
(512 . "LATIN CAPITAL LETTER A WITH DOUBLE GRAVE")
(513 . "LATIN SMALL LETTER A WITH DOUBLE GRAVE")
(514 . "LATIN CAPITAL LETTER A WITH INVERTED BREVE")
(515 . "LATIN SMALL LETTER A WITH INVERTED BREVE")
(516 . "LATIN CAPITAL LETTER E WITH DOUBLE GRAVE")
(517 . "LATIN SMALL LETTER E WITH DOUBLE GRAVE")
(518 . "LATIN CAPITAL LETTER E WITH INVERTED BREVE")
(519 . "LATIN SMALL LETTER E WITH INVERTED BREVE")
(520 . "LATIN CAPITAL LETTER I WITH DOUBLE GRAVE")
(521 . "LATIN SMALL LETTER I WITH DOUBLE GRAVE")
(522 . "LATIN CAPITAL LETTER I WITH INVERTED BREVE")
(523 . "LATIN SMALL LETTER I WITH INVERTED BREVE")
(524 . "LATIN CAPITAL LETTER O WITH DOUBLE GRAVE")
(525 . "LATIN SMALL LETTER O WITH DOUBLE GRAVE")
(526 . "LATIN CAPITAL LETTER O WITH INVERTED BREVE")
(527 . "LATIN SMALL LETTER O WITH INVERTED BREVE")
(528 . "LATIN CAPITAL LETTER R WITH DOUBLE GRAVE")
(529 . "LATIN SMALL LETTER R WITH DOUBLE GRAVE")
(530 . "LATIN CAPITAL LETTER R WITH INVERTED BREVE")
(531 . "LATIN SMALL LETTER R WITH INVERTED BREVE")
(532 . "LATIN CAPITAL LETTER U WITH DOUBLE GRAVE")
(533 . "LATIN SMALL LETTER U WITH DOUBLE GRAVE")
(534 . "LATIN CAPITAL LETTER U WITH INVERTED BREVE")
(535 . "LATIN SMALL LETTER U WITH INVERTED BREVE")
(536 . "LATIN CAPITAL LETTER S WITH COMMA BELOW")
(537 . "LATIN SMALL LETTER S WITH COMMA BELOW")
(538 . "LATIN CAPITAL LETTER T WITH COMMA BELOW")
(539 . "LATIN SMALL LETTER T WITH COMMA BELOW")
(540 . "LATIN CAPITAL LETTER YOGH")
(541 . "LATIN SMALL LETTER YOGH")
(542 . "LATIN CAPITAL LETTER H WITH CARON")
(543 . "LATIN SMALL LETTER H WITH CARON")
(544 . "LATIN CAPITAL LETTER N WITH LONG RIGHT LEG")
(545 . "LATIN SMALL LETTER D WITH CURL")
(546 . "LATIN CAPITAL LETTER OU")
(547 . "LATIN SMALL LETTER OU")
(548 . "LATIN CAPITAL LETTER Z WITH HOOK")
(549 . "LATIN SMALL LETTER Z WITH HOOK")
(550 . "LATIN CAPITAL LETTER A WITH DOT ABOVE")
(551 . "LATIN SMALL LETTER A WITH DOT ABOVE")
(552 . "LATIN CAPITAL LETTER E WITH CEDILLA")
(553 . "LATIN SMALL LETTER E WITH CEDILLA")
(554 . "LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON")
(555 . "LATIN SMALL LETTER O WITH DIAERESIS AND MACRON")
(556 . "LATIN CAPITAL LETTER O WITH TILDE AND MACRON")
(557 . "LATIN SMALL LETTER O WITH TILDE AND MACRON")
(558 . "LATIN CAPITAL LETTER O WITH DOT ABOVE")
(559 . "LATIN SMALL LETTER O WITH DOT ABOVE")
(560 . "LATIN CAPITAL LETTER O WITH DOT ABOVE AND MACRON")
(561 . "LATIN SMALL LETTER O WITH DOT ABOVE AND MACRON")
(562 . "LATIN CAPITAL LETTER Y WITH MACRON")
(563 . "LATIN SMALL LETTER Y WITH MACRON")
(564 . "LATIN SMALL LETTER L WITH CURL")
(565 . "LATIN SMALL LETTER N WITH CURL")
(566 . "LATIN SMALL LETTER T WITH CURL")
(567 . "LATIN SMALL LETTER DOTLESS J")
(568 . "LATIN SMALL LETTER DB DIGRAPH")
(569 . "LATIN SMALL LETTER QP DIGRAPH")
(570 . "LATIN CAPITAL LETTER A WITH STROKE")
(571 . "LATIN CAPITAL LETTER C WITH STROKE")
(572 . "LATIN SMALL LETTER C WITH STROKE")
(573 . "LATIN CAPITAL LETTER L WITH BAR")
(574 . "LATIN CAPITAL LETTER T WITH DIAGONAL STROKE")
(575 . "LATIN SMALL LETTER S WITH SWASH TAIL")
(576 . "LATIN SMALL LETTER Z WITH SWASH TAIL")
(577 . "LATIN CAPITAL LETTER GLOTTAL STOP")
(578 . "LATIN SMALL LETTER GLOTTAL STOP")
(579 . "LATIN CAPITAL LETTER B WITH STROKE")
(580 . "LATIN CAPITAL LETTER U BAR")
(581 . "LATIN CAPITAL LETTER TURNED V")
(582 . "LATIN CAPITAL LETTER E WITH STROKE")
(583 . "LATIN SMALL LETTER E WITH STROKE")
(584 . "LATIN CAPITAL LETTER J WITH STROKE")
(585 . "LATIN SMALL LETTER J WITH STROKE")
(586 . "LATIN CAPITAL LETTER SMALL Q WITH HOOK TAIL")
(587 . "LATIN SMALL LETTER Q WITH HOOK TAIL")
(588 . "LATIN CAPITAL LETTER R WITH STROKE")
(589 . "LATIN SMALL LETTER R WITH STROKE")
(590 . "LATIN CAPITAL LETTER Y WITH STROKE")
(591 . "LATIN SMALL LETTER Y WITH STROKE")
(592 . "LATIN SMALL LETTER TURNED A")
(593 . "LATIN SMALL LETTER ALPHA")
(594 . "LATIN SMALL LETTER TURNED ALPHA")
(595 . "LATIN SMALL LETTER B WITH HOOK")
(596 . "LATIN SMALL LETTER OPEN O")
(597 . "LATIN SMALL LETTER C WITH CURL")
(598 . "LATIN SMALL LETTER D WITH TAIL")
(599 . "LATIN SMALL LETTER D WITH HOOK")
(600 . "LATIN SMALL LETTER REVERSED E")
(601 . "LATIN SMALL LETTER SCHWA")
(602 . "LATIN SMALL LETTER SCHWA WITH HOOK")
(603 . "LATIN SMALL LETTER OPEN E")
(604 . "LATIN SMALL LETTER REVERSED OPEN E")
(605 . "LATIN SMALL LETTER REVERSED OPEN E WITH HOOK")
(606 . "LATIN SMALL LETTER CLOSED REVERSED OPEN E")
(607 . "LATIN SMALL LETTER DOTLESS J WITH STROKE")
(608 . "LATIN SMALL LETTER G WITH HOOK")
(609 . "LATIN SMALL LETTER SCRIPT G")
(610 . "LATIN LETTER SMALL CAPITAL G")
(611 . "LATIN SMALL LETTER GAMMA")
(612 . "LATIN SMALL LETTER RAMS HORN")
(613 . "LATIN SMALL LETTER TURNED H")
(614 . "LATIN SMALL LETTER H WITH HOOK")
(615 . "LATIN SMALL LETTER HENG WITH HOOK")
(616 . "LATIN SMALL LETTER I WITH STROKE")
(617 . "LATIN SMALL LETTER IOTA")
(618 . "LATIN LETTER SMALL CAPITAL I")
(619 . "LATIN SMALL LETTER L WITH MIDDLE TILDE")
(620 . "LATIN SMALL LETTER L WITH BELT")
(621 . "LATIN SMALL LETTER L WITH RETROFLEX HOOK")
(622 . "LATIN SMALL LETTER LEZH")
(623 . "LATIN SMALL LETTER TURNED M")
(624 . "LATIN SMALL LETTER TURNED M WITH LONG LEG")
(625 . "LATIN SMALL LETTER M WITH HOOK")
(626 . "LATIN SMALL LETTER N WITH LEFT HOOK")
(627 . "LATIN SMALL LETTER N WITH RETROFLEX HOOK")
(628 . "LATIN LETTER SMALL CAPITAL N")
(629 . "LATIN SMALL LETTER BARRED O")
(630 . "LATIN LETTER SMALL CAPITAL OE")
(631 . "LATIN SMALL LETTER CLOSED OMEGA")
(632 . "LATIN SMALL LETTER PHI")
(633 . "LATIN SMALL LETTER TURNED R")
(634 . "LATIN SMALL LETTER TURNED R WITH LONG LEG")
(635 . "LATIN SMALL LETTER TURNED R WITH HOOK")
(636 . "LATIN SMALL LETTER R WITH LONG LEG")
(637 . "LATIN SMALL LETTER R WITH TAIL")
(638 . "LATIN SMALL LETTER R WITH FISHHOOK")
(639 . "LATIN SMALL LETTER REVERSED R WITH FISHHOOK")
(640 . "LATIN LETTER SMALL CAPITAL R")
(641 . "LATIN LETTER SMALL CAPITAL INVERTED R")
(642 . "LATIN SMALL LETTER S WITH HOOK")
(643 . "LATIN SMALL LETTER ESH")
(644 . "LATIN SMALL LETTER DOTLESS J WITH STROKE AND HOOK")
(645 . "LATIN SMALL LETTER SQUAT REVERSED ESH")
(646 . "LATIN SMALL LETTER ESH WITH CURL")
(647 . "LATIN SMALL LETTER TURNED T")
(648 . "LATIN SMALL LETTER T WITH RETROFLEX HOOK")
(649 . "LATIN SMALL LETTER U BAR")
(650 . "LATIN SMALL LETTER UPSILON")
(651 . "LATIN SMALL LETTER V WITH HOOK")
(652 . "LATIN SMALL LETTER TURNED V")
(653 . "LATIN SMALL LETTER TURNED W")
(654 . "LATIN SMALL LETTER TURNED Y")
(655 . "LATIN LETTER SMALL CAPITAL Y")
(656 . "LATIN SMALL LETTER Z WITH RETROFLEX HOOK")
(657 . "LATIN SMALL LETTER Z WITH CURL")
(658 . "LATIN SMALL LETTER EZH")
(659 . "LATIN SMALL LETTER EZH WITH CURL")
(660 . "LATIN LETTER GLOTTAL STOP")
(661 . "LATIN LETTER PHARYNGEAL VOICED FRICATIVE")
(662 . "LATIN LETTER INVERTED GLOTTAL STOP")
(663 . "LATIN LETTER STRETCHED C")
(664 . "LATIN LETTER BILABIAL CLICK")
(665 . "LATIN LETTER SMALL CAPITAL B")
(666 . "LATIN SMALL LETTER CLOSED OPEN E")
(667 . "LATIN LETTER SMALL CAPITAL G WITH HOOK")
(668 . "LATIN LETTER SMALL CAPITAL H")
(669 . "LATIN SMALL LETTER J WITH CROSSED-TAIL")
(670 . "LATIN SMALL LETTER TURNED K")
(671 . "LATIN LETTER SMALL CAPITAL L")
(672 . "LATIN SMALL LETTER Q WITH HOOK")
(673 . "LATIN LETTER GLOTTAL STOP WITH STROKE")
(674 . "LATIN LETTER REVERSED GLOTTAL STOP WITH STROKE")
(675 . "LATIN SMALL LETTER DZ DIGRAPH")
(676 . "LATIN SMALL LETTER DEZH DIGRAPH")
(677 . "LATIN SMALL LETTER DZ DIGRAPH WITH CURL")
(678 . "LATIN SMALL LETTER TS DIGRAPH")
(679 . "LATIN SMALL LETTER TESH DIGRAPH")
(680 . "LATIN SMALL LETTER TC DIGRAPH WITH CURL")
(681 . "LATIN SMALL LETTER FENG DIGRAPH")
(682 . "LATIN SMALL LETTER LS DIGRAPH")
(683 . "LATIN SMALL LETTER LZ DIGRAPH")
(684 . "LATIN LETTER BILABIAL PERCUSSIVE")
(685 . "LATIN LETTER BIDENTAL PERCUSSIVE")
(686 . "LATIN SMALL LETTER TURNED H WITH FISHHOOK")
(687 . "LATIN SMALL LETTER TURNED H WITH FISHHOOK AND TAIL")
(688 . "MODIFIER LETTER SMALL H")
(689 . "MODIFIER LETTER SMALL H WITH HOOK")
(690 . "MODIFIER LETTER SMALL J")
(691 . "MODIFIER LETTER SMALL R")
(692 . "MODIFIER LETTER SMALL TURNED R")
(693 . "MODIFIER LETTER SMALL TURNED R WITH HOOK")
(694 . "MODIFIER LETTER SMALL CAPITAL INVERTED R")
(695 . "MODIFIER LETTER SMALL W")
(696 . "MODIFIER LETTER SMALL Y")
(697 . "MODIFIER LETTER PRIME")
(698 . "MODIFIER LETTER DOUBLE PRIME")
(699 . "MODIFIER LETTER TURNED COMMA")
(700 . "MODIFIER LETTER APOSTROPHE")
(701 . "MODIFIER LETTER REVERSED COMMA")
(702 . "MODIFIER LETTER RIGHT HALF RING")
(703 . "MODIFIER LETTER LEFT HALF RING")
(704 . "MODIFIER LETTER GLOTTAL STOP")
(705 . "MODIFIER LETTER REVERSED GLOTTAL STOP")
(706 . "MODIFIER LETTER LEFT ARROWHEAD")
(707 . "MODIFIER LETTER RIGHT ARROWHEAD")
(708 . "MODIFIER LETTER UP ARROWHEAD")
(709 . "MODIFIER LETTER DOWN ARROWHEAD")
(710 . "MODIFIER LETTER CIRCUMFLEX ACCENT")
(711 . "CARON")
(712 . "MODIFIER LETTER VERTICAL LINE")
(713 . "MODIFIER LETTER MACRON")
(714 . "MODIFIER LETTER ACUTE ACCENT")
(715 . "MODIFIER LETTER GRAVE ACCENT")
(716 . "MODIFIER LETTER LOW VERTICAL LINE")
(717 . "MODIFIER LETTER LOW MACRON")
(718 . "MODIFIER LETTER LOW GRAVE ACCENT")
(719 . "MODIFIER LETTER LOW ACUTE ACCENT")
(720 . "MODIFIER LETTER TRIANGULAR COLON")
(721 . "MODIFIER LETTER HALF TRIANGULAR COLON")
(722 . "MODIFIER LETTER CENTRED RIGHT HALF RING")
(723 . "MODIFIER LETTER CENTRED LEFT HALF RING")
(724 . "MODIFIER LETTER UP TACK")
(725 . "MODIFIER LETTER DOWN TACK")
(726 . "MODIFIER LETTER PLUS SIGN")
(727 . "MODIFIER LETTER MINUS SIGN")
(728 . "BREVE")
(729 . "DOT ABOVE")
(730 . "RING ABOVE")
(731 . "OGONEK")
(732 . "SMALL TILDE")
(733 . "DOUBLE ACUTE ACCENT")
(734 . "MODIFIER LETTER RHOTIC HOOK")
(735 . "MODIFIER LETTER CROSS ACCENT")
(736 . "MODIFIER LETTER SMALL GAMMA")
(737 . "MODIFIER LETTER SMALL L")
(738 . "MODIFIER LETTER SMALL S")
(739 . "MODIFIER LETTER SMALL X")
(740 . "MODIFIER LETTER SMALL REVERSED GLOTTAL STOP")
(741 . "MODIFIER LETTER EXTRA-HIGH TONE BAR")
(742 . "MODIFIER LETTER HIGH TONE BAR")
(743 . "MODIFIER LETTER MID TONE BAR")
(744 . "MODIFIER LETTER LOW TONE BAR")
(745 . "MODIFIER LETTER EXTRA-LOW TONE BAR")
(746 . "MODIFIER LETTER YIN DEPARTING TONE MARK")
(747 . "MODIFIER LETTER YANG DEPARTING TONE MARK")
(748 . "MODIFIER LETTER VOICING")
(749 . "MODIFIER LETTER UNASPIRATED")
(750 . "MODIFIER LETTER DOUBLE APOSTROPHE")
(751 . "MODIFIER LETTER LOW DOWN ARROWHEAD")
(752 . "MODIFIER LETTER LOW UP ARROWHEAD")
(753 . "MODIFIER LETTER LOW LEFT ARROWHEAD")
(754 . "MODIFIER LETTER LOW RIGHT ARROWHEAD")
(755 . "MODIFIER LETTER LOW RING")
(756 . "MODIFIER LETTER MIDDLE GRAVE ACCENT")
(757 . "MODIFIER LETTER MIDDLE DOUBLE GRAVE ACCENT")
(758 . "MODIFIER LETTER MIDDLE DOUBLE ACUTE ACCENT")
(759 . "MODIFIER LETTER LOW TILDE")
(760 . "MODIFIER LETTER RAISED COLON")
(761 . "MODIFIER LETTER BEGIN HIGH TONE")
(762 . "MODIFIER LETTER END HIGH TONE")
(763 . "MODIFIER LETTER BEGIN LOW TONE")
(764 . "MODIFIER LETTER END LOW TONE")
(765 . "MODIFIER LETTER SHELF")
(766 . "MODIFIER LETTER OPEN SHELF")
(767 . "MODIFIER LETTER LOW LEFT ARROW")
(768 . "COMBINING GRAVE ACCENT")
(769 . "COMBINING ACUTE ACCENT")
(770 . "COMBINING CIRCUMFLEX ACCENT")
(771 . "COMBINING TILDE")
(772 . "COMBINING MACRON")
(773 . "COMBINING OVERLINE")
(774 . "COMBINING BREVE")
(775 . "COMBINING DOT ABOVE")
(776 . "COMBINING DIAERESIS")
(777 . "COMBINING HOOK ABOVE")
(778 . "COMBINING RING ABOVE")
(779 . "COMBINING DOUBLE ACUTE ACCENT")
(780 . "COMBINING CARON")
(781 . "COMBINING VERTICAL LINE ABOVE")
(782 . "COMBINING DOUBLE VERTICAL LINE ABOVE")
(783 . "COMBINING DOUBLE GRAVE ACCENT")
(784 . "COMBINING CANDRABINDU")
(785 . "COMBINING INVERTED BREVE")
(786 . "COMBINING TURNED COMMA ABOVE")
(787 . "COMBINING COMMA ABOVE")
(788 . "COMBINING REVERSED COMMA ABOVE")
(789 . "COMBINING COMMA ABOVE RIGHT")
(790 . "COMBINING GRAVE ACCENT BELOW")
(791 . "COMBINING ACUTE ACCENT BELOW")
(792 . "COMBINING LEFT TACK BELOW")
(793 . "COMBINING RIGHT TACK BELOW")
(794 . "COMBINING LEFT ANGLE ABOVE")
(795 . "COMBINING HORN")
(796 . "COMBINING LEFT HALF RING BELOW")
(797 . "COMBINING UP TACK BELOW")
(798 . "COMBINING DOWN TACK BELOW")
(799 . "COMBINING PLUS SIGN BELOW")
(800 . "COMBINING MINUS SIGN BELOW")
(801 . "COMBINING PALATALIZED HOOK BELOW")
(802 . "COMBINING RETROFLEX HOOK BELOW")
(803 . "COMBINING DOT BELOW")
(804 . "COMBINING DIAERESIS BELOW")
(805 . "COMBINING RING BELOW")
(806 . "COMBINING COMMA BELOW")
(807 . "COMBINING CEDILLA")
(808 . "COMBINING OGONEK")
(809 . "COMBINING VERTICAL LINE BELOW")
(810 . "COMBINING BRIDGE BELOW")
(811 . "COMBINING INVERTED DOUBLE ARCH BELOW")
(812 . "COMBINING CARON BELOW")
(813 . "COMBINING CIRCUMFLEX ACCENT BELOW")
(814 . "COMBINING BREVE BELOW")
(815 . "COMBINING INVERTED BREVE BELOW")
(816 . "COMBINING TILDE BELOW")
(817 . "COMBINING MACRON BELOW")
(818 . "COMBINING LOW LINE")
(819 . "COMBINING DOUBLE LOW LINE")
(820 . "COMBINING TILDE OVERLAY")
(821 . "COMBINING SHORT STROKE OVERLAY")
(822 . "COMBINING LONG STROKE OVERLAY")
(823 . "COMBINING SHORT SOLIDUS OVERLAY")
(824 . "COMBINING LONG SOLIDUS OVERLAY")
(825 . "COMBINING RIGHT HALF RING BELOW")
(826 . "COMBINING INVERTED BRIDGE BELOW")
(827 . "COMBINING SQUARE BELOW")
(828 . "COMBINING SEAGULL BELOW")
(829 . "COMBINING X ABOVE")
(830 . "COMBINING VERTICAL TILDE")
(831 . "COMBINING DOUBLE OVERLINE")
(832 . "COMBINING GRAVE TONE MARK")
(833 . "COMBINING ACUTE TONE MARK")
(834 . "COMBINING GREEK PERISPOMENI")
(835 . "COMBINING GREEK KORONIS")
(836 . "COMBINING GREEK DIALYTIKA TONOS")
(837 . "COMBINING GREEK YPOGEGRAMMENI")
(838 . "COMBINING BRIDGE ABOVE")
(839 . "COMBINING EQUALS SIGN BELOW")
(840 . "COMBINING DOUBLE VERTICAL LINE BELOW")
(841 . "COMBINING LEFT ANGLE BELOW")
(842 . "COMBINING NOT TILDE ABOVE")
(843 . "COMBINING HOMOTHETIC ABOVE")
(844 . "COMBINING ALMOST EQUAL TO ABOVE")
(845 . "COMBINING LEFT RIGHT ARROW BELOW")
(846 . "COMBINING UPWARDS ARROW BELOW")
(847 . "COMBINING GRAPHEME JOINER")
(848 . "COMBINING RIGHT ARROWHEAD ABOVE")
(849 . "COMBINING LEFT HALF RING ABOVE")
(850 . "COMBINING FERMATA")
(851 . "COMBINING X BELOW")
(852 . "COMBINING LEFT ARROWHEAD BELOW")
(853 . "COMBINING RIGHT ARROWHEAD BELOW")
(854 . "COMBINING RIGHT ARROWHEAD AND UP ARROWHEAD BELOW")
(855 . "COMBINING RIGHT HALF RING ABOVE")
(856 . "COMBINING DOT ABOVE RIGHT")
(857 . "COMBINING ASTERISK BELOW")
(858 . "COMBINING DOUBLE RING BELOW")
(859 . "COMBINING ZIGZAG ABOVE")
(860 . "COMBINING DOUBLE BREVE BELOW")
(861 . "COMBINING DOUBLE BREVE")
(862 . "COMBINING DOUBLE MACRON")
(863 . "COMBINING DOUBLE MACRON BELOW")
(864 . "COMBINING DOUBLE TILDE")
(865 . "COMBINING DOUBLE INVERTED BREVE")
(866 . "COMBINING DOUBLE RIGHTWARDS ARROW BELOW")
(867 . "COMBINING LATIN SMALL LETTER A")
(868 . "COMBINING LATIN SMALL LETTER E")
(869 . "COMBINING LATIN SMALL LETTER I")
(870 . "COMBINING LATIN SMALL LETTER O")
(871 . "COMBINING LATIN SMALL LETTER U")
(872 . "COMBINING LATIN SMALL LETTER C")
(873 . "COMBINING LATIN SMALL LETTER D")
(874 . "COMBINING LATIN SMALL LETTER H")
(875 . "COMBINING LATIN SMALL LETTER M")
(876 . "COMBINING LATIN SMALL LETTER R")
(877 . "COMBINING LATIN SMALL LETTER T")
(878 . "COMBINING LATIN SMALL LETTER V")
(879 . "COMBINING LATIN SMALL LETTER X")
(880 . "GREEK CAPITAL LETTER HETA")
(881 . "GREEK SMALL LETTER HETA")
(882 . "GREEK CAPITAL LETTER ARCHAIC SAMPI")
(883 . "GREEK SMALL LETTER ARCHAIC SAMPI")
(884 . "GREEK NUMERAL SIGN")
(885 . "GREEK LOWER NUMERAL SIGN")
(886 . "GREEK CAPITAL LETTER PAMPHYLIAN DIGAMMA")
(887 . "GREEK SMALL LETTER PAMPHYLIAN DIGAMMA")
((888 . 890) . #f)
(890 . "GREEK YPOGEGRAMMENI")
(891 . "GREEK SMALL REVERSED LUNATE SIGMA SYMBOL")
(892 . "GREEK SMALL DOTTED LUNATE SIGMA SYMBOL")
(893 . "GREEK SMALL REVERSED DOTTED LUNATE SIGMA SYMBOL")
(894 . "GREEK QUESTION MARK")
(895 . "GREEK CAPITAL LETTER YOT")
((896 . 900) . #f)
(900 . "GREEK TONOS")
(901 . "GREEK DIALYTIKA TONOS")
(902 . "GREEK CAPITAL LETTER ALPHA WITH TONOS")
(903 . "GREEK ANO TELEIA")
(904 . "GREEK CAPITAL LETTER EPSILON WITH TONOS")
(905 . "GREEK CAPITAL LETTER ETA WITH TONOS")
(906 . "GREEK CAPITAL LETTER IOTA WITH TONOS")
(907 . #f)
(908 . "GREEK CAPITAL LETTER OMICRON WITH TONOS")
(909 . #f)
(910 . "GREEK CAPITAL LETTER UPSILON WITH TONOS")
(911 . "GREEK CAPITAL LETTER OMEGA WITH TONOS")
(912 . "GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS")
(913 . "GREEK CAPITAL LETTER ALPHA")
(914 . "GREEK CAPITAL LETTER BETA")
(915 . "GREEK CAPITAL LETTER GAMMA")
(916 . "GREEK CAPITAL LETTER DELTA")
(917 . "GREEK CAPITAL LETTER EPSILON")
(918 . "GREEK CAPITAL LETTER ZETA")
(919 . "GREEK CAPITAL LETTER ETA")
(920 . "GREEK CAPITAL LETTER THETA")
(921 . "GREEK CAPITAL LETTER IOTA")
(922 . "GREEK CAPITAL LETTER KAPPA")
(923 . "GREEK CAPITAL LETTER LAMDA")
(924 . "GREEK CAPITAL LETTER MU")
(925 . "GREEK CAPITAL LETTER NU")
(926 . "GREEK CAPITAL LETTER XI")
(927 . "GREEK CAPITAL LETTER OMICRON")
(928 . "GREEK CAPITAL LETTER PI")
(929 . "GREEK CAPITAL LETTER RHO")
(930 . #f)
(931 . "GREEK CAPITAL LETTER SIGMA")
(932 . "GREEK CAPITAL LETTER TAU")
(933 . "GREEK CAPITAL LETTER UPSILON")
(934 . "GREEK CAPITAL LETTER PHI")
(935 . "GREEK CAPITAL LETTER CHI")
(936 . "GREEK CAPITAL LETTER PSI")
(937 . "GREEK CAPITAL LETTER OMEGA")
(938 . "GREEK CAPITAL LETTER IOTA WITH DIALYTIKA")
(939 . "GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA")
(940 . "GREEK SMALL LETTER ALPHA WITH TONOS")
(941 . "GREEK SMALL LETTER EPSILON WITH TONOS")
(942 . "GREEK SMALL LETTER ETA WITH TONOS")
(943 . "GREEK SMALL LETTER IOTA WITH TONOS")
(944 . "GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS")
(945 . "GREEK SMALL LETTER ALPHA")
(946 . "GREEK SMALL LETTER BETA")
(947 . "GREEK SMALL LETTER GAMMA")
(948 . "GREEK SMALL LETTER DELTA")
(949 . "GREEK SMALL LETTER EPSILON")
(950 . "GREEK SMALL LETTER ZETA")
(951 . "GREEK SMALL LETTER ETA")
(952 . "GREEK SMALL LETTER THETA")
(953 . "GREEK SMALL LETTER IOTA")
(954 . "GREEK SMALL LETTER KAPPA")
(955 . "GREEK SMALL LETTER LAMDA")
(956 . "GREEK SMALL LETTER MU")
(957 . "GREEK SMALL LETTER NU")
(958 . "GREEK SMALL LETTER XI")
(959 . "GREEK SMALL LETTER OMICRON")
(960 . "GREEK SMALL LETTER PI")
(961 . "GREEK SMALL LETTER RHO")
(962 . "GREEK SMALL LETTER FINAL SIGMA")
(963 . "GREEK SMALL LETTER SIGMA")
(964 . "GREEK SMALL LETTER TAU")
(965 . "GREEK SMALL LETTER UPSILON")
(966 . "GREEK SMALL LETTER PHI")
(967 . "GREEK SMALL LETTER CHI")
(968 . "GREEK SMALL LETTER PSI")
(969 . "GREEK SMALL LETTER OMEGA")
(970 . "GREEK SMALL LETTER IOTA WITH DIALYTIKA")
(971 . "GREEK SMALL LETTER UPSILON WITH DIALYTIKA")
(972 . "GREEK SMALL LETTER OMICRON WITH TONOS")
(973 . "GREEK SMALL LETTER UPSILON WITH TONOS")
(974 . "GREEK SMALL LETTER OMEGA WITH TONOS")
(975 . "GREEK CAPITAL KAI SYMBOL")
(976 . "GREEK BETA SYMBOL")
(977 . "GREEK THETA SYMBOL")
(978 . "GREEK UPSILON WITH HOOK SYMBOL")
(979 . "GREEK UPSILON WITH ACUTE AND HOOK SYMBOL")
(980 . "GREEK UPSILON WITH DIAERESIS AND HOOK SYMBOL")
(981 . "GREEK PHI SYMBOL")
(982 . "GREEK PI SYMBOL")
(983 . "GREEK KAI SYMBOL")
(984 . "GREEK LETTER ARCHAIC KOPPA")
(985 . "GREEK SMALL LETTER ARCHAIC KOPPA")
(986 . "GREEK LETTER STIGMA")
(987 . "GREEK SMALL LETTER STIGMA")
(988 . "GREEK LETTER DIGAMMA")
(989 . "GREEK SMALL LETTER DIGAMMA")
(990 . "GREEK LETTER KOPPA")
(991 . "GREEK SMALL LETTER KOPPA")
(992 . "GREEK LETTER SAMPI")
(993 . "GREEK SMALL LETTER SAMPI")
(994 . "COPTIC CAPITAL LETTER SHEI")
(995 . "COPTIC SMALL LETTER SHEI")
(996 . "COPTIC CAPITAL LETTER FEI")
(997 . "COPTIC SMALL LETTER FEI")
(998 . "COPTIC CAPITAL LETTER KHEI")
(999 . "COPTIC SMALL LETTER KHEI")
(1000 . "COPTIC CAPITAL LETTER HORI")
(1001 . "COPTIC SMALL LETTER HORI")
(1002 . "COPTIC CAPITAL LETTER GANGIA")
(1003 . "COPTIC SMALL LETTER GANGIA")
(1004 . "COPTIC CAPITAL LETTER SHIMA")
(1005 . "COPTIC SMALL LETTER SHIMA")
(1006 . "COPTIC CAPITAL LETTER DEI")
(1007 . "COPTIC SMALL LETTER DEI")
(1008 . "GREEK KAPPA SYMBOL")
(1009 . "GREEK RHO SYMBOL")
(1010 . "GREEK LUNATE SIGMA SYMBOL")
(1011 . "GREEK LETTER YOT")
(1012 . "GREEK CAPITAL THETA SYMBOL")
(1013 . "GREEK LUNATE EPSILON SYMBOL")
(1014 . "GREEK REVERSED LUNATE EPSILON SYMBOL")
(1015 . "GREEK CAPITAL LETTER SHO")
(1016 . "GREEK SMALL LETTER SHO")
(1017 . "GREEK CAPITAL LUNATE SIGMA SYMBOL")
(1018 . "GREEK CAPITAL LETTER SAN")
(1019 . "GREEK SMALL LETTER SAN")
(1020 . "GREEK RHO WITH STROKE SYMBOL")
(1021 . "GREEK CAPITAL REVERSED LUNATE SIGMA SYMBOL")
(1022 . "GREEK CAPITAL DOTTED LUNATE SIGMA SYMBOL")
(1023 . "GREEK CAPITAL REVERSED DOTTED LUNATE SIGMA SYMBOL")
(1024 . "CYRILLIC CAPITAL LETTER IE WITH GRAVE")
(1025 . "CYRILLIC CAPITAL LETTER IO")
(1026 . "CYRILLIC CAPITAL LETTER DJE")
(1027 . "CYRILLIC CAPITAL LETTER GJE")
(1028 . "CYRILLIC CAPITAL LETTER UKRAINIAN IE")
(1029 . "CYRILLIC CAPITAL LETTER DZE")
(1030 . "CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I")
(1031 . "CYRILLIC CAPITAL LETTER YI")
(1032 . "CYRILLIC CAPITAL LETTER JE")
(1033 . "CYRILLIC CAPITAL LETTER LJE")
(1034 . "CYRILLIC CAPITAL LETTER NJE")
(1035 . "CYRILLIC CAPITAL LETTER TSHE")
(1036 . "CYRILLIC CAPITAL LETTER KJE")
(1037 . "CYRILLIC CAPITAL LETTER I WITH GRAVE")
(1038 . "CYRILLIC CAPITAL LETTER SHORT U")
(1039 . "CYRILLIC CAPITAL LETTER DZHE")
(1040 . "CYRILLIC CAPITAL LETTER A")
(1041 . "CYRILLIC CAPITAL LETTER BE")
(1042 . "CYRILLIC CAPITAL LETTER VE")
(1043 . "CYRILLIC CAPITAL LETTER GHE")
(1044 . "CYRILLIC CAPITAL LETTER DE")
(1045 . "CYRILLIC CAPITAL LETTER IE")
(1046 . "CYRILLIC CAPITAL LETTER ZHE")
(1047 . "CYRILLIC CAPITAL LETTER ZE")
(1048 . "CYRILLIC CAPITAL LETTER I")
(1049 . "CYRILLIC CAPITAL LETTER SHORT I")
(1050 . "CYRILLIC CAPITAL LETTER KA")
(1051 . "CYRILLIC CAPITAL LETTER EL")
(1052 . "CYRILLIC CAPITAL LETTER EM")
(1053 . "CYRILLIC CAPITAL LETTER EN")
(1054 . "CYRILLIC CAPITAL LETTER O")
(1055 . "CYRILLIC CAPITAL LETTER PE")
(1056 . "CYRILLIC CAPITAL LETTER ER")
(1057 . "CYRILLIC CAPITAL LETTER ES")
(1058 . "CYRILLIC CAPITAL LETTER TE")
(1059 . "CYRILLIC CAPITAL LETTER U")
(1060 . "CYRILLIC CAPITAL LETTER EF")
(1061 . "CYRILLIC CAPITAL LETTER HA")
(1062 . "CYRILLIC CAPITAL LETTER TSE")
(1063 . "CYRILLIC CAPITAL LETTER CHE")
(1064 . "CYRILLIC CAPITAL LETTER SHA")
(1065 . "CYRILLIC CAPITAL LETTER SHCHA")
(1066 . "CYRILLIC CAPITAL LETTER HARD SIGN")
(1067 . "CYRILLIC CAPITAL LETTER YERU")
(1068 . "CYRILLIC CAPITAL LETTER SOFT SIGN")
(1069 . "CYRILLIC CAPITAL LETTER E")
(1070 . "CYRILLIC CAPITAL LETTER YU")
(1071 . "CYRILLIC CAPITAL LETTER YA")
(1072 . "CYRILLIC SMALL LETTER A")
(1073 . "CYRILLIC SMALL LETTER BE")
(1074 . "CYRILLIC SMALL LETTER VE")
(1075 . "CYRILLIC SMALL LETTER GHE")
(1076 . "CYRILLIC SMALL LETTER DE")
(1077 . "CYRILLIC SMALL LETTER IE")
(1078 . "CYRILLIC SMALL LETTER ZHE")
(1079 . "CYRILLIC SMALL LETTER ZE")
(1080 . "CYRILLIC SMALL LETTER I")
(1081 . "CYRILLIC SMALL LETTER SHORT I")
(1082 . "CYRILLIC SMALL LETTER KA")
(1083 . "CYRILLIC SMALL LETTER EL")
(1084 . "CYRILLIC SMALL LETTER EM")
(1085 . "CYRILLIC SMALL LETTER EN")
(1086 . "CYRILLIC SMALL LETTER O")
(1087 . "CYRILLIC SMALL LETTER PE")
(1088 . "CYRILLIC SMALL LETTER ER")
(1089 . "CYRILLIC SMALL LETTER ES")
(1090 . "CYRILLIC SMALL LETTER TE")
(1091 . "CYRILLIC SMALL LETTER U")
(1092 . "CYRILLIC SMALL LETTER EF")
(1093 . "CYRILLIC SMALL LETTER HA")
(1094 . "CYRILLIC SMALL LETTER TSE")
(1095 . "CYRILLIC SMALL LETTER CHE")
(1096 . "CYRILLIC SMALL LETTER SHA")
(1097 . "CYRILLIC SMALL LETTER SHCHA")
(1098 . "CYRILLIC SMALL LETTER HARD SIGN")
(1099 . "CYRILLIC SMALL LETTER YERU")
(1100 . "CYRILLIC SMALL LETTER SOFT SIGN")
(1101 . "CYRILLIC SMALL LETTER E")
(1102 . "CYRILLIC SMALL LETTER YU")
(1103 . "CYRILLIC SMALL LETTER YA")
(1104 . "CYRILLIC SMALL LETTER IE WITH GRAVE")
(1105 . "CYRILLIC SMALL LETTER IO")
(1106 . "CYRILLIC SMALL LETTER DJE")
(1107 . "CYRILLIC SMALL LETTER GJE")
(1108 . "CYRILLIC SMALL LETTER UKRAINIAN IE")
(1109 . "CYRILLIC SMALL LETTER DZE")
(1110 . "CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I")
(1111 . "CYRILLIC SMALL LETTER YI")
(1112 . "CYRILLIC SMALL LETTER JE")
(1113 . "CYRILLIC SMALL LETTER LJE")
(1114 . "CYRILLIC SMALL LETTER NJE")
(1115 . "CYRILLIC SMALL LETTER TSHE")
(1116 . "CYRILLIC SMALL LETTER KJE")
(1117 . "CYRILLIC SMALL LETTER I WITH GRAVE")
(1118 . "CYRILLIC SMALL LETTER SHORT U")
(1119 . "CYRILLIC SMALL LETTER DZHE")
(1120 . "CYRILLIC CAPITAL LETTER OMEGA")
(1121 . "CYRILLIC SMALL LETTER OMEGA")
(1122 . "CYRILLIC CAPITAL LETTER YAT")
(1123 . "CYRILLIC SMALL LETTER YAT")
(1124 . "CYRILLIC CAPITAL LETTER IOTIFIED E")
(1125 . "CYRILLIC SMALL LETTER IOTIFIED E")
(1126 . "CYRILLIC CAPITAL LETTER LITTLE YUS")
(1127 . "CYRILLIC SMALL LETTER LITTLE YUS")
(1128 . "CYRILLIC CAPITAL LETTER IOTIFIED LITTLE YUS")
(1129 . "CYRILLIC SMALL LETTER IOTIFIED LITTLE YUS")
(1130 . "CYRILLIC CAPITAL LETTER BIG YUS")
(1131 . "CYRILLIC SMALL LETTER BIG YUS")
(1132 . "CYRILLIC CAPITAL LETTER IOTIFIED BIG YUS")
(1133 . "CYRILLIC SMALL LETTER IOTIFIED BIG YUS")
(1134 . "CYRILLIC CAPITAL LETTER KSI")
(1135 . "CYRILLIC SMALL LETTER KSI")
(1136 . "CYRILLIC CAPITAL LETTER PSI")
(1137 . "CYRILLIC SMALL LETTER PSI")
(1138 . "CYRILLIC CAPITAL LETTER FITA")
(1139 . "CYRILLIC SMALL LETTER FITA")
(1140 . "CYRILLIC CAPITAL LETTER IZHITSA")
(1141 . "CYRILLIC SMALL LETTER IZHITSA")
(1142 . "CYRILLIC CAPITAL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT")
(1143 . "CYRILLIC SMALL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT")
(1144 . "CYRILLIC CAPITAL LETTER UK")
(1145 . "CYRILLIC SMALL LETTER UK")
(1146 . "CYRILLIC CAPITAL LETTER ROUND OMEGA")
(1147 . "CYRILLIC SMALL LETTER ROUND OMEGA")
(1148 . "CYRILLIC CAPITAL LETTER OMEGA WITH TITLO")
(1149 . "CYRILLIC SMALL LETTER OMEGA WITH TITLO")
(1150 . "CYRILLIC CAPITAL LETTER OT")
(1151 . "CYRILLIC SMALL LETTER OT")
(1152 . "CYRILLIC CAPITAL LETTER KOPPA")
(1153 . "CYRILLIC SMALL LETTER KOPPA")
(1154 . "CYRILLIC THOUSANDS SIGN")
(1155 . "COMBINING CYRILLIC TITLO")
(1156 . "COMBINING CYRILLIC PALATALIZATION")
(1157 . "COMBINING CYRILLIC DASIA PNEUMATA")
(1158 . "COMBINING CYRILLIC PSILI PNEUMATA")
(1159 . "COMBINING CYRILLIC POKRYTIE")
(1160 . "COMBINING CYRILLIC HUNDRED THOUSANDS SIGN")
(1161 . "COMBINING CYRILLIC MILLIONS SIGN")
(1162 . "CYRILLIC CAPITAL LETTER SHORT I WITH TAIL")
(1163 . "CYRILLIC SMALL LETTER SHORT I WITH TAIL")
(1164 . "CYRILLIC CAPITAL LETTER SEMISOFT SIGN")
(1165 . "CYRILLIC SMALL LETTER SEMISOFT SIGN")
(1166 . "CYRILLIC CAPITAL LETTER ER WITH TICK")
(1167 . "CYRILLIC SMALL LETTER ER WITH TICK")
(1168 . "CYRILLIC CAPITAL LETTER GHE WITH UPTURN")
(1169 . "CYRILLIC SMALL LETTER GHE WITH UPTURN")
(1170 . "CYRILLIC CAPITAL LETTER GHE WITH STROKE")
(1171 . "CYRILLIC SMALL LETTER GHE WITH STROKE")
(1172 . "CYRILLIC CAPITAL LETTER GHE WITH MIDDLE HOOK")
(1173 . "CYRILLIC SMALL LETTER GHE WITH MIDDLE HOOK")
(1174 . "CYRILLIC CAPITAL LETTER ZHE WITH DESCENDER")
(1175 . "CYRILLIC SMALL LETTER ZHE WITH DESCENDER")
(1176 . "CYRILLIC CAPITAL LETTER ZE WITH DESCENDER")
(1177 . "CYRILLIC SMALL LETTER ZE WITH DESCENDER")
(1178 . "CYRILLIC CAPITAL LETTER KA WITH DESCENDER")
(1179 . "CYRILLIC SMALL LETTER KA WITH DESCENDER")
(1180 . "CYRILLIC CAPITAL LETTER KA WITH VERTICAL STROKE")
(1181 . "CYRILLIC SMALL LETTER KA WITH VERTICAL STROKE")
(1182 . "CYRILLIC CAPITAL LETTER KA WITH STROKE")
(1183 . "CYRILLIC SMALL LETTER KA WITH STROKE")
(1184 . "CYRILLIC CAPITAL LETTER BASHKIR KA")
(1185 . "CYRILLIC SMALL LETTER BASHKIR KA")
(1186 . "CYRILLIC CAPITAL LETTER EN WITH DESCENDER")
(1187 . "CYRILLIC SMALL LETTER EN WITH DESCENDER")
(1188 . "CYRILLIC CAPITAL LIGATURE EN GHE")
(1189 . "CYRILLIC SMALL LIGATURE EN GHE")
(1190 . "CYRILLIC CAPITAL LETTER PE WITH MIDDLE HOOK")
(1191 . "CYRILLIC SMALL LETTER PE WITH MIDDLE HOOK")
(1192 . "CYRILLIC CAPITAL LETTER ABKHASIAN HA")
(1193 . "CYRILLIC SMALL LETTER ABKHASIAN HA")
(1194 . "CYRILLIC CAPITAL LETTER ES WITH DESCENDER")
(1195 . "CYRILLIC SMALL LETTER ES WITH DESCENDER")
(1196 . "CYRILLIC CAPITAL LETTER TE WITH DESCENDER")
(1197 . "CYRILLIC SMALL LETTER TE WITH DESCENDER")
(1198 . "CYRILLIC CAPITAL LETTER STRAIGHT U")
(1199 . "CYRILLIC SMALL LETTER STRAIGHT U")
(1200 . "CYRILLIC CAPITAL LETTER STRAIGHT U WITH STROKE")
(1201 . "CYRILLIC SMALL LETTER STRAIGHT U WITH STROKE")
(1202 . "CYRILLIC CAPITAL LETTER HA WITH DESCENDER")
(1203 . "CYRILLIC SMALL LETTER HA WITH DESCENDER")
(1204 . "CYRILLIC CAPITAL LIGATURE TE TSE")
(1205 . "CYRILLIC SMALL LIGATURE TE TSE")
(1206 . "CYRILLIC CAPITAL LETTER CHE WITH DESCENDER")
(1207 . "CYRILLIC SMALL LETTER CHE WITH DESCENDER")
(1208 . "CYRILLIC CAPITAL LETTER CHE WITH VERTICAL STROKE")
(1209 . "CYRILLIC SMALL LETTER CHE WITH VERTICAL STROKE")
(1210 . "CYRILLIC CAPITAL LETTER SHHA")
(1211 . "CYRILLIC SMALL LETTER SHHA")
(1212 . "CYRILLIC CAPITAL LETTER ABKHASIAN CHE")
(1213 . "CYRILLIC SMALL LETTER ABKHASIAN CHE")
(1214 . "CYRILLIC CAPITAL LETTER ABKHASIAN CHE WITH DESCENDER")
(1215 . "CYRILLIC SMALL LETTER ABKHASIAN CHE WITH DESCENDER")
(1216 . "CYRILLIC LETTER PALOCHKA")
(1217 . "CYRILLIC CAPITAL LETTER ZHE WITH BREVE")
(1218 . "CYRILLIC SMALL LETTER ZHE WITH BREVE")
(1219 . "CYRILLIC CAPITAL LETTER KA WITH HOOK")
(1220 . "CYRILLIC SMALL LETTER KA WITH HOOK")
(1221 . "CYRILLIC CAPITAL LETTER EL WITH TAIL")
(1222 . "CYRILLIC SMALL LETTER EL WITH TAIL")
(1223 . "CYRILLIC CAPITAL LETTER EN WITH HOOK")
(1224 . "CYRILLIC SMALL LETTER EN WITH HOOK")
(1225 . "CYRILLIC CAPITAL LETTER EN WITH TAIL")
(1226 . "CYRILLIC SMALL LETTER EN WITH TAIL")
(1227 . "CYRILLIC CAPITAL LETTER KHAKASSIAN CHE")
(1228 . "CYRILLIC SMALL LETTER KHAKASSIAN CHE")
(1229 . "CYRILLIC CAPITAL LETTER EM WITH TAIL")
(1230 . "CYRILLIC SMALL LETTER EM WITH TAIL")
(1231 . "CYRILLIC SMALL LETTER PALOCHKA")
(1232 . "CYRILLIC CAPITAL LETTER A WITH BREVE")
(1233 . "CYRILLIC SMALL LETTER A WITH BREVE")
(1234 . "CYRILLIC CAPITAL LETTER A WITH DIAERESIS")
(1235 . "CYRILLIC SMALL LETTER A WITH DIAERESIS")
(1236 . "CYRILLIC CAPITAL LIGATURE A IE")
(1237 . "CYRILLIC SMALL LIGATURE A IE")
(1238 . "CYRILLIC CAPITAL LETTER IE WITH BREVE")
(1239 . "CYRILLIC SMALL LETTER IE WITH BREVE")
(1240 . "CYRILLIC CAPITAL LETTER SCHWA")
(1241 . "CYRILLIC SMALL LETTER SCHWA")
(1242 . "CYRILLIC CAPITAL LETTER SCHWA WITH DIAERESIS")
(1243 . "CYRILLIC SMALL LETTER SCHWA WITH DIAERESIS")
(1244 . "CYRILLIC CAPITAL LETTER ZHE WITH DIAERESIS")
(1245 . "CYRILLIC SMALL LETTER ZHE WITH DIAERESIS")
(1246 . "CYRILLIC CAPITAL LETTER ZE WITH DIAERESIS")
(1247 . "CYRILLIC SMALL LETTER ZE WITH DIAERESIS")
(1248 . "CYRILLIC CAPITAL LETTER ABKHASIAN DZE")
(1249 . "CYRILLIC SMALL LETTER ABKHASIAN DZE")
(1250 . "CYRILLIC CAPITAL LETTER I WITH MACRON")
(1251 . "CYRILLIC SMALL LETTER I WITH MACRON")
(1252 . "CYRILLIC CAPITAL LETTER I WITH DIAERESIS")
(1253 . "CYRILLIC SMALL LETTER I WITH DIAERESIS")
(1254 . "CYRILLIC CAPITAL LETTER O WITH DIAERESIS")
(1255 . "CYRILLIC SMALL LETTER O WITH DIAERESIS")
(1256 . "CYRILLIC CAPITAL LETTER BARRED O")
(1257 . "CYRILLIC SMALL LETTER BARRED O")
(1258 . "CYRILLIC CAPITAL LETTER BARRED O WITH DIAERESIS")
(1259 . "CYRILLIC SMALL LETTER BARRED O WITH DIAERESIS")
(1260 . "CYRILLIC CAPITAL LETTER E WITH DIAERESIS")
(1261 . "CYRILLIC SMALL LETTER E WITH DIAERESIS")
(1262 . "CYRILLIC CAPITAL LETTER U WITH MACRON")
(1263 . "CYRILLIC SMALL LETTER U WITH MACRON")
(1264 . "CYRILLIC CAPITAL LETTER U WITH DIAERESIS")
(1265 . "CYRILLIC SMALL LETTER U WITH DIAERESIS")
(1266 . "CYRILLIC CAPITAL LETTER U WITH DOUBLE ACUTE")
(1267 . "CYRILLIC SMALL LETTER U WITH DOUBLE ACUTE")
(1268 . "CYRILLIC CAPITAL LETTER CHE WITH DIAERESIS")
(1269 . "CYRILLIC SMALL LETTER CHE WITH DIAERESIS")
(1270 . "CYRILLIC CAPITAL LETTER GHE WITH DESCENDER")
(1271 . "CYRILLIC SMALL LETTER GHE WITH DESCENDER")
(1272 . "CYRILLIC CAPITAL LETTER YERU WITH DIAERESIS")
(1273 . "CYRILLIC SMALL LETTER YERU WITH DIAERESIS")
(1274 . "CYRILLIC CAPITAL LETTER GHE WITH STROKE AND HOOK")
(1275 . "CYRILLIC SMALL LETTER GHE WITH STROKE AND HOOK")
(1276 . "CYRILLIC CAPITAL LETTER HA WITH HOOK")
(1277 . "CYRILLIC SMALL LETTER HA WITH HOOK")
(1278 . "CYRILLIC CAPITAL LETTER HA WITH STROKE")
(1279 . "CYRILLIC SMALL LETTER HA WITH STROKE")
(1280 . "CYRILLIC CAPITAL LETTER KOMI DE")
(1281 . "CYRILLIC SMALL LETTER KOMI DE")
(1282 . "CYRILLIC CAPITAL LETTER KOMI DJE")
(1283 . "CYRILLIC SMALL LETTER KOMI DJE")
(1284 . "CYRILLIC CAPITAL LETTER KOMI ZJE")
(1285 . "CYRILLIC SMALL LETTER KOMI ZJE")
(1286 . "CYRILLIC CAPITAL LETTER KOMI DZJE")
(1287 . "CYRILLIC SMALL LETTER KOMI DZJE")
(1288 . "CYRILLIC CAPITAL LETTER KOMI LJE")
(1289 . "CYRILLIC SMALL LETTER KOMI LJE")
(1290 . "CYRILLIC CAPITAL LETTER KOMI NJE")
(1291 . "CYRILLIC SMALL LETTER KOMI NJE")
(1292 . "CYRILLIC CAPITAL LETTER KOMI SJE")
(1293 . "CYRILLIC SMALL LETTER KOMI SJE")
(1294 . "CYRILLIC CAPITAL LETTER KOMI TJE")
(1295 . "CYRILLIC SMALL LETTER KOMI TJE")
(1296 . "CYRILLIC CAPITAL LETTER REVERSED ZE")
(1297 . "CYRILLIC SMALL LETTER REVERSED ZE")
(1298 . "CYRILLIC CAPITAL LETTER EL WITH HOOK")
(1299 . "CYRILLIC SMALL LETTER EL WITH HOOK")
(1300 . "CYRILLIC CAPITAL LETTER LHA")
(1301 . "CYRILLIC SMALL LETTER LHA")
(1302 . "CYRILLIC CAPITAL LETTER RHA")
(1303 . "CYRILLIC SMALL LETTER RHA")
(1304 . "CYRILLIC CAPITAL LETTER YAE")
(1305 . "CYRILLIC SMALL LETTER YAE")
(1306 . "CYRILLIC CAPITAL LETTER QA")
(1307 . "CYRILLIC SMALL LETTER QA")
(1308 . "CYRILLIC CAPITAL LETTER WE")
(1309 . "CYRILLIC SMALL LETTER WE")
(1310 . "CYRILLIC CAPITAL LETTER ALEUT KA")
(1311 . "CYRILLIC SMALL LETTER ALEUT KA")
(1312 . "CYRILLIC CAPITAL LETTER EL WITH MIDDLE HOOK")
(1313 . "CYRILLIC SMALL LETTER EL WITH MIDDLE HOOK")
(1314 . "CYRILLIC CAPITAL LETTER EN WITH MIDDLE HOOK")
(1315 . "CYRILLIC SMALL LETTER EN WITH MIDDLE HOOK")
(1316 . "CYRILLIC CAPITAL LETTER PE WITH DESCENDER")
(1317 . "CYRILLIC SMALL LETTER PE WITH DESCENDER")
(1318 . "CYRILLIC CAPITAL LETTER SHHA WITH DESCENDER")
(1319 . "CYRILLIC SMALL LETTER SHHA WITH DESCENDER")
(1320 . "CYRILLIC CAPITAL LETTER EN WITH LEFT HOOK")
(1321 . "CYRILLIC SMALL LETTER EN WITH LEFT HOOK")
(1322 . "CYRILLIC CAPITAL LETTER DZZHE")
(1323 . "CYRILLIC SMALL LETTER DZZHE")
(1324 . "CYRILLIC CAPITAL LETTER DCHE")
(1325 . "CYRILLIC SMALL LETTER DCHE")
(1326 . "CYRILLIC CAPITAL LETTER EL WITH DESCENDER")
(1327 . "CYRILLIC SMALL LETTER EL WITH DESCENDER")
(1328 . #f)
(1329 . "ARMENIAN CAPITAL LETTER AYB")
(1330 . "ARMENIAN CAPITAL LETTER BEN")
(1331 . "ARMENIAN CAPITAL LETTER GIM")
(1332 . "ARMENIAN CAPITAL LETTER DA")
(1333 . "ARMENIAN CAPITAL LETTER ECH")
(1334 . "ARMENIAN CAPITAL LETTER ZA")
(1335 . "ARMENIAN CAPITAL LETTER EH")
(1336 . "ARMENIAN CAPITAL LETTER ET")
(1337 . "ARMENIAN CAPITAL LETTER TO")
(1338 . "ARMENIAN CAPITAL LETTER ZHE")
(1339 . "ARMENIAN CAPITAL LETTER INI")
(1340 . "ARMENIAN CAPITAL LETTER LIWN")
(1341 . "ARMENIAN CAPITAL LETTER XEH")
(1342 . "ARMENIAN CAPITAL LETTER CA")
(1343 . "ARMENIAN CAPITAL LETTER KEN")
(1344 . "ARMENIAN CAPITAL LETTER HO")
(1345 . "ARMENIAN CAPITAL LETTER JA")
(1346 . "ARMENIAN CAPITAL LETTER GHAD")
(1347 . "ARMENIAN CAPITAL LETTER CHEH")
(1348 . "ARMENIAN CAPITAL LETTER MEN")
(1349 . "ARMENIAN CAPITAL LETTER YI")
(1350 . "ARMENIAN CAPITAL LETTER NOW")
(1351 . "ARMENIAN CAPITAL LETTER SHA")
(1352 . "ARMENIAN CAPITAL LETTER VO")
(1353 . "ARMENIAN CAPITAL LETTER CHA")
(1354 . "ARMENIAN CAPITAL LETTER PEH")
(1355 . "ARMENIAN CAPITAL LETTER JHEH")
(1356 . "ARMENIAN CAPITAL LETTER RA")
(1357 . "ARMENIAN CAPITAL LETTER SEH")
(1358 . "ARMENIAN CAPITAL LETTER VEW")
(1359 . "ARMENIAN CAPITAL LETTER TIWN")
(1360 . "ARMENIAN CAPITAL LETTER REH")
(1361 . "ARMENIAN CAPITAL LETTER CO")
(1362 . "ARMENIAN CAPITAL LETTER YIWN")
(1363 . "ARMENIAN CAPITAL LETTER PIWR")
(1364 . "ARMENIAN CAPITAL LETTER KEH")
(1365 . "ARMENIAN CAPITAL LETTER OH")
(1366 . "ARMENIAN CAPITAL LETTER FEH")
((1367 . 1369) . #f)
(1369 . "ARMENIAN MODIFIER LETTER LEFT HALF RING")
(1370 . "ARMENIAN APOSTROPHE")
(1371 . "ARMENIAN EMPHASIS MARK")
(1372 . "ARMENIAN EXCLAMATION MARK")
(1373 . "ARMENIAN COMMA")
(1374 . "ARMENIAN QUESTION MARK")
(1375 . "ARMENIAN ABBREVIATION MARK")
(1376 . #f)
(1377 . "ARMENIAN SMALL LETTER AYB")
(1378 . "ARMENIAN SMALL LETTER BEN")
(1379 . "ARMENIAN SMALL LETTER GIM")
(1380 . "ARMENIAN SMALL LETTER DA")
(1381 . "ARMENIAN SMALL LETTER ECH")
(1382 . "ARMENIAN SMALL LETTER ZA")
(1383 . "ARMENIAN SMALL LETTER EH")
(1384 . "ARMENIAN SMALL LETTER ET")
(1385 . "ARMENIAN SMALL LETTER TO")
(1386 . "ARMENIAN SMALL LETTER ZHE")
(1387 . "ARMENIAN SMALL LETTER INI")
(1388 . "ARMENIAN SMALL LETTER LIWN")
(1389 . "ARMENIAN SMALL LETTER XEH")
(1390 . "ARMENIAN SMALL LETTER CA")
(1391 . "ARMENIAN SMALL LETTER KEN")
(1392 . "ARMENIAN SMALL LETTER HO")
(1393 . "ARMENIAN SMALL LETTER JA")
(1394 . "ARMENIAN SMALL LETTER GHAD")
(1395 . "ARMENIAN SMALL LETTER CHEH")
(1396 . "ARMENIAN SMALL LETTER MEN")
(1397 . "ARMENIAN SMALL LETTER YI")
(1398 . "ARMENIAN SMALL LETTER NOW")
(1399 . "ARMENIAN SMALL LETTER SHA")
(1400 . "ARMENIAN SMALL LETTER VO")
(1401 . "ARMENIAN SMALL LETTER CHA")
(1402 . "ARMENIAN SMALL LETTER PEH")
(1403 . "ARMENIAN SMALL LETTER JHEH")
(1404 . "ARMENIAN SMALL LETTER RA")
(1405 . "ARMENIAN SMALL LETTER SEH")
(1406 . "ARMENIAN SMALL LETTER VEW")
(1407 . "ARMENIAN SMALL LETTER TIWN")
(1408 . "ARMENIAN SMALL LETTER REH")
(1409 . "ARMENIAN SMALL LETTER CO")
(1410 . "ARMENIAN SMALL LETTER YIWN")
(1411 . "ARMENIAN SMALL LETTER PIWR")
(1412 . "ARMENIAN SMALL LETTER KEH")
(1413 . "ARMENIAN SMALL LETTER OH")
(1414 . "ARMENIAN SMALL LETTER FEH")
(1415 . "ARMENIAN SMALL LIGATURE ECH YIWN")
(1416 . #f)
(1417 . "ARMENIAN FULL STOP")
(1418 . "ARMENIAN HYPHEN")
((1419 . 1421) . #f)
(1421 . "RIGHT-FACING ARMENIAN ETERNITY SIGN")
(1422 . "LEFT-FACING ARMENIAN ETERNITY SIGN")
(1423 . "ARMENIAN DRAM SIGN")
(1424 . #f)
(1425 . "HEBREW ACCENT ETNAHTA")
(1426 . "HEBREW ACCENT SEGOL")
(1427 . "HEBREW ACCENT SHALSHELET")
(1428 . "HEBREW ACCENT ZAQEF QATAN")
(1429 . "HEBREW ACCENT ZAQEF GADOL")
(1430 . "HEBREW ACCENT TIPEHA")
(1431 . "HEBREW ACCENT REVIA")
(1432 . "HEBREW ACCENT ZARQA")
(1433 . "HEBREW ACCENT PASHTA")
(1434 . "HEBREW ACCENT YETIV")
(1435 . "HEBREW ACCENT TEVIR")
(1436 . "HEBREW ACCENT GERESH")
(1437 . "HEBREW ACCENT GERESH MUQDAM")
(1438 . "HEBREW ACCENT GERSHAYIM")
(1439 . "HEBREW ACCENT QARNEY PARA")
(1440 . "HEBREW ACCENT TELISHA GEDOLA")
(1441 . "HEBREW ACCENT PAZER")
(1442 . "HEBREW ACCENT ATNAH HAFUKH")
(1443 . "HEBREW ACCENT MUNAH")
(1444 . "HEBREW ACCENT MAHAPAKH")
(1445 . "HEBREW ACCENT MERKHA")
(1446 . "HEBREW ACCENT MERKHA KEFULA")
(1447 . "HEBREW ACCENT DARGA")
(1448 . "HEBREW ACCENT QADMA")
(1449 . "HEBREW ACCENT TELISHA QETANA")
(1450 . "HEBREW ACCENT YERAH BEN YOMO")
(1451 . "HEBREW ACCENT OLE")
(1452 . "HEBREW ACCENT ILUY")
(1453 . "HEBREW ACCENT DEHI")
(1454 . "HEBREW ACCENT ZINOR")
(1455 . "HEBREW MARK MASORA CIRCLE")
(1456 . "HEBREW POINT SHEVA")
(1457 . "HEBREW POINT HATAF SEGOL")
(1458 . "HEBREW POINT HATAF PATAH")
(1459 . "HEBREW POINT HATAF QAMATS")
(1460 . "HEBREW POINT HIRIQ")
(1461 . "HEBREW POINT TSERE")
(1462 . "HEBREW POINT SEGOL")
(1463 . "HEBREW POINT PATAH")
(1464 . "HEBREW POINT QAMATS")
(1465 . "HEBREW POINT HOLAM")
(1466 . "HEBREW POINT HOLAM HASER FOR VAV")
(1467 . "HEBREW POINT QUBUTS")
(1468 . "HEBREW POINT DAGESH OR MAPIQ")
(1469 . "HEBREW POINT METEG")
(1470 . "HEBREW PUNCTUATION MAQAF")
(1471 . "HEBREW POINT RAFE")
(1472 . "HEBREW PUNCTUATION PASEQ")
(1473 . "HEBREW POINT SHIN DOT")
(1474 . "HEBREW POINT SIN DOT")
(1475 . "HEBREW PUNCTUATION SOF PASUQ")
(1476 . "HEBREW MARK UPPER DOT")
(1477 . "HEBREW MARK LOWER DOT")
(1478 . "HEBREW PUNCTUATION NUN HAFUKHA")
(1479 . "HEBREW POINT QAMATS QATAN")
((1480 . 1488) . #f)
(1488 . "HEBREW LETTER ALEF")
(1489 . "HEBREW LETTER BET")
(1490 . "HEBREW LETTER GIMEL")
(1491 . "HEBREW LETTER DALET")
(1492 . "HEBREW LETTER HE")
(1493 . "HEBREW LETTER VAV")
(1494 . "HEBREW LETTER ZAYIN")
(1495 . "HEBREW LETTER HET")
(1496 . "HEBREW LETTER TET")
(1497 . "HEBREW LETTER YOD")
(1498 . "HEBREW LETTER FINAL KAF")
(1499 . "HEBREW LETTER KAF")
(1500 . "HEBREW LETTER LAMED")
(1501 . "HEBREW LETTER FINAL MEM")
(1502 . "HEBREW LETTER MEM")
(1503 . "HEBREW LETTER FINAL NUN")
(1504 . "HEBREW LETTER NUN")
(1505 . "HEBREW LETTER SAMEKH")
(1506 . "HEBREW LETTER AYIN")
(1507 . "HEBREW LETTER FINAL PE")
(1508 . "HEBREW LETTER PE")
(1509 . "HEBREW LETTER FINAL TSADI")
(1510 . "HEBREW LETTER TSADI")
(1511 . "HEBREW LETTER QOF")
(1512 . "HEBREW LETTER RESH")
(1513 . "HEBREW LETTER SHIN")
(1514 . "HEBREW LETTER TAV")
((1515 . 1520) . #f)
(1520 . "HEBREW LIGATURE YIDDISH DOUBLE VAV")
(1521 . "HEBREW LIGATURE YIDDISH VAV YOD")
(1522 . "HEBREW LIGATURE YIDDISH DOUBLE YOD")
(1523 . "HEBREW PUNCTUATION GERESH")
(1524 . "HEBREW PUNCTUATION GERSHAYIM")
((1525 . 1536) . #f)
(1536 . "ARABIC NUMBER SIGN")
(1537 . "ARABIC SIGN SANAH")
(1538 . "ARABIC FOOTNOTE MARKER")
(1539 . "ARABIC SIGN SAFHA")
(1540 . "ARABIC SIGN SAMVAT")
(1541 . "ARABIC NUMBER MARK ABOVE")
(1542 . "ARABIC-INDIC CUBE ROOT")
(1543 . "ARABIC-INDIC FOURTH ROOT")
(1544 . "ARABIC RAY")
(1545 . "ARABIC-INDIC PER MILLE SIGN")
(1546 . "ARABIC-INDIC PER TEN THOUSAND SIGN")
(1547 . "AFGHANI SIGN")
(1548 . "ARABIC COMMA")
(1549 . "ARABIC DATE SEPARATOR")
(1550 . "ARABIC POETIC VERSE SIGN")
(1551 . "ARABIC SIGN MISRA")
(1552 . "ARABIC SIGN SALLALLAHOU ALAYHE WASSALLAM")
(1553 . "ARABIC SIGN ALAYHE ASSALLAM")
(1554 . "ARABIC SIGN RAHMATULLAH ALAYHE")
(1555 . "ARABIC SIGN RADI ALLAHOU ANHU")
(1556 . "ARABIC SIGN TAKHALLUS")
(1557 . "ARABIC SMALL HIGH TAH")
(1558 . "ARABIC SMALL HIGH LIGATURE ALEF WITH LAM WITH YEH")
(1559 . "ARABIC SMALL HIGH ZAIN")
(1560 . "ARABIC SMALL FATHA")
(1561 . "ARABIC SMALL DAMMA")
(1562 . "ARABIC SMALL KASRA")
(1563 . "ARABIC SEMICOLON")
(1564 . "ARABIC LETTER MARK")
(1565 . #f)
(1566 . "ARABIC TRIPLE DOT PUNCTUATION MARK")
(1567 . "ARABIC QUESTION MARK")
(1568 . "ARABIC LETTER KASHMIRI YEH")
(1569 . "ARABIC LETTER HAMZA")
(1570 . "ARABIC LETTER ALEF WITH MADDA ABOVE")
(1571 . "ARABIC LETTER ALEF WITH HAMZA ABOVE")
(1572 . "ARABIC LETTER WAW WITH HAMZA ABOVE")
(1573 . "ARABIC LETTER ALEF WITH HAMZA BELOW")
(1574 . "ARABIC LETTER YEH WITH HAMZA ABOVE")
(1575 . "ARABIC LETTER ALEF")
(1576 . "ARABIC LETTER BEH")
(1577 . "ARABIC LETTER TEH MARBUTA")
(1578 . "ARABIC LETTER TEH")
(1579 . "ARABIC LETTER THEH")
(1580 . "ARABIC LETTER JEEM")
(1581 . "ARABIC LETTER HAH")
(1582 . "ARABIC LETTER KHAH")
(1583 . "ARABIC LETTER DAL")
(1584 . "ARABIC LETTER THAL")
(1585 . "ARABIC LETTER REH")
(1586 . "ARABIC LETTER ZAIN")
(1587 . "ARABIC LETTER SEEN")
(1588 . "ARABIC LETTER SHEEN")
(1589 . "ARABIC LETTER SAD")
(1590 . "ARABIC LETTER DAD")
(1591 . "ARABIC LETTER TAH")
(1592 . "ARABIC LETTER ZAH")
(1593 . "ARABIC LETTER AIN")
(1594 . "ARABIC LETTER GHAIN")
(1595 . "ARABIC LETTER KEHEH WITH TWO DOTS ABOVE")
(1596 . "ARABIC LETTER KEHEH WITH THREE DOTS BELOW")
(1597 . "ARABIC LETTER FARSI YEH WITH INVERTED V")
(1598 . "ARABIC LETTER FARSI YEH WITH TWO DOTS ABOVE")
(1599 . "ARABIC LETTER FARSI YEH WITH THREE DOTS ABOVE")
(1600 . "ARABIC TATWEEL")
(1601 . "ARABIC LETTER FEH")
(1602 . "ARABIC LETTER QAF")
(1603 . "ARABIC LETTER KAF")
(1604 . "ARABIC LETTER LAM")
(1605 . "ARABIC LETTER MEEM")
(1606 . "ARABIC LETTER NOON")
(1607 . "ARABIC LETTER HEH")
(1608 . "ARABIC LETTER WAW")
(1609 . "ARABIC LETTER ALEF MAKSURA")
(1610 . "ARABIC LETTER YEH")
(1611 . "ARABIC FATHATAN")
(1612 . "ARABIC DAMMATAN")
(1613 . "ARABIC KASRATAN")
(1614 . "ARABIC FATHA")
(1615 . "ARABIC DAMMA")
(1616 . "ARABIC KASRA")
(1617 . "ARABIC SHADDA")
(1618 . "ARABIC SUKUN")
(1619 . "ARABIC MADDAH ABOVE")
(1620 . "ARABIC HAMZA ABOVE")
(1621 . "ARABIC HAMZA BELOW")
(1622 . "ARABIC SUBSCRIPT ALEF")
(1623 . "ARABIC INVERTED DAMMA")
(1624 . "ARABIC MARK NOON GHUNNA")
(1625 . "ARABIC ZWARAKAY")
(1626 . "ARABIC VOWEL SIGN SMALL V ABOVE")
(1627 . "ARABIC VOWEL SIGN INVERTED SMALL V ABOVE")
(1628 . "ARABIC VOWEL SIGN DOT BELOW")
(1629 . "ARABIC REVERSED DAMMA")
(1630 . "ARABIC FATHA WITH TWO DOTS")
(1631 . "ARABIC WAVY HAMZA BELOW")
(1632 . "ARABIC-INDIC DIGIT ZERO")
(1633 . "ARABIC-INDIC DIGIT ONE")
(1634 . "ARABIC-INDIC DIGIT TWO")
(1635 . "ARABIC-INDIC DIGIT THREE")
(1636 . "ARABIC-INDIC DIGIT FOUR")
(1637 . "ARABIC-INDIC DIGIT FIVE")
(1638 . "ARABIC-INDIC DIGIT SIX")
(1639 . "ARABIC-INDIC DIGIT SEVEN")
(1640 . "ARABIC-INDIC DIGIT EIGHT")
(1641 . "ARABIC-INDIC DIGIT NINE")
(1642 . "ARABIC PERCENT SIGN")
(1643 . "ARABIC DECIMAL SEPARATOR")
(1644 . "ARABIC THOUSANDS SEPARATOR")
(1645 . "ARABIC FIVE POINTED STAR")
(1646 . "ARABIC LETTER DOTLESS BEH")
(1647 . "ARABIC LETTER DOTLESS QAF")
(1648 . "ARABIC LETTER SUPERSCRIPT ALEF")
(1649 . "ARABIC LETTER ALEF WASLA")
(1650 . "ARABIC LETTER ALEF WITH WAVY HAMZA ABOVE")
(1651 . "ARABIC LETTER ALEF WITH WAVY HAMZA BELOW")
(1652 . "ARABIC LETTER HIGH HAMZA")
(1653 . "ARABIC LETTER HIGH HAMZA ALEF")
(1654 . "ARABIC LETTER HIGH HAMZA WAW")
(1655 . "ARABIC LETTER U WITH HAMZA ABOVE")
(1656 . "ARABIC LETTER HIGH HAMZA YEH")
(1657 . "ARABIC LETTER TTEH")
(1658 . "ARABIC LETTER TTEHEH")
(1659 . "ARABIC LETTER BEEH")
(1660 . "ARABIC LETTER TEH WITH RING")
(1661 . "ARABIC LETTER TEH WITH THREE DOTS ABOVE DOWNWARDS")
(1662 . "ARABIC LETTER PEH")
(1663 . "ARABIC LETTER TEHEH")
(1664 . "ARABIC LETTER BEHEH")
(1665 . "ARABIC LETTER HAH WITH HAMZA ABOVE")
(1666 . "ARABIC LETTER HAH WITH TWO DOTS VERTICAL ABOVE")
(1667 . "ARABIC LETTER NYEH")
(1668 . "ARABIC LETTER DYEH")
(1669 . "ARABIC LETTER HAH WITH THREE DOTS ABOVE")
(1670 . "ARABIC LETTER TCHEH")
(1671 . "ARABIC LETTER TCHEHEH")
(1672 . "ARABIC LETTER DDAL")
(1673 . "ARABIC LETTER DAL WITH RING")
(1674 . "ARABIC LETTER DAL WITH DOT BELOW")
(1675 . "ARABIC LETTER DAL WITH DOT BELOW AND SMALL TAH")
(1676 . "ARABIC LETTER DAHAL")
(1677 . "ARABIC LETTER DDAHAL")
(1678 . "ARABIC LETTER DUL")
(1679 . "ARABIC LETTER DAL WITH THREE DOTS ABOVE DOWNWARDS")
(1680 . "ARABIC LETTER DAL WITH FOUR DOTS ABOVE")
(1681 . "ARABIC LETTER RREH")
(1682 . "ARABIC LETTER REH WITH SMALL V")
(1683 . "ARABIC LETTER REH WITH RING")
(1684 . "ARABIC LETTER REH WITH DOT BELOW")
(1685 . "ARABIC LETTER REH WITH SMALL V BELOW")
(1686 . "ARABIC LETTER REH WITH DOT BELOW AND DOT ABOVE")
(1687 . "ARABIC LETTER REH WITH TWO DOTS ABOVE")
(1688 . "ARABIC LETTER JEH")
(1689 . "ARABIC LETTER REH WITH FOUR DOTS ABOVE")
(1690 . "ARABIC LETTER SEEN WITH DOT BELOW AND DOT ABOVE")
(1691 . "ARABIC LETTER SEEN WITH THREE DOTS BELOW")
(1692 . "ARABIC LETTER SEEN WITH THREE DOTS BELOW AND THREE DOTS ABOVE")
(1693 . "ARABIC LETTER SAD WITH TWO DOTS BELOW")
(1694 . "ARABIC LETTER SAD WITH THREE DOTS ABOVE")
(1695 . "ARABIC LETTER TAH WITH THREE DOTS ABOVE")
(1696 . "ARABIC LETTER AIN WITH THREE DOTS ABOVE")
(1697 . "ARABIC LETTER DOTLESS FEH")
(1698 . "ARABIC LETTER FEH WITH DOT MOVED BELOW")
(1699 . "ARABIC LETTER FEH WITH DOT BELOW")
(1700 . "ARABIC LETTER VEH")
(1701 . "ARABIC LETTER FEH WITH THREE DOTS BELOW")
(1702 . "ARABIC LETTER PEHEH")
(1703 . "ARABIC LETTER QAF WITH DOT ABOVE")
(1704 . "ARABIC LETTER QAF WITH THREE DOTS ABOVE")
(1705 . "ARABIC LETTER KEHEH")
(1706 . "ARABIC LETTER SWASH KAF")
(1707 . "ARABIC LETTER KAF WITH RING")
(1708 . "ARABIC LETTER KAF WITH DOT ABOVE")
(1709 . "ARABIC LETTER NG")
(1710 . "ARABIC LETTER KAF WITH THREE DOTS BELOW")
(1711 . "ARABIC LETTER GAF")
(1712 . "ARABIC LETTER GAF WITH RING")
(1713 . "ARABIC LETTER NGOEH")
(1714 . "ARABIC LETTER GAF WITH TWO DOTS BELOW")
(1715 . "ARABIC LETTER GUEH")
(1716 . "ARABIC LETTER GAF WITH THREE DOTS ABOVE")
(1717 . "ARABIC LETTER LAM WITH SMALL V")
(1718 . "ARABIC LETTER LAM WITH DOT ABOVE")
(1719 . "ARABIC LETTER LAM WITH THREE DOTS ABOVE")
(1720 . "ARABIC LETTER LAM WITH THREE DOTS BELOW")
(1721 . "ARABIC LETTER NOON WITH DOT BELOW")
(1722 . "ARABIC LETTER NOON GHUNNA")
(1723 . "ARABIC LETTER RNOON")
(1724 . "ARABIC LETTER NOON WITH RING")
(1725 . "ARABIC LETTER NOON WITH THREE DOTS ABOVE")
(1726 . "ARABIC LETTER HEH DOACHASHMEE")
(1727 . "ARABIC LETTER TCHEH WITH DOT ABOVE")
(1728 . "ARABIC LETTER HEH WITH YEH ABOVE")
(1729 . "ARABIC LETTER HEH GOAL")
(1730 . "ARABIC LETTER HEH GOAL WITH HAMZA ABOVE")
(1731 . "ARABIC LETTER TEH MARBUTA GOAL")
(1732 . "ARABIC LETTER WAW WITH RING")
(1733 . "ARABIC LETTER KIRGHIZ OE")
(1734 . "ARABIC LETTER OE")
(1735 . "ARABIC LETTER U")
(1736 . "ARABIC LETTER YU")
(1737 . "ARABIC LETTER KIRGHIZ YU")
(1738 . "ARABIC LETTER WAW WITH TWO DOTS ABOVE")
(1739 . "ARABIC LETTER VE")
(1740 . "ARABIC LETTER FARSI YEH")
(1741 . "ARABIC LETTER YEH WITH TAIL")
(1742 . "ARABIC LETTER YEH WITH SMALL V")
(1743 . "ARABIC LETTER WAW WITH DOT ABOVE")
(1744 . "ARABIC LETTER E")
(1745 . "ARABIC LETTER YEH WITH THREE DOTS BELOW")
(1746 . "ARABIC LETTER YEH BARREE")
(1747 . "ARABIC LETTER YEH BARREE WITH HAMZA ABOVE")
(1748 . "ARABIC FULL STOP")
(1749 . "ARABIC LETTER AE")
(1750 . "ARABIC SMALL HIGH LIGATURE SAD WITH LAM WITH ALEF MAKSURA")
(1751 . "ARABIC SMALL HIGH LIGATURE QAF WITH LAM WITH ALEF MAKSURA")
(1752 . "ARABIC SMALL HIGH MEEM INITIAL FORM")
(1753 . "ARABIC SMALL HIGH LAM ALEF")
(1754 . "ARABIC SMALL HIGH JEEM")
(1755 . "ARABIC SMALL HIGH THREE DOTS")
(1756 . "ARABIC SMALL HIGH SEEN")
(1757 . "ARABIC END OF AYAH")
(1758 . "ARABIC START OF RUB EL HIZB")
(1759 . "ARABIC SMALL HIGH ROUNDED ZERO")
(1760 . "ARABIC SMALL HIGH UPRIGHT RECTANGULAR ZERO")
(1761 . "ARABIC SMALL HIGH DOTLESS HEAD OF KHAH")
(1762 . "ARABIC SMALL HIGH MEEM ISOLATED FORM")
(1763 . "ARABIC SMALL LOW SEEN")
(1764 . "ARABIC SMALL HIGH MADDA")
(1765 . "ARABIC SMALL WAW")
(1766 . "ARABIC SMALL YEH")
(1767 . "ARABIC SMALL HIGH YEH")
(1768 . "ARABIC SMALL HIGH NOON")
(1769 . "ARABIC PLACE OF SAJDAH")
(1770 . "ARABIC EMPTY CENTRE LOW STOP")
(1771 . "ARABIC EMPTY CENTRE HIGH STOP")
(1772 . "ARABIC ROUNDED HIGH STOP WITH FILLED CENTRE")
(1773 . "ARABIC SMALL LOW MEEM")
(1774 . "ARABIC LETTER DAL WITH INVERTED V")
(1775 . "ARABIC LETTER REH WITH INVERTED V")
(1776 . "EXTENDED ARABIC-INDIC DIGIT ZERO")
(1777 . "EXTENDED ARABIC-INDIC DIGIT ONE")
(1778 . "EXTENDED ARABIC-INDIC DIGIT TWO")
(1779 . "EXTENDED ARABIC-INDIC DIGIT THREE")
(1780 . "EXTENDED ARABIC-INDIC DIGIT FOUR")
(1781 . "EXTENDED ARABIC-INDIC DIGIT FIVE")
(1782 . "EXTENDED ARABIC-INDIC DIGIT SIX")
(1783 . "EXTENDED ARABIC-INDIC DIGIT SEVEN")
(1784 . "EXTENDED ARABIC-INDIC DIGIT EIGHT")
(1785 . "EXTENDED ARABIC-INDIC DIGIT NINE")
(1786 . "ARABIC LETTER SHEEN WITH DOT BELOW")
(1787 . "ARABIC LETTER DAD WITH DOT BELOW")
(1788 . "ARABIC LETTER GHAIN WITH DOT BELOW")
(1789 . "ARABIC SIGN SINDHI AMPERSAND")
(1790 . "ARABIC SIGN SINDHI POSTPOSITION MEN")
(1791 . "ARABIC LETTER HEH WITH INVERTED V")
(1792 . "SYRIAC END OF PARAGRAPH")
(1793 . "SYRIAC SUPRALINEAR FULL STOP")
(1794 . "SYRIAC SUBLINEAR FULL STOP")
(1795 . "SYRIAC SUPRALINEAR COLON")
(1796 . "SYRIAC SUBLINEAR COLON")
(1797 . "SYRIAC HORIZONTAL COLON")
(1798 . "SYRIAC COLON SKEWED LEFT")
(1799 . "SYRIAC COLON SKEWED RIGHT")
(1800 . "SYRIAC SUPRALINEAR COLON SKEWED LEFT")
(1801 . "SYRIAC SUBLINEAR COLON SKEWED RIGHT")
(1802 . "SYRIAC CONTRACTION")
(1803 . "SYRIAC HARKLEAN OBELUS")
(1804 . "SYRIAC HARKLEAN METOBELUS")
(1805 . "SYRIAC HARKLEAN ASTERISCUS")
(1806 . #f)
(1807 . "SYRIAC ABBREVIATION MARK")
(1808 . "SYRIAC LETTER ALAPH")
(1809 . "SYRIAC LETTER SUPERSCRIPT ALAPH")
(1810 . "SYRIAC LETTER BETH")
(1811 . "SYRIAC LETTER GAMAL")
(1812 . "SYRIAC LETTER GAMAL GARSHUNI")
(1813 . "SYRIAC LETTER DALATH")
(1814 . "SYRIAC LETTER DOTLESS DALATH RISH")
(1815 . "SYRIAC LETTER HE")
(1816 . "SYRIAC LETTER WAW")
(1817 . "SYRIAC LETTER ZAIN")
(1818 . "SYRIAC LETTER HETH")
(1819 . "SYRIAC LETTER TETH")
(1820 . "SYRIAC LETTER TETH GARSHUNI")
(1821 . "SYRIAC LETTER YUDH")
(1822 . "SYRIAC LETTER YUDH HE")
(1823 . "SYRIAC LETTER KAPH")
(1824 . "SYRIAC LETTER LAMADH")
(1825 . "SYRIAC LETTER MIM")
(1826 . "SYRIAC LETTER NUN")
(1827 . "SYRIAC LETTER SEMKATH")
(1828 . "SYRIAC LETTER FINAL SEMKATH")
(1829 . "SYRIAC LETTER E")
(1830 . "SYRIAC LETTER PE")
(1831 . "SYRIAC LETTER REVERSED PE")
(1832 . "SYRIAC LETTER SADHE")
(1833 . "SYRIAC LETTER QAPH")
(1834 . "SYRIAC LETTER RISH")
(1835 . "SYRIAC LETTER SHIN")
(1836 . "SYRIAC LETTER TAW")
(1837 . "SYRIAC LETTER PERSIAN BHETH")
(1838 . "SYRIAC LETTER PERSIAN GHAMAL")
(1839 . "SYRIAC LETTER PERSIAN DHALATH")
(1840 . "SYRIAC PTHAHA ABOVE")
(1841 . "SYRIAC PTHAHA BELOW")
(1842 . "SYRIAC PTHAHA DOTTED")
(1843 . "SYRIAC ZQAPHA ABOVE")
(1844 . "SYRIAC ZQAPHA BELOW")
(1845 . "SYRIAC ZQAPHA DOTTED")
(1846 . "SYRIAC RBASA ABOVE")
(1847 . "SYRIAC RBASA BELOW")
(1848 . "SYRIAC DOTTED ZLAMA HORIZONTAL")
(1849 . "SYRIAC DOTTED ZLAMA ANGULAR")
(1850 . "SYRIAC HBASA ABOVE")
(1851 . "SYRIAC HBASA BELOW")
(1852 . "SYRIAC HBASA-ESASA DOTTED")
(1853 . "SYRIAC ESASA ABOVE")
(1854 . "SYRIAC ESASA BELOW")
(1855 . "SYRIAC RWAHA")
(1856 . "SYRIAC FEMININE DOT")
(1857 . "SYRIAC QUSHSHAYA")
(1858 . "SYRIAC RUKKAKHA")
(1859 . "SYRIAC TWO VERTICAL DOTS ABOVE")
(1860 . "SYRIAC TWO VERTICAL DOTS BELOW")
(1861 . "SYRIAC THREE DOTS ABOVE")
(1862 . "SYRIAC THREE DOTS BELOW")
(1863 . "SYRIAC OBLIQUE LINE ABOVE")
(1864 . "SYRIAC OBLIQUE LINE BELOW")
(1865 . "SYRIAC MUSIC")
(1866 . "SYRIAC BARREKH")
((1867 . 1869) . #f)
(1869 . "SYRIAC LETTER SOGDIAN ZHAIN")
(1870 . "SYRIAC LETTER SOGDIAN KHAPH")
(1871 . "SYRIAC LETTER SOGDIAN FE")
(1872 . "ARABIC LETTER BEH WITH THREE DOTS HORIZONTALLY BELOW")
(1873 . "ARABIC LETTER BEH WITH DOT BELOW AND THREE DOTS ABOVE")
(1874 . "ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW")
(1875 . "ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW AND TWO DOTS ABOVE")
(1876 . "ARABIC LETTER BEH WITH TWO DOTS BELOW AND DOT ABOVE")
(1877 . "ARABIC LETTER BEH WITH INVERTED SMALL V BELOW")
(1878 . "ARABIC LETTER BEH WITH SMALL V")
(1879 . "ARABIC LETTER HAH WITH TWO DOTS ABOVE")
(1880 . "ARABIC LETTER HAH WITH THREE DOTS POINTING UPWARDS BELOW")
(1881 . "ARABIC LETTER DAL WITH TWO DOTS VERTICALLY BELOW AND SMALL TAH")
(1882 . "ARABIC LETTER DAL WITH INVERTED SMALL V BELOW")
(1883 . "ARABIC LETTER REH WITH STROKE")
(1884 . "ARABIC LETTER SEEN WITH FOUR DOTS ABOVE")
(1885 . "ARABIC LETTER AIN WITH TWO DOTS ABOVE")
(1886 . "ARABIC LETTER AIN WITH THREE DOTS POINTING DOWNWARDS ABOVE")
(1887 . "ARABIC LETTER AIN WITH TWO DOTS VERTICALLY ABOVE")
(1888 . "ARABIC LETTER FEH WITH TWO DOTS BELOW")
(1889 . "ARABIC LETTER FEH WITH THREE DOTS POINTING UPWARDS BELOW")
(1890 . "ARABIC LETTER KEHEH WITH DOT ABOVE")
(1891 . "ARABIC LETTER KEHEH WITH THREE DOTS ABOVE")
(1892 . "ARABIC LETTER KEHEH WITH THREE DOTS POINTING UPWARDS BELOW")
(1893 . "ARABIC LETTER MEEM WITH DOT ABOVE")
(1894 . "ARABIC LETTER MEEM WITH DOT BELOW")
(1895 . "ARABIC LETTER NOON WITH TWO DOTS BELOW")
(1896 . "ARABIC LETTER NOON WITH SMALL TAH")
(1897 . "ARABIC LETTER NOON WITH SMALL V")
(1898 . "ARABIC LETTER LAM WITH BAR")
(1899 . "ARABIC LETTER REH WITH TWO DOTS VERTICALLY ABOVE")
(1900 . "ARABIC LETTER REH WITH HAMZA ABOVE")
(1901 . "ARABIC LETTER SEEN WITH TWO DOTS VERTICALLY ABOVE")
(1902 . "ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH BELOW")
(1903 . "ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH AND TWO DOTS")
(1904 . "ARABIC LETTER SEEN WITH SMALL ARABIC LETTER TAH AND TWO DOTS")
(1905 . "ARABIC LETTER REH WITH SMALL ARABIC LETTER TAH AND TWO DOTS")
(1906 . "ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH ABOVE")
(1907 . "ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE")
(1908 . "ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE")
(1909 . "ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE")
(1910 . "ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE")
(1911 . "ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW")
(1912 . "ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE")
(1913 . "ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE")
(1914 . "ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE")
(1915 . "ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE")
(1916 . "ARABIC LETTER HAH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW")
(1917 . "ARABIC LETTER SEEN WITH EXTENDED ARABIC-INDIC DIGIT FOUR ABOVE")
(1918 . "ARABIC LETTER SEEN WITH INVERTED V")
(1919 . "ARABIC LETTER KAF WITH TWO DOTS ABOVE")
(1920 . "THAANA LETTER HAA")
(1921 . "THAANA LETTER SHAVIYANI")
(1922 . "THAANA LETTER NOONU")
(1923 . "THAANA LETTER RAA")
(1924 . "THAANA LETTER BAA")
(1925 . "THAANA LETTER LHAVIYANI")
(1926 . "THAANA LETTER KAAFU")
(1927 . "THAANA LETTER ALIFU")
(1928 . "THAANA LETTER VAAVU")
(1929 . "THAANA LETTER MEEMU")
(1930 . "THAANA LETTER FAAFU")
(1931 . "THAANA LETTER DHAALU")
(1932 . "THAANA LETTER THAA")
(1933 . "THAANA LETTER LAAMU")
(1934 . "THAANA LETTER GAAFU")
(1935 . "THAANA LETTER GNAVIYANI")
(1936 . "THAANA LETTER SEENU")
(1937 . "THAANA LETTER DAVIYANI")
(1938 . "THAANA LETTER ZAVIYANI")
(1939 . "THAANA LETTER TAVIYANI")
(1940 . "THAANA LETTER YAA")
(1941 . "THAANA LETTER PAVIYANI")
(1942 . "THAANA LETTER JAVIYANI")
(1943 . "THAANA LETTER CHAVIYANI")
(1944 . "THAANA LETTER TTAA")
(1945 . "THAANA LETTER HHAA")
(1946 . "THAANA LETTER KHAA")
(1947 . "THAANA LETTER THAALU")
(1948 . "THAANA LETTER ZAA")
(1949 . "THAANA LETTER SHEENU")
(1950 . "THAANA LETTER SAADHU")
(1951 . "THAANA LETTER DAADHU")
(1952 . "THAANA LETTER TO")
(1953 . "THAANA LETTER ZO")
(1954 . "THAANA LETTER AINU")
(1955 . "THAANA LETTER GHAINU")
(1956 . "THAANA LETTER QAAFU")
(1957 . "THAANA LETTER WAAVU")
(1958 . "THAANA ABAFILI")
(1959 . "THAANA AABAAFILI")
(1960 . "THAANA IBIFILI")
(1961 . "THAANA EEBEEFILI")
(1962 . "THAANA UBUFILI")
(1963 . "THAANA OOBOOFILI")
(1964 . "THAANA EBEFILI")
(1965 . "THAANA EYBEYFILI")
(1966 . "THAANA OBOFILI")
(1967 . "THAANA OABOAFILI")
(1968 . "THAANA SUKUN")
(1969 . "THAANA LETTER NAA")
((1970 . 1984) . #f)
(1984 . "NKO DIGIT ZERO")
(1985 . "NKO DIGIT ONE")
(1986 . "NKO DIGIT TWO")
(1987 . "NKO DIGIT THREE")
(1988 . "NKO DIGIT FOUR")
(1989 . "NKO DIGIT FIVE")
(1990 . "NKO DIGIT SIX")
(1991 . "NKO DIGIT SEVEN")
(1992 . "NKO DIGIT EIGHT")
(1993 . "NKO DIGIT NINE")
(1994 . "NKO LETTER A")
(1995 . "NKO LETTER EE")
(1996 . "NKO LETTER I")
(1997 . "NKO LETTER E")
(1998 . "NKO LETTER U")
(1999 . "NKO LETTER OO")
(2000 . "NKO LETTER O")
(2001 . "NKO LETTER DAGBASINNA")
(2002 . "NKO LETTER N")
(2003 . "NKO LETTER BA")
(2004 . "NKO LETTER PA")
(2005 . "NKO LETTER TA")
(2006 . "NKO LETTER JA")
(2007 . "NKO LETTER CHA")
(2008 . "NKO LETTER DA")
(2009 . "NKO LETTER RA")
(2010 . "NKO LETTER RRA")
(2011 . "NKO LETTER SA")
(2012 . "NKO LETTER GBA")
(2013 . "NKO LETTER FA")
(2014 . "NKO LETTER KA")
(2015 . "NKO LETTER LA")
(2016 . "NKO LETTER NA WOLOSO")
(2017 . "NKO LETTER MA")
(2018 . "NKO LETTER NYA")
(2019 . "NKO LETTER NA")
(2020 . "NKO LETTER HA")
(2021 . "NKO LETTER WA")
(2022 . "NKO LETTER YA")
(2023 . "NKO LETTER NYA WOLOSO")
(2024 . "NKO LETTER JONA JA")
(2025 . "NKO LETTER JONA CHA")
(2026 . "NKO LETTER JONA RA")
(2027 . "NKO COMBINING SHORT HIGH TONE")
(2028 . "NKO COMBINING SHORT LOW TONE")
(2029 . "NKO COMBINING SHORT RISING TONE")
(2030 . "NKO COMBINING LONG DESCENDING TONE")
(2031 . "NKO COMBINING LONG HIGH TONE")
(2032 . "NKO COMBINING LONG LOW TONE")
(2033 . "NKO COMBINING LONG RISING TONE")
(2034 . "NKO COMBINING NASALIZATION MARK")
(2035 . "NKO COMBINING DOUBLE DOT ABOVE")
(2036 . "NKO HIGH TONE APOSTROPHE")
(2037 . "NKO LOW TONE APOSTROPHE")
(2038 . "NKO SYMBOL OO DENNEN")
(2039 . "NKO SYMBOL GBAKURUNEN")
(2040 . "NKO COMMA")
(2041 . "NKO EXCLAMATION MARK")
(2042 . "NKO LAJANYALAN")
((2043 . 2048) . #f)
(2048 . "SAMARITAN LETTER ALAF")
(2049 . "SAMARITAN LETTER BIT")
(2050 . "SAMARITAN LETTER GAMAN")
(2051 . "SAMARITAN LETTER DALAT")
(2052 . "SAMARITAN LETTER IY")
(2053 . "SAMARITAN LETTER BAA")
(2054 . "SAMARITAN LETTER ZEN")
(2055 . "SAMARITAN LETTER IT")
(2056 . "SAMARITAN LETTER TIT")
(2057 . "SAMARITAN LETTER YUT")
(2058 . "SAMARITAN LETTER KAAF")
(2059 . "SAMARITAN LETTER LABAT")
(2060 . "SAMARITAN LETTER MIM")
(2061 . "SAMARITAN LETTER NUN")
(2062 . "SAMARITAN LETTER SINGAAT")
(2063 . "SAMARITAN LETTER IN")
(2064 . "SAMARITAN LETTER FI")
(2065 . "SAMARITAN LETTER TSAADIY")
(2066 . "SAMARITAN LETTER QUF")
(2067 . "SAMARITAN LETTER RISH")
(2068 . "SAMARITAN LETTER SHAN")
(2069 . "SAMARITAN LETTER TAAF")
(2070 . "SAMARITAN MARK IN")
(2071 . "SAMARITAN MARK IN-ALAF")
(2072 . "SAMARITAN MARK OCCLUSION")
(2073 . "SAMARITAN MARK DAGESH")
(2074 . "SAMARITAN MODIFIER LETTER EPENTHETIC YUT")
(2075 . "SAMARITAN MARK EPENTHETIC YUT")
(2076 . "SAMARITAN VOWEL SIGN LONG E")
(2077 . "SAMARITAN VOWEL SIGN E")
(2078 . "SAMARITAN VOWEL SIGN OVERLONG AA")
(2079 . "SAMARITAN VOWEL SIGN LONG AA")
(2080 . "SAMARITAN VOWEL SIGN AA")
(2081 . "SAMARITAN VOWEL SIGN OVERLONG A")
(2082 . "SAMARITAN VOWEL SIGN LONG A")
(2083 . "SAMARITAN VOWEL SIGN A")
(2084 . "SAMARITAN MODIFIER LETTER SHORT A")
(2085 . "SAMARITAN VOWEL SIGN SHORT A")
(2086 . "SAMARITAN VOWEL SIGN LONG U")
(2087 . "SAMARITAN VOWEL SIGN U")
(2088 . "SAMARITAN MODIFIER LETTER I")
(2089 . "SAMARITAN VOWEL SIGN LONG I")
(2090 . "SAMARITAN VOWEL SIGN I")
(2091 . "SAMARITAN VOWEL SIGN O")
(2092 . "SAMARITAN VOWEL SIGN SUKUN")
(2093 . "SAMARITAN MARK NEQUDAA")
((2094 . 2096) . #f)
(2096 . "SAMARITAN PUNCTUATION NEQUDAA")
(2097 . "SAMARITAN PUNCTUATION AFSAAQ")
(2098 . "SAMARITAN PUNCTUATION ANGED")
(2099 . "SAMARITAN PUNCTUATION BAU")
(2100 . "SAMARITAN PUNCTUATION ATMAAU")
(2101 . "SAMARITAN PUNCTUATION SHIYYAALAA")
(2102 . "SAMARITAN ABBREVIATION MARK")
(2103 . "SAMARITAN PUNCTUATION MELODIC QITSA")
(2104 . "SAMARITAN PUNCTUATION ZIQAA")
(2105 . "SAMARITAN PUNCTUATION QITSA")
(2106 . "SAMARITAN PUNCTUATION ZAEF")
(2107 . "SAMARITAN PUNCTUATION TURU")
(2108 . "SAMARITAN PUNCTUATION ARKAANU")
(2109 . "SAMARITAN PUNCTUATION SOF MASHFAAT")
(2110 . "SAMARITAN PUNCTUATION ANNAAU")
(2111 . #f)
(2112 . "MANDAIC LETTER HALQA")
(2113 . "MANDAIC LETTER AB")
(2114 . "MANDAIC LETTER AG")
(2115 . "MANDAIC LETTER AD")
(2116 . "MANDAIC LETTER AH")
(2117 . "MANDAIC LETTER USHENNA")
(2118 . "MANDAIC LETTER AZ")
(2119 . "MANDAIC LETTER IT")
(2120 . "MANDAIC LETTER ATT")
(2121 . "MANDAIC LETTER AKSA")
(2122 . "MANDAIC LETTER AK")
(2123 . "MANDAIC LETTER AL")
(2124 . "MANDAIC LETTER AM")
(2125 . "MANDAIC LETTER AN")
(2126 . "MANDAIC LETTER AS")
(2127 . "MANDAIC LETTER IN")
(2128 . "MANDAIC LETTER AP")
(2129 . "MANDAIC LETTER ASZ")
(2130 . "MANDAIC LETTER AQ")
(2131 . "MANDAIC LETTER AR")
(2132 . "MANDAIC LETTER ASH")
(2133 . "MANDAIC LETTER AT")
(2134 . "MANDAIC LETTER DUSHENNA")
(2135 . "MANDAIC LETTER KAD")
(2136 . "MANDAIC LETTER AIN")
(2137 . "MANDAIC AFFRICATION MARK")
(2138 . "MANDAIC VOCALIZATION MARK")
(2139 . "MANDAIC GEMINATION MARK")
((2140 . 2142) . #f)
(2142 . "MANDAIC PUNCTUATION")
((2143 . 2208) . #f)
(2208 . "ARABIC LETTER BEH WITH SMALL V BELOW")
(2209 . "ARABIC LETTER BEH WITH HAMZA ABOVE")
(2210 . "ARABIC LETTER JEEM WITH TWO DOTS ABOVE")
(2211 . "ARABIC LETTER TAH WITH TWO DOTS ABOVE")
(2212 . "ARABIC LETTER FEH WITH DOT BELOW AND THREE DOTS ABOVE")
(2213 . "ARABIC LETTER QAF WITH DOT BELOW")
(2214 . "ARABIC LETTER LAM WITH DOUBLE BAR")
(2215 . "ARABIC LETTER MEEM WITH THREE DOTS ABOVE")
(2216 . "ARABIC LETTER YEH WITH TWO DOTS BELOW AND HAMZA ABOVE")
(2217 . "ARABIC LETTER YEH WITH TWO DOTS BELOW AND DOT ABOVE")
(2218 . "ARABIC LETTER REH WITH LOOP")
(2219 . "ARABIC LETTER WAW WITH DOT WITHIN")
(2220 . "ARABIC LETTER ROHINGYA YEH")
(2221 . "ARABIC LETTER LOW ALEF")
(2222 . "ARABIC LETTER DAL WITH THREE DOTS BELOW")
(2223 . "ARABIC LETTER SAD WITH THREE DOTS BELOW")
(2224 . "ARABIC LETTER GAF WITH INVERTED STROKE")
(2225 . "ARABIC LETTER STRAIGHT WAW")
(2226 . "ARABIC LETTER ZAIN WITH INVERTED V ABOVE")
(2227 . "ARABIC LETTER AIN WITH THREE DOTS BELOW")
(2228 . "ARABIC LETTER KAF WITH DOT BELOW")
(2229 . #f)
(2230 . "ARABIC LETTER BEH WITH SMALL MEEM ABOVE")
(2231 . "ARABIC LETTER PEH WITH SMALL MEEM ABOVE")
(2232 . "ARABIC LETTER TEH WITH SMALL TEH ABOVE")
(2233 . "ARABIC LETTER REH WITH SMALL NOON ABOVE")
(2234 . "ARABIC LETTER YEH WITH TWO DOTS BELOW AND SMALL NOON ABOVE")
(2235 . "ARABIC LETTER AFRICAN FEH")
(2236 . "ARABIC LETTER AFRICAN QAF")
(2237 . "ARABIC LETTER AFRICAN NOON")
((2238 . 2260) . #f)
(2260 . "ARABIC SMALL HIGH WORD AR-RUB")
(2261 . "ARABIC SMALL HIGH SAD")
(2262 . "ARABIC SMALL HIGH AIN")
(2263 . "ARABIC SMALL HIGH QAF")
(2264 . "ARABIC SMALL HIGH NOON WITH KASRA")
(2265 . "ARABIC SMALL LOW NOON WITH KASRA")
(2266 . "ARABIC SMALL HIGH WORD ATH-THALATHA")
(2267 . "ARABIC SMALL HIGH WORD AS-SAJDA")
(2268 . "ARABIC SMALL HIGH WORD AN-NISF")
(2269 . "ARABIC SMALL HIGH WORD SAKTA")
(2270 . "ARABIC SMALL HIGH WORD QIF")
(2271 . "ARABIC SMALL HIGH WORD WAQFA")
(2272 . "ARABIC SMALL HIGH FOOTNOTE MARKER")
(2273 . "ARABIC SMALL HIGH SIGN SAFHA")
(2274 . "ARABIC DISPUTED END OF AYAH")
(2275 . "ARABIC TURNED DAMMA BELOW")
(2276 . "ARABIC CURLY FATHA")
(2277 . "ARABIC CURLY DAMMA")
(2278 . "ARABIC CURLY KASRA")
(2279 . "ARABIC CURLY FATHATAN")
(2280 . "ARABIC CURLY DAMMATAN")
(2281 . "ARABIC CURLY KASRATAN")
(2282 . "ARABIC TONE ONE DOT ABOVE")
(2283 . "ARABIC TONE TWO DOTS ABOVE")
(2284 . "ARABIC TONE LOOP ABOVE")
(2285 . "ARABIC TONE ONE DOT BELOW")
(2286 . "ARABIC TONE TWO DOTS BELOW")
(2287 . "ARABIC TONE LOOP BELOW")
(2288 . "ARABIC OPEN FATHATAN")
(2289 . "ARABIC OPEN DAMMATAN")
(2290 . "ARABIC OPEN KASRATAN")
(2291 . "ARABIC SMALL HIGH WAW")
(2292 . "ARABIC FATHA WITH RING")
(2293 . "ARABIC FATHA WITH DOT ABOVE")
(2294 . "ARABIC KASRA WITH DOT BELOW")
(2295 . "ARABIC LEFT ARROWHEAD ABOVE")
(2296 . "ARABIC RIGHT ARROWHEAD ABOVE")
(2297 . "ARABIC LEFT ARROWHEAD BELOW")
(2298 . "ARABIC RIGHT ARROWHEAD BELOW")
(2299 . "ARABIC DOUBLE RIGHT ARROWHEAD ABOVE")
(2300 . "ARABIC DOUBLE RIGHT ARROWHEAD ABOVE WITH DOT")
(2301 . "ARABIC RIGHT ARROWHEAD ABOVE WITH DOT")
(2302 . "ARABIC DAMMA WITH DOT")
(2303 . "ARABIC MARK SIDEWAYS NOON GHUNNA")
(2304 . "DEVANAGARI SIGN INVERTED CANDRABINDU")
(2305 . "DEVANAGARI SIGN CANDRABINDU")
(2306 . "DEVANAGARI SIGN ANUSVARA")
(2307 . "DEVANAGARI SIGN VISARGA")
(2308 . "DEVANAGARI LETTER SHORT A")
(2309 . "DEVANAGARI LETTER A")
(2310 . "DEVANAGARI LETTER AA")
(2311 . "DEVANAGARI LETTER I")
(2312 . "DEVANAGARI LETTER II")
(2313 . "DEVANAGARI LETTER U")
(2314 . "DEVANAGARI LETTER UU")
(2315 . "DEVANAGARI LETTER VOCALIC R")
(2316 . "DEVANAGARI LETTER VOCALIC L")
(2317 . "DEVANAGARI LETTER CANDRA E")
(2318 . "DEVANAGARI LETTER SHORT E")
(2319 . "DEVANAGARI LETTER E")
(2320 . "DEVANAGARI LETTER AI")
(2321 . "DEVANAGARI LETTER CANDRA O")
(2322 . "DEVANAGARI LETTER SHORT O")
(2323 . "DEVANAGARI LETTER O")
(2324 . "DEVANAGARI LETTER AU")
(2325 . "DEVANAGARI LETTER KA")
(2326 . "DEVANAGARI LETTER KHA")
(2327 . "DEVANAGARI LETTER GA")
(2328 . "DEVANAGARI LETTER GHA")
(2329 . "DEVANAGARI LETTER NGA")
(2330 . "DEVANAGARI LETTER CA")
(2331 . "DEVANAGARI LETTER CHA")
(2332 . "DEVANAGARI LETTER JA")
(2333 . "DEVANAGARI LETTER JHA")
(2334 . "DEVANAGARI LETTER NYA")
(2335 . "DEVANAGARI LETTER TTA")
(2336 . "DEVANAGARI LETTER TTHA")
(2337 . "DEVANAGARI LETTER DDA")
(2338 . "DEVANAGARI LETTER DDHA")
(2339 . "DEVANAGARI LETTER NNA")
(2340 . "DEVANAGARI LETTER TA")
(2341 . "DEVANAGARI LETTER THA")
(2342 . "DEVANAGARI LETTER DA")
(2343 . "DEVANAGARI LETTER DHA")
(2344 . "DEVANAGARI LETTER NA")
(2345 . "DEVANAGARI LETTER NNNA")
(2346 . "DEVANAGARI LETTER PA")
(2347 . "DEVANAGARI LETTER PHA")
(2348 . "DEVANAGARI LETTER BA")
(2349 . "DEVANAGARI LETTER BHA")
(2350 . "DEVANAGARI LETTER MA")
(2351 . "DEVANAGARI LETTER YA")
(2352 . "DEVANAGARI LETTER RA")
(2353 . "DEVANAGARI LETTER RRA")
(2354 . "DEVANAGARI LETTER LA")
(2355 . "DEVANAGARI LETTER LLA")
(2356 . "DEVANAGARI LETTER LLLA")
(2357 . "DEVANAGARI LETTER VA")
(2358 . "DEVANAGARI LETTER SHA")
(2359 . "DEVANAGARI LETTER SSA")
(2360 . "DEVANAGARI LETTER SA")
(2361 . "DEVANAGARI LETTER HA")
(2362 . "DEVANAGARI VOWEL SIGN OE")
(2363 . "DEVANAGARI VOWEL SIGN OOE")
(2364 . "DEVANAGARI SIGN NUKTA")
(2365 . "DEVANAGARI SIGN AVAGRAHA")
(2366 . "DEVANAGARI VOWEL SIGN AA")
(2367 . "DEVANAGARI VOWEL SIGN I")
(2368 . "DEVANAGARI VOWEL SIGN II")
(2369 . "DEVANAGARI VOWEL SIGN U")
(2370 . "DEVANAGARI VOWEL SIGN UU")
(2371 . "DEVANAGARI VOWEL SIGN VOCALIC R")
(2372 . "DEVANAGARI VOWEL SIGN VOCALIC RR")
(2373 . "DEVANAGARI VOWEL SIGN CANDRA E")
(2374 . "DEVANAGARI VOWEL SIGN SHORT E")
(2375 . "DEVANAGARI VOWEL SIGN E")
(2376 . "DEVANAGARI VOWEL SIGN AI")
(2377 . "DEVANAGARI VOWEL SIGN CANDRA O")
(2378 . "DEVANAGARI VOWEL SIGN SHORT O")
(2379 . "DEVANAGARI VOWEL SIGN O")
(2380 . "DEVANAGARI VOWEL SIGN AU")
(2381 . "DEVANAGARI SIGN VIRAMA")
(2382 . "DEVANAGARI VOWEL SIGN PRISHTHAMATRA E")
(2383 . "DEVANAGARI VOWEL SIGN AW")
(2384 . "DEVANAGARI OM")
(2385 . "DEVANAGARI STRESS SIGN UDATTA")
(2386 . "DEVANAGARI STRESS SIGN ANUDATTA")
(2387 . "DEVANAGARI GRAVE ACCENT")
(2388 . "DEVANAGARI ACUTE ACCENT")
(2389 . "DEVANAGARI VOWEL SIGN CANDRA LONG E")
(2390 . "DEVANAGARI VOWEL SIGN UE")
(2391 . "DEVANAGARI VOWEL SIGN UUE")
(2392 . "DEVANAGARI LETTER QA")
(2393 . "DEVANAGARI LETTER KHHA")
(2394 . "DEVANAGARI LETTER GHHA")
(2395 . "DEVANAGARI LETTER ZA")
(2396 . "DEVANAGARI LETTER DDDHA")
(2397 . "DEVANAGARI LETTER RHA")
(2398 . "DEVANAGARI LETTER FA")
(2399 . "DEVANAGARI LETTER YYA")
(2400 . "DEVANAGARI LETTER VOCALIC RR")
(2401 . "DEVANAGARI LETTER VOCALIC LL")
(2402 . "DEVANAGARI VOWEL SIGN VOCALIC L")
(2403 . "DEVANAGARI VOWEL SIGN VOCALIC LL")
(2404 . "DEVANAGARI DANDA")
(2405 . "DEVANAGARI DOUBLE DANDA")
(2406 . "DEVANAGARI DIGIT ZERO")
(2407 . "DEVANAGARI DIGIT ONE")
(2408 . "DEVANAGARI DIGIT TWO")
(2409 . "DEVANAGARI DIGIT THREE")
(2410 . "DEVANAGARI DIGIT FOUR")
(2411 . "DEVANAGARI DIGIT FIVE")
(2412 . "DEVANAGARI DIGIT SIX")
(2413 . "DEVANAGARI DIGIT SEVEN")
(2414 . "DEVANAGARI DIGIT EIGHT")
(2415 . "DEVANAGARI DIGIT NINE")
(2416 . "DEVANAGARI ABBREVIATION SIGN")
(2417 . "DEVANAGARI SIGN HIGH SPACING DOT")
(2418 . "DEVANAGARI LETTER CANDRA A")
(2419 . "DEVANAGARI LETTER OE")
(2420 . "DEVANAGARI LETTER OOE")
(2421 . "DEVANAGARI LETTER AW")
(2422 . "DEVANAGARI LETTER UE")
(2423 . "DEVANAGARI LETTER UUE")
(2424 . "DEVANAGARI LETTER MARWARI DDA")
(2425 . "DEVANAGARI LETTER ZHA")
(2426 . "DEVANAGARI LETTER HEAVY YA")
(2427 . "DEVANAGARI LETTER GGA")
(2428 . "DEVANAGARI LETTER JJA")
(2429 . "DEVANAGARI LETTER GLOTTAL STOP")
(2430 . "DEVANAGARI LETTER DDDA")
(2431 . "DEVANAGARI LETTER BBA")
(2432 . "BENGALI ANJI")
(2433 . "BENGALI SIGN CANDRABINDU")
(2434 . "BENGALI SIGN ANUSVARA")
(2435 . "BENGALI SIGN VISARGA")
(2436 . #f)
(2437 . "BENGALI LETTER A")
(2438 . "BENGALI LETTER AA")
(2439 . "BENGALI LETTER I")
(2440 . "BENGALI LETTER II")
(2441 . "BENGALI LETTER U")
(2442 . "BENGALI LETTER UU")
(2443 . "BENGALI LETTER VOCALIC R")
(2444 . "BENGALI LETTER VOCALIC L")
((2445 . 2447) . #f)
(2447 . "BENGALI LETTER E")
(2448 . "BENGALI LETTER AI")
((2449 . 2451) . #f)
(2451 . "BENGALI LETTER O")
(2452 . "BENGALI LETTER AU")
(2453 . "BENGALI LETTER KA")
(2454 . "BENGALI LETTER KHA")
(2455 . "BENGALI LETTER GA")
(2456 . "BENGALI LETTER GHA")
(2457 . "BENGALI LETTER NGA")
(2458 . "BENGALI LETTER CA")
(2459 . "BENGALI LETTER CHA")
(2460 . "BENGALI LETTER JA")
(2461 . "BENGALI LETTER JHA")
(2462 . "BENGALI LETTER NYA")
(2463 . "BENGALI LETTER TTA")
(2464 . "BENGALI LETTER TTHA")
(2465 . "BENGALI LETTER DDA")
(2466 . "BENGALI LETTER DDHA")
(2467 . "BENGALI LETTER NNA")
(2468 . "BENGALI LETTER TA")
(2469 . "BENGALI LETTER THA")
(2470 . "BENGALI LETTER DA")
(2471 . "BENGALI LETTER DHA")
(2472 . "BENGALI LETTER NA")
(2473 . #f)
(2474 . "BENGALI LETTER PA")
(2475 . "BENGALI LETTER PHA")
(2476 . "BENGALI LETTER BA")
(2477 . "BENGALI LETTER BHA")
(2478 . "BENGALI LETTER MA")
(2479 . "BENGALI LETTER YA")
(2480 . "BENGALI LETTER RA")
(2481 . #f)
(2482 . "BENGALI LETTER LA")
((2483 . 2486) . #f)
(2486 . "BENGALI LETTER SHA")
(2487 . "BENGALI LETTER SSA")
(2488 . "BENGALI LETTER SA")
(2489 . "BENGALI LETTER HA")
((2490 . 2492) . #f)
(2492 . "BENGALI SIGN NUKTA")
(2493 . "BENGALI SIGN AVAGRAHA")
(2494 . "BENGALI VOWEL SIGN AA")
(2495 . "BENGALI VOWEL SIGN I")
(2496 . "BENGALI VOWEL SIGN II")
(2497 . "BENGALI VOWEL SIGN U")
(2498 . "BENGALI VOWEL SIGN UU")
(2499 . "BENGALI VOWEL SIGN VOCALIC R")
(2500 . "BENGALI VOWEL SIGN VOCALIC RR")
((2501 . 2503) . #f)
(2503 . "BENGALI VOWEL SIGN E")
(2504 . "BENGALI VOWEL SIGN AI")
((2505 . 2507) . #f)
(2507 . "BENGALI VOWEL SIGN O")
(2508 . "BENGALI VOWEL SIGN AU")
(2509 . "BENGALI SIGN VIRAMA")
(2510 . "BENGALI LETTER KHANDA TA")
((2511 . 2519) . #f)
(2519 . "BENGALI AU LENGTH MARK")
((2520 . 2524) . #f)
(2524 . "BENGALI LETTER RRA")
(2525 . "BENGALI LETTER RHA")
(2526 . #f)
(2527 . "BENGALI LETTER YYA")
(2528 . "BENGALI LETTER VOCALIC RR")
(2529 . "BENGALI LETTER VOCALIC LL")
(2530 . "BENGALI VOWEL SIGN VOCALIC L")
(2531 . "BENGALI VOWEL SIGN VOCALIC LL")
((2532 . 2534) . #f)
(2534 . "BENGALI DIGIT ZERO")
(2535 . "BENGALI DIGIT ONE")
(2536 . "BENGALI DIGIT TWO")
(2537 . "BENGALI DIGIT THREE")
(2538 . "BENGALI DIGIT FOUR")
(2539 . "BENGALI DIGIT FIVE")
(2540 . "BENGALI DIGIT SIX")
(2541 . "BENGALI DIGIT SEVEN")
(2542 . "BENGALI DIGIT EIGHT")
(2543 . "BENGALI DIGIT NINE")
(2544 . "BENGALI LETTER RA WITH MIDDLE DIAGONAL")
(2545 . "BENGALI LETTER RA WITH LOWER DIAGONAL")
(2546 . "BENGALI RUPEE MARK")
(2547 . "BENGALI RUPEE SIGN")
(2548 . "BENGALI CURRENCY NUMERATOR ONE")
(2549 . "BENGALI CURRENCY NUMERATOR TWO")
(2550 . "BENGALI CURRENCY NUMERATOR THREE")
(2551 . "BENGALI CURRENCY NUMERATOR FOUR")
(2552 . "BENGALI CURRENCY NUMERATOR ONE LESS THAN THE DENOMINATOR")
(2553 . "BENGALI CURRENCY DENOMINATOR SIXTEEN")
(2554 . "BENGALI ISSHAR")
(2555 . "BENGALI GANDA MARK")
((2556 . 2561) . #f)
(2561 . "GURMUKHI SIGN ADAK BINDI")
(2562 . "GURMUKHI SIGN BINDI")
(2563 . "GURMUKHI SIGN VISARGA")
(2564 . #f)
(2565 . "GURMUKHI LETTER A")
(2566 . "GURMUKHI LETTER AA")
(2567 . "GURMUKHI LETTER I")
(2568 . "GURMUKHI LETTER II")
(2569 . "GURMUKHI LETTER U")
(2570 . "GURMUKHI LETTER UU")
((2571 . 2575) . #f)
(2575 . "GURMUKHI LETTER EE")
(2576 . "GURMUKHI LETTER AI")
((2577 . 2579) . #f)
(2579 . "GURMUKHI LETTER OO")
(2580 . "GURMUKHI LETTER AU")
(2581 . "GURMUKHI LETTER KA")
(2582 . "GURMUKHI LETTER KHA")
(2583 . "GURMUKHI LETTER GA")
(2584 . "GURMUKHI LETTER GHA")
(2585 . "GURMUKHI LETTER NGA")
(2586 . "GURMUKHI LETTER CA")
(2587 . "GURMUKHI LETTER CHA")
(2588 . "GURMUKHI LETTER JA")
(2589 . "GURMUKHI LETTER JHA")
(2590 . "GURMUKHI LETTER NYA")
(2591 . "GURMUKHI LETTER TTA")
(2592 . "GURMUKHI LETTER TTHA")
(2593 . "GURMUKHI LETTER DDA")
(2594 . "GURMUKHI LETTER DDHA")
(2595 . "GURMUKHI LETTER NNA")
(2596 . "GURMUKHI LETTER TA")
(2597 . "GURMUKHI LETTER THA")
(2598 . "GURMUKHI LETTER DA")
(2599 . "GURMUKHI LETTER DHA")
(2600 . "GURMUKHI LETTER NA")
(2601 . #f)
(2602 . "GURMUKHI LETTER PA")
(2603 . "GURMUKHI LETTER PHA")
(2604 . "GURMUKHI LETTER BA")
(2605 . "GURMUKHI LETTER BHA")
(2606 . "GURMUKHI LETTER MA")
(2607 . "GURMUKHI LETTER YA")
(2608 . "GURMUKHI LETTER RA")
(2609 . #f)
(2610 . "GURMUKHI LETTER LA")
(2611 . "GURMUKHI LETTER LLA")
(2612 . #f)
(2613 . "GURMUKHI LETTER VA")
(2614 . "GURMUKHI LETTER SHA")
(2615 . #f)
(2616 . "GURMUKHI LETTER SA")
(2617 . "GURMUKHI LETTER HA")
((2618 . 2620) . #f)
(2620 . "GURMUKHI SIGN NUKTA")
(2621 . #f)
(2622 . "GURMUKHI VOWEL SIGN AA")
(2623 . "GURMUKHI VOWEL SIGN I")
(2624 . "GURMUKHI VOWEL SIGN II")
(2625 . "GURMUKHI VOWEL SIGN U")
(2626 . "GURMUKHI VOWEL SIGN UU")
((2627 . 2631) . #f)
(2631 . "GURMUKHI VOWEL SIGN EE")
(2632 . "GURMUKHI VOWEL SIGN AI")
((2633 . 2635) . #f)
(2635 . "GURMUKHI VOWEL SIGN OO")
(2636 . "GURMUKHI VOWEL SIGN AU")
(2637 . "GURMUKHI SIGN VIRAMA")
((2638 . 2641) . #f)
(2641 . "GURMUKHI SIGN UDAAT")
((2642 . 2649) . #f)
(2649 . "GURMUKHI LETTER KHHA")
(2650 . "GURMUKHI LETTER GHHA")
(2651 . "GURMUKHI LETTER ZA")
(2652 . "GURMUKHI LETTER RRA")
(2653 . #f)
(2654 . "GURMUKHI LETTER FA")
((2655 . 2662) . #f)
(2662 . "GURMUKHI DIGIT ZERO")
(2663 . "GURMUKHI DIGIT ONE")
(2664 . "GURMUKHI DIGIT TWO")
(2665 . "GURMUKHI DIGIT THREE")
(2666 . "GURMUKHI DIGIT FOUR")
(2667 . "GURMUKHI DIGIT FIVE")
(2668 . "GURMUKHI DIGIT SIX")
(2669 . "GURMUKHI DIGIT SEVEN")
(2670 . "GURMUKHI DIGIT EIGHT")
(2671 . "GURMUKHI DIGIT NINE")
(2672 . "GURMUKHI TIPPI")
(2673 . "GURMUKHI ADDAK")
(2674 . "GURMUKHI IRI")
(2675 . "GURMUKHI URA")
(2676 . "GURMUKHI EK ONKAR")
(2677 . "GURMUKHI SIGN YAKASH")
((2678 . 2689) . #f)
(2689 . "GUJARATI SIGN CANDRABINDU")
(2690 . "GUJARATI SIGN ANUSVARA")
(2691 . "GUJARATI SIGN VISARGA")
(2692 . #f)
(2693 . "GUJARATI LETTER A")
(2694 . "GUJARATI LETTER AA")
(2695 . "GUJARATI LETTER I")
(2696 . "GUJARATI LETTER II")
(2697 . "GUJARATI LETTER U")
(2698 . "GUJARATI LETTER UU")
(2699 . "GUJARATI LETTER VOCALIC R")
(2700 . "GUJARATI LETTER VOCALIC L")
(2701 . "GUJARATI VOWEL CANDRA E")
(2702 . #f)
(2703 . "GUJARATI LETTER E")
(2704 . "GUJARATI LETTER AI")
(2705 . "GUJARATI VOWEL CANDRA O")
(2706 . #f)
(2707 . "GUJARATI LETTER O")
(2708 . "GUJARATI LETTER AU")
(2709 . "GUJARATI LETTER KA")
(2710 . "GUJARATI LETTER KHA")
(2711 . "GUJARATI LETTER GA")
(2712 . "GUJARATI LETTER GHA")
(2713 . "GUJARATI LETTER NGA")
(2714 . "GUJARATI LETTER CA")
(2715 . "GUJARATI LETTER CHA")
(2716 . "GUJARATI LETTER JA")
(2717 . "GUJARATI LETTER JHA")
(2718 . "GUJARATI LETTER NYA")
(2719 . "GUJARATI LETTER TTA")
(2720 . "GUJARATI LETTER TTHA")
(2721 . "GUJARATI LETTER DDA")
(2722 . "GUJARATI LETTER DDHA")
(2723 . "GUJARATI LETTER NNA")
(2724 . "GUJARATI LETTER TA")
(2725 . "GUJARATI LETTER THA")
(2726 . "GUJARATI LETTER DA")
(2727 . "GUJARATI LETTER DHA")
(2728 . "GUJARATI LETTER NA")
(2729 . #f)
(2730 . "GUJARATI LETTER PA")
(2731 . "GUJARATI LETTER PHA")
(2732 . "GUJARATI LETTER BA")
(2733 . "GUJARATI LETTER BHA")
(2734 . "GUJARATI LETTER MA")
(2735 . "GUJARATI LETTER YA")
(2736 . "GUJARATI LETTER RA")
(2737 . #f)
(2738 . "GUJARATI LETTER LA")
(2739 . "GUJARATI LETTER LLA")
(2740 . #f)
(2741 . "GUJARATI LETTER VA")
(2742 . "GUJARATI LETTER SHA")
(2743 . "GUJARATI LETTER SSA")
(2744 . "GUJARATI LETTER SA")
(2745 . "GUJARATI LETTER HA")
((2746 . 2748) . #f)
(2748 . "GUJARATI SIGN NUKTA")
(2749 . "GUJARATI SIGN AVAGRAHA")
(2750 . "GUJARATI VOWEL SIGN AA")
(2751 . "GUJARATI VOWEL SIGN I")
(2752 . "GUJARATI VOWEL SIGN II")
(2753 . "GUJARATI VOWEL SIGN U")
(2754 . "GUJARATI VOWEL SIGN UU")
(2755 . "GUJARATI VOWEL SIGN VOCALIC R")
(2756 . "GUJARATI VOWEL SIGN VOCALIC RR")
(2757 . "GUJARATI VOWEL SIGN CANDRA E")
(2758 . #f)
(2759 . "GUJARATI VOWEL SIGN E")
(2760 . "GUJARATI VOWEL SIGN AI")
(2761 . "GUJARATI VOWEL SIGN CANDRA O")
(2762 . #f)
(2763 . "GUJARATI VOWEL SIGN O")
(2764 . "GUJARATI VOWEL SIGN AU")
(2765 . "GUJARATI SIGN VIRAMA")
((2766 . 2768) . #f)
(2768 . "GUJARATI OM")
((2769 . 2784) . #f)
(2784 . "GUJARATI LETTER VOCALIC RR")
(2785 . "GUJARATI LETTER VOCALIC LL")
(2786 . "GUJARATI VOWEL SIGN VOCALIC L")
(2787 . "GUJARATI VOWEL SIGN VOCALIC LL")
((2788 . 2790) . #f)
(2790 . "GUJARATI DIGIT ZERO")
(2791 . "GUJARATI DIGIT ONE")
(2792 . "GUJARATI DIGIT TWO")
(2793 . "GUJARATI DIGIT THREE")
(2794 . "GUJARATI DIGIT FOUR")
(2795 . "GUJARATI DIGIT FIVE")
(2796 . "GUJARATI DIGIT SIX")
(2797 . "GUJARATI DIGIT SEVEN")
(2798 . "GUJARATI DIGIT EIGHT")
(2799 . "GUJARATI DIGIT NINE")
(2800 . "GUJARATI ABBREVIATION SIGN")
(2801 . "GUJARATI RUPEE SIGN")
((2802 . 2809) . #f)
(2809 . "GUJARATI LETTER ZHA")
((2810 . 2817) . #f)
(2817 . "ORIYA SIGN CANDRABINDU")
(2818 . "ORIYA SIGN ANUSVARA")
(2819 . "ORIYA SIGN VISARGA")
(2820 . #f)
(2821 . "ORIYA LETTER A")
(2822 . "ORIYA LETTER AA")
(2823 . "ORIYA LETTER I")
(2824 . "ORIYA LETTER II")
(2825 . "ORIYA LETTER U")
(2826 . "ORIYA LETTER UU")
(2827 . "ORIYA LETTER VOCALIC R")
(2828 . "ORIYA LETTER VOCALIC L")
((2829 . 2831) . #f)
(2831 . "ORIYA LETTER E")
(2832 . "ORIYA LETTER AI")
((2833 . 2835) . #f)
(2835 . "ORIYA LETTER O")
(2836 . "ORIYA LETTER AU")
(2837 . "ORIYA LETTER KA")
(2838 . "ORIYA LETTER KHA")
(2839 . "ORIYA LETTER GA")
(2840 . "ORIYA LETTER GHA")
(2841 . "ORIYA LETTER NGA")
(2842 . "ORIYA LETTER CA")
(2843 . "ORIYA LETTER CHA")
(2844 . "ORIYA LETTER JA")
(2845 . "ORIYA LETTER JHA")
(2846 . "ORIYA LETTER NYA")
(2847 . "ORIYA LETTER TTA")
(2848 . "ORIYA LETTER TTHA")
(2849 . "ORIYA LETTER DDA")
(2850 . "ORIYA LETTER DDHA")
(2851 . "ORIYA LETTER NNA")
(2852 . "ORIYA LETTER TA")
(2853 . "ORIYA LETTER THA")
(2854 . "ORIYA LETTER DA")
(2855 . "ORIYA LETTER DHA")
(2856 . "ORIYA LETTER NA")
(2857 . #f)
(2858 . "ORIYA LETTER PA")
(2859 . "ORIYA LETTER PHA")
(2860 . "ORIYA LETTER BA")
(2861 . "ORIYA LETTER BHA")
(2862 . "ORIYA LETTER MA")
(2863 . "ORIYA LETTER YA")
(2864 . "ORIYA LETTER RA")
(2865 . #f)
(2866 . "ORIYA LETTER LA")
(2867 . "ORIYA LETTER LLA")
(2868 . #f)
(2869 . "ORIYA LETTER VA")
(2870 . "ORIYA LETTER SHA")
(2871 . "ORIYA LETTER SSA")
(2872 . "ORIYA LETTER SA")
(2873 . "ORIYA LETTER HA")
((2874 . 2876) . #f)
(2876 . "ORIYA SIGN NUKTA")
(2877 . "ORIYA SIGN AVAGRAHA")
(2878 . "ORIYA VOWEL SIGN AA")
(2879 . "ORIYA VOWEL SIGN I")
(2880 . "ORIYA VOWEL SIGN II")
(2881 . "ORIYA VOWEL SIGN U")
(2882 . "ORIYA VOWEL SIGN UU")
(2883 . "ORIYA VOWEL SIGN VOCALIC R")
(2884 . "ORIYA VOWEL SIGN VOCALIC RR")
((2885 . 2887) . #f)
(2887 . "ORIYA VOWEL SIGN E")
(2888 . "ORIYA VOWEL SIGN AI")
((2889 . 2891) . #f)
(2891 . "ORIYA VOWEL SIGN O")
(2892 . "ORIYA VOWEL SIGN AU")
(2893 . "ORIYA SIGN VIRAMA")
((2894 . 2902) . #f)
(2902 . "ORIYA AI LENGTH MARK")
(2903 . "ORIYA AU LENGTH MARK")
((2904 . 2908) . #f)
(2908 . "ORIYA LETTER RRA")
(2909 . "ORIYA LETTER RHA")
(2910 . #f)
(2911 . "ORIYA LETTER YYA")
(2912 . "ORIYA LETTER VOCALIC RR")
(2913 . "ORIYA LETTER VOCALIC LL")
(2914 . "ORIYA VOWEL SIGN VOCALIC L")
(2915 . "ORIYA VOWEL SIGN VOCALIC LL")
((2916 . 2918) . #f)
(2918 . "ORIYA DIGIT ZERO")
(2919 . "ORIYA DIGIT ONE")
(2920 . "ORIYA DIGIT TWO")
(2921 . "ORIYA DIGIT THREE")
(2922 . "ORIYA DIGIT FOUR")
(2923 . "ORIYA DIGIT FIVE")
(2924 . "ORIYA DIGIT SIX")
(2925 . "ORIYA DIGIT SEVEN")
(2926 . "ORIYA DIGIT EIGHT")
(2927 . "ORIYA DIGIT NINE")
(2928 . "ORIYA ISSHAR")
(2929 . "ORIYA LETTER WA")
(2930 . "ORIYA FRACTION ONE QUARTER")
(2931 . "ORIYA FRACTION ONE HALF")
(2932 . "ORIYA FRACTION THREE QUARTERS")
(2933 . "ORIYA FRACTION ONE SIXTEENTH")
(2934 . "ORIYA FRACTION ONE EIGHTH")
(2935 . "ORIYA FRACTION THREE SIXTEENTHS")
((2936 . 2946) . #f)
(2946 . "TAMIL SIGN ANUSVARA")
(2947 . "TAMIL SIGN VISARGA")
(2948 . #f)
(2949 . "TAMIL LETTER A")
(2950 . "TAMIL LETTER AA")
(2951 . "TAMIL LETTER I")
(2952 . "TAMIL LETTER II")
(2953 . "TAMIL LETTER U")
(2954 . "TAMIL LETTER UU")
((2955 . 2958) . #f)
(2958 . "TAMIL LETTER E")
(2959 . "TAMIL LETTER EE")
(2960 . "TAMIL LETTER AI")
(2961 . #f)
(2962 . "TAMIL LETTER O")
(2963 . "TAMIL LETTER OO")
(2964 . "TAMIL LETTER AU")
(2965 . "TAMIL LETTER KA")
((2966 . 2969) . #f)
(2969 . "TAMIL LETTER NGA")
(2970 . "TAMIL LETTER CA")
(2971 . #f)
(2972 . "TAMIL LETTER JA")
(2973 . #f)
(2974 . "TAMIL LETTER NYA")
(2975 . "TAMIL LETTER TTA")
((2976 . 2979) . #f)
(2979 . "TAMIL LETTER NNA")
(2980 . "TAMIL LETTER TA")
((2981 . 2984) . #f)
(2984 . "TAMIL LETTER NA")
(2985 . "TAMIL LETTER NNNA")
(2986 . "TAMIL LETTER PA")
((2987 . 2990) . #f)
(2990 . "TAMIL LETTER MA")
(2991 . "TAMIL LETTER YA")
(2992 . "TAMIL LETTER RA")
(2993 . "TAMIL LETTER RRA")
(2994 . "TAMIL LETTER LA")
(2995 . "TAMIL LETTER LLA")
(2996 . "TAMIL LETTER LLLA")
(2997 . "TAMIL LETTER VA")
(2998 . "TAMIL LETTER SHA")
(2999 . "TAMIL LETTER SSA")
(3000 . "TAMIL LETTER SA")
(3001 . "TAMIL LETTER HA")
((3002 . 3006) . #f)
(3006 . "TAMIL VOWEL SIGN AA")
(3007 . "TAMIL VOWEL SIGN I")
(3008 . "TAMIL VOWEL SIGN II")
(3009 . "TAMIL VOWEL SIGN U")
(3010 . "TAMIL VOWEL SIGN UU")
((3011 . 3014) . #f)
(3014 . "TAMIL VOWEL SIGN E")
(3015 . "TAMIL VOWEL SIGN EE")
(3016 . "TAMIL VOWEL SIGN AI")
(3017 . #f)
(3018 . "TAMIL VOWEL SIGN O")
(3019 . "TAMIL VOWEL SIGN OO")
(3020 . "TAMIL VOWEL SIGN AU")
(3021 . "TAMIL SIGN VIRAMA")
((3022 . 3024) . #f)
(3024 . "TAMIL OM")
((3025 . 3031) . #f)
(3031 . "TAMIL AU LENGTH MARK")
((3032 . 3046) . #f)
(3046 . "TAMIL DIGIT ZERO")
(3047 . "TAMIL DIGIT ONE")
(3048 . "TAMIL DIGIT TWO")
(3049 . "TAMIL DIGIT THREE")
(3050 . "TAMIL DIGIT FOUR")
(3051 . "TAMIL DIGIT FIVE")
(3052 . "TAMIL DIGIT SIX")
(3053 . "TAMIL DIGIT SEVEN")
(3054 . "TAMIL DIGIT EIGHT")
(3055 . "TAMIL DIGIT NINE")
(3056 . "TAMIL NUMBER TEN")
(3057 . "TAMIL NUMBER ONE HUNDRED")
(3058 . "TAMIL NUMBER ONE THOUSAND")
(3059 . "TAMIL DAY SIGN")
(3060 . "TAMIL MONTH SIGN")
(3061 . "TAMIL YEAR SIGN")
(3062 . "TAMIL DEBIT SIGN")
(3063 . "TAMIL CREDIT SIGN")
(3064 . "TAMIL AS ABOVE SIGN")
(3065 . "TAMIL RUPEE SIGN")
(3066 . "TAMIL NUMBER SIGN")
((3067 . 3072) . #f)
(3072 . "TELUGU SIGN COMBINING CANDRABINDU ABOVE")
(3073 . "TELUGU SIGN CANDRABINDU")
(3074 . "TELUGU SIGN ANUSVARA")
(3075 . "TELUGU SIGN VISARGA")
(3076 . #f)
(3077 . "TELUGU LETTER A")
(3078 . "TELUGU LETTER AA")
(3079 . "TELUGU LETTER I")
(3080 . "TELUGU LETTER II")
(3081 . "TELUGU LETTER U")
(3082 . "TELUGU LETTER UU")
(3083 . "TELUGU LETTER VOCALIC R")
(3084 . "TELUGU LETTER VOCALIC L")
(3085 . #f)
(3086 . "TELUGU LETTER E")
(3087 . "TELUGU LETTER EE")
(3088 . "TELUGU LETTER AI")
(3089 . #f)
(3090 . "TELUGU LETTER O")
(3091 . "TELUGU LETTER OO")
(3092 . "TELUGU LETTER AU")
(3093 . "TELUGU LETTER KA")
(3094 . "TELUGU LETTER KHA")
(3095 . "TELUGU LETTER GA")
(3096 . "TELUGU LETTER GHA")
(3097 . "TELUGU LETTER NGA")
(3098 . "TELUGU LETTER CA")
(3099 . "TELUGU LETTER CHA")
(3100 . "TELUGU LETTER JA")
(3101 . "TELUGU LETTER JHA")
(3102 . "TELUGU LETTER NYA")
(3103 . "TELUGU LETTER TTA")
(3104 . "TELUGU LETTER TTHA")
(3105 . "TELUGU LETTER DDA")
(3106 . "TELUGU LETTER DDHA")
(3107 . "TELUGU LETTER NNA")
(3108 . "TELUGU LETTER TA")
(3109 . "TELUGU LETTER THA")
(3110 . "TELUGU LETTER DA")
(3111 . "TELUGU LETTER DHA")
(3112 . "TELUGU LETTER NA")
(3113 . #f)
(3114 . "TELUGU LETTER PA")
(3115 . "TELUGU LETTER PHA")
(3116 . "TELUGU LETTER BA")
(3117 . "TELUGU LETTER BHA")
(3118 . "TELUGU LETTER MA")
(3119 . "TELUGU LETTER YA")
(3120 . "TELUGU LETTER RA")
(3121 . "TELUGU LETTER RRA")
(3122 . "TELUGU LETTER LA")
(3123 . "TELUGU LETTER LLA")
(3124 . "TELUGU LETTER LLLA")
(3125 . "TELUGU LETTER VA")
(3126 . "TELUGU LETTER SHA")
(3127 . "TELUGU LETTER SSA")
(3128 . "TELUGU LETTER SA")
(3129 . "TELUGU LETTER HA")
((3130 . 3133) . #f)
(3133 . "TELUGU SIGN AVAGRAHA")
(3134 . "TELUGU VOWEL SIGN AA")
(3135 . "TELUGU VOWEL SIGN I")
(3136 . "TELUGU VOWEL SIGN II")
(3137 . "TELUGU VOWEL SIGN U")
(3138 . "TELUGU VOWEL SIGN UU")
(3139 . "TELUGU VOWEL SIGN VOCALIC R")
(3140 . "TELUGU VOWEL SIGN VOCALIC RR")
(3141 . #f)
(3142 . "TELUGU VOWEL SIGN E")
(3143 . "TELUGU VOWEL SIGN EE")
(3144 . "TELUGU VOWEL SIGN AI")
(3145 . #f)
(3146 . "TELUGU VOWEL SIGN O")
(3147 . "TELUGU VOWEL SIGN OO")
(3148 . "TELUGU VOWEL SIGN AU")
(3149 . "TELUGU SIGN VIRAMA")
((3150 . 3157) . #f)
(3157 . "TELUGU LENGTH MARK")
(3158 . "TELUGU AI LENGTH MARK")
(3159 . #f)
(3160 . "TELUGU LETTER TSA")
(3161 . "TELUGU LETTER DZA")
(3162 . "TELUGU LETTER RRRA")
((3163 . 3168) . #f)
(3168 . "TELUGU LETTER VOCALIC RR")
(3169 . "TELUGU LETTER VOCALIC LL")
(3170 . "TELUGU VOWEL SIGN VOCALIC L")
(3171 . "TELUGU VOWEL SIGN VOCALIC LL")
((3172 . 3174) . #f)
(3174 . "TELUGU DIGIT ZERO")
(3175 . "TELUGU DIGIT ONE")
(3176 . "TELUGU DIGIT TWO")
(3177 . "TELUGU DIGIT THREE")
(3178 . "TELUGU DIGIT FOUR")
(3179 . "TELUGU DIGIT FIVE")
(3180 . "TELUGU DIGIT SIX")
(3181 . "TELUGU DIGIT SEVEN")
(3182 . "TELUGU DIGIT EIGHT")
(3183 . "TELUGU DIGIT NINE")
((3184 . 3192) . #f)
(3192 . "TELUGU FRACTION DIGIT ZERO FOR ODD POWERS OF FOUR")
(3193 . "TELUGU FRACTION DIGIT ONE FOR ODD POWERS OF FOUR")
(3194 . "TELUGU FRACTION DIGIT TWO FOR ODD POWERS OF FOUR")
(3195 . "TELUGU FRACTION DIGIT THREE FOR ODD POWERS OF FOUR")
(3196 . "TELUGU FRACTION DIGIT ONE FOR EVEN POWERS OF FOUR")
(3197 . "TELUGU FRACTION DIGIT TWO FOR EVEN POWERS OF FOUR")
(3198 . "TELUGU FRACTION DIGIT THREE FOR EVEN POWERS OF FOUR")
(3199 . "TELUGU SIGN TUUMU")
(3200 . "KANNADA SIGN SPACING CANDRABINDU")
(3201 . "KANNADA SIGN CANDRABINDU")
(3202 . "KANNADA SIGN ANUSVARA")
(3203 . "KANNADA SIGN VISARGA")
(3204 . #f)
(3205 . "KANNADA LETTER A")
(3206 . "KANNADA LETTER AA")
(3207 . "KANNADA LETTER I")
(3208 . "KANNADA LETTER II")
(3209 . "KANNADA LETTER U")
(3210 . "KANNADA LETTER UU")
(3211 . "KANNADA LETTER VOCALIC R")
(3212 . "KANNADA LETTER VOCALIC L")
(3213 . #f)
(3214 . "KANNADA LETTER E")
(3215 . "KANNADA LETTER EE")
(3216 . "KANNADA LETTER AI")
(3217 . #f)
(3218 . "KANNADA LETTER O")
(3219 . "KANNADA LETTER OO")
(3220 . "KANNADA LETTER AU")
(3221 . "KANNADA LETTER KA")
(3222 . "KANNADA LETTER KHA")
(3223 . "KANNADA LETTER GA")
(3224 . "KANNADA LETTER GHA")
(3225 . "KANNADA LETTER NGA")
(3226 . "KANNADA LETTER CA")
(3227 . "KANNADA LETTER CHA")
(3228 . "KANNADA LETTER JA")
(3229 . "KANNADA LETTER JHA")
(3230 . "KANNADA LETTER NYA")
(3231 . "KANNADA LETTER TTA")
(3232 . "KANNADA LETTER TTHA")
(3233 . "KANNADA LETTER DDA")
(3234 . "KANNADA LETTER DDHA")
(3235 . "KANNADA LETTER NNA")
(3236 . "KANNADA LETTER TA")
(3237 . "KANNADA LETTER THA")
(3238 . "KANNADA LETTER DA")
(3239 . "KANNADA LETTER DHA")
(3240 . "KANNADA LETTER NA")
(3241 . #f)
(3242 . "KANNADA LETTER PA")
(3243 . "KANNADA LETTER PHA")
(3244 . "KANNADA LETTER BA")
(3245 . "KANNADA LETTER BHA")
(3246 . "KANNADA LETTER MA")
(3247 . "KANNADA LETTER YA")
(3248 . "KANNADA LETTER RA")
(3249 . "KANNADA LETTER RRA")
(3250 . "KANNADA LETTER LA")
(3251 . "KANNADA LETTER LLA")
(3252 . #f)
(3253 . "KANNADA LETTER VA")
(3254 . "KANNADA LETTER SHA")
(3255 . "KANNADA LETTER SSA")
(3256 . "KANNADA LETTER SA")
(3257 . "KANNADA LETTER HA")
((3258 . 3260) . #f)
(3260 . "KANNADA SIGN NUKTA")
(3261 . "KANNADA SIGN AVAGRAHA")
(3262 . "KANNADA VOWEL SIGN AA")
(3263 . "KANNADA VOWEL SIGN I")
(3264 . "KANNADA VOWEL SIGN II")
(3265 . "KANNADA VOWEL SIGN U")
(3266 . "KANNADA VOWEL SIGN UU")
(3267 . "KANNADA VOWEL SIGN VOCALIC R")
(3268 . "KANNADA VOWEL SIGN VOCALIC RR")
(3269 . #f)
(3270 . "KANNADA VOWEL SIGN E")
(3271 . "KANNADA VOWEL SIGN EE")
(3272 . "KANNADA VOWEL SIGN AI")
(3273 . #f)
(3274 . "KANNADA VOWEL SIGN O")
(3275 . "KANNADA VOWEL SIGN OO")
(3276 . "KANNADA VOWEL SIGN AU")
(3277 . "KANNADA SIGN VIRAMA")
((3278 . 3285) . #f)
(3285 . "KANNADA LENGTH MARK")
(3286 . "KANNADA AI LENGTH MARK")
((3287 . 3294) . #f)
(3294 . "KANNADA LETTER FA")
(3295 . #f)
(3296 . "KANNADA LETTER VOCALIC RR")
(3297 . "KANNADA LETTER VOCALIC LL")
(3298 . "KANNADA VOWEL SIGN VOCALIC L")
(3299 . "KANNADA VOWEL SIGN VOCALIC LL")
((3300 . 3302) . #f)
(3302 . "KANNADA DIGIT ZERO")
(3303 . "KANNADA DIGIT ONE")
(3304 . "KANNADA DIGIT TWO")
(3305 . "KANNADA DIGIT THREE")
(3306 . "KANNADA DIGIT FOUR")
(3307 . "KANNADA DIGIT FIVE")
(3308 . "KANNADA DIGIT SIX")
(3309 . "KANNADA DIGIT SEVEN")
(3310 . "KANNADA DIGIT EIGHT")
(3311 . "KANNADA DIGIT NINE")
(3312 . #f)
(3313 . "KANNADA SIGN JIHVAMULIYA")
(3314 . "KANNADA SIGN UPADHMANIYA")
((3315 . 3329) . #f)
(3329 . "MALAYALAM SIGN CANDRABINDU")
(3330 . "MALAYALAM SIGN ANUSVARA")
(3331 . "MALAYALAM SIGN VISARGA")
(3332 . #f)
(3333 . "MALAYALAM LETTER A")
(3334 . "MALAYALAM LETTER AA")
(3335 . "MALAYALAM LETTER I")
(3336 . "MALAYALAM LETTER II")
(3337 . "MALAYALAM LETTER U")
(3338 . "MALAYALAM LETTER UU")
(3339 . "MALAYALAM LETTER VOCALIC R")
(3340 . "MALAYALAM LETTER VOCALIC L")
(3341 . #f)
(3342 . "MALAYALAM LETTER E")
(3343 . "MALAYALAM LETTER EE")
(3344 . "MALAYALAM LETTER AI")
(3345 . #f)
(3346 . "MALAYALAM LETTER O")
(3347 . "MALAYALAM LETTER OO")
(3348 . "MALAYALAM LETTER AU")
(3349 . "MALAYALAM LETTER KA")
(3350 . "MALAYALAM LETTER KHA")
(3351 . "MALAYALAM LETTER GA")
(3352 . "MALAYALAM LETTER GHA")
(3353 . "MALAYALAM LETTER NGA")
(3354 . "MALAYALAM LETTER CA")
(3355 . "MALAYALAM LETTER CHA")
(3356 . "MALAYALAM LETTER JA")
(3357 . "MALAYALAM LETTER JHA")
(3358 . "MALAYALAM LETTER NYA")
(3359 . "MALAYALAM LETTER TTA")
(3360 . "MALAYALAM LETTER TTHA")
(3361 . "MALAYALAM LETTER DDA")
(3362 . "MALAYALAM LETTER DDHA")
(3363 . "MALAYALAM LETTER NNA")
(3364 . "MALAYALAM LETTER TA")
(3365 . "MALAYALAM LETTER THA")
(3366 . "MALAYALAM LETTER DA")
(3367 . "MALAYALAM LETTER DHA")
(3368 . "MALAYALAM LETTER NA")
(3369 . "MALAYALAM LETTER NNNA")
(3370 . "MALAYALAM LETTER PA")
(3371 . "MALAYALAM LETTER PHA")
(3372 . "MALAYALAM LETTER BA")
(3373 . "MALAYALAM LETTER BHA")
(3374 . "MALAYALAM LETTER MA")
(3375 . "MALAYALAM LETTER YA")
(3376 . "MALAYALAM LETTER RA")
(3377 . "MALAYALAM LETTER RRA")
(3378 . "MALAYALAM LETTER LA")
(3379 . "MALAYALAM LETTER LLA")
(3380 . "MALAYALAM LETTER LLLA")
(3381 . "MALAYALAM LETTER VA")
(3382 . "MALAYALAM LETTER SHA")
(3383 . "MALAYALAM LETTER SSA")
(3384 . "MALAYALAM LETTER SA")
(3385 . "MALAYALAM LETTER HA")
(3386 . "MALAYALAM LETTER TTTA")
((3387 . 3389) . #f)
(3389 . "MALAYALAM SIGN AVAGRAHA")
(3390 . "MALAYALAM VOWEL SIGN AA")
(3391 . "MALAYALAM VOWEL SIGN I")
(3392 . "MALAYALAM VOWEL SIGN II")
(3393 . "MALAYALAM VOWEL SIGN U")
(3394 . "MALAYALAM VOWEL SIGN UU")
(3395 . "MALAYALAM VOWEL SIGN VOCALIC R")
(3396 . "MALAYALAM VOWEL SIGN VOCALIC RR")
(3397 . #f)
(3398 . "MALAYALAM VOWEL SIGN E")
(3399 . "MALAYALAM VOWEL SIGN EE")
(3400 . "MALAYALAM VOWEL SIGN AI")
(3401 . #f)
(3402 . "MALAYALAM VOWEL SIGN O")
(3403 . "MALAYALAM VOWEL SIGN OO")
(3404 . "MALAYALAM VOWEL SIGN AU")
(3405 . "MALAYALAM SIGN VIRAMA")
(3406 . "MALAYALAM LETTER DOT REPH")
(3407 . "MALAYALAM SIGN PARA")
((3408 . 3412) . #f)
(3412 . "MALAYALAM LETTER CHILLU M")
(3413 . "MALAYALAM LETTER CHILLU Y")
(3414 . "MALAYALAM LETTER CHILLU LLL")
(3415 . "MALAYALAM AU LENGTH MARK")
(3416 . "MALAYALAM FRACTION ONE ONE-HUNDRED-AND-SIXTIETH")
(3417 . "MALAYALAM FRACTION ONE FORTIETH")
(3418 . "MALAYALAM FRACTION THREE EIGHTIETHS")
(3419 . "MALAYALAM FRACTION ONE TWENTIETH")
(3420 . "MALAYALAM FRACTION ONE TENTH")
(3421 . "MALAYALAM FRACTION THREE TWENTIETHS")
(3422 . "MALAYALAM FRACTION ONE FIFTH")
(3423 . "MALAYALAM LETTER ARCHAIC II")
(3424 . "MALAYALAM LETTER VOCALIC RR")
(3425 . "MALAYALAM LETTER VOCALIC LL")
(3426 . "MALAYALAM VOWEL SIGN VOCALIC L")
(3427 . "MALAYALAM VOWEL SIGN VOCALIC LL")
((3428 . 3430) . #f)
(3430 . "MALAYALAM DIGIT ZERO")
(3431 . "MALAYALAM DIGIT ONE")
(3432 . "MALAYALAM DIGIT TWO")
(3433 . "MALAYALAM DIGIT THREE")
(3434 . "MALAYALAM DIGIT FOUR")
(3435 . "MALAYALAM DIGIT FIVE")
(3436 . "MALAYALAM DIGIT SIX")
(3437 . "MALAYALAM DIGIT SEVEN")
(3438 . "MALAYALAM DIGIT EIGHT")
(3439 . "MALAYALAM DIGIT NINE")
(3440 . "MALAYALAM NUMBER TEN")
(3441 . "MALAYALAM NUMBER ONE HUNDRED")
(3442 . "MALAYALAM NUMBER ONE THOUSAND")
(3443 . "MALAYALAM FRACTION ONE QUARTER")
(3444 . "MALAYALAM FRACTION ONE HALF")
(3445 . "MALAYALAM FRACTION THREE QUARTERS")
(3446 . "MALAYALAM FRACTION ONE SIXTEENTH")
(3447 . "MALAYALAM FRACTION ONE EIGHTH")
(3448 . "MALAYALAM FRACTION THREE SIXTEENTHS")
(3449 . "MALAYALAM DATE MARK")
(3450 . "MALAYALAM LETTER CHILLU NN")
(3451 . "MALAYALAM LETTER CHILLU N")
(3452 . "MALAYALAM LETTER CHILLU RR")
(3453 . "MALAYALAM LETTER CHILLU L")
(3454 . "MALAYALAM LETTER CHILLU LL")
(3455 . "MALAYALAM LETTER CHILLU K")
((3456 . 3458) . #f)
(3458 . "SINHALA SIGN ANUSVARAYA")
(3459 . "SINHALA SIGN VISARGAYA")
(3460 . #f)
(3461 . "SINHALA LETTER AYANNA")
(3462 . "SINHALA LETTER AAYANNA")
(3463 . "SINHALA LETTER AEYANNA")
(3464 . "SINHALA LETTER AEEYANNA")
(3465 . "SINHALA LETTER IYANNA")
(3466 . "SINHALA LETTER IIYANNA")
(3467 . "SINHALA LETTER UYANNA")
(3468 . "SINHALA LETTER UUYANNA")
(3469 . "SINHALA LETTER IRUYANNA")
(3470 . "SINHALA LETTER IRUUYANNA")
(3471 . "SINHALA LETTER ILUYANNA")
(3472 . "SINHALA LETTER ILUUYANNA")
(3473 . "SINHALA LETTER EYANNA")
(3474 . "SINHALA LETTER EEYANNA")
(3475 . "SINHALA LETTER AIYANNA")
(3476 . "SINHALA LETTER OYANNA")
(3477 . "SINHALA LETTER OOYANNA")
(3478 . "SINHALA LETTER AUYANNA")
((3479 . 3482) . #f)
(3482 . "SINHALA LETTER ALPAPRAANA KAYANNA")
(3483 . "SINHALA LETTER MAHAAPRAANA KAYANNA")
(3484 . "SINHALA LETTER ALPAPRAANA GAYANNA")
(3485 . "SINHALA LETTER MAHAAPRAANA GAYANNA")
(3486 . "SINHALA LETTER KANTAJA NAASIKYAYA")
(3487 . "SINHALA LETTER SANYAKA GAYANNA")
(3488 . "SINHALA LETTER ALPAPRAANA CAYANNA")
(3489 . "SINHALA LETTER MAHAAPRAANA CAYANNA")
(3490 . "SINHALA LETTER ALPAPRAANA JAYANNA")
(3491 . "SINHALA LETTER MAHAAPRAANA JAYANNA")
(3492 . "SINHALA LETTER TAALUJA NAASIKYAYA")
(3493 . "SINHALA LETTER TAALUJA SANYOOGA NAAKSIKYAYA")
(3494 . "SINHALA LETTER SANYAKA JAYANNA")
(3495 . "SINHALA LETTER ALPAPRAANA TTAYANNA")
(3496 . "SINHALA LETTER MAHAAPRAANA TTAYANNA")
(3497 . "SINHALA LETTER ALPAPRAANA DDAYANNA")
(3498 . "SINHALA LETTER MAHAAPRAANA DDAYANNA")
(3499 . "SINHALA LETTER MUURDHAJA NAYANNA")
(3500 . "SINHALA LETTER SANYAKA DDAYANNA")
(3501 . "SINHALA LETTER ALPAPRAANA TAYANNA")
(3502 . "SINHALA LETTER MAHAAPRAANA TAYANNA")
(3503 . "SINHALA LETTER ALPAPRAANA DAYANNA")
(3504 . "SINHALA LETTER MAHAAPRAANA DAYANNA")
(3505 . "SINHALA LETTER DANTAJA NAYANNA")
(3506 . #f)
(3507 . "SINHALA LETTER SANYAKA DAYANNA")
(3508 . "SINHALA LETTER ALPAPRAANA PAYANNA")
(3509 . "SINHALA LETTER MAHAAPRAANA PAYANNA")
(3510 . "SINHALA LETTER ALPAPRAANA BAYANNA")
(3511 . "SINHALA LETTER MAHAAPRAANA BAYANNA")
(3512 . "SINHALA LETTER MAYANNA")
(3513 . "SINHALA LETTER AMBA BAYANNA")
(3514 . "SINHALA LETTER YAYANNA")
(3515 . "SINHALA LETTER RAYANNA")
(3516 . #f)
(3517 . "SINHALA LETTER DANTAJA LAYANNA")
((3518 . 3520) . #f)
(3520 . "SINHALA LETTER VAYANNA")
(3521 . "SINHALA LETTER TAALUJA SAYANNA")
(3522 . "SINHALA LETTER MUURDHAJA SAYANNA")
(3523 . "SINHALA LETTER DANTAJA SAYANNA")
(3524 . "SINHALA LETTER HAYANNA")
(3525 . "SINHALA LETTER MUURDHAJA LAYANNA")
(3526 . "SINHALA LETTER FAYANNA")
((3527 . 3530) . #f)
(3530 . "SINHALA SIGN AL-LAKUNA")
((3531 . 3535) . #f)
(3535 . "SINHALA VOWEL SIGN AELA-PILLA")
(3536 . "SINHALA VOWEL SIGN KETTI AEDA-PILLA")
(3537 . "SINHALA VOWEL SIGN DIGA AEDA-PILLA")
(3538 . "SINHALA VOWEL SIGN KETTI IS-PILLA")
(3539 . "SINHALA VOWEL SIGN DIGA IS-PILLA")
(3540 . "SINHALA VOWEL SIGN KETTI PAA-PILLA")
(3541 . #f)
(3542 . "SINHALA VOWEL SIGN DIGA PAA-PILLA")
(3543 . #f)
(3544 . "SINHALA VOWEL SIGN GAETTA-PILLA")
(3545 . "SINHALA VOWEL SIGN KOMBUVA")
(3546 . "SINHALA VOWEL SIGN DIGA KOMBUVA")
(3547 . "SINHALA VOWEL SIGN KOMBU DEKA")
(3548 . "SINHALA VOWEL SIGN KOMBUVA HAA AELA-PILLA")
(3549 . "SINHALA VOWEL SIGN KOMBUVA HAA DIGA AELA-PILLA")
(3550 . "SINHALA VOWEL SIGN KOMBUVA HAA GAYANUKITTA")
(3551 . "SINHALA VOWEL SIGN GAYANUKITTA")
((3552 . 3558) . #f)
(3558 . "SINHALA LITH DIGIT ZERO")
(3559 . "SINHALA LITH DIGIT ONE")
(3560 . "SINHALA LITH DIGIT TWO")
(3561 . "SINHALA LITH DIGIT THREE")
(3562 . "SINHALA LITH DIGIT FOUR")
(3563 . "SINHALA LITH DIGIT FIVE")
(3564 . "SINHALA LITH DIGIT SIX")
(3565 . "SINHALA LITH DIGIT SEVEN")
(3566 . "SINHALA LITH DIGIT EIGHT")
(3567 . "SINHALA LITH DIGIT NINE")
((3568 . 3570) . #f)
(3570 . "SINHALA VOWEL SIGN DIGA GAETTA-PILLA")
(3571 . "SINHALA VOWEL SIGN DIGA GAYANUKITTA")
(3572 . "SINHALA PUNCTUATION KUNDDALIYA")
((3573 . 3585) . #f)
(3585 . "THAI CHARACTER KO KAI")
(3586 . "THAI CHARACTER KHO KHAI")
(3587 . "THAI CHARACTER KHO KHUAT")
(3588 . "THAI CHARACTER KHO KHWAI")
(3589 . "THAI CHARACTER KHO KHON")
(3590 . "THAI CHARACTER KHO RAKHANG")
(3591 . "THAI CHARACTER NGO NGU")
(3592 . "THAI CHARACTER CHO CHAN")
(3593 . "THAI CHARACTER CHO CHING")
(3594 . "THAI CHARACTER CHO CHANG")
(3595 . "THAI CHARACTER SO SO")
(3596 . "THAI CHARACTER CHO CHOE")
(3597 . "THAI CHARACTER YO YING")
(3598 . "THAI CHARACTER DO CHADA")
(3599 . "THAI CHARACTER TO PATAK")
(3600 . "THAI CHARACTER THO THAN")
(3601 . "THAI CHARACTER THO NANGMONTHO")
(3602 . "THAI CHARACTER THO PHUTHAO")
(3603 . "THAI CHARACTER NO NEN")
(3604 . "THAI CHARACTER DO DEK")
(3605 . "THAI CHARACTER TO TAO")
(3606 . "THAI CHARACTER THO THUNG")
(3607 . "THAI CHARACTER THO THAHAN")
(3608 . "THAI CHARACTER THO THONG")
(3609 . "THAI CHARACTER NO NU")
(3610 . "THAI CHARACTER BO BAIMAI")
(3611 . "THAI CHARACTER PO PLA")
(3612 . "THAI CHARACTER PHO PHUNG")
(3613 . "THAI CHARACTER FO FA")
(3614 . "THAI CHARACTER PHO PHAN")
(3615 . "THAI CHARACTER FO FAN")
(3616 . "THAI CHARACTER PHO SAMPHAO")
(3617 . "THAI CHARACTER MO MA")
(3618 . "THAI CHARACTER YO YAK")
(3619 . "THAI CHARACTER RO RUA")
(3620 . "THAI CHARACTER RU")
(3621 . "THAI CHARACTER LO LING")
(3622 . "THAI CHARACTER LU")
(3623 . "THAI CHARACTER WO WAEN")
(3624 . "THAI CHARACTER SO SALA")
(3625 . "THAI CHARACTER SO RUSI")
(3626 . "THAI CHARACTER SO SUA")
(3627 . "THAI CHARACTER HO HIP")
(3628 . "THAI CHARACTER LO CHULA")
(3629 . "THAI CHARACTER O ANG")
(3630 . "THAI CHARACTER HO NOKHUK")
(3631 . "THAI CHARACTER PAIYANNOI")
(3632 . "THAI CHARACTER SARA A")
(3633 . "THAI CHARACTER MAI HAN-AKAT")
(3634 . "THAI CHARACTER SARA AA")
(3635 . "THAI CHARACTER SARA AM")
(3636 . "THAI CHARACTER SARA I")
(3637 . "THAI CHARACTER SARA II")
(3638 . "THAI CHARACTER SARA UE")
(3639 . "THAI CHARACTER SARA UEE")
(3640 . "THAI CHARACTER SARA U")
(3641 . "THAI CHARACTER SARA UU")
(3642 . "THAI CHARACTER PHINTHU")
((3643 . 3647) . #f)
(3647 . "THAI CURRENCY SYMBOL BAHT")
(3648 . "THAI CHARACTER SARA E")
(3649 . "THAI CHARACTER SARA AE")
(3650 . "THAI CHARACTER SARA O")
(3651 . "THAI CHARACTER SARA AI MAIMUAN")
(3652 . "THAI CHARACTER SARA AI MAIMALAI")
(3653 . "THAI CHARACTER LAKKHANGYAO")
(3654 . "THAI CHARACTER MAIYAMOK")
(3655 . "THAI CHARACTER MAITAIKHU")
(3656 . "THAI CHARACTER MAI EK")
(3657 . "THAI CHARACTER MAI THO")
(3658 . "THAI CHARACTER MAI TRI")
(3659 . "THAI CHARACTER MAI CHATTAWA")
(3660 . "THAI CHARACTER THANTHAKHAT")
(3661 . "THAI CHARACTER NIKHAHIT")
(3662 . "THAI CHARACTER YAMAKKAN")
(3663 . "THAI CHARACTER FONGMAN")
(3664 . "THAI DIGIT ZERO")
(3665 . "THAI DIGIT ONE")
(3666 . "THAI DIGIT TWO")
(3667 . "THAI DIGIT THREE")
(3668 . "THAI DIGIT FOUR")
(3669 . "THAI DIGIT FIVE")
(3670 . "THAI DIGIT SIX")
(3671 . "THAI DIGIT SEVEN")
(3672 . "THAI DIGIT EIGHT")
(3673 . "THAI DIGIT NINE")
(3674 . "THAI CHARACTER ANGKHANKHU")
(3675 . "THAI CHARACTER KHOMUT")
((3676 . 3713) . #f)
(3713 . "LAO LETTER KO")
(3714 . "LAO LETTER KHO SUNG")
(3715 . #f)
(3716 . "LAO LETTER KHO TAM")
((3717 . 3719) . #f)
(3719 . "LAO LETTER NGO")
(3720 . "LAO LETTER CO")
(3721 . #f)
(3722 . "LAO LETTER SO TAM")
((3723 . 3725) . #f)
(3725 . "LAO LETTER NYO")
((3726 . 3732) . #f)
(3732 . "LAO LETTER DO")
(3733 . "LAO LETTER TO")
(3734 . "LAO LETTER THO SUNG")
(3735 . "LAO LETTER THO TAM")
(3736 . #f)
(3737 . "LAO LETTER NO")
(3738 . "LAO LETTER BO")
(3739 . "LAO LETTER PO")
(3740 . "LAO LETTER PHO SUNG")
(3741 . "LAO LETTER FO TAM")
(3742 . "LAO LETTER PHO TAM")
(3743 . "LAO LETTER FO SUNG")
(3744 . #f)
(3745 . "LAO LETTER MO")
(3746 . "LAO LETTER YO")
(3747 . "LAO LETTER LO LING")
(3748 . #f)
(3749 . "LAO LETTER LO LOOT")
(3750 . #f)
(3751 . "LAO LETTER WO")
((3752 . 3754) . #f)
(3754 . "LAO LETTER SO SUNG")
(3755 . "LAO LETTER HO SUNG")
(3756 . #f)
(3757 . "LAO LETTER O")
(3758 . "LAO LETTER HO TAM")
(3759 . "LAO ELLIPSIS")
(3760 . "LAO VOWEL SIGN A")
(3761 . "LAO VOWEL SIGN MAI KAN")
(3762 . "LAO VOWEL SIGN AA")
(3763 . "LAO VOWEL SIGN AM")
(3764 . "LAO VOWEL SIGN I")
(3765 . "LAO VOWEL SIGN II")
(3766 . "LAO VOWEL SIGN Y")
(3767 . "LAO VOWEL SIGN YY")
(3768 . "LAO VOWEL SIGN U")
(3769 . "LAO VOWEL SIGN UU")
(3770 . #f)
(3771 . "LAO VOWEL SIGN MAI KON")
(3772 . "LAO SEMIVOWEL SIGN LO")
(3773 . "LAO SEMIVOWEL SIGN NYO")
((3774 . 3776) . #f)
(3776 . "LAO VOWEL SIGN E")
(3777 . "LAO VOWEL SIGN EI")
(3778 . "LAO VOWEL SIGN O")
(3779 . "LAO VOWEL SIGN AY")
(3780 . "LAO VOWEL SIGN AI")
(3781 . #f)
(3782 . "LAO KO LA")
(3783 . #f)
(3784 . "LAO TONE MAI EK")
(3785 . "LAO TONE MAI THO")
(3786 . "LAO TONE MAI TI")
(3787 . "LAO TONE MAI CATAWA")
(3788 . "LAO CANCELLATION MARK")
(3789 . "LAO NIGGAHITA")
((3790 . 3792) . #f)
(3792 . "LAO DIGIT ZERO")
(3793 . "LAO DIGIT ONE")
(3794 . "LAO DIGIT TWO")
(3795 . "LAO DIGIT THREE")
(3796 . "LAO DIGIT FOUR")
(3797 . "LAO DIGIT FIVE")
(3798 . "LAO DIGIT SIX")
(3799 . "LAO DIGIT SEVEN")
(3800 . "LAO DIGIT EIGHT")
(3801 . "LAO DIGIT NINE")
((3802 . 3804) . #f)
(3804 . "LAO HO NO")
(3805 . "LAO HO MO")
(3806 . "LAO LETTER KHMU GO")
(3807 . "LAO LETTER KHMU NYO")
((3808 . 3840) . #f)
(3840 . "TIBETAN SYLLABLE OM")
(3841 . "TIBETAN MARK GTER YIG MGO TRUNCATED A")
(3842 . "TIBETAN MARK GTER YIG MGO -UM RNAM BCAD MA")
(3843 . "TIBETAN MARK GTER YIG MGO -UM GTER TSHEG MA")
(3844 . "TIBETAN MARK INITIAL YIG MGO MDUN MA")
(3845 . "TIBETAN MARK CLOSING YIG MGO SGAB MA")
(3846 . "TIBETAN MARK CARET YIG MGO PHUR SHAD MA")
(3847 . "TIBETAN MARK YIG MGO TSHEG SHAD MA")
(3848 . "TIBETAN MARK SBRUL SHAD")
(3849 . "TIBETAN MARK BSKUR YIG MGO")
(3850 . "TIBETAN MARK BKA- SHOG YIG MGO")
(3851 . "TIBETAN MARK INTERSYLLABIC TSHEG")
(3852 . "TIBETAN MARK DELIMITER TSHEG BSTAR")
(3853 . "TIBETAN MARK SHAD")
(3854 . "TIBETAN MARK NYIS SHAD")
(3855 . "TIBETAN MARK TSHEG SHAD")
(3856 . "TIBETAN MARK NYIS TSHEG SHAD")
(3857 . "TIBETAN MARK RIN CHEN SPUNGS SHAD")
(3858 . "TIBETAN MARK RGYA GRAM SHAD")
(3859 . "TIBETAN MARK CARET -DZUD RTAGS ME LONG CAN")
(3860 . "TIBETAN MARK GTER TSHEG")
(3861 . "TIBETAN LOGOTYPE SIGN CHAD RTAGS")
(3862 . "TIBETAN LOGOTYPE SIGN LHAG RTAGS")
(3863 . "TIBETAN ASTROLOGICAL SIGN SGRA GCAN -CHAR RTAGS")
(3864 . "TIBETAN ASTROLOGICAL SIGN -KHYUD PA")
(3865 . "TIBETAN ASTROLOGICAL SIGN SDONG TSHUGS")
(3866 . "TIBETAN SIGN RDEL DKAR GCIG")
(3867 . "TIBETAN SIGN RDEL DKAR GNYIS")
(3868 . "TIBETAN SIGN RDEL DKAR GSUM")
(3869 . "TIBETAN SIGN RDEL NAG GCIG")
(3870 . "TIBETAN SIGN RDEL NAG GNYIS")
(3871 . "TIBETAN SIGN RDEL DKAR RDEL NAG")
(3872 . "TIBETAN DIGIT ZERO")
(3873 . "TIBETAN DIGIT ONE")
(3874 . "TIBETAN DIGIT TWO")
(3875 . "TIBETAN DIGIT THREE")
(3876 . "TIBETAN DIGIT FOUR")
(3877 . "TIBETAN DIGIT FIVE")
(3878 . "TIBETAN DIGIT SIX")
(3879 . "TIBETAN DIGIT SEVEN")
(3880 . "TIBETAN DIGIT EIGHT")
(3881 . "TIBETAN DIGIT NINE")
(3882 . "TIBETAN DIGIT HALF ONE")
(3883 . "TIBETAN DIGIT HALF TWO")
(3884 . "TIBETAN DIGIT HALF THREE")
(3885 . "TIBETAN DIGIT HALF FOUR")
(3886 . "TIBETAN DIGIT HALF FIVE")
(3887 . "TIBETAN DIGIT HALF SIX")
(3888 . "TIBETAN DIGIT HALF SEVEN")
(3889 . "TIBETAN DIGIT HALF EIGHT")
(3890 . "TIBETAN DIGIT HALF NINE")
(3891 . "TIBETAN DIGIT HALF ZERO")
(3892 . "TIBETAN MARK BSDUS RTAGS")
(3893 . "TIBETAN MARK NGAS BZUNG NYI ZLA")
(3894 . "TIBETAN MARK CARET -DZUD RTAGS BZHI MIG CAN")
(3895 . "TIBETAN MARK NGAS BZUNG SGOR RTAGS")
(3896 . "TIBETAN MARK CHE MGO")
(3897 . "TIBETAN MARK TSA -PHRU")
(3898 . "TIBETAN MARK GUG RTAGS GYON")
(3899 . "TIBETAN MARK GUG RTAGS GYAS")
(3900 . "TIBETAN MARK ANG KHANG GYON")
(3901 . "TIBETAN MARK ANG KHANG GYAS")
(3902 . "TIBETAN SIGN YAR TSHES")
(3903 . "TIBETAN SIGN MAR TSHES")
(3904 . "TIBETAN LETTER KA")
(3905 . "TIBETAN LETTER KHA")
(3906 . "TIBETAN LETTER GA")
(3907 . "TIBETAN LETTER GHA")
(3908 . "TIBETAN LETTER NGA")
(3909 . "TIBETAN LETTER CA")
(3910 . "TIBETAN LETTER CHA")
(3911 . "TIBETAN LETTER JA")
(3912 . #f)
(3913 . "TIBETAN LETTER NYA")
(3914 . "TIBETAN LETTER TTA")
(3915 . "TIBETAN LETTER TTHA")
(3916 . "TIBETAN LETTER DDA")
(3917 . "TIBETAN LETTER DDHA")
(3918 . "TIBETAN LETTER NNA")
(3919 . "TIBETAN LETTER TA")
(3920 . "TIBETAN LETTER THA")
(3921 . "TIBETAN LETTER DA")
(3922 . "TIBETAN LETTER DHA")
(3923 . "TIBETAN LETTER NA")
(3924 . "TIBETAN LETTER PA")
(3925 . "TIBETAN LETTER PHA")
(3926 . "TIBETAN LETTER BA")
(3927 . "TIBETAN LETTER BHA")
(3928 . "TIBETAN LETTER MA")
(3929 . "TIBETAN LETTER TSA")
(3930 . "TIBETAN LETTER TSHA")
(3931 . "TIBETAN LETTER DZA")
(3932 . "TIBETAN LETTER DZHA")
(3933 . "TIBETAN LETTER WA")
(3934 . "TIBETAN LETTER ZHA")
(3935 . "TIBETAN LETTER ZA")
(3936 . "TIBETAN LETTER -A")
(3937 . "TIBETAN LETTER YA")
(3938 . "TIBETAN LETTER RA")
(3939 . "TIBETAN LETTER LA")
(3940 . "TIBETAN LETTER SHA")
(3941 . "TIBETAN LETTER SSA")
(3942 . "TIBETAN LETTER SA")
(3943 . "TIBETAN LETTER HA")
(3944 . "TIBETAN LETTER A")
(3945 . "TIBETAN LETTER KSSA")
(3946 . "TIBETAN LETTER FIXED-FORM RA")
(3947 . "TIBETAN LETTER KKA")
(3948 . "TIBETAN LETTER RRA")
((3949 . 3953) . #f)
(3953 . "TIBETAN VOWEL SIGN AA")
(3954 . "TIBETAN VOWEL SIGN I")
(3955 . "TIBETAN VOWEL SIGN II")
(3956 . "TIBETAN VOWEL SIGN U")
(3957 . "TIBETAN VOWEL SIGN UU")
(3958 . "TIBETAN VOWEL SIGN VOCALIC R")
(3959 . "TIBETAN VOWEL SIGN VOCALIC RR")
(3960 . "TIBETAN VOWEL SIGN VOCALIC L")
(3961 . "TIBETAN VOWEL SIGN VOCALIC LL")
(3962 . "TIBETAN VOWEL SIGN E")
(3963 . "TIBETAN VOWEL SIGN EE")
(3964 . "TIBETAN VOWEL SIGN O")
(3965 . "TIBETAN VOWEL SIGN OO")
(3966 . "TIBETAN SIGN RJES SU NGA RO")
(3967 . "TIBETAN SIGN RNAM BCAD")
(3968 . "TIBETAN VOWEL SIGN REVERSED I")
(3969 . "TIBETAN VOWEL SIGN REVERSED II")
(3970 . "TIBETAN SIGN NYI ZLA NAA DA")
(3971 . "TIBETAN SIGN SNA LDAN")
(3972 . "TIBETAN MARK HALANTA")
(3973 . "TIBETAN MARK PALUTA")
(3974 . "TIBETAN SIGN LCI RTAGS")
(3975 . "TIBETAN SIGN YANG RTAGS")
(3976 . "TIBETAN SIGN LCE TSA CAN")
(3977 . "TIBETAN SIGN MCHU CAN")
(3978 . "TIBETAN SIGN GRU CAN RGYINGS")
(3979 . "TIBETAN SIGN GRU MED RGYINGS")
(3980 . "TIBETAN SIGN INVERTED MCHU CAN")
(3981 . "TIBETAN SUBJOINED SIGN LCE TSA CAN")
(3982 . "TIBETAN SUBJOINED SIGN MCHU CAN")
(3983 . "TIBETAN SUBJOINED SIGN INVERTED MCHU CAN")
(3984 . "TIBETAN SUBJOINED LETTER KA")
(3985 . "TIBETAN SUBJOINED LETTER KHA")
(3986 . "TIBETAN SUBJOINED LETTER GA")
(3987 . "TIBETAN SUBJOINED LETTER GHA")
(3988 . "TIBETAN SUBJOINED LETTER NGA")
(3989 . "TIBETAN SUBJOINED LETTER CA")
(3990 . "TIBETAN SUBJOINED LETTER CHA")
(3991 . "TIBETAN SUBJOINED LETTER JA")
(3992 . #f)
(3993 . "TIBETAN SUBJOINED LETTER NYA")
(3994 . "TIBETAN SUBJOINED LETTER TTA")
(3995 . "TIBETAN SUBJOINED LETTER TTHA")
(3996 . "TIBETAN SUBJOINED LETTER DDA")
(3997 . "TIBETAN SUBJOINED LETTER DDHA")
(3998 . "TIBETAN SUBJOINED LETTER NNA")
(3999 . "TIBETAN SUBJOINED LETTER TA")
(4000 . "TIBETAN SUBJOINED LETTER THA")
(4001 . "TIBETAN SUBJOINED LETTER DA")
(4002 . "TIBETAN SUBJOINED LETTER DHA")
(4003 . "TIBETAN SUBJOINED LETTER NA")
(4004 . "TIBETAN SUBJOINED LETTER PA")
(4005 . "TIBETAN SUBJOINED LETTER PHA")
(4006 . "TIBETAN SUBJOINED LETTER BA")
(4007 . "TIBETAN SUBJOINED LETTER BHA")
(4008 . "TIBETAN SUBJOINED LETTER MA")
(4009 . "TIBETAN SUBJOINED LETTER TSA")
(4010 . "TIBETAN SUBJOINED LETTER TSHA")
(4011 . "TIBETAN SUBJOINED LETTER DZA")
(4012 . "TIBETAN SUBJOINED LETTER DZHA")
(4013 . "TIBETAN SUBJOINED LETTER WA")
(4014 . "TIBETAN SUBJOINED LETTER ZHA")
(4015 . "TIBETAN SUBJOINED LETTER ZA")
(4016 . "TIBETAN SUBJOINED LETTER -A")
(4017 . "TIBETAN SUBJOINED LETTER YA")
(4018 . "TIBETAN SUBJOINED LETTER RA")
(4019 . "TIBETAN SUBJOINED LETTER LA")
(4020 . "TIBETAN SUBJOINED LETTER SHA")
(4021 . "TIBETAN SUBJOINED LETTER SSA")
(4022 . "TIBETAN SUBJOINED LETTER SA")
(4023 . "TIBETAN SUBJOINED LETTER HA")
(4024 . "TIBETAN SUBJOINED LETTER A")
(4025 . "TIBETAN SUBJOINED LETTER KSSA")
(4026 . "TIBETAN SUBJOINED LETTER FIXED-FORM WA")
(4027 . "TIBETAN SUBJOINED LETTER FIXED-FORM YA")
(4028 . "TIBETAN SUBJOINED LETTER FIXED-FORM RA")
(4029 . #f)
(4030 . "TIBETAN KU RU KHA")
(4031 . "TIBETAN KU RU KHA BZHI MIG CAN")
(4032 . "TIBETAN CANTILLATION SIGN HEAVY BEAT")
(4033 . "TIBETAN CANTILLATION SIGN LIGHT BEAT")
(4034 . "TIBETAN CANTILLATION SIGN CANG TE-U")
(4035 . "TIBETAN CANTILLATION SIGN SBUB -CHAL")
(4036 . "TIBETAN SYMBOL DRIL BU")
(4037 . "TIBETAN SYMBOL RDO RJE")
(4038 . "TIBETAN SYMBOL PADMA GDAN")
(4039 . "TIBETAN SYMBOL RDO RJE RGYA GRAM")
(4040 . "TIBETAN SYMBOL PHUR PA")
(4041 . "TIBETAN SYMBOL NOR BU")
(4042 . "TIBETAN SYMBOL NOR BU NYIS -KHYIL")
(4043 . "TIBETAN SYMBOL NOR BU GSUM -KHYIL")
(4044 . "TIBETAN SYMBOL NOR BU BZHI -KHYIL")
(4045 . #f)
(4046 . "TIBETAN SIGN RDEL NAG RDEL DKAR")
(4047 . "TIBETAN SIGN RDEL NAG GSUM")
(4048 . "TIBETAN MARK BSKA- SHOG GI MGO RGYAN")
(4049 . "TIBETAN MARK MNYAM YIG GI MGO RGYAN")
(4050 . "TIBETAN MARK NYIS TSHEG")
(4051 . "TIBETAN MARK INITIAL BRDA RNYING YIG MGO MDUN MA")
(4052 . "TIBETAN MARK CLOSING BRDA RNYING YIG MGO SGAB MA")
(4053 . "RIGHT-FACING SVASTI SIGN")
(4054 . "LEFT-FACING SVASTI SIGN")
(4055 . "RIGHT-FACING SVASTI SIGN WITH DOTS")
(4056 . "LEFT-FACING SVASTI SIGN WITH DOTS")
(4057 . "TIBETAN MARK LEADING MCHAN RTAGS")
(4058 . "TIBETAN MARK TRAILING MCHAN RTAGS")
((4059 . 4096) . #f)
(4096 . "MYANMAR LETTER KA")
(4097 . "MYANMAR LETTER KHA")
(4098 . "MYANMAR LETTER GA")
(4099 . "MYANMAR LETTER GHA")
(4100 . "MYANMAR LETTER NGA")
(4101 . "MYANMAR LETTER CA")
(4102 . "MYANMAR LETTER CHA")
(4103 . "MYANMAR LETTER JA")
(4104 . "MYANMAR LETTER JHA")
(4105 . "MYANMAR LETTER NYA")
(4106 . "MYANMAR LETTER NNYA")
(4107 . "MYANMAR LETTER TTA")
(4108 . "MYANMAR LETTER TTHA")
(4109 . "MYANMAR LETTER DDA")
(4110 . "MYANMAR LETTER DDHA")
(4111 . "MYANMAR LETTER NNA")
(4112 . "MYANMAR LETTER TA")
(4113 . "MYANMAR LETTER THA")
(4114 . "MYANMAR LETTER DA")
(4115 . "MYANMAR LETTER DHA")
(4116 . "MYANMAR LETTER NA")
(4117 . "MYANMAR LETTER PA")
(4118 . "MYANMAR LETTER PHA")
(4119 . "MYANMAR LETTER BA")
(4120 . "MYANMAR LETTER BHA")
(4121 . "MYANMAR LETTER MA")
(4122 . "MYANMAR LETTER YA")
(4123 . "MYANMAR LETTER RA")
(4124 . "MYANMAR LETTER LA")
(4125 . "MYANMAR LETTER WA")
(4126 . "MYANMAR LETTER SA")
(4127 . "MYANMAR LETTER HA")
(4128 . "MYANMAR LETTER LLA")
(4129 . "MYANMAR LETTER A")
(4130 . "MYANMAR LETTER SHAN A")
(4131 . "MYANMAR LETTER I")
(4132 . "MYANMAR LETTER II")
(4133 . "MYANMAR LETTER U")
(4134 . "MYANMAR LETTER UU")
(4135 . "MYANMAR LETTER E")
(4136 . "MYANMAR LETTER MON E")
(4137 . "MYANMAR LETTER O")
(4138 . "MYANMAR LETTER AU")
(4139 . "MYANMAR VOWEL SIGN TALL AA")
(4140 . "MYANMAR VOWEL SIGN AA")
(4141 . "MYANMAR VOWEL SIGN I")
(4142 . "MYANMAR VOWEL SIGN II")
(4143 . "MYANMAR VOWEL SIGN U")
(4144 . "MYANMAR VOWEL SIGN UU")
(4145 . "MYANMAR VOWEL SIGN E")
(4146 . "MYANMAR VOWEL SIGN AI")
(4147 . "MYANMAR VOWEL SIGN MON II")
(4148 . "MYANMAR VOWEL SIGN MON O")
(4149 . "MYANMAR VOWEL SIGN E ABOVE")
(4150 . "MYANMAR SIGN ANUSVARA")
(4151 . "MYANMAR SIGN DOT BELOW")
(4152 . "MYANMAR SIGN VISARGA")
(4153 . "MYANMAR SIGN VIRAMA")
(4154 . "MYANMAR SIGN ASAT")
(4155 . "MYANMAR CONSONANT SIGN MEDIAL YA")
(4156 . "MYANMAR CONSONANT SIGN MEDIAL RA")
(4157 . "MYANMAR CONSONANT SIGN MEDIAL WA")
(4158 . "MYANMAR CONSONANT SIGN MEDIAL HA")
(4159 . "MYANMAR LETTER GREAT SA")
(4160 . "MYANMAR DIGIT ZERO")
(4161 . "MYANMAR DIGIT ONE")
(4162 . "MYANMAR DIGIT TWO")
(4163 . "MYANMAR DIGIT THREE")
(4164 . "MYANMAR DIGIT FOUR")
(4165 . "MYANMAR DIGIT FIVE")
(4166 . "MYANMAR DIGIT SIX")
(4167 . "MYANMAR DIGIT SEVEN")
(4168 . "MYANMAR DIGIT EIGHT")
(4169 . "MYANMAR DIGIT NINE")
(4170 . "MYANMAR SIGN LITTLE SECTION")
(4171 . "MYANMAR SIGN SECTION")
(4172 . "MYANMAR SYMBOL LOCATIVE")
(4173 . "MYANMAR SYMBOL COMPLETED")
(4174 . "MYANMAR SYMBOL AFOREMENTIONED")
(4175 . "MYANMAR SYMBOL GENITIVE")
(4176 . "MYANMAR LETTER SHA")
(4177 . "MYANMAR LETTER SSA")
(4178 . "MYANMAR LETTER VOCALIC R")
(4179 . "MYANMAR LETTER VOCALIC RR")
(4180 . "MYANMAR LETTER VOCALIC L")
(4181 . "MYANMAR LETTER VOCALIC LL")
(4182 . "MYANMAR VOWEL SIGN VOCALIC R")
(4183 . "MYANMAR VOWEL SIGN VOCALIC RR")
(4184 . "MYANMAR VOWEL SIGN VOCALIC L")
(4185 . "MYANMAR VOWEL SIGN VOCALIC LL")
(4186 . "MYANMAR LETTER MON NGA")
(4187 . "MYANMAR LETTER MON JHA")
(4188 . "MYANMAR LETTER MON BBA")
(4189 . "MYANMAR LETTER MON BBE")
(4190 . "MYANMAR CONSONANT SIGN MON MEDIAL NA")
(4191 . "MYANMAR CONSONANT SIGN MON MEDIAL MA")
(4192 . "MYANMAR CONSONANT SIGN MON MEDIAL LA")
(4193 . "MYANMAR LETTER SGAW KAREN SHA")
(4194 . "MYANMAR VOWEL SIGN SGAW KAREN EU")
(4195 . "MYANMAR TONE MARK SGAW KAREN HATHI")
(4196 . "MYANMAR TONE MARK SGAW KAREN KE PHO")
(4197 . "MYANMAR LETTER WESTERN PWO KAREN THA")
(4198 . "MYANMAR LETTER WESTERN PWO KAREN PWA")
(4199 . "MYANMAR VOWEL SIGN WESTERN PWO KAREN EU")
(4200 . "MYANMAR VOWEL SIGN WESTERN PWO KAREN UE")
(4201 . "MYANMAR SIGN WESTERN PWO KAREN TONE-1")
(4202 . "MYANMAR SIGN WESTERN PWO KAREN TONE-2")
(4203 . "MYANMAR SIGN WESTERN PWO KAREN TONE-3")
(4204 . "MYANMAR SIGN WESTERN PWO KAREN TONE-4")
(4205 . "MYANMAR SIGN WESTERN PWO KAREN TONE-5")
(4206 . "MYANMAR LETTER EASTERN PWO KAREN NNA")
(4207 . "MYANMAR LETTER EASTERN PWO KAREN YWA")
(4208 . "MYANMAR LETTER EASTERN PWO KAREN GHWA")
(4209 . "MYANMAR VOWEL SIGN GEBA KAREN I")
(4210 . "MYANMAR VOWEL SIGN KAYAH OE")
(4211 . "MYANMAR VOWEL SIGN KAYAH U")
(4212 . "MYANMAR VOWEL SIGN KAYAH EE")
(4213 . "MYANMAR LETTER SHAN KA")
(4214 . "MYANMAR LETTER SHAN KHA")
(4215 . "MYANMAR LETTER SHAN GA")
(4216 . "MYANMAR LETTER SHAN CA")
(4217 . "MYANMAR LETTER SHAN ZA")
(4218 . "MYANMAR LETTER SHAN NYA")
(4219 . "MYANMAR LETTER SHAN DA")
(4220 . "MYANMAR LETTER SHAN NA")
(4221 . "MYANMAR LETTER SHAN PHA")
(4222 . "MYANMAR LETTER SHAN FA")
(4223 . "MYANMAR LETTER SHAN BA")
(4224 . "MYANMAR LETTER SHAN THA")
(4225 . "MYANMAR LETTER SHAN HA")
(4226 . "MYANMAR CONSONANT SIGN SHAN MEDIAL WA")
(4227 . "MYANMAR VOWEL SIGN SHAN AA")
(4228 . "MYANMAR VOWEL SIGN SHAN E")
(4229 . "MYANMAR VOWEL SIGN SHAN E ABOVE")
(4230 . "MYANMAR VOWEL SIGN SHAN FINAL Y")
(4231 . "MYANMAR SIGN SHAN TONE-2")
(4232 . "MYANMAR SIGN SHAN TONE-3")
(4233 . "MYANMAR SIGN SHAN TONE-5")
(4234 . "MYANMAR SIGN SHAN TONE-6")
(4235 . "MYANMAR SIGN SHAN COUNCIL TONE-2")
(4236 . "MYANMAR SIGN SHAN COUNCIL TONE-3")
(4237 . "MYANMAR SIGN SHAN COUNCIL EMPHATIC TONE")
(4238 . "MYANMAR LETTER RUMAI PALAUNG FA")
(4239 . "MYANMAR SIGN RUMAI PALAUNG TONE-5")
(4240 . "MYANMAR SHAN DIGIT ZERO")
(4241 . "MYANMAR SHAN DIGIT ONE")
(4242 . "MYANMAR SHAN DIGIT TWO")
(4243 . "MYANMAR SHAN DIGIT THREE")
(4244 . "MYANMAR SHAN DIGIT FOUR")
(4245 . "MYANMAR SHAN DIGIT FIVE")
(4246 . "MYANMAR SHAN DIGIT SIX")
(4247 . "MYANMAR SHAN DIGIT SEVEN")
(4248 . "MYANMAR SHAN DIGIT EIGHT")
(4249 . "MYANMAR SHAN DIGIT NINE")
(4250 . "MYANMAR SIGN KHAMTI TONE-1")
(4251 . "MYANMAR SIGN KHAMTI TONE-3")
(4252 . "MYANMAR VOWEL SIGN AITON A")
(4253 . "MYANMAR VOWEL SIGN AITON AI")
(4254 . "MYANMAR SYMBOL SHAN ONE")
(4255 . "MYANMAR SYMBOL SHAN EXCLAMATION")
(4256 . "GEORGIAN CAPITAL LETTER AN")
(4257 . "GEORGIAN CAPITAL LETTER BAN")
(4258 . "GEORGIAN CAPITAL LETTER GAN")
(4259 . "GEORGIAN CAPITAL LETTER DON")
(4260 . "GEORGIAN CAPITAL LETTER EN")
(4261 . "GEORGIAN CAPITAL LETTER VIN")
(4262 . "GEORGIAN CAPITAL LETTER ZEN")
(4263 . "GEORGIAN CAPITAL LETTER TAN")
(4264 . "GEORGIAN CAPITAL LETTER IN")
(4265 . "GEORGIAN CAPITAL LETTER KAN")
(4266 . "GEORGIAN CAPITAL LETTER LAS")
(4267 . "GEORGIAN CAPITAL LETTER MAN")
(4268 . "GEORGIAN CAPITAL LETTER NAR")
(4269 . "GEORGIAN CAPITAL LETTER ON")
(4270 . "GEORGIAN CAPITAL LETTER PAR")
(4271 . "GEORGIAN CAPITAL LETTER ZHAR")
(4272 . "GEORGIAN CAPITAL LETTER RAE")
(4273 . "GEORGIAN CAPITAL LETTER SAN")
(4274 . "GEORGIAN CAPITAL LETTER TAR")
(4275 . "GEORGIAN CAPITAL LETTER UN")
(4276 . "GEORGIAN CAPITAL LETTER PHAR")
(4277 . "GEORGIAN CAPITAL LETTER KHAR")
(4278 . "GEORGIAN CAPITAL LETTER GHAN")
(4279 . "GEORGIAN CAPITAL LETTER QAR")
(4280 . "GEORGIAN CAPITAL LETTER SHIN")
(4281 . "GEORGIAN CAPITAL LETTER CHIN")
(4282 . "GEORGIAN CAPITAL LETTER CAN")
(4283 . "GEORGIAN CAPITAL LETTER JIL")
(4284 . "GEORGIAN CAPITAL LETTER CIL")
(4285 . "GEORGIAN CAPITAL LETTER CHAR")
(4286 . "GEORGIAN CAPITAL LETTER XAN")
(4287 . "GEORGIAN CAPITAL LETTER JHAN")
(4288 . "GEORGIAN CAPITAL LETTER HAE")
(4289 . "GEORGIAN CAPITAL LETTER HE")
(4290 . "GEORGIAN CAPITAL LETTER HIE")
(4291 . "GEORGIAN CAPITAL LETTER WE")
(4292 . "GEORGIAN CAPITAL LETTER HAR")
(4293 . "GEORGIAN CAPITAL LETTER HOE")
(4294 . #f)
(4295 . "GEORGIAN CAPITAL LETTER YN")
((4296 . 4301) . #f)
(4301 . "GEORGIAN CAPITAL LETTER AEN")
((4302 . 4304) . #f)
(4304 . "GEORGIAN LETTER AN")
(4305 . "GEORGIAN LETTER BAN")
(4306 . "GEORGIAN LETTER GAN")
(4307 . "GEORGIAN LETTER DON")
(4308 . "GEORGIAN LETTER EN")
(4309 . "GEORGIAN LETTER VIN")
(4310 . "GEORGIAN LETTER ZEN")
(4311 . "GEORGIAN LETTER TAN")
(4312 . "GEORGIAN LETTER IN")
(4313 . "GEORGIAN LETTER KAN")
(4314 . "GEORGIAN LETTER LAS")
(4315 . "GEORGIAN LETTER MAN")
(4316 . "GEORGIAN LETTER NAR")
(4317 . "GEORGIAN LETTER ON")
(4318 . "GEORGIAN LETTER PAR")
(4319 . "GEORGIAN LETTER ZHAR")
(4320 . "GEORGIAN LETTER RAE")
(4321 . "GEORGIAN LETTER SAN")
(4322 . "GEORGIAN LETTER TAR")
(4323 . "GEORGIAN LETTER UN")
(4324 . "GEORGIAN LETTER PHAR")
(4325 . "GEORGIAN LETTER KHAR")
(4326 . "GEORGIAN LETTER GHAN")
(4327 . "GEORGIAN LETTER QAR")
(4328 . "GEORGIAN LETTER SHIN")
(4329 . "GEORGIAN LETTER CHIN")
(4330 . "GEORGIAN LETTER CAN")
(4331 . "GEORGIAN LETTER JIL")
(4332 . "GEORGIAN LETTER CIL")
(4333 . "GEORGIAN LETTER CHAR")
(4334 . "GEORGIAN LETTER XAN")
(4335 . "GEORGIAN LETTER JHAN")
(4336 . "GEORGIAN LETTER HAE")
(4337 . "GEORGIAN LETTER HE")
(4338 . "GEORGIAN LETTER HIE")
(4339 . "GEORGIAN LETTER WE")
(4340 . "GEORGIAN LETTER HAR")
(4341 . "GEORGIAN LETTER HOE")
(4342 . "GEORGIAN LETTER FI")
(4343 . "GEORGIAN LETTER YN")
(4344 . "GEORGIAN LETTER ELIFI")
(4345 . "GEORGIAN LETTER TURNED GAN")
(4346 . "GEORGIAN LETTER AIN")
(4347 . "GEORGIAN PARAGRAPH SEPARATOR")
(4348 . "MODIFIER LETTER GEORGIAN NAR")
(4349 . "GEORGIAN LETTER AEN")
(4350 . "GEORGIAN LETTER HARD SIGN")
(4351 . "GEORGIAN LETTER LABIAL SIGN")
(4352 . "HANGUL CHOSEONG KIYEOK")
(4353 . "HANGUL CHOSEONG SSANGKIYEOK")
(4354 . "HANGUL CHOSEONG NIEUN")
(4355 . "HANGUL CHOSEONG TIKEUT")
(4356 . "HANGUL CHOSEONG SSANGTIKEUT")
(4357 . "HANGUL CHOSEONG RIEUL")
(4358 . "HANGUL CHOSEONG MIEUM")
(4359 . "HANGUL CHOSEONG PIEUP")
(4360 . "HANGUL CHOSEONG SSANGPIEUP")
(4361 . "HANGUL CHOSEONG SIOS")
(4362 . "HANGUL CHOSEONG SSANGSIOS")
(4363 . "HANGUL CHOSEONG IEUNG")
(4364 . "HANGUL CHOSEONG CIEUC")
(4365 . "HANGUL CHOSEONG SSANGCIEUC")
(4366 . "HANGUL CHOSEONG CHIEUCH")
(4367 . "HANGUL CHOSEONG KHIEUKH")
(4368 . "HANGUL CHOSEONG THIEUTH")
(4369 . "HANGUL CHOSEONG PHIEUPH")
(4370 . "HANGUL CHOSEONG HIEUH")
(4371 . "HANGUL CHOSEONG NIEUN-KIYEOK")
(4372 . "HANGUL CHOSEONG SSANGNIEUN")
(4373 . "HANGUL CHOSEONG NIEUN-TIKEUT")
(4374 . "HANGUL CHOSEONG NIEUN-PIEUP")
(4375 . "HANGUL CHOSEONG TIKEUT-KIYEOK")
(4376 . "HANGUL CHOSEONG RIEUL-NIEUN")
(4377 . "HANGUL CHOSEONG SSANGRIEUL")
(4378 . "HANGUL CHOSEONG RIEUL-HIEUH")
(4379 . "HANGUL CHOSEONG KAPYEOUNRIEUL")
(4380 . "HANGUL CHOSEONG MIEUM-PIEUP")
(4381 . "HANGUL CHOSEONG KAPYEOUNMIEUM")
(4382 . "HANGUL CHOSEONG PIEUP-KIYEOK")
(4383 . "HANGUL CHOSEONG PIEUP-NIEUN")
(4384 . "HANGUL CHOSEONG PIEUP-TIKEUT")
(4385 . "HANGUL CHOSEONG PIEUP-SIOS")
(4386 . "HANGUL CHOSEONG PIEUP-SIOS-KIYEOK")
(4387 . "HANGUL CHOSEONG PIEUP-SIOS-TIKEUT")
(4388 . "HANGUL CHOSEONG PIEUP-SIOS-PIEUP")
(4389 . "HANGUL CHOSEONG PIEUP-SSANGSIOS")
(4390 . "HANGUL CHOSEONG PIEUP-SIOS-CIEUC")
(4391 . "HANGUL CHOSEONG PIEUP-CIEUC")
(4392 . "HANGUL CHOSEONG PIEUP-CHIEUCH")
(4393 . "HANGUL CHOSEONG PIEUP-THIEUTH")
(4394 . "HANGUL CHOSEONG PIEUP-PHIEUPH")
(4395 . "HANGUL CHOSEONG KAPYEOUNPIEUP")
(4396 . "HANGUL CHOSEONG KAPYEOUNSSANGPIEUP")
(4397 . "HANGUL CHOSEONG SIOS-KIYEOK")
(4398 . "HANGUL CHOSEONG SIOS-NIEUN")
(4399 . "HANGUL CHOSEONG SIOS-TIKEUT")
(4400 . "HANGUL CHOSEONG SIOS-RIEUL")
(4401 . "HANGUL CHOSEONG SIOS-MIEUM")
(4402 . "HANGUL CHOSEONG SIOS-PIEUP")
(4403 . "HANGUL CHOSEONG SIOS-PIEUP-KIYEOK")
(4404 . "HANGUL CHOSEONG SIOS-SSANGSIOS")
(4405 . "HANGUL CHOSEONG SIOS-IEUNG")
(4406 . "HANGUL CHOSEONG SIOS-CIEUC")
(4407 . "HANGUL CHOSEONG SIOS-CHIEUCH")
(4408 . "HANGUL CHOSEONG SIOS-KHIEUKH")
(4409 . "HANGUL CHOSEONG SIOS-THIEUTH")
(4410 . "HANGUL CHOSEONG SIOS-PHIEUPH")
(4411 . "HANGUL CHOSEONG SIOS-HIEUH")
(4412 . "HANGUL CHOSEONG CHITUEUMSIOS")
(4413 . "HANGUL CHOSEONG CHITUEUMSSANGSIOS")
(4414 . "HANGUL CHOSEONG CEONGCHIEUMSIOS")
(4415 . "HANGUL CHOSEONG CEONGCHIEUMSSANGSIOS")
(4416 . "HANGUL CHOSEONG PANSIOS")
(4417 . "HANGUL CHOSEONG IEUNG-KIYEOK")
(4418 . "HANGUL CHOSEONG IEUNG-TIKEUT")
(4419 . "HANGUL CHOSEONG IEUNG-MIEUM")
(4420 . "HANGUL CHOSEONG IEUNG-PIEUP")
(4421 . "HANGUL CHOSEONG IEUNG-SIOS")
(4422 . "HANGUL CHOSEONG IEUNG-PANSIOS")
(4423 . "HANGUL CHOSEONG SSANGIEUNG")
(4424 . "HANGUL CHOSEONG IEUNG-CIEUC")
(4425 . "HANGUL CHOSEONG IEUNG-CHIEUCH")
(4426 . "HANGUL CHOSEONG IEUNG-THIEUTH")
(4427 . "HANGUL CHOSEONG IEUNG-PHIEUPH")
(4428 . "HANGUL CHOSEONG YESIEUNG")
(4429 . "HANGUL CHOSEONG CIEUC-IEUNG")
(4430 . "HANGUL CHOSEONG CHITUEUMCIEUC")
(4431 . "HANGUL CHOSEONG CHITUEUMSSANGCIEUC")
(4432 . "HANGUL CHOSEONG CEONGCHIEUMCIEUC")
(4433 . "HANGUL CHOSEONG CEONGCHIEUMSSANGCIEUC")
(4434 . "HANGUL CHOSEONG CHIEUCH-KHIEUKH")
(4435 . "HANGUL CHOSEONG CHIEUCH-HIEUH")
(4436 . "HANGUL CHOSEONG CHITUEUMCHIEUCH")
(4437 . "HANGUL CHOSEONG CEONGCHIEUMCHIEUCH")
(4438 . "HANGUL CHOSEONG PHIEUPH-PIEUP")
(4439 . "HANGUL CHOSEONG KAPYEOUNPHIEUPH")
(4440 . "HANGUL CHOSEONG SSANGHIEUH")
(4441 . "HANGUL CHOSEONG YEORINHIEUH")
(4442 . "HANGUL CHOSEONG KIYEOK-TIKEUT")
(4443 . "HANGUL CHOSEONG NIEUN-SIOS")
(4444 . "HANGUL CHOSEONG NIEUN-CIEUC")
(4445 . "HANGUL CHOSEONG NIEUN-HIEUH")
(4446 . "HANGUL CHOSEONG TIKEUT-RIEUL")
(4447 . "HANGUL CHOSEONG FILLER")
(4448 . "HANGUL JUNGSEONG FILLER")
(4449 . "HANGUL JUNGSEONG A")
(4450 . "HANGUL JUNGSEONG AE")
(4451 . "HANGUL JUNGSEONG YA")
(4452 . "HANGUL JUNGSEONG YAE")
(4453 . "HANGUL JUNGSEONG EO")
(4454 . "HANGUL JUNGSEONG E")
(4455 . "HANGUL JUNGSEONG YEO")
(4456 . "HANGUL JUNGSEONG YE")
(4457 . "HANGUL JUNGSEONG O")
(4458 . "HANGUL JUNGSEONG WA")
(4459 . "HANGUL JUNGSEONG WAE")
(4460 . "HANGUL JUNGSEONG OE")
(4461 . "HANGUL JUNGSEONG YO")
(4462 . "HANGUL JUNGSEONG U")
(4463 . "HANGUL JUNGSEONG WEO")
(4464 . "HANGUL JUNGSEONG WE")
(4465 . "HANGUL JUNGSEONG WI")
(4466 . "HANGUL JUNGSEONG YU")
(4467 . "HANGUL JUNGSEONG EU")
(4468 . "HANGUL JUNGSEONG YI")
(4469 . "HANGUL JUNGSEONG I")
(4470 . "HANGUL JUNGSEONG A-O")
(4471 . "HANGUL JUNGSEONG A-U")
(4472 . "HANGUL JUNGSEONG YA-O")
(4473 . "HANGUL JUNGSEONG YA-YO")
(4474 . "HANGUL JUNGSEONG EO-O")
(4475 . "HANGUL JUNGSEONG EO-U")
(4476 . "HANGUL JUNGSEONG EO-EU")
(4477 . "HANGUL JUNGSEONG YEO-O")
(4478 . "HANGUL JUNGSEONG YEO-U")
(4479 . "HANGUL JUNGSEONG O-EO")
(4480 . "HANGUL JUNGSEONG O-E")
(4481 . "HANGUL JUNGSEONG O-YE")
(4482 . "HANGUL JUNGSEONG O-O")
(4483 . "HANGUL JUNGSEONG O-U")
(4484 . "HANGUL JUNGSEONG YO-YA")
(4485 . "HANGUL JUNGSEONG YO-YAE")
(4486 . "HANGUL JUNGSEONG YO-YEO")
(4487 . "HANGUL JUNGSEONG YO-O")
(4488 . "HANGUL JUNGSEONG YO-I")
(4489 . "HANGUL JUNGSEONG U-A")
(4490 . "HANGUL JUNGSEONG U-AE")
(4491 . "HANGUL JUNGSEONG U-EO-EU")
(4492 . "HANGUL JUNGSEONG U-YE")
(4493 . "HANGUL JUNGSEONG U-U")
(4494 . "HANGUL JUNGSEONG YU-A")
(4495 . "HANGUL JUNGSEONG YU-EO")
(4496 . "HANGUL JUNGSEONG YU-E")
(4497 . "HANGUL JUNGSEONG YU-YEO")
(4498 . "HANGUL JUNGSEONG YU-YE")
(4499 . "HANGUL JUNGSEONG YU-U")
(4500 . "HANGUL JUNGSEONG YU-I")
(4501 . "HANGUL JUNGSEONG EU-U")
(4502 . "HANGUL JUNGSEONG EU-EU")
(4503 . "HANGUL JUNGSEONG YI-U")
(4504 . "HANGUL JUNGSEONG I-A")
(4505 . "HANGUL JUNGSEONG I-YA")
(4506 . "HANGUL JUNGSEONG I-O")
(4507 . "HANGUL JUNGSEONG I-U")
(4508 . "HANGUL JUNGSEONG I-EU")
(4509 . "HANGUL JUNGSEONG I-ARAEA")
(4510 . "HANGUL JUNGSEONG ARAEA")
(4511 . "HANGUL JUNGSEONG ARAEA-EO")
(4512 . "HANGUL JUNGSEONG ARAEA-U")
(4513 . "HANGUL JUNGSEONG ARAEA-I")
(4514 . "HANGUL JUNGSEONG SSANGARAEA")
(4515 . "HANGUL JUNGSEONG A-EU")
(4516 . "HANGUL JUNGSEONG YA-U")
(4517 . "HANGUL JUNGSEONG YEO-YA")
(4518 . "HANGUL JUNGSEONG O-YA")
(4519 . "HANGUL JUNGSEONG O-YAE")
(4520 . "HANGUL JONGSEONG KIYEOK")
(4521 . "HANGUL JONGSEONG SSANGKIYEOK")
(4522 . "HANGUL JONGSEONG KIYEOK-SIOS")
(4523 . "HANGUL JONGSEONG NIEUN")
(4524 . "HANGUL JONGSEONG NIEUN-CIEUC")
(4525 . "HANGUL JONGSEONG NIEUN-HIEUH")
(4526 . "HANGUL JONGSEONG TIKEUT")
(4527 . "HANGUL JONGSEONG RIEUL")
(4528 . "HANGUL JONGSEONG RIEUL-KIYEOK")
(4529 . "HANGUL JONGSEONG RIEUL-MIEUM")
(4530 . "HANGUL JONGSEONG RIEUL-PIEUP")
(4531 . "HANGUL JONGSEONG RIEUL-SIOS")
(4532 . "HANGUL JONGSEONG RIEUL-THIEUTH")
(4533 . "HANGUL JONGSEONG RIEUL-PHIEUPH")
(4534 . "HANGUL JONGSEONG RIEUL-HIEUH")
(4535 . "HANGUL JONGSEONG MIEUM")
(4536 . "HANGUL JONGSEONG PIEUP")
(4537 . "HANGUL JONGSEONG PIEUP-SIOS")
(4538 . "HANGUL JONGSEONG SIOS")
(4539 . "HANGUL JONGSEONG SSANGSIOS")
(4540 . "HANGUL JONGSEONG IEUNG")
(4541 . "HANGUL JONGSEONG CIEUC")
(4542 . "HANGUL JONGSEONG CHIEUCH")
(4543 . "HANGUL JONGSEONG KHIEUKH")
(4544 . "HANGUL JONGSEONG THIEUTH")
(4545 . "HANGUL JONGSEONG PHIEUPH")
(4546 . "HANGUL JONGSEONG HIEUH")
(4547 . "HANGUL JONGSEONG KIYEOK-RIEUL")
(4548 . "HANGUL JONGSEONG KIYEOK-SIOS-KIYEOK")
(4549 . "HANGUL JONGSEONG NIEUN-KIYEOK")
(4550 . "HANGUL JONGSEONG NIEUN-TIKEUT")
(4551 . "HANGUL JONGSEONG NIEUN-SIOS")
(4552 . "HANGUL JONGSEONG NIEUN-PANSIOS")
(4553 . "HANGUL JONGSEONG NIEUN-THIEUTH")
(4554 . "HANGUL JONGSEONG TIKEUT-KIYEOK")
(4555 . "HANGUL JONGSEONG TIKEUT-RIEUL")
(4556 . "HANGUL JONGSEONG RIEUL-KIYEOK-SIOS")
(4557 . "HANGUL JONGSEONG RIEUL-NIEUN")
(4558 . "HANGUL JONGSEONG RIEUL-TIKEUT")
(4559 . "HANGUL JONGSEONG RIEUL-TIKEUT-HIEUH")
(4560 . "HANGUL JONGSEONG SSANGRIEUL")
(4561 . "HANGUL JONGSEONG RIEUL-MIEUM-KIYEOK")
(4562 . "HANGUL JONGSEONG RIEUL-MIEUM-SIOS")
(4563 . "HANGUL JONGSEONG RIEUL-PIEUP-SIOS")
(4564 . "HANGUL JONGSEONG RIEUL-PIEUP-HIEUH")
(4565 . "HANGUL JONGSEONG RIEUL-KAPYEOUNPIEUP")
(4566 . "HANGUL JONGSEONG RIEUL-SSANGSIOS")
(4567 . "HANGUL JONGSEONG RIEUL-PANSIOS")
(4568 . "HANGUL JONGSEONG RIEUL-KHIEUKH")
(4569 . "HANGUL JONGSEONG RIEUL-YEORINHIEUH")
(4570 . "HANGUL JONGSEONG MIEUM-KIYEOK")
(4571 . "HANGUL JONGSEONG MIEUM-RIEUL")
(4572 . "HANGUL JONGSEONG MIEUM-PIEUP")
(4573 . "HANGUL JONGSEONG MIEUM-SIOS")
(4574 . "HANGUL JONGSEONG MIEUM-SSANGSIOS")
(4575 . "HANGUL JONGSEONG MIEUM-PANSIOS")
(4576 . "HANGUL JONGSEONG MIEUM-CHIEUCH")
(4577 . "HANGUL JONGSEONG MIEUM-HIEUH")
(4578 . "HANGUL JONGSEONG KAPYEOUNMIEUM")
(4579 . "HANGUL JONGSEONG PIEUP-RIEUL")
(4580 . "HANGUL JONGSEONG PIEUP-PHIEUPH")
(4581 . "HANGUL JONGSEONG PIEUP-HIEUH")
(4582 . "HANGUL JONGSEONG KAPYEOUNPIEUP")
(4583 . "HANGUL JONGSEONG SIOS-KIYEOK")
(4584 . "HANGUL JONGSEONG SIOS-TIKEUT")
(4585 . "HANGUL JONGSEONG SIOS-RIEUL")
(4586 . "HANGUL JONGSEONG SIOS-PIEUP")
(4587 . "HANGUL JONGSEONG PANSIOS")
(4588 . "HANGUL JONGSEONG IEUNG-KIYEOK")
(4589 . "HANGUL JONGSEONG IEUNG-SSANGKIYEOK")
(4590 . "HANGUL JONGSEONG SSANGIEUNG")
(4591 . "HANGUL JONGSEONG IEUNG-KHIEUKH")
(4592 . "HANGUL JONGSEONG YESIEUNG")
(4593 . "HANGUL JONGSEONG YESIEUNG-SIOS")
(4594 . "HANGUL JONGSEONG YESIEUNG-PANSIOS")
(4595 . "HANGUL JONGSEONG PHIEUPH-PIEUP")
(4596 . "HANGUL JONGSEONG KAPYEOUNPHIEUPH")
(4597 . "HANGUL JONGSEONG HIEUH-NIEUN")
(4598 . "HANGUL JONGSEONG HIEUH-RIEUL")
(4599 . "HANGUL JONGSEONG HIEUH-MIEUM")
(4600 . "HANGUL JONGSEONG HIEUH-PIEUP")
(4601 . "HANGUL JONGSEONG YEORINHIEUH")
(4602 . "HANGUL JONGSEONG KIYEOK-NIEUN")
(4603 . "HANGUL JONGSEONG KIYEOK-PIEUP")
(4604 . "HANGUL JONGSEONG KIYEOK-CHIEUCH")
(4605 . "HANGUL JONGSEONG KIYEOK-KHIEUKH")
(4606 . "HANGUL JONGSEONG KIYEOK-HIEUH")
(4607 . "HANGUL JONGSEONG SSANGNIEUN")
(4608 . "ETHIOPIC SYLLABLE HA")
(4609 . "ETHIOPIC SYLLABLE HU")
(4610 . "ETHIOPIC SYLLABLE HI")
(4611 . "ETHIOPIC SYLLABLE HAA")
(4612 . "ETHIOPIC SYLLABLE HEE")
(4613 . "ETHIOPIC SYLLABLE HE")
(4614 . "ETHIOPIC SYLLABLE HO")
(4615 . "ETHIOPIC SYLLABLE HOA")
(4616 . "ETHIOPIC SYLLABLE LA")
(4617 . "ETHIOPIC SYLLABLE LU")
(4618 . "ETHIOPIC SYLLABLE LI")
(4619 . "ETHIOPIC SYLLABLE LAA")
(4620 . "ETHIOPIC SYLLABLE LEE")
(4621 . "ETHIOPIC SYLLABLE LE")
(4622 . "ETHIOPIC SYLLABLE LO")
(4623 . "ETHIOPIC SYLLABLE LWA")
(4624 . "ETHIOPIC SYLLABLE HHA")
(4625 . "ETHIOPIC SYLLABLE HHU")
(4626 . "ETHIOPIC SYLLABLE HHI")
(4627 . "ETHIOPIC SYLLABLE HHAA")
(4628 . "ETHIOPIC SYLLABLE HHEE")
(4629 . "ETHIOPIC SYLLABLE HHE")
(4630 . "ETHIOPIC SYLLABLE HHO")
(4631 . "ETHIOPIC SYLLABLE HHWA")
(4632 . "ETHIOPIC SYLLABLE MA")
(4633 . "ETHIOPIC SYLLABLE MU")
(4634 . "ETHIOPIC SYLLABLE MI")
(4635 . "ETHIOPIC SYLLABLE MAA")
(4636 . "ETHIOPIC SYLLABLE MEE")
(4637 . "ETHIOPIC SYLLABLE ME")
(4638 . "ETHIOPIC SYLLABLE MO")
(4639 . "ETHIOPIC SYLLABLE MWA")
(4640 . "ETHIOPIC SYLLABLE SZA")
(4641 . "ETHIOPIC SYLLABLE SZU")
(4642 . "ETHIOPIC SYLLABLE SZI")
(4643 . "ETHIOPIC SYLLABLE SZAA")
(4644 . "ETHIOPIC SYLLABLE SZEE")
(4645 . "ETHIOPIC SYLLABLE SZE")
(4646 . "ETHIOPIC SYLLABLE SZO")
(4647 . "ETHIOPIC SYLLABLE SZWA")
(4648 . "ETHIOPIC SYLLABLE RA")
(4649 . "ETHIOPIC SYLLABLE RU")
(4650 . "ETHIOPIC SYLLABLE RI")
(4651 . "ETHIOPIC SYLLABLE RAA")
(4652 . "ETHIOPIC SYLLABLE REE")
(4653 . "ETHIOPIC SYLLABLE RE")
(4654 . "ETHIOPIC SYLLABLE RO")
(4655 . "ETHIOPIC SYLLABLE RWA")
(4656 . "ETHIOPIC SYLLABLE SA")
(4657 . "ETHIOPIC SYLLABLE SU")
(4658 . "ETHIOPIC SYLLABLE SI")
(4659 . "ETHIOPIC SYLLABLE SAA")
(4660 . "ETHIOPIC SYLLABLE SEE")
(4661 . "ETHIOPIC SYLLABLE SE")
(4662 . "ETHIOPIC SYLLABLE SO")
(4663 . "ETHIOPIC SYLLABLE SWA")
(4664 . "ETHIOPIC SYLLABLE SHA")
(4665 . "ETHIOPIC SYLLABLE SHU")
(4666 . "ETHIOPIC SYLLABLE SHI")
(4667 . "ETHIOPIC SYLLABLE SHAA")
(4668 . "ETHIOPIC SYLLABLE SHEE")
(4669 . "ETHIOPIC SYLLABLE SHE")
(4670 . "ETHIOPIC SYLLABLE SHO")
(4671 . "ETHIOPIC SYLLABLE SHWA")
(4672 . "ETHIOPIC SYLLABLE QA")
(4673 . "ETHIOPIC SYLLABLE QU")
(4674 . "ETHIOPIC SYLLABLE QI")
(4675 . "ETHIOPIC SYLLABLE QAA")
(4676 . "ETHIOPIC SYLLABLE QEE")
(4677 . "ETHIOPIC SYLLABLE QE")
(4678 . "ETHIOPIC SYLLABLE QO")
(4679 . "ETHIOPIC SYLLABLE QOA")
(4680 . "ETHIOPIC SYLLABLE QWA")
(4681 . #f)
(4682 . "ETHIOPIC SYLLABLE QWI")
(4683 . "ETHIOPIC SYLLABLE QWAA")
(4684 . "ETHIOPIC SYLLABLE QWEE")
(4685 . "ETHIOPIC SYLLABLE QWE")
((4686 . 4688) . #f)
(4688 . "ETHIOPIC SYLLABLE QHA")
(4689 . "ETHIOPIC SYLLABLE QHU")
(4690 . "ETHIOPIC SYLLABLE QHI")
(4691 . "ETHIOPIC SYLLABLE QHAA")
(4692 . "ETHIOPIC SYLLABLE QHEE")
(4693 . "ETHIOPIC SYLLABLE QHE")
(4694 . "ETHIOPIC SYLLABLE QHO")
(4695 . #f)
(4696 . "ETHIOPIC SYLLABLE QHWA")
(4697 . #f)
(4698 . "ETHIOPIC SYLLABLE QHWI")
(4699 . "ETHIOPIC SYLLABLE QHWAA")
(4700 . "ETHIOPIC SYLLABLE QHWEE")
(4701 . "ETHIOPIC SYLLABLE QHWE")
((4702 . 4704) . #f)
(4704 . "ETHIOPIC SYLLABLE BA")
(4705 . "ETHIOPIC SYLLABLE BU")
(4706 . "ETHIOPIC SYLLABLE BI")
(4707 . "ETHIOPIC SYLLABLE BAA")
(4708 . "ETHIOPIC SYLLABLE BEE")
(4709 . "ETHIOPIC SYLLABLE BE")
(4710 . "ETHIOPIC SYLLABLE BO")
(4711 . "ETHIOPIC SYLLABLE BWA")
(4712 . "ETHIOPIC SYLLABLE VA")
(4713 . "ETHIOPIC SYLLABLE VU")
(4714 . "ETHIOPIC SYLLABLE VI")
(4715 . "ETHIOPIC SYLLABLE VAA")
(4716 . "ETHIOPIC SYLLABLE VEE")
(4717 . "ETHIOPIC SYLLABLE VE")
(4718 . "ETHIOPIC SYLLABLE VO")
(4719 . "ETHIOPIC SYLLABLE VWA")
(4720 . "ETHIOPIC SYLLABLE TA")
(4721 . "ETHIOPIC SYLLABLE TU")
(4722 . "ETHIOPIC SYLLABLE TI")
(4723 . "ETHIOPIC SYLLABLE TAA")
(4724 . "ETHIOPIC SYLLABLE TEE")
(4725 . "ETHIOPIC SYLLABLE TE")
(4726 . "ETHIOPIC SYLLABLE TO")
(4727 . "ETHIOPIC SYLLABLE TWA")
(4728 . "ETHIOPIC SYLLABLE CA")
(4729 . "ETHIOPIC SYLLABLE CU")
(4730 . "ETHIOPIC SYLLABLE CI")
(4731 . "ETHIOPIC SYLLABLE CAA")
(4732 . "ETHIOPIC SYLLABLE CEE")
(4733 . "ETHIOPIC SYLLABLE CE")
(4734 . "ETHIOPIC SYLLABLE CO")
(4735 . "ETHIOPIC SYLLABLE CWA")
(4736 . "ETHIOPIC SYLLABLE XA")
(4737 . "ETHIOPIC SYLLABLE XU")
(4738 . "ETHIOPIC SYLLABLE XI")
(4739 . "ETHIOPIC SYLLABLE XAA")
(4740 . "ETHIOPIC SYLLABLE XEE")
(4741 . "ETHIOPIC SYLLABLE XE")
(4742 . "ETHIOPIC SYLLABLE XO")
(4743 . "ETHIOPIC SYLLABLE XOA")
(4744 . "ETHIOPIC SYLLABLE XWA")
(4745 . #f)
(4746 . "ETHIOPIC SYLLABLE XWI")
(4747 . "ETHIOPIC SYLLABLE XWAA")
(4748 . "ETHIOPIC SYLLABLE XWEE")
(4749 . "ETHIOPIC SYLLABLE XWE")
((4750 . 4752) . #f)
(4752 . "ETHIOPIC SYLLABLE NA")
(4753 . "ETHIOPIC SYLLABLE NU")
(4754 . "ETHIOPIC SYLLABLE NI")
(4755 . "ETHIOPIC SYLLABLE NAA")
(4756 . "ETHIOPIC SYLLABLE NEE")
(4757 . "ETHIOPIC SYLLABLE NE")
(4758 . "ETHIOPIC SYLLABLE NO")
(4759 . "ETHIOPIC SYLLABLE NWA")
(4760 . "ETHIOPIC SYLLABLE NYA")
(4761 . "ETHIOPIC SYLLABLE NYU")
(4762 . "ETHIOPIC SYLLABLE NYI")
(4763 . "ETHIOPIC SYLLABLE NYAA")
(4764 . "ETHIOPIC SYLLABLE NYEE")
(4765 . "ETHIOPIC SYLLABLE NYE")
(4766 . "ETHIOPIC SYLLABLE NYO")
(4767 . "ETHIOPIC SYLLABLE NYWA")
(4768 . "ETHIOPIC SYLLABLE GLOTTAL A")
(4769 . "ETHIOPIC SYLLABLE GLOTTAL U")
(4770 . "ETHIOPIC SYLLABLE GLOTTAL I")
(4771 . "ETHIOPIC SYLLABLE GLOTTAL AA")
(4772 . "ETHIOPIC SYLLABLE GLOTTAL EE")
(4773 . "ETHIOPIC SYLLABLE GLOTTAL E")
(4774 . "ETHIOPIC SYLLABLE GLOTTAL O")
(4775 . "ETHIOPIC SYLLABLE GLOTTAL WA")
(4776 . "ETHIOPIC SYLLABLE KA")
(4777 . "ETHIOPIC SYLLABLE KU")
(4778 . "ETHIOPIC SYLLABLE KI")
(4779 . "ETHIOPIC SYLLABLE KAA")
(4780 . "ETHIOPIC SYLLABLE KEE")
(4781 . "ETHIOPIC SYLLABLE KE")
(4782 . "ETHIOPIC SYLLABLE KO")
(4783 . "ETHIOPIC SYLLABLE KOA")
(4784 . "ETHIOPIC SYLLABLE KWA")
(4785 . #f)
(4786 . "ETHIOPIC SYLLABLE KWI")
(4787 . "ETHIOPIC SYLLABLE KWAA")
(4788 . "ETHIOPIC SYLLABLE KWEE")
(4789 . "ETHIOPIC SYLLABLE KWE")
((4790 . 4792) . #f)
(4792 . "ETHIOPIC SYLLABLE KXA")
(4793 . "ETHIOPIC SYLLABLE KXU")
(4794 . "ETHIOPIC SYLLABLE KXI")
(4795 . "ETHIOPIC SYLLABLE KXAA")
(4796 . "ETHIOPIC SYLLABLE KXEE")
(4797 . "ETHIOPIC SYLLABLE KXE")
(4798 . "ETHIOPIC SYLLABLE KXO")
(4799 . #f)
(4800 . "ETHIOPIC SYLLABLE KXWA")
(4801 . #f)
(4802 . "ETHIOPIC SYLLABLE KXWI")
(4803 . "ETHIOPIC SYLLABLE KXWAA")
(4804 . "ETHIOPIC SYLLABLE KXWEE")
(4805 . "ETHIOPIC SYLLABLE KXWE")
((4806 . 4808) . #f)
(4808 . "ETHIOPIC SYLLABLE WA")
(4809 . "ETHIOPIC SYLLABLE WU")
(4810 . "ETHIOPIC SYLLABLE WI")
(4811 . "ETHIOPIC SYLLABLE WAA")
(4812 . "ETHIOPIC SYLLABLE WEE")
(4813 . "ETHIOPIC SYLLABLE WE")
(4814 . "ETHIOPIC SYLLABLE WO")
(4815 . "ETHIOPIC SYLLABLE WOA")
(4816 . "ETHIOPIC SYLLABLE PHARYNGEAL A")
(4817 . "ETHIOPIC SYLLABLE PHARYNGEAL U")
(4818 . "ETHIOPIC SYLLABLE PHARYNGEAL I")
(4819 . "ETHIOPIC SYLLABLE PHARYNGEAL AA")
(4820 . "ETHIOPIC SYLLABLE PHARYNGEAL EE")
(4821 . "ETHIOPIC SYLLABLE PHARYNGEAL E")
(4822 . "ETHIOPIC SYLLABLE PHARYNGEAL O")
(4823 . #f)
(4824 . "ETHIOPIC SYLLABLE ZA")
(4825 . "ETHIOPIC SYLLABLE ZU")
(4826 . "ETHIOPIC SYLLABLE ZI")
(4827 . "ETHIOPIC SYLLABLE ZAA")
(4828 . "ETHIOPIC SYLLABLE ZEE")
(4829 . "ETHIOPIC SYLLABLE ZE")
(4830 . "ETHIOPIC SYLLABLE ZO")
(4831 . "ETHIOPIC SYLLABLE ZWA")
(4832 . "ETHIOPIC SYLLABLE ZHA")
(4833 . "ETHIOPIC SYLLABLE ZHU")
(4834 . "ETHIOPIC SYLLABLE ZHI")
(4835 . "ETHIOPIC SYLLABLE ZHAA")
(4836 . "ETHIOPIC SYLLABLE ZHEE")
(4837 . "ETHIOPIC SYLLABLE ZHE")
(4838 . "ETHIOPIC SYLLABLE ZHO")
(4839 . "ETHIOPIC SYLLABLE ZHWA")
(4840 . "ETHIOPIC SYLLABLE YA")
(4841 . "ETHIOPIC SYLLABLE YU")
(4842 . "ETHIOPIC SYLLABLE YI")
(4843 . "ETHIOPIC SYLLABLE YAA")
(4844 . "ETHIOPIC SYLLABLE YEE")
(4845 . "ETHIOPIC SYLLABLE YE")
(4846 . "ETHIOPIC SYLLABLE YO")
(4847 . "ETHIOPIC SYLLABLE YOA")
(4848 . "ETHIOPIC SYLLABLE DA")
(4849 . "ETHIOPIC SYLLABLE DU")
(4850 . "ETHIOPIC SYLLABLE DI")
(4851 . "ETHIOPIC SYLLABLE DAA")
(4852 . "ETHIOPIC SYLLABLE DEE")
(4853 . "ETHIOPIC SYLLABLE DE")
(4854 . "ETHIOPIC SYLLABLE DO")
(4855 . "ETHIOPIC SYLLABLE DWA")
(4856 . "ETHIOPIC SYLLABLE DDA")
(4857 . "ETHIOPIC SYLLABLE DDU")
(4858 . "ETHIOPIC SYLLABLE DDI")
(4859 . "ETHIOPIC SYLLABLE DDAA")
(4860 . "ETHIOPIC SYLLABLE DDEE")
(4861 . "ETHIOPIC SYLLABLE DDE")
(4862 . "ETHIOPIC SYLLABLE DDO")
(4863 . "ETHIOPIC SYLLABLE DDWA")
(4864 . "ETHIOPIC SYLLABLE JA")
(4865 . "ETHIOPIC SYLLABLE JU")
(4866 . "ETHIOPIC SYLLABLE JI")
(4867 . "ETHIOPIC SYLLABLE JAA")
(4868 . "ETHIOPIC SYLLABLE JEE")
(4869 . "ETHIOPIC SYLLABLE JE")
(4870 . "ETHIOPIC SYLLABLE JO")
(4871 . "ETHIOPIC SYLLABLE JWA")
(4872 . "ETHIOPIC SYLLABLE GA")
(4873 . "ETHIOPIC SYLLABLE GU")
(4874 . "ETHIOPIC SYLLABLE GI")
(4875 . "ETHIOPIC SYLLABLE GAA")
(4876 . "ETHIOPIC SYLLABLE GEE")
(4877 . "ETHIOPIC SYLLABLE GE")
(4878 . "ETHIOPIC SYLLABLE GO")
(4879 . "ETHIOPIC SYLLABLE GOA")
(4880 . "ETHIOPIC SYLLABLE GWA")
(4881 . #f)
(4882 . "ETHIOPIC SYLLABLE GWI")
(4883 . "ETHIOPIC SYLLABLE GWAA")
(4884 . "ETHIOPIC SYLLABLE GWEE")
(4885 . "ETHIOPIC SYLLABLE GWE")
((4886 . 4888) . #f)
(4888 . "ETHIOPIC SYLLABLE GGA")
(4889 . "ETHIOPIC SYLLABLE GGU")
(4890 . "ETHIOPIC SYLLABLE GGI")
(4891 . "ETHIOPIC SYLLABLE GGAA")
(4892 . "ETHIOPIC SYLLABLE GGEE")
(4893 . "ETHIOPIC SYLLABLE GGE")
(4894 . "ETHIOPIC SYLLABLE GGO")
(4895 . "ETHIOPIC SYLLABLE GGWAA")
(4896 . "ETHIOPIC SYLLABLE THA")
(4897 . "ETHIOPIC SYLLABLE THU")
(4898 . "ETHIOPIC SYLLABLE THI")
(4899 . "ETHIOPIC SYLLABLE THAA")
(4900 . "ETHIOPIC SYLLABLE THEE")
(4901 . "ETHIOPIC SYLLABLE THE")
(4902 . "ETHIOPIC SYLLABLE THO")
(4903 . "ETHIOPIC SYLLABLE THWA")
(4904 . "ETHIOPIC SYLLABLE CHA")
(4905 . "ETHIOPIC SYLLABLE CHU")
(4906 . "ETHIOPIC SYLLABLE CHI")
(4907 . "ETHIOPIC SYLLABLE CHAA")
(4908 . "ETHIOPIC SYLLABLE CHEE")
(4909 . "ETHIOPIC SYLLABLE CHE")
(4910 . "ETHIOPIC SYLLABLE CHO")
(4911 . "ETHIOPIC SYLLABLE CHWA")
(4912 . "ETHIOPIC SYLLABLE PHA")
(4913 . "ETHIOPIC SYLLABLE PHU")
(4914 . "ETHIOPIC SYLLABLE PHI")
(4915 . "ETHIOPIC SYLLABLE PHAA")
(4916 . "ETHIOPIC SYLLABLE PHEE")
(4917 . "ETHIOPIC SYLLABLE PHE")
(4918 . "ETHIOPIC SYLLABLE PHO")
(4919 . "ETHIOPIC SYLLABLE PHWA")
(4920 . "ETHIOPIC SYLLABLE TSA")
(4921 . "ETHIOPIC SYLLABLE TSU")
(4922 . "ETHIOPIC SYLLABLE TSI")
(4923 . "ETHIOPIC SYLLABLE TSAA")
(4924 . "ETHIOPIC SYLLABLE TSEE")
(4925 . "ETHIOPIC SYLLABLE TSE")
(4926 . "ETHIOPIC SYLLABLE TSO")
(4927 . "ETHIOPIC SYLLABLE TSWA")
(4928 . "ETHIOPIC SYLLABLE TZA")
(4929 . "ETHIOPIC SYLLABLE TZU")
(4930 . "ETHIOPIC SYLLABLE TZI")
(4931 . "ETHIOPIC SYLLABLE TZAA")
(4932 . "ETHIOPIC SYLLABLE TZEE")
(4933 . "ETHIOPIC SYLLABLE TZE")
(4934 . "ETHIOPIC SYLLABLE TZO")
(4935 . "ETHIOPIC SYLLABLE TZOA")
(4936 . "ETHIOPIC SYLLABLE FA")
(4937 . "ETHIOPIC SYLLABLE FU")
(4938 . "ETHIOPIC SYLLABLE FI")
(4939 . "ETHIOPIC SYLLABLE FAA")
(4940 . "ETHIOPIC SYLLABLE FEE")
(4941 . "ETHIOPIC SYLLABLE FE")
(4942 . "ETHIOPIC SYLLABLE FO")
(4943 . "ETHIOPIC SYLLABLE FWA")
(4944 . "ETHIOPIC SYLLABLE PA")
(4945 . "ETHIOPIC SYLLABLE PU")
(4946 . "ETHIOPIC SYLLABLE PI")
(4947 . "ETHIOPIC SYLLABLE PAA")
(4948 . "ETHIOPIC SYLLABLE PEE")
(4949 . "ETHIOPIC SYLLABLE PE")
(4950 . "ETHIOPIC SYLLABLE PO")
(4951 . "ETHIOPIC SYLLABLE PWA")
(4952 . "ETHIOPIC SYLLABLE RYA")
(4953 . "ETHIOPIC SYLLABLE MYA")
(4954 . "ETHIOPIC SYLLABLE FYA")
((4955 . 4957) . #f)
(4957 . "ETHIOPIC COMBINING GEMINATION AND VOWEL LENGTH MARK")
(4958 . "ETHIOPIC COMBINING VOWEL LENGTH MARK")
(4959 . "ETHIOPIC COMBINING GEMINATION MARK")
(4960 . "ETHIOPIC SECTION MARK")
(4961 . "ETHIOPIC WORDSPACE")
(4962 . "ETHIOPIC FULL STOP")
(4963 . "ETHIOPIC COMMA")
(4964 . "ETHIOPIC SEMICOLON")
(4965 . "ETHIOPIC COLON")
(4966 . "ETHIOPIC PREFACE COLON")
(4967 . "ETHIOPIC QUESTION MARK")
(4968 . "ETHIOPIC PARAGRAPH SEPARATOR")
(4969 . "ETHIOPIC DIGIT ONE")
(4970 . "ETHIOPIC DIGIT TWO")
(4971 . "ETHIOPIC DIGIT THREE")
(4972 . "ETHIOPIC DIGIT FOUR")
(4973 . "ETHIOPIC DIGIT FIVE")
(4974 . "ETHIOPIC DIGIT SIX")
(4975 . "ETHIOPIC DIGIT SEVEN")
(4976 . "ETHIOPIC DIGIT EIGHT")
(4977 . "ETHIOPIC DIGIT NINE")
(4978 . "ETHIOPIC NUMBER TEN")
(4979 . "ETHIOPIC NUMBER TWENTY")
(4980 . "ETHIOPIC NUMBER THIRTY")
(4981 . "ETHIOPIC NUMBER FORTY")
(4982 . "ETHIOPIC NUMBER FIFTY")
(4983 . "ETHIOPIC NUMBER SIXTY")
(4984 . "ETHIOPIC NUMBER SEVENTY")
(4985 . "ETHIOPIC NUMBER EIGHTY")
(4986 . "ETHIOPIC NUMBER NINETY")
(4987 . "ETHIOPIC NUMBER HUNDRED")
(4988 . "ETHIOPIC NUMBER TEN THOUSAND")
((4989 . 4992) . #f)
(4992 . "ETHIOPIC SYLLABLE SEBATBEIT MWA")
(4993 . "ETHIOPIC SYLLABLE MWI")
(4994 . "ETHIOPIC SYLLABLE MWEE")
(4995 . "ETHIOPIC SYLLABLE MWE")
(4996 . "ETHIOPIC SYLLABLE SEBATBEIT BWA")
(4997 . "ETHIOPIC SYLLABLE BWI")
(4998 . "ETHIOPIC SYLLABLE BWEE")
(4999 . "ETHIOPIC SYLLABLE BWE")
(5000 . "ETHIOPIC SYLLABLE SEBATBEIT FWA")
(5001 . "ETHIOPIC SYLLABLE FWI")
(5002 . "ETHIOPIC SYLLABLE FWEE")
(5003 . "ETHIOPIC SYLLABLE FWE")
(5004 . "ETHIOPIC SYLLABLE SEBATBEIT PWA")
(5005 . "ETHIOPIC SYLLABLE PWI")
(5006 . "ETHIOPIC SYLLABLE PWEE")
(5007 . "ETHIOPIC SYLLABLE PWE")
(5008 . "ETHIOPIC TONAL MARK YIZET")
(5009 . "ETHIOPIC TONAL MARK DERET")
(5010 . "ETHIOPIC TONAL MARK RIKRIK")
(5011 . "ETHIOPIC TONAL MARK SHORT RIKRIK")
(5012 . "ETHIOPIC TONAL MARK DIFAT")
(5013 . "ETHIOPIC TONAL MARK KENAT")
(5014 . "ETHIOPIC TONAL MARK CHIRET")
(5015 . "ETHIOPIC TONAL MARK HIDET")
(5016 . "ETHIOPIC TONAL MARK DERET-HIDET")
(5017 . "ETHIOPIC TONAL MARK KURT")
((5018 . 5024) . #f)
(5024 . "CHEROKEE LETTER A")
(5025 . "CHEROKEE LETTER E")
(5026 . "CHEROKEE LETTER I")
(5027 . "CHEROKEE LETTER O")
(5028 . "CHEROKEE LETTER U")
(5029 . "CHEROKEE LETTER V")
(5030 . "CHEROKEE LETTER GA")
(5031 . "CHEROKEE LETTER KA")
(5032 . "CHEROKEE LETTER GE")
(5033 . "CHEROKEE LETTER GI")
(5034 . "CHEROKEE LETTER GO")
(5035 . "CHEROKEE LETTER GU")
(5036 . "CHEROKEE LETTER GV")
(5037 . "CHEROKEE LETTER HA")
(5038 . "CHEROKEE LETTER HE")
(5039 . "CHEROKEE LETTER HI")
(5040 . "CHEROKEE LETTER HO")
(5041 . "CHEROKEE LETTER HU")
(5042 . "CHEROKEE LETTER HV")
(5043 . "CHEROKEE LETTER LA")
(5044 . "CHEROKEE LETTER LE")
(5045 . "CHEROKEE LETTER LI")
(5046 . "CHEROKEE LETTER LO")
(5047 . "CHEROKEE LETTER LU")
(5048 . "CHEROKEE LETTER LV")
(5049 . "CHEROKEE LETTER MA")
(5050 . "CHEROKEE LETTER ME")
(5051 . "CHEROKEE LETTER MI")
(5052 . "CHEROKEE LETTER MO")
(5053 . "CHEROKEE LETTER MU")
(5054 . "CHEROKEE LETTER NA")
(5055 . "CHEROKEE LETTER HNA")
(5056 . "CHEROKEE LETTER NAH")
(5057 . "CHEROKEE LETTER NE")
(5058 . "CHEROKEE LETTER NI")
(5059 . "CHEROKEE LETTER NO")
(5060 . "CHEROKEE LETTER NU")
(5061 . "CHEROKEE LETTER NV")
(5062 . "CHEROKEE LETTER QUA")
(5063 . "CHEROKEE LETTER QUE")
(5064 . "CHEROKEE LETTER QUI")
(5065 . "CHEROKEE LETTER QUO")
(5066 . "CHEROKEE LETTER QUU")
(5067 . "CHEROKEE LETTER QUV")
(5068 . "CHEROKEE LETTER SA")
(5069 . "CHEROKEE LETTER S")
(5070 . "CHEROKEE LETTER SE")
(5071 . "CHEROKEE LETTER SI")
(5072 . "CHEROKEE LETTER SO")
(5073 . "CHEROKEE LETTER SU")
(5074 . "CHEROKEE LETTER SV")
(5075 . "CHEROKEE LETTER DA")
(5076 . "CHEROKEE LETTER TA")
(5077 . "CHEROKEE LETTER DE")
(5078 . "CHEROKEE LETTER TE")
(5079 . "CHEROKEE LETTER DI")
(5080 . "CHEROKEE LETTER TI")
(5081 . "CHEROKEE LETTER DO")
(5082 . "CHEROKEE LETTER DU")
(5083 . "CHEROKEE LETTER DV")
(5084 . "CHEROKEE LETTER DLA")
(5085 . "CHEROKEE LETTER TLA")
(5086 . "CHEROKEE LETTER TLE")
(5087 . "CHEROKEE LETTER TLI")
(5088 . "CHEROKEE LETTER TLO")
(5089 . "CHEROKEE LETTER TLU")
(5090 . "CHEROKEE LETTER TLV")
(5091 . "CHEROKEE LETTER TSA")
(5092 . "CHEROKEE LETTER TSE")
(5093 . "CHEROKEE LETTER TSI")
(5094 . "CHEROKEE LETTER TSO")
(5095 . "CHEROKEE LETTER TSU")
(5096 . "CHEROKEE LETTER TSV")
(5097 . "CHEROKEE LETTER WA")
(5098 . "CHEROKEE LETTER WE")
(5099 . "CHEROKEE LETTER WI")
(5100 . "CHEROKEE LETTER WO")
(5101 . "CHEROKEE LETTER WU")
(5102 . "CHEROKEE LETTER WV")
(5103 . "CHEROKEE LETTER YA")
(5104 . "CHEROKEE LETTER YE")
(5105 . "CHEROKEE LETTER YI")
(5106 . "CHEROKEE LETTER YO")
(5107 . "CHEROKEE LETTER YU")
(5108 . "CHEROKEE LETTER YV")
(5109 . "CHEROKEE LETTER MV")
((5110 . 5112) . #f)
(5112 . "CHEROKEE SMALL LETTER YE")
(5113 . "CHEROKEE SMALL LETTER YI")
(5114 . "CHEROKEE SMALL LETTER YO")
(5115 . "CHEROKEE SMALL LETTER YU")
(5116 . "CHEROKEE SMALL LETTER YV")
(5117 . "CHEROKEE SMALL LETTER MV")
((5118 . 5120) . #f)
(5120 . "CANADIAN SYLLABICS HYPHEN")
(5121 . "CANADIAN SYLLABICS E")
(5122 . "CANADIAN SYLLABICS AAI")
(5123 . "CANADIAN SYLLABICS I")
(5124 . "CANADIAN SYLLABICS II")
(5125 . "CANADIAN SYLLABICS O")
(5126 . "CANADIAN SYLLABICS OO")
(5127 . "CANADIAN SYLLABICS Y-CREE OO")
(5128 . "CANADIAN SYLLABICS CARRIER EE")
(5129 . "CANADIAN SYLLABICS CARRIER I")
(5130 . "CANADIAN SYLLABICS A")
(5131 . "CANADIAN SYLLABICS AA")
(5132 . "CANADIAN SYLLABICS WE")
(5133 . "CANADIAN SYLLABICS WEST-CREE WE")
(5134 . "CANADIAN SYLLABICS WI")
(5135 . "CANADIAN SYLLABICS WEST-CREE WI")
(5136 . "CANADIAN SYLLABICS WII")
(5137 . "CANADIAN SYLLABICS WEST-CREE WII")
(5138 . "CANADIAN SYLLABICS WO")
(5139 . "CANADIAN SYLLABICS WEST-CREE WO")
(5140 . "CANADIAN SYLLABICS WOO")
(5141 . "CANADIAN SYLLABICS WEST-CREE WOO")
(5142 . "CANADIAN SYLLABICS NASKAPI WOO")
(5143 . "CANADIAN SYLLABICS WA")
(5144 . "CANADIAN SYLLABICS WEST-CREE WA")
(5145 . "CANADIAN SYLLABICS WAA")
(5146 . "CANADIAN SYLLABICS WEST-CREE WAA")
(5147 . "CANADIAN SYLLABICS NASKAPI WAA")
(5148 . "CANADIAN SYLLABICS AI")
(5149 . "CANADIAN SYLLABICS Y-CREE W")
(5150 . "CANADIAN SYLLABICS GLOTTAL STOP")
(5151 . "CANADIAN SYLLABICS FINAL ACUTE")
(5152 . "CANADIAN SYLLABICS FINAL GRAVE")
(5153 . "CANADIAN SYLLABICS FINAL BOTTOM HALF RING")
(5154 . "CANADIAN SYLLABICS FINAL TOP HALF RING")
(5155 . "CANADIAN SYLLABICS FINAL RIGHT HALF RING")
(5156 . "CANADIAN SYLLABICS FINAL RING")
(5157 . "CANADIAN SYLLABICS FINAL DOUBLE ACUTE")
(5158 . "CANADIAN SYLLABICS FINAL DOUBLE SHORT VERTICAL STROKES")
(5159 . "CANADIAN SYLLABICS FINAL MIDDLE DOT")
(5160 . "CANADIAN SYLLABICS FINAL SHORT HORIZONTAL STROKE")
(5161 . "CANADIAN SYLLABICS FINAL PLUS")
(5162 . "CANADIAN SYLLABICS FINAL DOWN TACK")
(5163 . "CANADIAN SYLLABICS EN")
(5164 . "CANADIAN SYLLABICS IN")
(5165 . "CANADIAN SYLLABICS ON")
(5166 . "CANADIAN SYLLABICS AN")
(5167 . "CANADIAN SYLLABICS PE")
(5168 . "CANADIAN SYLLABICS PAAI")
(5169 . "CANADIAN SYLLABICS PI")
(5170 . "CANADIAN SYLLABICS PII")
(5171 . "CANADIAN SYLLABICS PO")
(5172 . "CANADIAN SYLLABICS POO")
(5173 . "CANADIAN SYLLABICS Y-CREE POO")
(5174 . "CANADIAN SYLLABICS CARRIER HEE")
(5175 . "CANADIAN SYLLABICS CARRIER HI")
(5176 . "CANADIAN SYLLABICS PA")
(5177 . "CANADIAN SYLLABICS PAA")
(5178 . "CANADIAN SYLLABICS PWE")
(5179 . "CANADIAN SYLLABICS WEST-CREE PWE")
(5180 . "CANADIAN SYLLABICS PWI")
(5181 . "CANADIAN SYLLABICS WEST-CREE PWI")
(5182 . "CANADIAN SYLLABICS PWII")
(5183 . "CANADIAN SYLLABICS WEST-CREE PWII")
(5184 . "CANADIAN SYLLABICS PWO")
(5185 . "CANADIAN SYLLABICS WEST-CREE PWO")
(5186 . "CANADIAN SYLLABICS PWOO")
(5187 . "CANADIAN SYLLABICS WEST-CREE PWOO")
(5188 . "CANADIAN SYLLABICS PWA")
(5189 . "CANADIAN SYLLABICS WEST-CREE PWA")
(5190 . "CANADIAN SYLLABICS PWAA")
(5191 . "CANADIAN SYLLABICS WEST-CREE PWAA")
(5192 . "CANADIAN SYLLABICS Y-CREE PWAA")
(5193 . "CANADIAN SYLLABICS P")
(5194 . "CANADIAN SYLLABICS WEST-CREE P")
(5195 . "CANADIAN SYLLABICS CARRIER H")
(5196 . "CANADIAN SYLLABICS TE")
(5197 . "CANADIAN SYLLABICS TAAI")
(5198 . "CANADIAN SYLLABICS TI")
(5199 . "CANADIAN SYLLABICS TII")
(5200 . "CANADIAN SYLLABICS TO")
(5201 . "CANADIAN SYLLABICS TOO")
(5202 . "CANADIAN SYLLABICS Y-CREE TOO")
(5203 . "CANADIAN SYLLABICS CARRIER DEE")
(5204 . "CANADIAN SYLLABICS CARRIER DI")
(5205 . "CANADIAN SYLLABICS TA")
(5206 . "CANADIAN SYLLABICS TAA")
(5207 . "CANADIAN SYLLABICS TWE")
(5208 . "CANADIAN SYLLABICS WEST-CREE TWE")
(5209 . "CANADIAN SYLLABICS TWI")
(5210 . "CANADIAN SYLLABICS WEST-CREE TWI")
(5211 . "CANADIAN SYLLABICS TWII")
(5212 . "CANADIAN SYLLABICS WEST-CREE TWII")
(5213 . "CANADIAN SYLLABICS TWO")
(5214 . "CANADIAN SYLLABICS WEST-CREE TWO")
(5215 . "CANADIAN SYLLABICS TWOO")
(5216 . "CANADIAN SYLLABICS WEST-CREE TWOO")
(5217 . "CANADIAN SYLLABICS TWA")
(5218 . "CANADIAN SYLLABICS WEST-CREE TWA")
(5219 . "CANADIAN SYLLABICS TWAA")
(5220 . "CANADIAN SYLLABICS WEST-CREE TWAA")
(5221 . "CANADIAN SYLLABICS NASKAPI TWAA")
(5222 . "CANADIAN SYLLABICS T")
(5223 . "CANADIAN SYLLABICS TTE")
(5224 . "CANADIAN SYLLABICS TTI")
(5225 . "CANADIAN SYLLABICS TTO")
(5226 . "CANADIAN SYLLABICS TTA")
(5227 . "CANADIAN SYLLABICS KE")
(5228 . "CANADIAN SYLLABICS KAAI")
(5229 . "CANADIAN SYLLABICS KI")
(5230 . "CANADIAN SYLLABICS KII")
(5231 . "CANADIAN SYLLABICS KO")
(5232 . "CANADIAN SYLLABICS KOO")
(5233 . "CANADIAN SYLLABICS Y-CREE KOO")
(5234 . "CANADIAN SYLLABICS KA")
(5235 . "CANADIAN SYLLABICS KAA")
(5236 . "CANADIAN SYLLABICS KWE")
(5237 . "CANADIAN SYLLABICS WEST-CREE KWE")
(5238 . "CANADIAN SYLLABICS KWI")
(5239 . "CANADIAN SYLLABICS WEST-CREE KWI")
(5240 . "CANADIAN SYLLABICS KWII")
(5241 . "CANADIAN SYLLABICS WEST-CREE KWII")
(5242 . "CANADIAN SYLLABICS KWO")
(5243 . "CANADIAN SYLLABICS WEST-CREE KWO")
(5244 . "CANADIAN SYLLABICS KWOO")
(5245 . "CANADIAN SYLLABICS WEST-CREE KWOO")
(5246 . "CANADIAN SYLLABICS KWA")
(5247 . "CANADIAN SYLLABICS WEST-CREE KWA")
(5248 . "CANADIAN SYLLABICS KWAA")
(5249 . "CANADIAN SYLLABICS WEST-CREE KWAA")
(5250 . "CANADIAN SYLLABICS NASKAPI KWAA")
(5251 . "CANADIAN SYLLABICS K")
(5252 . "CANADIAN SYLLABICS KW")
(5253 . "CANADIAN SYLLABICS SOUTH-SLAVEY KEH")
(5254 . "CANADIAN SYLLABICS SOUTH-SLAVEY KIH")
(5255 . "CANADIAN SYLLABICS SOUTH-SLAVEY KOH")
(5256 . "CANADIAN SYLLABICS SOUTH-SLAVEY KAH")
(5257 . "CANADIAN SYLLABICS CE")
(5258 . "CANADIAN SYLLABICS CAAI")
(5259 . "CANADIAN SYLLABICS CI")
(5260 . "CANADIAN SYLLABICS CII")
(5261 . "CANADIAN SYLLABICS CO")
(5262 . "CANADIAN SYLLABICS COO")
(5263 . "CANADIAN SYLLABICS Y-CREE COO")
(5264 . "CANADIAN SYLLABICS CA")
(5265 . "CANADIAN SYLLABICS CAA")
(5266 . "CANADIAN SYLLABICS CWE")
(5267 . "CANADIAN SYLLABICS WEST-CREE CWE")
(5268 . "CANADIAN SYLLABICS CWI")
(5269 . "CANADIAN SYLLABICS WEST-CREE CWI")
(5270 . "CANADIAN SYLLABICS CWII")
(5271 . "CANADIAN SYLLABICS WEST-CREE CWII")
(5272 . "CANADIAN SYLLABICS CWO")
(5273 . "CANADIAN SYLLABICS WEST-CREE CWO")
(5274 . "CANADIAN SYLLABICS CWOO")
(5275 . "CANADIAN SYLLABICS WEST-CREE CWOO")
(5276 . "CANADIAN SYLLABICS CWA")
(5277 . "CANADIAN SYLLABICS WEST-CREE CWA")
(5278 . "CANADIAN SYLLABICS CWAA")
(5279 . "CANADIAN SYLLABICS WEST-CREE CWAA")
(5280 . "CANADIAN SYLLABICS NASKAPI CWAA")
(5281 . "CANADIAN SYLLABICS C")
(5282 . "CANADIAN SYLLABICS SAYISI TH")
(5283 . "CANADIAN SYLLABICS ME")
(5284 . "CANADIAN SYLLABICS MAAI")
(5285 . "CANADIAN SYLLABICS MI")
(5286 . "CANADIAN SYLLABICS MII")
(5287 . "CANADIAN SYLLABICS MO")
(5288 . "CANADIAN SYLLABICS MOO")
(5289 . "CANADIAN SYLLABICS Y-CREE MOO")
(5290 . "CANADIAN SYLLABICS MA")
(5291 . "CANADIAN SYLLABICS MAA")
(5292 . "CANADIAN SYLLABICS MWE")
(5293 . "CANADIAN SYLLABICS WEST-CREE MWE")
(5294 . "CANADIAN SYLLABICS MWI")
(5295 . "CANADIAN SYLLABICS WEST-CREE MWI")
(5296 . "CANADIAN SYLLABICS MWII")
(5297 . "CANADIAN SYLLABICS WEST-CREE MWII")
(5298 . "CANADIAN SYLLABICS MWO")
(5299 . "CANADIAN SYLLABICS WEST-CREE MWO")
(5300 . "CANADIAN SYLLABICS MWOO")
(5301 . "CANADIAN SYLLABICS WEST-CREE MWOO")
(5302 . "CANADIAN SYLLABICS MWA")
(5303 . "CANADIAN SYLLABICS WEST-CREE MWA")
(5304 . "CANADIAN SYLLABICS MWAA")
(5305 . "CANADIAN SYLLABICS WEST-CREE MWAA")
(5306 . "CANADIAN SYLLABICS NASKAPI MWAA")
(5307 . "CANADIAN SYLLABICS M")
(5308 . "CANADIAN SYLLABICS WEST-CREE M")
(5309 . "CANADIAN SYLLABICS MH")
(5310 . "CANADIAN SYLLABICS ATHAPASCAN M")
(5311 . "CANADIAN SYLLABICS SAYISI M")
(5312 . "CANADIAN SYLLABICS NE")
(5313 . "CANADIAN SYLLABICS NAAI")
(5314 . "CANADIAN SYLLABICS NI")
(5315 . "CANADIAN SYLLABICS NII")
(5316 . "CANADIAN SYLLABICS NO")
(5317 . "CANADIAN SYLLABICS NOO")
(5318 . "CANADIAN SYLLABICS Y-CREE NOO")
(5319 . "CANADIAN SYLLABICS NA")
(5320 . "CANADIAN SYLLABICS NAA")
(5321 . "CANADIAN SYLLABICS NWE")
(5322 . "CANADIAN SYLLABICS WEST-CREE NWE")
(5323 . "CANADIAN SYLLABICS NWA")
(5324 . "CANADIAN SYLLABICS WEST-CREE NWA")
(5325 . "CANADIAN SYLLABICS NWAA")
(5326 . "CANADIAN SYLLABICS WEST-CREE NWAA")
(5327 . "CANADIAN SYLLABICS NASKAPI NWAA")
(5328 . "CANADIAN SYLLABICS N")
(5329 . "CANADIAN SYLLABICS CARRIER NG")
(5330 . "CANADIAN SYLLABICS NH")
(5331 . "CANADIAN SYLLABICS LE")
(5332 . "CANADIAN SYLLABICS LAAI")
(5333 . "CANADIAN SYLLABICS LI")
(5334 . "CANADIAN SYLLABICS LII")
(5335 . "CANADIAN SYLLABICS LO")
(5336 . "CANADIAN SYLLABICS LOO")
(5337 . "CANADIAN SYLLABICS Y-CREE LOO")
(5338 . "CANADIAN SYLLABICS LA")
(5339 . "CANADIAN SYLLABICS LAA")
(5340 . "CANADIAN SYLLABICS LWE")
(5341 . "CANADIAN SYLLABICS WEST-CREE LWE")
(5342 . "CANADIAN SYLLABICS LWI")
(5343 . "CANADIAN SYLLABICS WEST-CREE LWI")
(5344 . "CANADIAN SYLLABICS LWII")
(5345 . "CANADIAN SYLLABICS WEST-CREE LWII")
(5346 . "CANADIAN SYLLABICS LWO")
(5347 . "CANADIAN SYLLABICS WEST-CREE LWO")
(5348 . "CANADIAN SYLLABICS LWOO")
(5349 . "CANADIAN SYLLABICS WEST-CREE LWOO")
(5350 . "CANADIAN SYLLABICS LWA")
(5351 . "CANADIAN SYLLABICS WEST-CREE LWA")
(5352 . "CANADIAN SYLLABICS LWAA")
(5353 . "CANADIAN SYLLABICS WEST-CREE LWAA")
(5354 . "CANADIAN SYLLABICS L")
(5355 . "CANADIAN SYLLABICS WEST-CREE L")
(5356 . "CANADIAN SYLLABICS MEDIAL L")
(5357 . "CANADIAN SYLLABICS SE")
(5358 . "CANADIAN SYLLABICS SAAI")
(5359 . "CANADIAN SYLLABICS SI")
(5360 . "CANADIAN SYLLABICS SII")
(5361 . "CANADIAN SYLLABICS SO")
(5362 . "CANADIAN SYLLABICS SOO")
(5363 . "CANADIAN SYLLABICS Y-CREE SOO")
(5364 . "CANADIAN SYLLABICS SA")
(5365 . "CANADIAN SYLLABICS SAA")
(5366 . "CANADIAN SYLLABICS SWE")
(5367 . "CANADIAN SYLLABICS WEST-CREE SWE")
(5368 . "CANADIAN SYLLABICS SWI")
(5369 . "CANADIAN SYLLABICS WEST-CREE SWI")
(5370 . "CANADIAN SYLLABICS SWII")
(5371 . "CANADIAN SYLLABICS WEST-CREE SWII")
(5372 . "CANADIAN SYLLABICS SWO")
(5373 . "CANADIAN SYLLABICS WEST-CREE SWO")
(5374 . "CANADIAN SYLLABICS SWOO")
(5375 . "CANADIAN SYLLABICS WEST-CREE SWOO")
(5376 . "CANADIAN SYLLABICS SWA")
(5377 . "CANADIAN SYLLABICS WEST-CREE SWA")
(5378 . "CANADIAN SYLLABICS SWAA")
(5379 . "CANADIAN SYLLABICS WEST-CREE SWAA")
(5380 . "CANADIAN SYLLABICS NASKAPI SWAA")
(5381 . "CANADIAN SYLLABICS S")
(5382 . "CANADIAN SYLLABICS ATHAPASCAN S")
(5383 . "CANADIAN SYLLABICS SW")
(5384 . "CANADIAN SYLLABICS BLACKFOOT S")
(5385 . "CANADIAN SYLLABICS MOOSE-CREE SK")
(5386 . "CANADIAN SYLLABICS NASKAPI SKW")
(5387 . "CANADIAN SYLLABICS NASKAPI S-W")
(5388 . "CANADIAN SYLLABICS NASKAPI SPWA")
(5389 . "CANADIAN SYLLABICS NASKAPI STWA")
(5390 . "CANADIAN SYLLABICS NASKAPI SKWA")
(5391 . "CANADIAN SYLLABICS NASKAPI SCWA")
(5392 . "CANADIAN SYLLABICS SHE")
(5393 . "CANADIAN SYLLABICS SHI")
(5394 . "CANADIAN SYLLABICS SHII")
(5395 . "CANADIAN SYLLABICS SHO")
(5396 . "CANADIAN SYLLABICS SHOO")
(5397 . "CANADIAN SYLLABICS SHA")
(5398 . "CANADIAN SYLLABICS SHAA")
(5399 . "CANADIAN SYLLABICS SHWE")
(5400 . "CANADIAN SYLLABICS WEST-CREE SHWE")
(5401 . "CANADIAN SYLLABICS SHWI")
(5402 . "CANADIAN SYLLABICS WEST-CREE SHWI")
(5403 . "CANADIAN SYLLABICS SHWII")
(5404 . "CANADIAN SYLLABICS WEST-CREE SHWII")
(5405 . "CANADIAN SYLLABICS SHWO")
(5406 . "CANADIAN SYLLABICS WEST-CREE SHWO")
(5407 . "CANADIAN SYLLABICS SHWOO")
(5408 . "CANADIAN SYLLABICS WEST-CREE SHWOO")
(5409 . "CANADIAN SYLLABICS SHWA")
(5410 . "CANADIAN SYLLABICS WEST-CREE SHWA")
(5411 . "CANADIAN SYLLABICS SHWAA")
(5412 . "CANADIAN SYLLABICS WEST-CREE SHWAA")
(5413 . "CANADIAN SYLLABICS SH")
(5414 . "CANADIAN SYLLABICS YE")
(5415 . "CANADIAN SYLLABICS YAAI")
(5416 . "CANADIAN SYLLABICS YI")
(5417 . "CANADIAN SYLLABICS YII")
(5418 . "CANADIAN SYLLABICS YO")
(5419 . "CANADIAN SYLLABICS YOO")
(5420 . "CANADIAN SYLLABICS Y-CREE YOO")
(5421 . "CANADIAN SYLLABICS YA")
(5422 . "CANADIAN SYLLABICS YAA")
(5423 . "CANADIAN SYLLABICS YWE")
(5424 . "CANADIAN SYLLABICS WEST-CREE YWE")
(5425 . "CANADIAN SYLLABICS YWI")
(5426 . "CANADIAN SYLLABICS WEST-CREE YWI")
(5427 . "CANADIAN SYLLABICS YWII")
(5428 . "CANADIAN SYLLABICS WEST-CREE YWII")
(5429 . "CANADIAN SYLLABICS YWO")
(5430 . "CANADIAN SYLLABICS WEST-CREE YWO")
(5431 . "CANADIAN SYLLABICS YWOO")
(5432 . "CANADIAN SYLLABICS WEST-CREE YWOO")
(5433 . "CANADIAN SYLLABICS YWA")
(5434 . "CANADIAN SYLLABICS WEST-CREE YWA")
(5435 . "CANADIAN SYLLABICS YWAA")
(5436 . "CANADIAN SYLLABICS WEST-CREE YWAA")
(5437 . "CANADIAN SYLLABICS NASKAPI YWAA")
(5438 . "CANADIAN SYLLABICS Y")
(5439 . "CANADIAN SYLLABICS BIBLE-CREE Y")
(5440 . "CANADIAN SYLLABICS WEST-CREE Y")
(5441 . "CANADIAN SYLLABICS SAYISI YI")
(5442 . "CANADIAN SYLLABICS RE")
(5443 . "CANADIAN SYLLABICS R-CREE RE")
(5444 . "CANADIAN SYLLABICS WEST-CREE LE")
(5445 . "CANADIAN SYLLABICS RAAI")
(5446 . "CANADIAN SYLLABICS RI")
(5447 . "CANADIAN SYLLABICS RII")
(5448 . "CANADIAN SYLLABICS RO")
(5449 . "CANADIAN SYLLABICS ROO")
(5450 . "CANADIAN SYLLABICS WEST-CREE LO")
(5451 . "CANADIAN SYLLABICS RA")
(5452 . "CANADIAN SYLLABICS RAA")
(5453 . "CANADIAN SYLLABICS WEST-CREE LA")
(5454 . "CANADIAN SYLLABICS RWAA")
(5455 . "CANADIAN SYLLABICS WEST-CREE RWAA")
(5456 . "CANADIAN SYLLABICS R")
(5457 . "CANADIAN SYLLABICS WEST-CREE R")
(5458 . "CANADIAN SYLLABICS MEDIAL R")
(5459 . "CANADIAN SYLLABICS FE")
(5460 . "CANADIAN SYLLABICS FAAI")
(5461 . "CANADIAN SYLLABICS FI")
(5462 . "CANADIAN SYLLABICS FII")
(5463 . "CANADIAN SYLLABICS FO")
(5464 . "CANADIAN SYLLABICS FOO")
(5465 . "CANADIAN SYLLABICS FA")
(5466 . "CANADIAN SYLLABICS FAA")
(5467 . "CANADIAN SYLLABICS FWAA")
(5468 . "CANADIAN SYLLABICS WEST-CREE FWAA")
(5469 . "CANADIAN SYLLABICS F")
(5470 . "CANADIAN SYLLABICS THE")
(5471 . "CANADIAN SYLLABICS N-CREE THE")
(5472 . "CANADIAN SYLLABICS THI")
(5473 . "CANADIAN SYLLABICS N-CREE THI")
(5474 . "CANADIAN SYLLABICS THII")
(5475 . "CANADIAN SYLLABICS N-CREE THII")
(5476 . "CANADIAN SYLLABICS THO")
(5477 . "CANADIAN SYLLABICS THOO")
(5478 . "CANADIAN SYLLABICS THA")
(5479 . "CANADIAN SYLLABICS THAA")
(5480 . "CANADIAN SYLLABICS THWAA")
(5481 . "CANADIAN SYLLABICS WEST-CREE THWAA")
(5482 . "CANADIAN SYLLABICS TH")
(5483 . "CANADIAN SYLLABICS TTHE")
(5484 . "CANADIAN SYLLABICS TTHI")
(5485 . "CANADIAN SYLLABICS TTHO")
(5486 . "CANADIAN SYLLABICS TTHA")
(5487 . "CANADIAN SYLLABICS TTH")
(5488 . "CANADIAN SYLLABICS TYE")
(5489 . "CANADIAN SYLLABICS TYI")
(5490 . "CANADIAN SYLLABICS TYO")
(5491 . "CANADIAN SYLLABICS TYA")
(5492 . "CANADIAN SYLLABICS NUNAVIK HE")
(5493 . "CANADIAN SYLLABICS NUNAVIK HI")
(5494 . "CANADIAN SYLLABICS NUNAVIK HII")
(5495 . "CANADIAN SYLLABICS NUNAVIK HO")
(5496 . "CANADIAN SYLLABICS NUNAVIK HOO")
(5497 . "CANADIAN SYLLABICS NUNAVIK HA")
(5498 . "CANADIAN SYLLABICS NUNAVIK HAA")
(5499 . "CANADIAN SYLLABICS NUNAVIK H")
(5500 . "CANADIAN SYLLABICS NUNAVUT H")
(5501 . "CANADIAN SYLLABICS HK")
(5502 . "CANADIAN SYLLABICS QAAI")
(5503 . "CANADIAN SYLLABICS QI")
(5504 . "CANADIAN SYLLABICS QII")
(5505 . "CANADIAN SYLLABICS QO")
(5506 . "CANADIAN SYLLABICS QOO")
(5507 . "CANADIAN SYLLABICS QA")
(5508 . "CANADIAN SYLLABICS QAA")
(5509 . "CANADIAN SYLLABICS Q")
(5510 . "CANADIAN SYLLABICS TLHE")
(5511 . "CANADIAN SYLLABICS TLHI")
(5512 . "CANADIAN SYLLABICS TLHO")
(5513 . "CANADIAN SYLLABICS TLHA")
(5514 . "CANADIAN SYLLABICS WEST-CREE RE")
(5515 . "CANADIAN SYLLABICS WEST-CREE RI")
(5516 . "CANADIAN SYLLABICS WEST-CREE RO")
(5517 . "CANADIAN SYLLABICS WEST-CREE RA")
(5518 . "CANADIAN SYLLABICS NGAAI")
(5519 . "CANADIAN SYLLABICS NGI")
(5520 . "CANADIAN SYLLABICS NGII")
(5521 . "CANADIAN SYLLABICS NGO")
(5522 . "CANADIAN SYLLABICS NGOO")
(5523 . "CANADIAN SYLLABICS NGA")
(5524 . "CANADIAN SYLLABICS NGAA")
(5525 . "CANADIAN SYLLABICS NG")
(5526 . "CANADIAN SYLLABICS NNG")
(5527 . "CANADIAN SYLLABICS SAYISI SHE")
(5528 . "CANADIAN SYLLABICS SAYISI SHI")
(5529 . "CANADIAN SYLLABICS SAYISI SHO")
(5530 . "CANADIAN SYLLABICS SAYISI SHA")
(5531 . "CANADIAN SYLLABICS WOODS-CREE THE")
(5532 . "CANADIAN SYLLABICS WOODS-CREE THI")
(5533 . "CANADIAN SYLLABICS WOODS-CREE THO")
(5534 . "CANADIAN SYLLABICS WOODS-CREE THA")
(5535 . "CANADIAN SYLLABICS WOODS-CREE TH")
(5536 . "CANADIAN SYLLABICS LHI")
(5537 . "CANADIAN SYLLABICS LHII")
(5538 . "CANADIAN SYLLABICS LHO")
(5539 . "CANADIAN SYLLABICS LHOO")
(5540 . "CANADIAN SYLLABICS LHA")
(5541 . "CANADIAN SYLLABICS LHAA")
(5542 . "CANADIAN SYLLABICS LH")
(5543 . "CANADIAN SYLLABICS TH-CREE THE")
(5544 . "CANADIAN SYLLABICS TH-CREE THI")
(5545 . "CANADIAN SYLLABICS TH-CREE THII")
(5546 . "CANADIAN SYLLABICS TH-CREE THO")
(5547 . "CANADIAN SYLLABICS TH-CREE THOO")
(5548 . "CANADIAN SYLLABICS TH-CREE THA")
(5549 . "CANADIAN SYLLABICS TH-CREE THAA")
(5550 . "CANADIAN SYLLABICS TH-CREE TH")
(5551 . "CANADIAN SYLLABICS AIVILIK B")
(5552 . "CANADIAN SYLLABICS BLACKFOOT E")
(5553 . "CANADIAN SYLLABICS BLACKFOOT I")
(5554 . "CANADIAN SYLLABICS BLACKFOOT O")
(5555 . "CANADIAN SYLLABICS BLACKFOOT A")
(5556 . "CANADIAN SYLLABICS BLACKFOOT WE")
(5557 . "CANADIAN SYLLABICS BLACKFOOT WI")
(5558 . "CANADIAN SYLLABICS BLACKFOOT WO")
(5559 . "CANADIAN SYLLABICS BLACKFOOT WA")
(5560 . "CANADIAN SYLLABICS BLACKFOOT NE")
(5561 . "CANADIAN SYLLABICS BLACKFOOT NI")
(5562 . "CANADIAN SYLLABICS BLACKFOOT NO")
(5563 . "CANADIAN SYLLABICS BLACKFOOT NA")
(5564 . "CANADIAN SYLLABICS BLACKFOOT KE")
(5565 . "CANADIAN SYLLABICS BLACKFOOT KI")
(5566 . "CANADIAN SYLLABICS BLACKFOOT KO")
(5567 . "CANADIAN SYLLABICS BLACKFOOT KA")
(5568 . "CANADIAN SYLLABICS SAYISI HE")
(5569 . "CANADIAN SYLLABICS SAYISI HI")
(5570 . "CANADIAN SYLLABICS SAYISI HO")
(5571 . "CANADIAN SYLLABICS SAYISI HA")
(5572 . "CANADIAN SYLLABICS CARRIER GHU")
(5573 . "CANADIAN SYLLABICS CARRIER GHO")
(5574 . "CANADIAN SYLLABICS CARRIER GHE")
(5575 . "CANADIAN SYLLABICS CARRIER GHEE")
(5576 . "CANADIAN SYLLABICS CARRIER GHI")
(5577 . "CANADIAN SYLLABICS CARRIER GHA")
(5578 . "CANADIAN SYLLABICS CARRIER RU")
(5579 . "CANADIAN SYLLABICS CARRIER RO")
(5580 . "CANADIAN SYLLABICS CARRIER RE")
(5581 . "CANADIAN SYLLABICS CARRIER REE")
(5582 . "CANADIAN SYLLABICS CARRIER RI")
(5583 . "CANADIAN SYLLABICS CARRIER RA")
(5584 . "CANADIAN SYLLABICS CARRIER WU")
(5585 . "CANADIAN SYLLABICS CARRIER WO")
(5586 . "CANADIAN SYLLABICS CARRIER WE")
(5587 . "CANADIAN SYLLABICS CARRIER WEE")
(5588 . "CANADIAN SYLLABICS CARRIER WI")
(5589 . "CANADIAN SYLLABICS CARRIER WA")
(5590 . "CANADIAN SYLLABICS CARRIER HWU")
(5591 . "CANADIAN SYLLABICS CARRIER HWO")
(5592 . "CANADIAN SYLLABICS CARRIER HWE")
(5593 . "CANADIAN SYLLABICS CARRIER HWEE")
(5594 . "CANADIAN SYLLABICS CARRIER HWI")
(5595 . "CANADIAN SYLLABICS CARRIER HWA")
(5596 . "CANADIAN SYLLABICS CARRIER THU")
(5597 . "CANADIAN SYLLABICS CARRIER THO")
(5598 . "CANADIAN SYLLABICS CARRIER THE")
(5599 . "CANADIAN SYLLABICS CARRIER THEE")
(5600 . "CANADIAN SYLLABICS CARRIER THI")
(5601 . "CANADIAN SYLLABICS CARRIER THA")
(5602 . "CANADIAN SYLLABICS CARRIER TTU")
(5603 . "CANADIAN SYLLABICS CARRIER TTO")
(5604 . "CANADIAN SYLLABICS CARRIER TTE")
(5605 . "CANADIAN SYLLABICS CARRIER TTEE")
(5606 . "CANADIAN SYLLABICS CARRIER TTI")
(5607 . "CANADIAN SYLLABICS CARRIER TTA")
(5608 . "CANADIAN SYLLABICS CARRIER PU")
(5609 . "CANADIAN SYLLABICS CARRIER PO")
(5610 . "CANADIAN SYLLABICS CARRIER PE")
(5611 . "CANADIAN SYLLABICS CARRIER PEE")
(5612 . "CANADIAN SYLLABICS CARRIER PI")
(5613 . "CANADIAN SYLLABICS CARRIER PA")
(5614 . "CANADIAN SYLLABICS CARRIER P")
(5615 . "CANADIAN SYLLABICS CARRIER GU")
(5616 . "CANADIAN SYLLABICS CARRIER GO")
(5617 . "CANADIAN SYLLABICS CARRIER GE")
(5618 . "CANADIAN SYLLABICS CARRIER GEE")
(5619 . "CANADIAN SYLLABICS CARRIER GI")
(5620 . "CANADIAN SYLLABICS CARRIER GA")
(5621 . "CANADIAN SYLLABICS CARRIER KHU")
(5622 . "CANADIAN SYLLABICS CARRIER KHO")
(5623 . "CANADIAN SYLLABICS CARRIER KHE")
(5624 . "CANADIAN SYLLABICS CARRIER KHEE")
(5625 . "CANADIAN SYLLABICS CARRIER KHI")
(5626 . "CANADIAN SYLLABICS CARRIER KHA")
(5627 . "CANADIAN SYLLABICS CARRIER KKU")
(5628 . "CANADIAN SYLLABICS CARRIER KKO")
(5629 . "CANADIAN SYLLABICS CARRIER KKE")
(5630 . "CANADIAN SYLLABICS CARRIER KKEE")
(5631 . "CANADIAN SYLLABICS CARRIER KKI")
(5632 . "CANADIAN SYLLABICS CARRIER KKA")
(5633 . "CANADIAN SYLLABICS CARRIER KK")
(5634 . "CANADIAN SYLLABICS CARRIER NU")
(5635 . "CANADIAN SYLLABICS CARRIER NO")
(5636 . "CANADIAN SYLLABICS CARRIER NE")
(5637 . "CANADIAN SYLLABICS CARRIER NEE")
(5638 . "CANADIAN SYLLABICS CARRIER NI")
(5639 . "CANADIAN SYLLABICS CARRIER NA")
(5640 . "CANADIAN SYLLABICS CARRIER MU")
(5641 . "CANADIAN SYLLABICS CARRIER MO")
(5642 . "CANADIAN SYLLABICS CARRIER ME")
(5643 . "CANADIAN SYLLABICS CARRIER MEE")
(5644 . "CANADIAN SYLLABICS CARRIER MI")
(5645 . "CANADIAN SYLLABICS CARRIER MA")
(5646 . "CANADIAN SYLLABICS CARRIER YU")
(5647 . "CANADIAN SYLLABICS CARRIER YO")
(5648 . "CANADIAN SYLLABICS CARRIER YE")
(5649 . "CANADIAN SYLLABICS CARRIER YEE")
(5650 . "CANADIAN SYLLABICS CARRIER YI")
(5651 . "CANADIAN SYLLABICS CARRIER YA")
(5652 . "CANADIAN SYLLABICS CARRIER JU")
(5653 . "CANADIAN SYLLABICS SAYISI JU")
(5654 . "CANADIAN SYLLABICS CARRIER JO")
(5655 . "CANADIAN SYLLABICS CARRIER JE")
(5656 . "CANADIAN SYLLABICS CARRIER JEE")
(5657 . "CANADIAN SYLLABICS CARRIER JI")
(5658 . "CANADIAN SYLLABICS SAYISI JI")
(5659 . "CANADIAN SYLLABICS CARRIER JA")
(5660 . "CANADIAN SYLLABICS CARRIER JJU")
(5661 . "CANADIAN SYLLABICS CARRIER JJO")
(5662 . "CANADIAN SYLLABICS CARRIER JJE")
(5663 . "CANADIAN SYLLABICS CARRIER JJEE")
(5664 . "CANADIAN SYLLABICS CARRIER JJI")
(5665 . "CANADIAN SYLLABICS CARRIER JJA")
(5666 . "CANADIAN SYLLABICS CARRIER LU")
(5667 . "CANADIAN SYLLABICS CARRIER LO")
(5668 . "CANADIAN SYLLABICS CARRIER LE")
(5669 . "CANADIAN SYLLABICS CARRIER LEE")
(5670 . "CANADIAN SYLLABICS CARRIER LI")
(5671 . "CANADIAN SYLLABICS CARRIER LA")
(5672 . "CANADIAN SYLLABICS CARRIER DLU")
(5673 . "CANADIAN SYLLABICS CARRIER DLO")
(5674 . "CANADIAN SYLLABICS CARRIER DLE")
(5675 . "CANADIAN SYLLABICS CARRIER DLEE")
(5676 . "CANADIAN SYLLABICS CARRIER DLI")
(5677 . "CANADIAN SYLLABICS CARRIER DLA")
(5678 . "CANADIAN SYLLABICS CARRIER LHU")
(5679 . "CANADIAN SYLLABICS CARRIER LHO")
(5680 . "CANADIAN SYLLABICS CARRIER LHE")
(5681 . "CANADIAN SYLLABICS CARRIER LHEE")
(5682 . "CANADIAN SYLLABICS CARRIER LHI")
(5683 . "CANADIAN SYLLABICS CARRIER LHA")
(5684 . "CANADIAN SYLLABICS CARRIER TLHU")
(5685 . "CANADIAN SYLLABICS CARRIER TLHO")
(5686 . "CANADIAN SYLLABICS CARRIER TLHE")
(5687 . "CANADIAN SYLLABICS CARRIER TLHEE")
(5688 . "CANADIAN SYLLABICS CARRIER TLHI")
(5689 . "CANADIAN SYLLABICS CARRIER TLHA")
(5690 . "CANADIAN SYLLABICS CARRIER TLU")
(5691 . "CANADIAN SYLLABICS CARRIER TLO")
(5692 . "CANADIAN SYLLABICS CARRIER TLE")
(5693 . "CANADIAN SYLLABICS CARRIER TLEE")
(5694 . "CANADIAN SYLLABICS CARRIER TLI")
(5695 . "CANADIAN SYLLABICS CARRIER TLA")
(5696 . "CANADIAN SYLLABICS CARRIER ZU")
(5697 . "CANADIAN SYLLABICS CARRIER ZO")
(5698 . "CANADIAN SYLLABICS CARRIER ZE")
(5699 . "CANADIAN SYLLABICS CARRIER ZEE")
(5700 . "CANADIAN SYLLABICS CARRIER ZI")
(5701 . "CANADIAN SYLLABICS CARRIER ZA")
(5702 . "CANADIAN SYLLABICS CARRIER Z")
(5703 . "CANADIAN SYLLABICS CARRIER INITIAL Z")
(5704 . "CANADIAN SYLLABICS CARRIER DZU")
(5705 . "CANADIAN SYLLABICS CARRIER DZO")
(5706 . "CANADIAN SYLLABICS CARRIER DZE")
(5707 . "CANADIAN SYLLABICS CARRIER DZEE")
(5708 . "CANADIAN SYLLABICS CARRIER DZI")
(5709 . "CANADIAN SYLLABICS CARRIER DZA")
(5710 . "CANADIAN SYLLABICS CARRIER SU")
(5711 . "CANADIAN SYLLABICS CARRIER SO")
(5712 . "CANADIAN SYLLABICS CARRIER SE")
(5713 . "CANADIAN SYLLABICS CARRIER SEE")
(5714 . "CANADIAN SYLLABICS CARRIER SI")
(5715 . "CANADIAN SYLLABICS CARRIER SA")
(5716 . "CANADIAN SYLLABICS CARRIER SHU")
(5717 . "CANADIAN SYLLABICS CARRIER SHO")
(5718 . "CANADIAN SYLLABICS CARRIER SHE")
(5719 . "CANADIAN SYLLABICS CARRIER SHEE")
(5720 . "CANADIAN SYLLABICS CARRIER SHI")
(5721 . "CANADIAN SYLLABICS CARRIER SHA")
(5722 . "CANADIAN SYLLABICS CARRIER SH")
(5723 . "CANADIAN SYLLABICS CARRIER TSU")
(5724 . "CANADIAN SYLLABICS CARRIER TSO")
(5725 . "CANADIAN SYLLABICS CARRIER TSE")
(5726 . "CANADIAN SYLLABICS CARRIER TSEE")
(5727 . "CANADIAN SYLLABICS CARRIER TSI")
(5728 . "CANADIAN SYLLABICS CARRIER TSA")
(5729 . "CANADIAN SYLLABICS CARRIER CHU")
(5730 . "CANADIAN SYLLABICS CARRIER CHO")
(5731 . "CANADIAN SYLLABICS CARRIER CHE")
(5732 . "CANADIAN SYLLABICS CARRIER CHEE")
(5733 . "CANADIAN SYLLABICS CARRIER CHI")
(5734 . "CANADIAN SYLLABICS CARRIER CHA")
(5735 . "CANADIAN SYLLABICS CARRIER TTSU")
(5736 . "CANADIAN SYLLABICS CARRIER TTSO")
(5737 . "CANADIAN SYLLABICS CARRIER TTSE")
(5738 . "CANADIAN SYLLABICS CARRIER TTSEE")
(5739 . "CANADIAN SYLLABICS CARRIER TTSI")
(5740 . "CANADIAN SYLLABICS CARRIER TTSA")
(5741 . "CANADIAN SYLLABICS CHI SIGN")
(5742 . "CANADIAN SYLLABICS FULL STOP")
(5743 . "CANADIAN SYLLABICS QAI")
(5744 . "CANADIAN SYLLABICS NGAI")
(5745 . "CANADIAN SYLLABICS NNGI")
(5746 . "CANADIAN SYLLABICS NNGII")
(5747 . "CANADIAN SYLLABICS NNGO")
(5748 . "CANADIAN SYLLABICS NNGOO")
(5749 . "CANADIAN SYLLABICS NNGA")
(5750 . "CANADIAN SYLLABICS NNGAA")
(5751 . "CANADIAN SYLLABICS WOODS-CREE THWEE")
(5752 . "CANADIAN SYLLABICS WOODS-CREE THWI")
(5753 . "CANADIAN SYLLABICS WOODS-CREE THWII")
(5754 . "CANADIAN SYLLABICS WOODS-CREE THWO")
(5755 . "CANADIAN SYLLABICS WOODS-CREE THWOO")
(5756 . "CANADIAN SYLLABICS WOODS-CREE THWA")
(5757 . "CANADIAN SYLLABICS WOODS-CREE THWAA")
(5758 . "CANADIAN SYLLABICS WOODS-CREE FINAL TH")
(5759 . "CANADIAN SYLLABICS BLACKFOOT W")
(5760 . "OGHAM SPACE MARK")
(5761 . "OGHAM LETTER BEITH")
(5762 . "OGHAM LETTER LUIS")
(5763 . "OGHAM LETTER FEARN")
(5764 . "OGHAM LETTER SAIL")
(5765 . "OGHAM LETTER NION")
(5766 . "OGHAM LETTER UATH")
(5767 . "OGHAM LETTER DAIR")
(5768 . "OGHAM LETTER TINNE")
(5769 . "OGHAM LETTER COLL")
(5770 . "OGHAM LETTER CEIRT")
(5771 . "OGHAM LETTER MUIN")
(5772 . "OGHAM LETTER GORT")
(5773 . "OGHAM LETTER NGEADAL")
(5774 . "OGHAM LETTER STRAIF")
(5775 . "OGHAM LETTER RUIS")
(5776 . "OGHAM LETTER AILM")
(5777 . "OGHAM LETTER ONN")
(5778 . "OGHAM LETTER UR")
(5779 . "OGHAM LETTER EADHADH")
(5780 . "OGHAM LETTER IODHADH")
(5781 . "OGHAM LETTER EABHADH")
(5782 . "OGHAM LETTER OR")
(5783 . "OGHAM LETTER UILLEANN")
(5784 . "OGHAM LETTER IFIN")
(5785 . "OGHAM LETTER EAMHANCHOLL")
(5786 . "OGHAM LETTER PEITH")
(5787 . "OGHAM FEATHER MARK")
(5788 . "OGHAM REVERSED FEATHER MARK")
((5789 . 5792) . #f)
(5792 . "RUNIC LETTER FEHU FEOH FE F")
(5793 . "RUNIC LETTER V")
(5794 . "RUNIC LETTER URUZ UR U")
(5795 . "RUNIC LETTER YR")
(5796 . "RUNIC LETTER Y")
(5797 . "RUNIC LETTER W")
(5798 . "RUNIC LETTER THURISAZ THURS THORN")
(5799 . "RUNIC LETTER ETH")
(5800 . "RUNIC LETTER ANSUZ A")
(5801 . "RUNIC LETTER OS O")
(5802 . "RUNIC LETTER AC A")
(5803 . "RUNIC LETTER AESC")
(5804 . "RUNIC LETTER LONG-BRANCH-OSS O")
(5805 . "RUNIC LETTER SHORT-TWIG-OSS O")
(5806 . "RUNIC LETTER O")
(5807 . "RUNIC LETTER OE")
(5808 . "RUNIC LETTER ON")
(5809 . "RUNIC LETTER RAIDO RAD REID R")
(5810 . "RUNIC LETTER KAUNA")
(5811 . "RUNIC LETTER CEN")
(5812 . "RUNIC LETTER KAUN K")
(5813 . "RUNIC LETTER G")
(5814 . "RUNIC LETTER ENG")
(5815 . "RUNIC LETTER GEBO GYFU G")
(5816 . "RUNIC LETTER GAR")
(5817 . "RUNIC LETTER WUNJO WYNN W")
(5818 . "RUNIC LETTER HAGLAZ H")
(5819 . "RUNIC LETTER HAEGL H")
(5820 . "RUNIC LETTER LONG-BRANCH-HAGALL H")
(5821 . "RUNIC LETTER SHORT-TWIG-HAGALL H")
(5822 . "RUNIC LETTER NAUDIZ NYD NAUD N")
(5823 . "RUNIC LETTER SHORT-TWIG-NAUD N")
(5824 . "RUNIC LETTER DOTTED-N")
(5825 . "RUNIC LETTER ISAZ IS ISS I")
(5826 . "RUNIC LETTER E")
(5827 . "RUNIC LETTER JERAN J")
(5828 . "RUNIC LETTER GER")
(5829 . "RUNIC LETTER LONG-BRANCH-AR AE")
(5830 . "RUNIC LETTER SHORT-TWIG-AR A")
(5831 . "RUNIC LETTER IWAZ EOH")
(5832 . "RUNIC LETTER PERTHO PEORTH P")
(5833 . "RUNIC LETTER ALGIZ EOLHX")
(5834 . "RUNIC LETTER SOWILO S")
(5835 . "RUNIC LETTER SIGEL LONG-BRANCH-SOL S")
(5836 . "RUNIC LETTER SHORT-TWIG-SOL S")
(5837 . "RUNIC LETTER C")
(5838 . "RUNIC LETTER Z")
(5839 . "RUNIC LETTER TIWAZ TIR TYR T")
(5840 . "RUNIC LETTER SHORT-TWIG-TYR T")
(5841 . "RUNIC LETTER D")
(5842 . "RUNIC LETTER BERKANAN BEORC BJARKAN B")
(5843 . "RUNIC LETTER SHORT-TWIG-BJARKAN B")
(5844 . "RUNIC LETTER DOTTED-P")
(5845 . "RUNIC LETTER OPEN-P")
(5846 . "RUNIC LETTER EHWAZ EH E")
(5847 . "RUNIC LETTER MANNAZ MAN M")
(5848 . "RUNIC LETTER LONG-BRANCH-MADR M")
(5849 . "RUNIC LETTER SHORT-TWIG-MADR M")
(5850 . "RUNIC LETTER LAUKAZ LAGU LOGR L")
(5851 . "RUNIC LETTER DOTTED-L")
(5852 . "RUNIC LETTER INGWAZ")
(5853 . "RUNIC LETTER ING")
(5854 . "RUNIC LETTER DAGAZ DAEG D")
(5855 . "RUNIC LETTER OTHALAN ETHEL O")
(5856 . "RUNIC LETTER EAR")
(5857 . "RUNIC LETTER IOR")
(5858 . "RUNIC LETTER CWEORTH")
(5859 . "RUNIC LETTER CALC")
(5860 . "RUNIC LETTER CEALC")
(5861 . "RUNIC LETTER STAN")
(5862 . "RUNIC LETTER LONG-BRANCH-YR")
(5863 . "RUNIC LETTER SHORT-TWIG-YR")
(5864 . "RUNIC LETTER ICELANDIC-YR")
(5865 . "RUNIC LETTER Q")
(5866 . "RUNIC LETTER X")
(5867 . "RUNIC SINGLE PUNCTUATION")
(5868 . "RUNIC MULTIPLE PUNCTUATION")
(5869 . "RUNIC CROSS PUNCTUATION")
(5870 . "RUNIC ARLAUG SYMBOL")
(5871 . "RUNIC TVIMADUR SYMBOL")
(5872 . "RUNIC BELGTHOR SYMBOL")
(5873 . "RUNIC LETTER K")
(5874 . "RUNIC LETTER SH")
(5875 . "RUNIC LETTER OO")
(5876 . "RUNIC LETTER FRANKS CASKET OS")
(5877 . "RUNIC LETTER FRANKS CASKET IS")
(5878 . "RUNIC LETTER FRANKS CASKET EH")
(5879 . "RUNIC LETTER FRANKS CASKET AC")
(5880 . "RUNIC LETTER FRANKS CASKET AESC")
((5881 . 5888) . #f)
(5888 . "TAGALOG LETTER A")
(5889 . "TAGALOG LETTER I")
(5890 . "TAGALOG LETTER U")
(5891 . "TAGALOG LETTER KA")
(5892 . "TAGALOG LETTER GA")
(5893 . "TAGALOG LETTER NGA")
(5894 . "TAGALOG LETTER TA")
(5895 . "TAGALOG LETTER DA")
(5896 . "TAGALOG LETTER NA")
(5897 . "TAGALOG LETTER PA")
(5898 . "TAGALOG LETTER BA")
(5899 . "TAGALOG LETTER MA")
(5900 . "TAGALOG LETTER YA")
(5901 . #f)
(5902 . "TAGALOG LETTER LA")
(5903 . "TAGALOG LETTER WA")
(5904 . "TAGALOG LETTER SA")
(5905 . "TAGALOG LETTER HA")
(5906 . "TAGALOG VOWEL SIGN I")
(5907 . "TAGALOG VOWEL SIGN U")
(5908 . "TAGALOG SIGN VIRAMA")
((5909 . 5920) . #f)
(5920 . "HANUNOO LETTER A")
(5921 . "HANUNOO LETTER I")
(5922 . "HANUNOO LETTER U")
(5923 . "HANUNOO LETTER KA")
(5924 . "HANUNOO LETTER GA")
(5925 . "HANUNOO LETTER NGA")
(5926 . "HANUNOO LETTER TA")
(5927 . "HANUNOO LETTER DA")
(5928 . "HANUNOO LETTER NA")
(5929 . "HANUNOO LETTER PA")
(5930 . "HANUNOO LETTER BA")
(5931 . "HANUNOO LETTER MA")
(5932 . "HANUNOO LETTER YA")
(5933 . "HANUNOO LETTER RA")
(5934 . "HANUNOO LETTER LA")
(5935 . "HANUNOO LETTER WA")
(5936 . "HANUNOO LETTER SA")
(5937 . "HANUNOO LETTER HA")
(5938 . "HANUNOO VOWEL SIGN I")
(5939 . "HANUNOO VOWEL SIGN U")
(5940 . "HANUNOO SIGN PAMUDPOD")
(5941 . "PHILIPPINE SINGLE PUNCTUATION")
(5942 . "PHILIPPINE DOUBLE PUNCTUATION")
((5943 . 5952) . #f)
(5952 . "BUHID LETTER A")
(5953 . "BUHID LETTER I")
(5954 . "BUHID LETTER U")
(5955 . "BUHID LETTER KA")
(5956 . "BUHID LETTER GA")
(5957 . "BUHID LETTER NGA")
(5958 . "BUHID LETTER TA")
(5959 . "BUHID LETTER DA")
(5960 . "BUHID LETTER NA")
(5961 . "BUHID LETTER PA")
(5962 . "BUHID LETTER BA")
(5963 . "BUHID LETTER MA")
(5964 . "BUHID LETTER YA")
(5965 . "BUHID LETTER RA")
(5966 . "BUHID LETTER LA")
(5967 . "BUHID LETTER WA")
(5968 . "BUHID LETTER SA")
(5969 . "BUHID LETTER HA")
(5970 . "BUHID VOWEL SIGN I")
(5971 . "BUHID VOWEL SIGN U")
((5972 . 5984) . #f)
(5984 . "TAGBANWA LETTER A")
(5985 . "TAGBANWA LETTER I")
(5986 . "TAGBANWA LETTER U")
(5987 . "TAGBANWA LETTER KA")
(5988 . "TAGBANWA LETTER GA")
(5989 . "TAGBANWA LETTER NGA")
(5990 . "TAGBANWA LETTER TA")
(5991 . "TAGBANWA LETTER DA")
(5992 . "TAGBANWA LETTER NA")
(5993 . "TAGBANWA LETTER PA")
(5994 . "TAGBANWA LETTER BA")
(5995 . "TAGBANWA LETTER MA")
(5996 . "TAGBANWA LETTER YA")
(5997 . #f)
(5998 . "TAGBANWA LETTER LA")
(5999 . "TAGBANWA LETTER WA")
(6000 . "TAGBANWA LETTER SA")
(6001 . #f)
(6002 . "TAGBANWA VOWEL SIGN I")
(6003 . "TAGBANWA VOWEL SIGN U")
((6004 . 6016) . #f)
(6016 . "KHMER LETTER KA")
(6017 . "KHMER LETTER KHA")
(6018 . "KHMER LETTER KO")
(6019 . "KHMER LETTER KHO")
(6020 . "KHMER LETTER NGO")
(6021 . "KHMER LETTER CA")
(6022 . "KHMER LETTER CHA")
(6023 . "KHMER LETTER CO")
(6024 . "KHMER LETTER CHO")
(6025 . "KHMER LETTER NYO")
(6026 . "KHMER LETTER DA")
(6027 . "KHMER LETTER TTHA")
(6028 . "KHMER LETTER DO")
(6029 . "KHMER LETTER TTHO")
(6030 . "KHMER LETTER NNO")
(6031 . "KHMER LETTER TA")
(6032 . "KHMER LETTER THA")
(6033 . "KHMER LETTER TO")
(6034 . "KHMER LETTER THO")
(6035 . "KHMER LETTER NO")
(6036 . "KHMER LETTER BA")
(6037 . "KHMER LETTER PHA")
(6038 . "KHMER LETTER PO")
(6039 . "KHMER LETTER PHO")
(6040 . "KHMER LETTER MO")
(6041 . "KHMER LETTER YO")
(6042 . "KHMER LETTER RO")
(6043 . "KHMER LETTER LO")
(6044 . "KHMER LETTER VO")
(6045 . "KHMER LETTER SHA")
(6046 . "KHMER LETTER SSO")
(6047 . "KHMER LETTER SA")
(6048 . "KHMER LETTER HA")
(6049 . "KHMER LETTER LA")
(6050 . "KHMER LETTER QA")
(6051 . "KHMER INDEPENDENT VOWEL QAQ")
(6052 . "KHMER INDEPENDENT VOWEL QAA")
(6053 . "KHMER INDEPENDENT VOWEL QI")
(6054 . "KHMER INDEPENDENT VOWEL QII")
(6055 . "KHMER INDEPENDENT VOWEL QU")
(6056 . "KHMER INDEPENDENT VOWEL QUK")
(6057 . "KHMER INDEPENDENT VOWEL QUU")
(6058 . "KHMER INDEPENDENT VOWEL QUUV")
(6059 . "KHMER INDEPENDENT VOWEL RY")
(6060 . "KHMER INDEPENDENT VOWEL RYY")
(6061 . "KHMER INDEPENDENT VOWEL LY")
(6062 . "KHMER INDEPENDENT VOWEL LYY")
(6063 . "KHMER INDEPENDENT VOWEL QE")
(6064 . "KHMER INDEPENDENT VOWEL QAI")
(6065 . "KHMER INDEPENDENT VOWEL QOO TYPE ONE")
(6066 . "KHMER INDEPENDENT VOWEL QOO TYPE TWO")
(6067 . "KHMER INDEPENDENT VOWEL QAU")
(6068 . "KHMER VOWEL INHERENT AQ")
(6069 . "KHMER VOWEL INHERENT AA")
(6070 . "KHMER VOWEL SIGN AA")
(6071 . "KHMER VOWEL SIGN I")
(6072 . "KHMER VOWEL SIGN II")
(6073 . "KHMER VOWEL SIGN Y")
(6074 . "KHMER VOWEL SIGN YY")
(6075 . "KHMER VOWEL SIGN U")
(6076 . "KHMER VOWEL SIGN UU")
(6077 . "KHMER VOWEL SIGN UA")
(6078 . "KHMER VOWEL SIGN OE")
(6079 . "KHMER VOWEL SIGN YA")
(6080 . "KHMER VOWEL SIGN IE")
(6081 . "KHMER VOWEL SIGN E")
(6082 . "KHMER VOWEL SIGN AE")
(6083 . "KHMER VOWEL SIGN AI")
(6084 . "KHMER VOWEL SIGN OO")
(6085 . "KHMER VOWEL SIGN AU")
(6086 . "KHMER SIGN NIKAHIT")
(6087 . "KHMER SIGN REAHMUK")
(6088 . "KHMER SIGN YUUKALEAPINTU")
(6089 . "KHMER SIGN MUUSIKATOAN")
(6090 . "KHMER SIGN TRIISAP")
(6091 . "KHMER SIGN BANTOC")
(6092 . "KHMER SIGN ROBAT")
(6093 . "KHMER SIGN TOANDAKHIAT")
(6094 . "KHMER SIGN KAKABAT")
(6095 . "KHMER SIGN AHSDA")
(6096 . "KHMER SIGN SAMYOK SANNYA")
(6097 . "KHMER SIGN VIRIAM")
(6098 . "KHMER SIGN COENG")
(6099 . "KHMER SIGN BATHAMASAT")
(6100 . "KHMER SIGN KHAN")
(6101 . "KHMER SIGN BARIYOOSAN")
(6102 . "KHMER SIGN CAMNUC PII KUUH")
(6103 . "KHMER SIGN LEK TOO")
(6104 . "KHMER SIGN BEYYAL")
(6105 . "KHMER SIGN PHNAEK MUAN")
(6106 . "KHMER SIGN KOOMUUT")
(6107 . "KHMER CURRENCY SYMBOL RIEL")
(6108 . "KHMER SIGN AVAKRAHASANYA")
(6109 . "KHMER SIGN ATTHACAN")
((6110 . 6112) . #f)
(6112 . "KHMER DIGIT ZERO")
(6113 . "KHMER DIGIT ONE")
(6114 . "KHMER DIGIT TWO")
(6115 . "KHMER DIGIT THREE")
(6116 . "KHMER DIGIT FOUR")
(6117 . "KHMER DIGIT FIVE")
(6118 . "KHMER DIGIT SIX")
(6119 . "KHMER DIGIT SEVEN")
(6120 . "KHMER DIGIT EIGHT")
(6121 . "KHMER DIGIT NINE")
((6122 . 6128) . #f)
(6128 . "KHMER SYMBOL LEK ATTAK SON")
(6129 . "KHMER SYMBOL LEK ATTAK MUOY")
(6130 . "KHMER SYMBOL LEK ATTAK PII")
(6131 . "KHMER SYMBOL LEK ATTAK BEI")
(6132 . "KHMER SYMBOL LEK ATTAK BUON")
(6133 . "KHMER SYMBOL LEK ATTAK PRAM")
(6134 . "KHMER SYMBOL LEK ATTAK PRAM-MUOY")
(6135 . "KHMER SYMBOL LEK ATTAK PRAM-PII")
(6136 . "KHMER SYMBOL LEK ATTAK PRAM-BEI")
(6137 . "KHMER SYMBOL LEK ATTAK PRAM-BUON")
((6138 . 6144) . #f)
(6144 . "MONGOLIAN BIRGA")
(6145 . "MONGOLIAN ELLIPSIS")
(6146 . "MONGOLIAN COMMA")
(6147 . "MONGOLIAN FULL STOP")
(6148 . "MONGOLIAN COLON")
(6149 . "MONGOLIAN FOUR DOTS")
(6150 . "MONGOLIAN TODO SOFT HYPHEN")
(6151 . "MONGOLIAN SIBE SYLLABLE BOUNDARY MARKER")
(6152 . "MONGOLIAN MANCHU COMMA")
(6153 . "MONGOLIAN MANCHU FULL STOP")
(6154 . "MONGOLIAN NIRUGU")
(6155 . "MONGOLIAN FREE VARIATION SELECTOR ONE")
(6156 . "MONGOLIAN FREE VARIATION SELECTOR TWO")
(6157 . "MONGOLIAN FREE VARIATION SELECTOR THREE")
(6158 . "MONGOLIAN VOWEL SEPARATOR")
(6159 . #f)
(6160 . "MONGOLIAN DIGIT ZERO")
(6161 . "MONGOLIAN DIGIT ONE")
(6162 . "MONGOLIAN DIGIT TWO")
(6163 . "MONGOLIAN DIGIT THREE")
(6164 . "MONGOLIAN DIGIT FOUR")
(6165 . "MONGOLIAN DIGIT FIVE")
(6166 . "MONGOLIAN DIGIT SIX")
(6167 . "MONGOLIAN DIGIT SEVEN")
(6168 . "MONGOLIAN DIGIT EIGHT")
(6169 . "MONGOLIAN DIGIT NINE")
((6170 . 6176) . #f)
(6176 . "MONGOLIAN LETTER A")
(6177 . "MONGOLIAN LETTER E")
(6178 . "MONGOLIAN LETTER I")
(6179 . "MONGOLIAN LETTER O")
(6180 . "MONGOLIAN LETTER U")
(6181 . "MONGOLIAN LETTER OE")
(6182 . "MONGOLIAN LETTER UE")
(6183 . "MONGOLIAN LETTER EE")
(6184 . "MONGOLIAN LETTER NA")
(6185 . "MONGOLIAN LETTER ANG")
(6186 . "MONGOLIAN LETTER BA")
(6187 . "MONGOLIAN LETTER PA")
(6188 . "MONGOLIAN LETTER QA")
(6189 . "MONGOLIAN LETTER GA")
(6190 . "MONGOLIAN LETTER MA")
(6191 . "MONGOLIAN LETTER LA")
(6192 . "MONGOLIAN LETTER SA")
(6193 . "MONGOLIAN LETTER SHA")
(6194 . "MONGOLIAN LETTER TA")
(6195 . "MONGOLIAN LETTER DA")
(6196 . "MONGOLIAN LETTER CHA")
(6197 . "MONGOLIAN LETTER JA")
(6198 . "MONGOLIAN LETTER YA")
(6199 . "MONGOLIAN LETTER RA")
(6200 . "MONGOLIAN LETTER WA")
(6201 . "MONGOLIAN LETTER FA")
(6202 . "MONGOLIAN LETTER KA")
(6203 . "MONGOLIAN LETTER KHA")
(6204 . "MONGOLIAN LETTER TSA")
(6205 . "MONGOLIAN LETTER ZA")
(6206 . "MONGOLIAN LETTER HAA")
(6207 . "MONGOLIAN LETTER ZRA")
(6208 . "MONGOLIAN LETTER LHA")
(6209 . "MONGOLIAN LETTER ZHI")
(6210 . "MONGOLIAN LETTER CHI")
(6211 . "MONGOLIAN LETTER TODO LONG VOWEL SIGN")
(6212 . "MONGOLIAN LETTER TODO E")
(6213 . "MONGOLIAN LETTER TODO I")
(6214 . "MONGOLIAN LETTER TODO O")
(6215 . "MONGOLIAN LETTER TODO U")
(6216 . "MONGOLIAN LETTER TODO OE")
(6217 . "MONGOLIAN LETTER TODO UE")
(6218 . "MONGOLIAN LETTER TODO ANG")
(6219 . "MONGOLIAN LETTER TODO BA")
(6220 . "MONGOLIAN LETTER TODO PA")
(6221 . "MONGOLIAN LETTER TODO QA")
(6222 . "MONGOLIAN LETTER TODO GA")
(6223 . "MONGOLIAN LETTER TODO MA")
(6224 . "MONGOLIAN LETTER TODO TA")
(6225 . "MONGOLIAN LETTER TODO DA")
(6226 . "MONGOLIAN LETTER TODO CHA")
(6227 . "MONGOLIAN LETTER TODO JA")
(6228 . "MONGOLIAN LETTER TODO TSA")
(6229 . "MONGOLIAN LETTER TODO YA")
(6230 . "MONGOLIAN LETTER TODO WA")
(6231 . "MONGOLIAN LETTER TODO KA")
(6232 . "MONGOLIAN LETTER TODO GAA")
(6233 . "MONGOLIAN LETTER TODO HAA")
(6234 . "MONGOLIAN LETTER TODO JIA")
(6235 . "MONGOLIAN LETTER TODO NIA")
(6236 . "MONGOLIAN LETTER TODO DZA")
(6237 . "MONGOLIAN LETTER SIBE E")
(6238 . "MONGOLIAN LETTER SIBE I")
(6239 . "MONGOLIAN LETTER SIBE IY")
(6240 . "MONGOLIAN LETTER SIBE UE")
(6241 . "MONGOLIAN LETTER SIBE U")
(6242 . "MONGOLIAN LETTER SIBE ANG")
(6243 . "MONGOLIAN LETTER SIBE KA")
(6244 . "MONGOLIAN LETTER SIBE GA")
(6245 . "MONGOLIAN LETTER SIBE HA")
(6246 . "MONGOLIAN LETTER SIBE PA")
(6247 . "MONGOLIAN LETTER SIBE SHA")
(6248 . "MONGOLIAN LETTER SIBE TA")
(6249 . "MONGOLIAN LETTER SIBE DA")
(6250 . "MONGOLIAN LETTER SIBE JA")
(6251 . "MONGOLIAN LETTER SIBE FA")
(6252 . "MONGOLIAN LETTER SIBE GAA")
(6253 . "MONGOLIAN LETTER SIBE HAA")
(6254 . "MONGOLIAN LETTER SIBE TSA")
(6255 . "MONGOLIAN LETTER SIBE ZA")
(6256 . "MONGOLIAN LETTER SIBE RAA")
(6257 . "MONGOLIAN LETTER SIBE CHA")
(6258 . "MONGOLIAN LETTER SIBE ZHA")
(6259 . "MONGOLIAN LETTER MANCHU I")
(6260 . "MONGOLIAN LETTER MANCHU KA")
(6261 . "MONGOLIAN LETTER MANCHU RA")
(6262 . "MONGOLIAN LETTER MANCHU FA")
(6263 . "MONGOLIAN LETTER MANCHU ZHA")
((6264 . 6272) . #f)
(6272 . "MONGOLIAN LETTER ALI GALI ANUSVARA ONE")
(6273 . "MONGOLIAN LETTER ALI GALI VISARGA ONE")
(6274 . "MONGOLIAN LETTER ALI GALI DAMARU")
(6275 . "MONGOLIAN LETTER ALI GALI UBADAMA")
(6276 . "MONGOLIAN LETTER ALI GALI INVERTED UBADAMA")
(6277 . "MONGOLIAN LETTER ALI GALI BALUDA")
(6278 . "MONGOLIAN LETTER ALI GALI THREE BALUDA")
(6279 . "MONGOLIAN LETTER ALI GALI A")
(6280 . "MONGOLIAN LETTER ALI GALI I")
(6281 . "MONGOLIAN LETTER ALI GALI KA")
(6282 . "MONGOLIAN LETTER ALI GALI NGA")
(6283 . "MONGOLIAN LETTER ALI GALI CA")
(6284 . "MONGOLIAN LETTER ALI GALI TTA")
(6285 . "MONGOLIAN LETTER ALI GALI TTHA")
(6286 . "MONGOLIAN LETTER ALI GALI DDA")
(6287 . "MONGOLIAN LETTER ALI GALI NNA")
(6288 . "MONGOLIAN LETTER ALI GALI TA")
(6289 . "MONGOLIAN LETTER ALI GALI DA")
(6290 . "MONGOLIAN LETTER ALI GALI PA")
(6291 . "MONGOLIAN LETTER ALI GALI PHA")
(6292 . "MONGOLIAN LETTER ALI GALI SSA")
(6293 . "MONGOLIAN LETTER ALI GALI ZHA")
(6294 . "MONGOLIAN LETTER ALI GALI ZA")
(6295 . "MONGOLIAN LETTER ALI GALI AH")
(6296 . "MONGOLIAN LETTER TODO ALI GALI TA")
(6297 . "MONGOLIAN LETTER TODO ALI GALI ZHA")
(6298 . "MONGOLIAN LETTER MANCHU ALI GALI GHA")
(6299 . "MONGOLIAN LETTER MANCHU ALI GALI NGA")
(6300 . "MONGOLIAN LETTER MANCHU ALI GALI CA")
(6301 . "MONGOLIAN LETTER MANCHU ALI GALI JHA")
(6302 . "MONGOLIAN LETTER MANCHU ALI GALI TTA")
(6303 . "MONGOLIAN LETTER MANCHU ALI GALI DDHA")
(6304 . "MONGOLIAN LETTER MANCHU ALI GALI TA")
(6305 . "MONGOLIAN LETTER MANCHU ALI GALI DHA")
(6306 . "MONGOLIAN LETTER MANCHU ALI GALI SSA")
(6307 . "MONGOLIAN LETTER MANCHU ALI GALI CYA")
(6308 . "MONGOLIAN LETTER MANCHU ALI GALI ZHA")
(6309 . "MONGOLIAN LETTER MANCHU ALI GALI ZA")
(6310 . "MONGOLIAN LETTER ALI GALI HALF U")
(6311 . "MONGOLIAN LETTER ALI GALI HALF YA")
(6312 . "MONGOLIAN LETTER MANCHU ALI GALI BHA")
(6313 . "MONGOLIAN LETTER ALI GALI DAGALGA")
(6314 . "MONGOLIAN LETTER MANCHU ALI GALI LHA")
((6315 . 6320) . #f)
(6320 . "CANADIAN SYLLABICS OY")
(6321 . "CANADIAN SYLLABICS AY")
(6322 . "CANADIAN SYLLABICS AAY")
(6323 . "CANADIAN SYLLABICS WAY")
(6324 . "CANADIAN SYLLABICS POY")
(6325 . "CANADIAN SYLLABICS PAY")
(6326 . "CANADIAN SYLLABICS PWOY")
(6327 . "CANADIAN SYLLABICS TAY")
(6328 . "CANADIAN SYLLABICS KAY")
(6329 . "CANADIAN SYLLABICS KWAY")
(6330 . "CANADIAN SYLLABICS MAY")
(6331 . "CANADIAN SYLLABICS NOY")
(6332 . "CANADIAN SYLLABICS NAY")
(6333 . "CANADIAN SYLLABICS LAY")
(6334 . "CANADIAN SYLLABICS SOY")
(6335 . "CANADIAN SYLLABICS SAY")
(6336 . "CANADIAN SYLLABICS SHOY")
(6337 . "CANADIAN SYLLABICS SHAY")
(6338 . "CANADIAN SYLLABICS SHWOY")
(6339 . "CANADIAN SYLLABICS YOY")
(6340 . "CANADIAN SYLLABICS YAY")
(6341 . "CANADIAN SYLLABICS RAY")
(6342 . "CANADIAN SYLLABICS NWI")
(6343 . "CANADIAN SYLLABICS OJIBWAY NWI")
(6344 . "CANADIAN SYLLABICS NWII")
(6345 . "CANADIAN SYLLABICS OJIBWAY NWII")
(6346 . "CANADIAN SYLLABICS NWO")
(6347 . "CANADIAN SYLLABICS OJIBWAY NWO")
(6348 . "CANADIAN SYLLABICS NWOO")
(6349 . "CANADIAN SYLLABICS OJIBWAY NWOO")
(6350 . "CANADIAN SYLLABICS RWEE")
(6351 . "CANADIAN SYLLABICS RWI")
(6352 . "CANADIAN SYLLABICS RWII")
(6353 . "CANADIAN SYLLABICS RWO")
(6354 . "CANADIAN SYLLABICS RWOO")
(6355 . "CANADIAN SYLLABICS RWA")
(6356 . "CANADIAN SYLLABICS OJIBWAY P")
(6357 . "CANADIAN SYLLABICS OJIBWAY T")
(6358 . "CANADIAN SYLLABICS OJIBWAY K")
(6359 . "CANADIAN SYLLABICS OJIBWAY C")
(6360 . "CANADIAN SYLLABICS OJIBWAY M")
(6361 . "CANADIAN SYLLABICS OJIBWAY N")
(6362 . "CANADIAN SYLLABICS OJIBWAY S")
(6363 . "CANADIAN SYLLABICS OJIBWAY SH")
(6364 . "CANADIAN SYLLABICS EASTERN W")
(6365 . "CANADIAN SYLLABICS WESTERN W")
(6366 . "CANADIAN SYLLABICS FINAL SMALL RING")
(6367 . "CANADIAN SYLLABICS FINAL RAISED DOT")
(6368 . "CANADIAN SYLLABICS R-CREE RWE")
(6369 . "CANADIAN SYLLABICS WEST-CREE LOO")
(6370 . "CANADIAN SYLLABICS WEST-CREE LAA")
(6371 . "CANADIAN SYLLABICS THWE")
(6372 . "CANADIAN SYLLABICS THWA")
(6373 . "CANADIAN SYLLABICS TTHWE")
(6374 . "CANADIAN SYLLABICS TTHOO")
(6375 . "CANADIAN SYLLABICS TTHAA")
(6376 . "CANADIAN SYLLABICS TLHWE")
(6377 . "CANADIAN SYLLABICS TLHOO")
(6378 . "CANADIAN SYLLABICS SAYISI SHWE")
(6379 . "CANADIAN SYLLABICS SAYISI SHOO")
(6380 . "CANADIAN SYLLABICS SAYISI HOO")
(6381 . "CANADIAN SYLLABICS CARRIER GWU")
(6382 . "CANADIAN SYLLABICS CARRIER DENE GEE")
(6383 . "CANADIAN SYLLABICS CARRIER GAA")
(6384 . "CANADIAN SYLLABICS CARRIER GWA")
(6385 . "CANADIAN SYLLABICS SAYISI JUU")
(6386 . "CANADIAN SYLLABICS CARRIER JWA")
(6387 . "CANADIAN SYLLABICS BEAVER DENE L")
(6388 . "CANADIAN SYLLABICS BEAVER DENE R")
(6389 . "CANADIAN SYLLABICS CARRIER DENTAL S")
((6390 . 6400) . #f)
(6400 . "LIMBU VOWEL-CARRIER LETTER")
(6401 . "LIMBU LETTER KA")
(6402 . "LIMBU LETTER KHA")
(6403 . "LIMBU LETTER GA")
(6404 . "LIMBU LETTER GHA")
(6405 . "LIMBU LETTER NGA")
(6406 . "LIMBU LETTER CA")
(6407 . "LIMBU LETTER CHA")
(6408 . "LIMBU LETTER JA")
(6409 . "LIMBU LETTER JHA")
(6410 . "LIMBU LETTER YAN")
(6411 . "LIMBU LETTER TA")
(6412 . "LIMBU LETTER THA")
(6413 . "LIMBU LETTER DA")
(6414 . "LIMBU LETTER DHA")
(6415 . "LIMBU LETTER NA")
(6416 . "LIMBU LETTER PA")
(6417 . "LIMBU LETTER PHA")
(6418 . "LIMBU LETTER BA")
(6419 . "LIMBU LETTER BHA")
(6420 . "LIMBU LETTER MA")
(6421 . "LIMBU LETTER YA")
(6422 . "LIMBU LETTER RA")
(6423 . "LIMBU LETTER LA")
(6424 . "LIMBU LETTER WA")
(6425 . "LIMBU LETTER SHA")
(6426 . "LIMBU LETTER SSA")
(6427 . "LIMBU LETTER SA")
(6428 . "LIMBU LETTER HA")
(6429 . "LIMBU LETTER GYAN")
(6430 . "LIMBU LETTER TRA")
(6431 . #f)
(6432 . "LIMBU VOWEL SIGN A")
(6433 . "LIMBU VOWEL SIGN I")
(6434 . "LIMBU VOWEL SIGN U")
(6435 . "LIMBU VOWEL SIGN EE")
(6436 . "LIMBU VOWEL SIGN AI")
(6437 . "LIMBU VOWEL SIGN OO")
(6438 . "LIMBU VOWEL SIGN AU")
(6439 . "LIMBU VOWEL SIGN E")
(6440 . "LIMBU VOWEL SIGN O")
(6441 . "LIMBU SUBJOINED LETTER YA")
(6442 . "LIMBU SUBJOINED LETTER RA")
(6443 . "LIMBU SUBJOINED LETTER WA")
((6444 . 6448) . #f)
(6448 . "LIMBU SMALL LETTER KA")
(6449 . "LIMBU SMALL LETTER NGA")
(6450 . "LIMBU SMALL LETTER ANUSVARA")
(6451 . "LIMBU SMALL LETTER TA")
(6452 . "LIMBU SMALL LETTER NA")
(6453 . "LIMBU SMALL LETTER PA")
(6454 . "LIMBU SMALL LETTER MA")
(6455 . "LIMBU SMALL LETTER RA")
(6456 . "LIMBU SMALL LETTER LA")
(6457 . "LIMBU SIGN MUKPHRENG")
(6458 . "LIMBU SIGN KEMPHRENG")
(6459 . "LIMBU SIGN SA-I")
((6460 . 6464) . #f)
(6464 . "LIMBU SIGN LOO")
((6465 . 6468) . #f)
(6468 . "LIMBU EXCLAMATION MARK")
(6469 . "LIMBU QUESTION MARK")
(6470 . "LIMBU DIGIT ZERO")
(6471 . "LIMBU DIGIT ONE")
(6472 . "LIMBU DIGIT TWO")
(6473 . "LIMBU DIGIT THREE")
(6474 . "LIMBU DIGIT FOUR")
(6475 . "LIMBU DIGIT FIVE")
(6476 . "LIMBU DIGIT SIX")
(6477 . "LIMBU DIGIT SEVEN")
(6478 . "LIMBU DIGIT EIGHT")
(6479 . "LIMBU DIGIT NINE")
(6480 . "TAI LE LETTER KA")
(6481 . "TAI LE LETTER XA")
(6482 . "TAI LE LETTER NGA")
(6483 . "TAI LE LETTER TSA")
(6484 . "TAI LE LETTER SA")
(6485 . "TAI LE LETTER YA")
(6486 . "TAI LE LETTER TA")
(6487 . "TAI LE LETTER THA")
(6488 . "TAI LE LETTER LA")
(6489 . "TAI LE LETTER PA")
(6490 . "TAI LE LETTER PHA")
(6491 . "TAI LE LETTER MA")
(6492 . "TAI LE LETTER FA")
(6493 . "TAI LE LETTER VA")
(6494 . "TAI LE LETTER HA")
(6495 . "TAI LE LETTER QA")
(6496 . "TAI LE LETTER KHA")
(6497 . "TAI LE LETTER TSHA")
(6498 . "TAI LE LETTER NA")
(6499 . "TAI LE LETTER A")
(6500 . "TAI LE LETTER I")
(6501 . "TAI LE LETTER EE")
(6502 . "TAI LE LETTER EH")
(6503 . "TAI LE LETTER U")
(6504 . "TAI LE LETTER OO")
(6505 . "TAI LE LETTER O")
(6506 . "TAI LE LETTER UE")
(6507 . "TAI LE LETTER E")
(6508 . "TAI LE LETTER AUE")
(6509 . "TAI LE LETTER AI")
((6510 . 6512) . #f)
(6512 . "TAI LE LETTER TONE-2")
(6513 . "TAI LE LETTER TONE-3")
(6514 . "TAI LE LETTER TONE-4")
(6515 . "TAI LE LETTER TONE-5")
(6516 . "TAI LE LETTER TONE-6")
((6517 . 6528) . #f)
(6528 . "NEW TAI LUE LETTER HIGH QA")
(6529 . "NEW TAI LUE LETTER LOW QA")
(6530 . "NEW TAI LUE LETTER HIGH KA")
(6531 . "NEW TAI LUE LETTER HIGH XA")
(6532 . "NEW TAI LUE LETTER HIGH NGA")
(6533 . "NEW TAI LUE LETTER LOW KA")
(6534 . "NEW TAI LUE LETTER LOW XA")
(6535 . "NEW TAI LUE LETTER LOW NGA")
(6536 . "NEW TAI LUE LETTER HIGH TSA")
(6537 . "NEW TAI LUE LETTER HIGH SA")
(6538 . "NEW TAI LUE LETTER HIGH YA")
(6539 . "NEW TAI LUE LETTER LOW TSA")
(6540 . "NEW TAI LUE LETTER LOW SA")
(6541 . "NEW TAI LUE LETTER LOW YA")
(6542 . "NEW TAI LUE LETTER HIGH TA")
(6543 . "NEW TAI LUE LETTER HIGH THA")
(6544 . "NEW TAI LUE LETTER HIGH NA")
(6545 . "NEW TAI LUE LETTER LOW TA")
(6546 . "NEW TAI LUE LETTER LOW THA")
(6547 . "NEW TAI LUE LETTER LOW NA")
(6548 . "NEW TAI LUE LETTER HIGH PA")
(6549 . "NEW TAI LUE LETTER HIGH PHA")
(6550 . "NEW TAI LUE LETTER HIGH MA")
(6551 . "NEW TAI LUE LETTER LOW PA")
(6552 . "NEW TAI LUE LETTER LOW PHA")
(6553 . "NEW TAI LUE LETTER LOW MA")
(6554 . "NEW TAI LUE LETTER HIGH FA")
(6555 . "NEW TAI LUE LETTER HIGH VA")
(6556 . "NEW TAI LUE LETTER HIGH LA")
(6557 . "NEW TAI LUE LETTER LOW FA")
(6558 . "NEW TAI LUE LETTER LOW VA")
(6559 . "NEW TAI LUE LETTER LOW LA")
(6560 . "NEW TAI LUE LETTER HIGH HA")
(6561 . "NEW TAI LUE LETTER HIGH DA")
(6562 . "NEW TAI LUE LETTER HIGH BA")
(6563 . "NEW TAI LUE LETTER LOW HA")
(6564 . "NEW TAI LUE LETTER LOW DA")
(6565 . "NEW TAI LUE LETTER LOW BA")
(6566 . "NEW TAI LUE LETTER HIGH KVA")
(6567 . "NEW TAI LUE LETTER HIGH XVA")
(6568 . "NEW TAI LUE LETTER LOW KVA")
(6569 . "NEW TAI LUE LETTER LOW XVA")
(6570 . "NEW TAI LUE LETTER HIGH SUA")
(6571 . "NEW TAI LUE LETTER LOW SUA")
((6572 . 6576) . #f)
(6576 . "NEW TAI LUE VOWEL SIGN VOWEL SHORTENER")
(6577 . "NEW TAI LUE VOWEL SIGN AA")
(6578 . "NEW TAI LUE VOWEL SIGN II")
(6579 . "NEW TAI LUE VOWEL SIGN U")
(6580 . "NEW TAI LUE VOWEL SIGN UU")
(6581 . "NEW TAI LUE VOWEL SIGN E")
(6582 . "NEW TAI LUE VOWEL SIGN AE")
(6583 . "NEW TAI LUE VOWEL SIGN O")
(6584 . "NEW TAI LUE VOWEL SIGN OA")
(6585 . "NEW TAI LUE VOWEL SIGN UE")
(6586 . "NEW TAI LUE VOWEL SIGN AY")
(6587 . "NEW TAI LUE VOWEL SIGN AAY")
(6588 . "NEW TAI LUE VOWEL SIGN UY")
(6589 . "NEW TAI LUE VOWEL SIGN OY")
(6590 . "NEW TAI LUE VOWEL SIGN OAY")
(6591 . "NEW TAI LUE VOWEL SIGN UEY")
(6592 . "NEW TAI LUE VOWEL SIGN IY")
(6593 . "NEW TAI LUE LETTER FINAL V")
(6594 . "NEW TAI LUE LETTER FINAL NG")
(6595 . "NEW TAI LUE LETTER FINAL N")
(6596 . "NEW TAI LUE LETTER FINAL M")
(6597 . "NEW TAI LUE LETTER FINAL K")
(6598 . "NEW TAI LUE LETTER FINAL D")
(6599 . "NEW TAI LUE LETTER FINAL B")
(6600 . "NEW TAI LUE TONE MARK-1")
(6601 . "NEW TAI LUE TONE MARK-2")
((6602 . 6608) . #f)
(6608 . "NEW TAI LUE DIGIT ZERO")
(6609 . "NEW TAI LUE DIGIT ONE")
(6610 . "NEW TAI LUE DIGIT TWO")
(6611 . "NEW TAI LUE DIGIT THREE")
(6612 . "NEW TAI LUE DIGIT FOUR")
(6613 . "NEW TAI LUE DIGIT FIVE")
(6614 . "NEW TAI LUE DIGIT SIX")
(6615 . "NEW TAI LUE DIGIT SEVEN")
(6616 . "NEW TAI LUE DIGIT EIGHT")
(6617 . "NEW TAI LUE DIGIT NINE")
(6618 . "NEW TAI LUE THAM DIGIT ONE")
((6619 . 6622) . #f)
(6622 . "NEW TAI LUE SIGN LAE")
(6623 . "NEW TAI LUE SIGN LAEV")
(6624 . "KHMER SYMBOL PATHAMASAT")
(6625 . "KHMER SYMBOL MUOY KOET")
(6626 . "KHMER SYMBOL PII KOET")
(6627 . "KHMER SYMBOL BEI KOET")
(6628 . "KHMER SYMBOL BUON KOET")
(6629 . "KHMER SYMBOL PRAM KOET")
(6630 . "KHMER SYMBOL PRAM-MUOY KOET")
(6631 . "KHMER SYMBOL PRAM-PII KOET")
(6632 . "KHMER SYMBOL PRAM-BEI KOET")
(6633 . "KHMER SYMBOL PRAM-BUON KOET")
(6634 . "KHMER SYMBOL DAP KOET")
(6635 . "KHMER SYMBOL DAP-MUOY KOET")
(6636 . "KHMER SYMBOL DAP-PII KOET")
(6637 . "KHMER SYMBOL DAP-BEI KOET")
(6638 . "KHMER SYMBOL DAP-BUON KOET")
(6639 . "KHMER SYMBOL DAP-PRAM KOET")
(6640 . "KHMER SYMBOL TUTEYASAT")
(6641 . "KHMER SYMBOL MUOY ROC")
(6642 . "KHMER SYMBOL PII ROC")
(6643 . "KHMER SYMBOL BEI ROC")
(6644 . "KHMER SYMBOL BUON ROC")
(6645 . "KHMER SYMBOL PRAM ROC")
(6646 . "KHMER SYMBOL PRAM-MUOY ROC")
(6647 . "KHMER SYMBOL PRAM-PII ROC")
(6648 . "KHMER SYMBOL PRAM-BEI ROC")
(6649 . "KHMER SYMBOL PRAM-BUON ROC")
(6650 . "KHMER SYMBOL DAP ROC")
(6651 . "KHMER SYMBOL DAP-MUOY ROC")
(6652 . "KHMER SYMBOL DAP-PII ROC")
(6653 . "KHMER SYMBOL DAP-BEI ROC")
(6654 . "KHMER SYMBOL DAP-BUON ROC")
(6655 . "KHMER SYMBOL DAP-PRAM ROC")
(6656 . "BUGINESE LETTER KA")
(6657 . "BUGINESE LETTER GA")
(6658 . "BUGINESE LETTER NGA")
(6659 . "BUGINESE LETTER NGKA")
(6660 . "BUGINESE LETTER PA")
(6661 . "BUGINESE LETTER BA")
(6662 . "BUGINESE LETTER MA")
(6663 . "BUGINESE LETTER MPA")
(6664 . "BUGINESE LETTER TA")
(6665 . "BUGINESE LETTER DA")
(6666 . "BUGINESE LETTER NA")
(6667 . "BUGINESE LETTER NRA")
(6668 . "BUGINESE LETTER CA")
(6669 . "BUGINESE LETTER JA")
(6670 . "BUGINESE LETTER NYA")
(6671 . "BUGINESE LETTER NYCA")
(6672 . "BUGINESE LETTER YA")
(6673 . "BUGINESE LETTER RA")
(6674 . "BUGINESE LETTER LA")
(6675 . "BUGINESE LETTER VA")
(6676 . "BUGINESE LETTER SA")
(6677 . "BUGINESE LETTER A")
(6678 . "BUGINESE LETTER HA")
(6679 . "BUGINESE VOWEL SIGN I")
(6680 . "BUGINESE VOWEL SIGN U")
(6681 . "BUGINESE VOWEL SIGN E")
(6682 . "BUGINESE VOWEL SIGN O")
(6683 . "BUGINESE VOWEL SIGN AE")
((6684 . 6686) . #f)
(6686 . "BUGINESE PALLAWA")
(6687 . "BUGINESE END OF SECTION")
(6688 . "TAI THAM LETTER HIGH KA")
(6689 . "TAI THAM LETTER HIGH KHA")
(6690 . "TAI THAM LETTER HIGH KXA")
(6691 . "TAI THAM LETTER LOW KA")
(6692 . "TAI THAM LETTER LOW KXA")
(6693 . "TAI THAM LETTER LOW KHA")
(6694 . "TAI THAM LETTER NGA")
(6695 . "TAI THAM LETTER HIGH CA")
(6696 . "TAI THAM LETTER HIGH CHA")
(6697 . "TAI THAM LETTER LOW CA")
(6698 . "TAI THAM LETTER LOW SA")
(6699 . "TAI THAM LETTER LOW CHA")
(6700 . "TAI THAM LETTER NYA")
(6701 . "TAI THAM LETTER RATA")
(6702 . "TAI THAM LETTER HIGH RATHA")
(6703 . "TAI THAM LETTER DA")
(6704 . "TAI THAM LETTER LOW RATHA")
(6705 . "TAI THAM LETTER RANA")
(6706 . "TAI THAM LETTER HIGH TA")
(6707 . "TAI THAM LETTER HIGH THA")
(6708 . "TAI THAM LETTER LOW TA")
(6709 . "TAI THAM LETTER LOW THA")
(6710 . "TAI THAM LETTER NA")
(6711 . "TAI THAM LETTER BA")
(6712 . "TAI THAM LETTER HIGH PA")
(6713 . "TAI THAM LETTER HIGH PHA")
(6714 . "TAI THAM LETTER HIGH FA")
(6715 . "TAI THAM LETTER LOW PA")
(6716 . "TAI THAM LETTER LOW FA")
(6717 . "TAI THAM LETTER LOW PHA")
(6718 . "TAI THAM LETTER MA")
(6719 . "TAI THAM LETTER LOW YA")
(6720 . "TAI THAM LETTER HIGH YA")
(6721 . "TAI THAM LETTER RA")
(6722 . "TAI THAM LETTER RUE")
(6723 . "TAI THAM LETTER LA")
(6724 . "TAI THAM LETTER LUE")
(6725 . "TAI THAM LETTER WA")
(6726 . "TAI THAM LETTER HIGH SHA")
(6727 . "TAI THAM LETTER HIGH SSA")
(6728 . "TAI THAM LETTER HIGH SA")
(6729 . "TAI THAM LETTER HIGH HA")
(6730 . "TAI THAM LETTER LLA")
(6731 . "TAI THAM LETTER A")
(6732 . "TAI THAM LETTER LOW HA")
(6733 . "TAI THAM LETTER I")
(6734 . "TAI THAM LETTER II")
(6735 . "TAI THAM LETTER U")
(6736 . "TAI THAM LETTER UU")
(6737 . "TAI THAM LETTER EE")
(6738 . "TAI THAM LETTER OO")
(6739 . "TAI THAM LETTER LAE")
(6740 . "TAI THAM LETTER GREAT SA")
(6741 . "TAI THAM CONSONANT SIGN MEDIAL RA")
(6742 . "TAI THAM CONSONANT SIGN MEDIAL LA")
(6743 . "TAI THAM CONSONANT SIGN LA TANG LAI")
(6744 . "TAI THAM SIGN MAI KANG LAI")
(6745 . "TAI THAM CONSONANT SIGN FINAL NGA")
(6746 . "TAI THAM CONSONANT SIGN LOW PA")
(6747 . "TAI THAM CONSONANT SIGN HIGH RATHA OR LOW PA")
(6748 . "TAI THAM CONSONANT SIGN MA")
(6749 . "TAI THAM CONSONANT SIGN BA")
(6750 . "TAI THAM CONSONANT SIGN SA")
(6751 . #f)
(6752 . "TAI THAM SIGN SAKOT")
(6753 . "TAI THAM VOWEL SIGN A")
(6754 . "TAI THAM VOWEL SIGN MAI SAT")
(6755 . "TAI THAM VOWEL SIGN AA")
(6756 . "TAI THAM VOWEL SIGN TALL AA")
(6757 . "TAI THAM VOWEL SIGN I")
(6758 . "TAI THAM VOWEL SIGN II")
(6759 . "TAI THAM VOWEL SIGN UE")
(6760 . "TAI THAM VOWEL SIGN UUE")
(6761 . "TAI THAM VOWEL SIGN U")
(6762 . "TAI THAM VOWEL SIGN UU")
(6763 . "TAI THAM VOWEL SIGN O")
(6764 . "TAI THAM VOWEL SIGN OA BELOW")
(6765 . "TAI THAM VOWEL SIGN OY")
(6766 . "TAI THAM VOWEL SIGN E")
(6767 . "TAI THAM VOWEL SIGN AE")
(6768 . "TAI THAM VOWEL SIGN OO")
(6769 . "TAI THAM VOWEL SIGN AI")
(6770 . "TAI THAM VOWEL SIGN THAM AI")
(6771 . "TAI THAM VOWEL SIGN OA ABOVE")
(6772 . "TAI THAM SIGN MAI KANG")
(6773 . "TAI THAM SIGN TONE-1")
(6774 . "TAI THAM SIGN TONE-2")
(6775 . "TAI THAM SIGN KHUEN TONE-3")
(6776 . "TAI THAM SIGN KHUEN TONE-4")
(6777 . "TAI THAM SIGN KHUEN TONE-5")
(6778 . "TAI THAM SIGN RA HAAM")
(6779 . "TAI THAM SIGN MAI SAM")
(6780 . "TAI THAM SIGN KHUEN-LUE KARAN")
((6781 . 6783) . #f)
(6783 . "TAI THAM COMBINING CRYPTOGRAMMIC DOT")
(6784 . "TAI THAM HORA DIGIT ZERO")
(6785 . "TAI THAM HORA DIGIT ONE")
(6786 . "TAI THAM HORA DIGIT TWO")
(6787 . "TAI THAM HORA DIGIT THREE")
(6788 . "TAI THAM HORA DIGIT FOUR")
(6789 . "TAI THAM HORA DIGIT FIVE")
(6790 . "TAI THAM HORA DIGIT SIX")
(6791 . "TAI THAM HORA DIGIT SEVEN")
(6792 . "TAI THAM HORA DIGIT EIGHT")
(6793 . "TAI THAM HORA DIGIT NINE")
((6794 . 6800) . #f)
(6800 . "TAI THAM THAM DIGIT ZERO")
(6801 . "TAI THAM THAM DIGIT ONE")
(6802 . "TAI THAM THAM DIGIT TWO")
(6803 . "TAI THAM THAM DIGIT THREE")
(6804 . "TAI THAM THAM DIGIT FOUR")
(6805 . "TAI THAM THAM DIGIT FIVE")
(6806 . "TAI THAM THAM DIGIT SIX")
(6807 . "TAI THAM THAM DIGIT SEVEN")
(6808 . "TAI THAM THAM DIGIT EIGHT")
(6809 . "TAI THAM THAM DIGIT NINE")
((6810 . 6816) . #f)
(6816 . "TAI THAM SIGN WIANG")
(6817 . "TAI THAM SIGN WIANGWAAK")
(6818 . "TAI THAM SIGN SAWAN")
(6819 . "TAI THAM SIGN KEOW")
(6820 . "TAI THAM SIGN HOY")
(6821 . "TAI THAM SIGN DOKMAI")
(6822 . "TAI THAM SIGN REVERSED ROTATED RANA")
(6823 . "TAI THAM SIGN MAI YAMOK")
(6824 . "TAI THAM SIGN KAAN")
(6825 . "TAI THAM SIGN KAANKUU")
(6826 . "TAI THAM SIGN SATKAAN")
(6827 . "TAI THAM SIGN SATKAANKUU")
(6828 . "TAI THAM SIGN HANG")
(6829 . "TAI THAM SIGN CAANG")
((6830 . 6832) . #f)
(6832 . "COMBINING DOUBLED CIRCUMFLEX ACCENT")
(6833 . "COMBINING DIAERESIS-RING")
(6834 . "COMBINING INFINITY")
(6835 . "COMBINING DOWNWARDS ARROW")
(6836 . "COMBINING TRIPLE DOT")
(6837 . "COMBINING X-X BELOW")
(6838 . "COMBINING WIGGLY LINE BELOW")
(6839 . "COMBINING OPEN MARK BELOW")
(6840 . "COMBINING DOUBLE OPEN MARK BELOW")
(6841 . "COMBINING LIGHT CENTRALIZATION STROKE BELOW")
(6842 . "COMBINING STRONG CENTRALIZATION STROKE BELOW")
(6843 . "COMBINING PARENTHESES ABOVE")
(6844 . "COMBINING DOUBLE PARENTHESES ABOVE")
(6845 . "COMBINING PARENTHESES BELOW")
(6846 . "COMBINING PARENTHESES OVERLAY")
((6847 . 6912) . #f)
(6912 . "BALINESE SIGN ULU RICEM")
(6913 . "BALINESE SIGN ULU CANDRA")
(6914 . "BALINESE SIGN CECEK")
(6915 . "BALINESE SIGN SURANG")
(6916 . "BALINESE SIGN BISAH")
(6917 . "BALINESE LETTER AKARA")
(6918 . "BALINESE LETTER AKARA TEDUNG")
(6919 . "BALINESE LETTER IKARA")
(6920 . "BALINESE LETTER IKARA TEDUNG")
(6921 . "BALINESE LETTER UKARA")
(6922 . "BALINESE LETTER UKARA TEDUNG")
(6923 . "BALINESE LETTER RA REPA")
(6924 . "BALINESE LETTER RA REPA TEDUNG")
(6925 . "BALINESE LETTER LA LENGA")
(6926 . "BALINESE LETTER LA LENGA TEDUNG")
(6927 . "BALINESE LETTER EKARA")
(6928 . "BALINESE LETTER AIKARA")
(6929 . "BALINESE LETTER OKARA")
(6930 . "BALINESE LETTER OKARA TEDUNG")
(6931 . "BALINESE LETTER KA")
(6932 . "BALINESE LETTER KA MAHAPRANA")
(6933 . "BALINESE LETTER GA")
(6934 . "BALINESE LETTER GA GORA")
(6935 . "BALINESE LETTER NGA")
(6936 . "BALINESE LETTER CA")
(6937 . "BALINESE LETTER CA LACA")
(6938 . "BALINESE LETTER JA")
(6939 . "BALINESE LETTER JA JERA")
(6940 . "BALINESE LETTER NYA")
(6941 . "BALINESE LETTER TA LATIK")
(6942 . "BALINESE LETTER TA MURDA MAHAPRANA")
(6943 . "BALINESE LETTER DA MURDA ALPAPRANA")
(6944 . "BALINESE LETTER DA MURDA MAHAPRANA")
(6945 . "BALINESE LETTER NA RAMBAT")
(6946 . "BALINESE LETTER TA")
(6947 . "BALINESE LETTER TA TAWA")
(6948 . "BALINESE LETTER DA")
(6949 . "BALINESE LETTER DA MADU")
(6950 . "BALINESE LETTER NA")
(6951 . "BALINESE LETTER PA")
(6952 . "BALINESE LETTER PA KAPAL")
(6953 . "BALINESE LETTER BA")
(6954 . "BALINESE LETTER BA KEMBANG")
(6955 . "BALINESE LETTER MA")
(6956 . "BALINESE LETTER YA")
(6957 . "BALINESE LETTER RA")
(6958 . "BALINESE LETTER LA")
(6959 . "BALINESE LETTER WA")
(6960 . "BALINESE LETTER SA SAGA")
(6961 . "BALINESE LETTER SA SAPA")
(6962 . "BALINESE LETTER SA")
(6963 . "BALINESE LETTER HA")
(6964 . "BALINESE SIGN REREKAN")
(6965 . "BALINESE VOWEL SIGN TEDUNG")
(6966 . "BALINESE VOWEL SIGN ULU")
(6967 . "BALINESE VOWEL SIGN ULU SARI")
(6968 . "BALINESE VOWEL SIGN SUKU")
(6969 . "BALINESE VOWEL SIGN SUKU ILUT")
(6970 . "BALINESE VOWEL SIGN RA REPA")
(6971 . "BALINESE VOWEL SIGN RA REPA TEDUNG")
(6972 . "BALINESE VOWEL SIGN LA LENGA")
(6973 . "BALINESE VOWEL SIGN LA LENGA TEDUNG")
(6974 . "BALINESE VOWEL SIGN TALING")
(6975 . "BALINESE VOWEL SIGN TALING REPA")
(6976 . "BALINESE VOWEL SIGN TALING TEDUNG")
(6977 . "BALINESE VOWEL SIGN TALING REPA TEDUNG")
(6978 . "BALINESE VOWEL SIGN PEPET")
(6979 . "BALINESE VOWEL SIGN PEPET TEDUNG")
(6980 . "BALINESE ADEG ADEG")
(6981 . "BALINESE LETTER KAF SASAK")
(6982 . "BALINESE LETTER KHOT SASAK")
(6983 . "BALINESE LETTER TZIR SASAK")
(6984 . "BALINESE LETTER EF SASAK")
(6985 . "BALINESE LETTER VE SASAK")
(6986 . "BALINESE LETTER ZAL SASAK")
(6987 . "BALINESE LETTER ASYURA SASAK")
((6988 . 6992) . #f)
(6992 . "BALINESE DIGIT ZERO")
(6993 . "BALINESE DIGIT ONE")
(6994 . "BALINESE DIGIT TWO")
(6995 . "BALINESE DIGIT THREE")
(6996 . "BALINESE DIGIT FOUR")
(6997 . "BALINESE DIGIT FIVE")
(6998 . "BALINESE DIGIT SIX")
(6999 . "BALINESE DIGIT SEVEN")
(7000 . "BALINESE DIGIT EIGHT")
(7001 . "BALINESE DIGIT NINE")
(7002 . "BALINESE PANTI")
(7003 . "BALINESE PAMADA")
(7004 . "BALINESE WINDU")
(7005 . "BALINESE CARIK PAMUNGKAH")
(7006 . "BALINESE CARIK SIKI")
(7007 . "BALINESE CARIK PAREREN")
(7008 . "BALINESE PAMENENG")
(7009 . "BALINESE MUSICAL SYMBOL DONG")
(7010 . "BALINESE MUSICAL SYMBOL DENG")
(7011 . "BALINESE MUSICAL SYMBOL DUNG")
(7012 . "BALINESE MUSICAL SYMBOL DANG")
(7013 . "BALINESE MUSICAL SYMBOL DANG SURANG")
(7014 . "BALINESE MUSICAL SYMBOL DING")
(7015 . "BALINESE MUSICAL SYMBOL DAENG")
(7016 . "BALINESE MUSICAL SYMBOL DEUNG")
(7017 . "BALINESE MUSICAL SYMBOL DAING")
(7018 . "BALINESE MUSICAL SYMBOL DANG GEDE")
(7019 . "BALINESE MUSICAL SYMBOL COMBINING TEGEH")
(7020 . "BALINESE MUSICAL SYMBOL COMBINING ENDEP")
(7021 . "BALINESE MUSICAL SYMBOL COMBINING KEMPUL")
(7022 . "BALINESE MUSICAL SYMBOL COMBINING KEMPLI")
(7023 . "BALINESE MUSICAL SYMBOL COMBINING JEGOGAN")
(7024 . "BALINESE MUSICAL SYMBOL COMBINING KEMPUL WITH JEGOGAN")
(7025 . "BALINESE MUSICAL SYMBOL COMBINING KEMPLI WITH JEGOGAN")
(7026 . "BALINESE MUSICAL SYMBOL COMBINING BENDE")
(7027 . "BALINESE MUSICAL SYMBOL COMBINING GONG")
(7028 . "BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DUG")
(7029 . "BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DAG")
(7030 . "BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TUK")
(7031 . "BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TAK")
(7032 . "BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PANG")
(7033 . "BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PUNG")
(7034 . "BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLAK")
(7035 . "BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLUK")
(7036 . "BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PING")
((7037 . 7040) . #f)
(7040 . "SUNDANESE SIGN PANYECEK")
(7041 . "SUNDANESE SIGN PANGLAYAR")
(7042 . "SUNDANESE SIGN PANGWISAD")
(7043 . "SUNDANESE LETTER A")
(7044 . "SUNDANESE LETTER I")
(7045 . "SUNDANESE LETTER U")
(7046 . "SUNDANESE LETTER AE")
(7047 . "SUNDANESE LETTER O")
(7048 . "SUNDANESE LETTER E")
(7049 . "SUNDANESE LETTER EU")
(7050 . "SUNDANESE LETTER KA")
(7051 . "SUNDANESE LETTER QA")
(7052 . "SUNDANESE LETTER GA")
(7053 . "SUNDANESE LETTER NGA")
(7054 . "SUNDANESE LETTER CA")
(7055 . "SUNDANESE LETTER JA")
(7056 . "SUNDANESE LETTER ZA")
(7057 . "SUNDANESE LETTER NYA")
(7058 . "SUNDANESE LETTER TA")
(7059 . "SUNDANESE LETTER DA")
(7060 . "SUNDANESE LETTER NA")
(7061 . "SUNDANESE LETTER PA")
(7062 . "SUNDANESE LETTER FA")
(7063 . "SUNDANESE LETTER VA")
(7064 . "SUNDANESE LETTER BA")
(7065 . "SUNDANESE LETTER MA")
(7066 . "SUNDANESE LETTER YA")
(7067 . "SUNDANESE LETTER RA")
(7068 . "SUNDANESE LETTER LA")
(7069 . "SUNDANESE LETTER WA")
(7070 . "SUNDANESE LETTER SA")
(7071 . "SUNDANESE LETTER XA")
(7072 . "SUNDANESE LETTER HA")
(7073 . "SUNDANESE CONSONANT SIGN PAMINGKAL")
(7074 . "SUNDANESE CONSONANT SIGN PANYAKRA")
(7075 . "SUNDANESE CONSONANT SIGN PANYIKU")
(7076 . "SUNDANESE VOWEL SIGN PANGHULU")
(7077 . "SUNDANESE VOWEL SIGN PANYUKU")
(7078 . "SUNDANESE VOWEL SIGN PANAELAENG")
(7079 . "SUNDANESE VOWEL SIGN PANOLONG")
(7080 . "SUNDANESE VOWEL SIGN PAMEPET")
(7081 . "SUNDANESE VOWEL SIGN PANEULEUNG")
(7082 . "SUNDANESE SIGN PAMAAEH")
(7083 . "SUNDANESE SIGN VIRAMA")
(7084 . "SUNDANESE CONSONANT SIGN PASANGAN MA")
(7085 . "SUNDANESE CONSONANT SIGN PASANGAN WA")
(7086 . "SUNDANESE LETTER KHA")
(7087 . "SUNDANESE LETTER SYA")
(7088 . "SUNDANESE DIGIT ZERO")
(7089 . "SUNDANESE DIGIT ONE")
(7090 . "SUNDANESE DIGIT TWO")
(7091 . "SUNDANESE DIGIT THREE")
(7092 . "SUNDANESE DIGIT FOUR")
(7093 . "SUNDANESE DIGIT FIVE")
(7094 . "SUNDANESE DIGIT SIX")
(7095 . "SUNDANESE DIGIT SEVEN")
(7096 . "SUNDANESE DIGIT EIGHT")
(7097 . "SUNDANESE DIGIT NINE")
(7098 . "SUNDANESE AVAGRAHA")
(7099 . "SUNDANESE LETTER REU")
(7100 . "SUNDANESE LETTER LEU")
(7101 . "SUNDANESE LETTER BHA")
(7102 . "SUNDANESE LETTER FINAL K")
(7103 . "SUNDANESE LETTER FINAL M")
(7104 . "BATAK LETTER A")
(7105 . "BATAK LETTER SIMALUNGUN A")
(7106 . "BATAK LETTER HA")
(7107 . "BATAK LETTER SIMALUNGUN HA")
(7108 . "BATAK LETTER MANDAILING HA")
(7109 . "BATAK LETTER BA")
(7110 . "BATAK LETTER KARO BA")
(7111 . "BATAK LETTER PA")
(7112 . "BATAK LETTER SIMALUNGUN PA")
(7113 . "BATAK LETTER NA")
(7114 . "BATAK LETTER MANDAILING NA")
(7115 . "BATAK LETTER WA")
(7116 . "BATAK LETTER SIMALUNGUN WA")
(7117 . "BATAK LETTER PAKPAK WA")
(7118 . "BATAK LETTER GA")
(7119 . "BATAK LETTER SIMALUNGUN GA")
(7120 . "BATAK LETTER JA")
(7121 . "BATAK LETTER DA")
(7122 . "BATAK LETTER RA")
(7123 . "BATAK LETTER SIMALUNGUN RA")
(7124 . "BATAK LETTER MA")
(7125 . "BATAK LETTER SIMALUNGUN MA")
(7126 . "BATAK LETTER SOUTHERN TA")
(7127 . "BATAK LETTER NORTHERN TA")
(7128 . "BATAK LETTER SA")
(7129 . "BATAK LETTER SIMALUNGUN SA")
(7130 . "BATAK LETTER MANDAILING SA")
(7131 . "BATAK LETTER YA")
(7132 . "BATAK LETTER SIMALUNGUN YA")
(7133 . "BATAK LETTER NGA")
(7134 . "BATAK LETTER LA")
(7135 . "BATAK LETTER SIMALUNGUN LA")
(7136 . "BATAK LETTER NYA")
(7137 . "BATAK LETTER CA")
(7138 . "BATAK LETTER NDA")
(7139 . "BATAK LETTER MBA")
(7140 . "BATAK LETTER I")
(7141 . "BATAK LETTER U")
(7142 . "BATAK SIGN TOMPI")
(7143 . "BATAK VOWEL SIGN E")
(7144 . "BATAK VOWEL SIGN PAKPAK E")
(7145 . "BATAK VOWEL SIGN EE")
(7146 . "BATAK VOWEL SIGN I")
(7147 . "BATAK VOWEL SIGN KARO I")
(7148 . "BATAK VOWEL SIGN O")
(7149 . "BATAK VOWEL SIGN KARO O")
(7150 . "BATAK VOWEL SIGN U")
(7151 . "BATAK VOWEL SIGN U FOR SIMALUNGUN SA")
(7152 . "BATAK CONSONANT SIGN NG")
(7153 . "BATAK CONSONANT SIGN H")
(7154 . "BATAK PANGOLAT")
(7155 . "BATAK PANONGONAN")
((7156 . 7164) . #f)
(7164 . "BATAK SYMBOL BINDU NA METEK")
(7165 . "BATAK SYMBOL BINDU PINARBORAS")
(7166 . "BATAK SYMBOL BINDU JUDUL")
(7167 . "BATAK SYMBOL BINDU PANGOLAT")
(7168 . "LEPCHA LETTER KA")
(7169 . "LEPCHA LETTER KLA")
(7170 . "LEPCHA LETTER KHA")
(7171 . "LEPCHA LETTER GA")
(7172 . "LEPCHA LETTER GLA")
(7173 . "LEPCHA LETTER NGA")
(7174 . "LEPCHA LETTER CA")
(7175 . "LEPCHA LETTER CHA")
(7176 . "LEPCHA LETTER JA")
(7177 . "LEPCHA LETTER NYA")
(7178 . "LEPCHA LETTER TA")
(7179 . "LEPCHA LETTER THA")
(7180 . "LEPCHA LETTER DA")
(7181 . "LEPCHA LETTER NA")
(7182 . "LEPCHA LETTER PA")
(7183 . "LEPCHA LETTER PLA")
(7184 . "LEPCHA LETTER PHA")
(7185 . "LEPCHA LETTER FA")
(7186 . "LEPCHA LETTER FLA")
(7187 . "LEPCHA LETTER BA")
(7188 . "LEPCHA LETTER BLA")
(7189 . "LEPCHA LETTER MA")
(7190 . "LEPCHA LETTER MLA")
(7191 . "LEPCHA LETTER TSA")
(7192 . "LEPCHA LETTER TSHA")
(7193 . "LEPCHA LETTER DZA")
(7194 . "LEPCHA LETTER YA")
(7195 . "LEPCHA LETTER RA")
(7196 . "LEPCHA LETTER LA")
(7197 . "LEPCHA LETTER HA")
(7198 . "LEPCHA LETTER HLA")
(7199 . "LEPCHA LETTER VA")
(7200 . "LEPCHA LETTER SA")
(7201 . "LEPCHA LETTER SHA")
(7202 . "LEPCHA LETTER WA")
(7203 . "LEPCHA LETTER A")
(7204 . "LEPCHA SUBJOINED LETTER YA")
(7205 . "LEPCHA SUBJOINED LETTER RA")
(7206 . "LEPCHA VOWEL SIGN AA")
(7207 . "LEPCHA VOWEL SIGN I")
(7208 . "LEPCHA VOWEL SIGN O")
(7209 . "LEPCHA VOWEL SIGN OO")
(7210 . "LEPCHA VOWEL SIGN U")
(7211 . "LEPCHA VOWEL SIGN UU")
(7212 . "LEPCHA VOWEL SIGN E")
(7213 . "LEPCHA CONSONANT SIGN K")
(7214 . "LEPCHA CONSONANT SIGN M")
(7215 . "LEPCHA CONSONANT SIGN L")
(7216 . "LEPCHA CONSONANT SIGN N")
(7217 . "LEPCHA CONSONANT SIGN P")
(7218 . "LEPCHA CONSONANT SIGN R")
(7219 . "LEPCHA CONSONANT SIGN T")
(7220 . "LEPCHA CONSONANT SIGN NYIN-DO")
(7221 . "LEPCHA CONSONANT SIGN KANG")
(7222 . "LEPCHA SIGN RAN")
(7223 . "LEPCHA SIGN NUKTA")
((7224 . 7227) . #f)
(7227 . "LEPCHA PUNCTUATION TA-ROL")
(7228 . "LEPCHA PUNCTUATION NYET THYOOM TA-ROL")
(7229 . "LEPCHA PUNCTUATION CER-WA")
(7230 . "LEPCHA PUNCTUATION TSHOOK CER-WA")
(7231 . "LEPCHA PUNCTUATION TSHOOK")
(7232 . "LEPCHA DIGIT ZERO")
(7233 . "LEPCHA DIGIT ONE")
(7234 . "LEPCHA DIGIT TWO")
(7235 . "LEPCHA DIGIT THREE")
(7236 . "LEPCHA DIGIT FOUR")
(7237 . "LEPCHA DIGIT FIVE")
(7238 . "LEPCHA DIGIT SIX")
(7239 . "LEPCHA DIGIT SEVEN")
(7240 . "LEPCHA DIGIT EIGHT")
(7241 . "LEPCHA DIGIT NINE")
((7242 . 7245) . #f)
(7245 . "LEPCHA LETTER TTA")
(7246 . "LEPCHA LETTER TTHA")
(7247 . "LEPCHA LETTER DDA")
(7248 . "OL CHIKI DIGIT ZERO")
(7249 . "OL CHIKI DIGIT ONE")
(7250 . "OL CHIKI DIGIT TWO")
(7251 . "OL CHIKI DIGIT THREE")
(7252 . "OL CHIKI DIGIT FOUR")
(7253 . "OL CHIKI DIGIT FIVE")
(7254 . "OL CHIKI DIGIT SIX")
(7255 . "OL CHIKI DIGIT SEVEN")
(7256 . "OL CHIKI DIGIT EIGHT")
(7257 . "OL CHIKI DIGIT NINE")
(7258 . "OL CHIKI LETTER LA")
(7259 . "OL CHIKI LETTER AT")
(7260 . "OL CHIKI LETTER AG")
(7261 . "OL CHIKI LETTER ANG")
(7262 . "OL CHIKI LETTER AL")
(7263 . "OL CHIKI LETTER LAA")
(7264 . "OL CHIKI LETTER AAK")
(7265 . "OL CHIKI LETTER AAJ")
(7266 . "OL CHIKI LETTER AAM")
(7267 . "OL CHIKI LETTER AAW")
(7268 . "OL CHIKI LETTER LI")
(7269 . "OL CHIKI LETTER IS")
(7270 . "OL CHIKI LETTER IH")
(7271 . "OL CHIKI LETTER INY")
(7272 . "OL CHIKI LETTER IR")
(7273 . "OL CHIKI LETTER LU")
(7274 . "OL CHIKI LETTER UC")
(7275 . "OL CHIKI LETTER UD")
(7276 . "OL CHIKI LETTER UNN")
(7277 . "OL CHIKI LETTER UY")
(7278 . "OL CHIKI LETTER LE")
(7279 . "OL CHIKI LETTER EP")
(7280 . "OL CHIKI LETTER EDD")
(7281 . "OL CHIKI LETTER EN")
(7282 . "OL CHIKI LETTER ERR")
(7283 . "OL CHIKI LETTER LO")
(7284 . "OL CHIKI LETTER OTT")
(7285 . "OL CHIKI LETTER OB")
(7286 . "OL CHIKI LETTER OV")
(7287 . "OL CHIKI LETTER OH")
(7288 . "OL CHIKI MU TTUDDAG")
(7289 . "OL CHIKI GAAHLAA TTUDDAAG")
(7290 . "OL CHIKI MU-GAAHLAA TTUDDAAG")
(7291 . "OL CHIKI RELAA")
(7292 . "OL CHIKI PHAARKAA")
(7293 . "OL CHIKI AHAD")
(7294 . "OL CHIKI PUNCTUATION MUCAAD")
(7295 . "OL CHIKI PUNCTUATION DOUBLE MUCAAD")
(7296 . "CYRILLIC SMALL LETTER ROUNDED VE")
(7297 . "CYRILLIC SMALL LETTER LONG-LEGGED DE")
(7298 . "CYRILLIC SMALL LETTER NARROW O")
(7299 . "CYRILLIC SMALL LETTER WIDE ES")
(7300 . "CYRILLIC SMALL LETTER TALL TE")
(7301 . "CYRILLIC SMALL LETTER THREE-LEGGED TE")
(7302 . "CYRILLIC SMALL LETTER TALL HARD SIGN")
(7303 . "CYRILLIC SMALL LETTER TALL YAT")
(7304 . "CYRILLIC SMALL LETTER UNBLENDED UK")
((7305 . 7360) . #f)
(7360 . "SUNDANESE PUNCTUATION BINDU SURYA")
(7361 . "SUNDANESE PUNCTUATION BINDU PANGLONG")
(7362 . "SUNDANESE PUNCTUATION BINDU PURNAMA")
(7363 . "SUNDANESE PUNCTUATION BINDU CAKRA")
(7364 . "SUNDANESE PUNCTUATION BINDU LEU SATANGA")
(7365 . "SUNDANESE PUNCTUATION BINDU KA SATANGA")
(7366 . "SUNDANESE PUNCTUATION BINDU DA SATANGA")
(7367 . "SUNDANESE PUNCTUATION BINDU BA SATANGA")
((7368 . 7376) . #f)
(7376 . "VEDIC TONE KARSHANA")
(7377 . "VEDIC TONE SHARA")
(7378 . "VEDIC TONE PRENKHA")
(7379 . "VEDIC SIGN NIHSHVASA")
(7380 . "VEDIC SIGN YAJURVEDIC MIDLINE SVARITA")
(7381 . "VEDIC TONE YAJURVEDIC AGGRAVATED INDEPENDENT SVARITA")
(7382 . "VEDIC TONE YAJURVEDIC INDEPENDENT SVARITA")
(7383 . "VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA")
(7384 . "VEDIC TONE CANDRA BELOW")
(7385 . "VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA SCHROEDER")
(7386 . "VEDIC TONE DOUBLE SVARITA")
(7387 . "VEDIC TONE TRIPLE SVARITA")
(7388 . "VEDIC TONE KATHAKA ANUDATTA")
(7389 . "VEDIC TONE DOT BELOW")
(7390 . "VEDIC TONE TWO DOTS BELOW")
(7391 . "VEDIC TONE THREE DOTS BELOW")
(7392 . "VEDIC TONE RIGVEDIC KASHMIRI INDEPENDENT SVARITA")
(7393 . "VEDIC TONE ATHARVAVEDIC INDEPENDENT SVARITA")
(7394 . "VEDIC SIGN VISARGA SVARITA")
(7395 . "VEDIC SIGN VISARGA UDATTA")
(7396 . "VEDIC SIGN REVERSED VISARGA UDATTA")
(7397 . "VEDIC SIGN VISARGA ANUDATTA")
(7398 . "VEDIC SIGN REVERSED VISARGA ANUDATTA")
(7399 . "VEDIC SIGN VISARGA UDATTA WITH TAIL")
(7400 . "VEDIC SIGN VISARGA ANUDATTA WITH TAIL")
(7401 . "VEDIC SIGN ANUSVARA ANTARGOMUKHA")
(7402 . "VEDIC SIGN ANUSVARA BAHIRGOMUKHA")
(7403 . "VEDIC SIGN ANUSVARA VAMAGOMUKHA")
(7404 . "VEDIC SIGN ANUSVARA VAMAGOMUKHA WITH TAIL")
(7405 . "VEDIC SIGN TIRYAK")
(7406 . "VEDIC SIGN HEXIFORM LONG ANUSVARA")
(7407 . "VEDIC SIGN LONG ANUSVARA")
(7408 . "VEDIC SIGN RTHANG LONG ANUSVARA")
(7409 . "VEDIC SIGN ANUSVARA UBHAYATO MUKHA")
(7410 . "VEDIC SIGN ARDHAVISARGA")
(7411 . "VEDIC SIGN ROTATED ARDHAVISARGA")
(7412 . "VEDIC TONE CANDRA ABOVE")
(7413 . "VEDIC SIGN JIHVAMULIYA")
(7414 . "VEDIC SIGN UPADHMANIYA")
(7415 . #f)
(7416 . "VEDIC TONE RING ABOVE")
(7417 . "VEDIC TONE DOUBLE RING ABOVE")
((7418 . 7424) . #f)
(7424 . "LATIN LETTER SMALL CAPITAL A")
(7425 . "LATIN LETTER SMALL CAPITAL AE")
(7426 . "LATIN SMALL LETTER TURNED AE")
(7427 . "LATIN LETTER SMALL CAPITAL BARRED B")
(7428 . "LATIN LETTER SMALL CAPITAL C")
(7429 . "LATIN LETTER SMALL CAPITAL D")
(7430 . "LATIN LETTER SMALL CAPITAL ETH")
(7431 . "LATIN LETTER SMALL CAPITAL E")
(7432 . "LATIN SMALL LETTER TURNED OPEN E")
(7433 . "LATIN SMALL LETTER TURNED I")
(7434 . "LATIN LETTER SMALL CAPITAL J")
(7435 . "LATIN LETTER SMALL CAPITAL K")
(7436 . "LATIN LETTER SMALL CAPITAL L WITH STROKE")
(7437 . "LATIN LETTER SMALL CAPITAL M")
(7438 . "LATIN LETTER SMALL CAPITAL REVERSED N")
(7439 . "LATIN LETTER SMALL CAPITAL O")
(7440 . "LATIN LETTER SMALL CAPITAL OPEN O")
(7441 . "LATIN SMALL LETTER SIDEWAYS O")
(7442 . "LATIN SMALL LETTER SIDEWAYS OPEN O")
(7443 . "LATIN SMALL LETTER SIDEWAYS O WITH STROKE")
(7444 . "LATIN SMALL LETTER TURNED OE")
(7445 . "LATIN LETTER SMALL CAPITAL OU")
(7446 . "LATIN SMALL LETTER TOP HALF O")
(7447 . "LATIN SMALL LETTER BOTTOM HALF O")
(7448 . "LATIN LETTER SMALL CAPITAL P")
(7449 . "LATIN LETTER SMALL CAPITAL REVERSED R")
(7450 . "LATIN LETTER SMALL CAPITAL TURNED R")
(7451 . "LATIN LETTER SMALL CAPITAL T")
(7452 . "LATIN LETTER SMALL CAPITAL U")
(7453 . "LATIN SMALL LETTER SIDEWAYS U")
(7454 . "LATIN SMALL LETTER SIDEWAYS DIAERESIZED U")
(7455 . "LATIN SMALL LETTER SIDEWAYS TURNED M")
(7456 . "LATIN LETTER SMALL CAPITAL V")
(7457 . "LATIN LETTER SMALL CAPITAL W")
(7458 . "LATIN LETTER SMALL CAPITAL Z")
(7459 . "LATIN LETTER SMALL CAPITAL EZH")
(7460 . "LATIN LETTER VOICED LARYNGEAL SPIRANT")
(7461 . "LATIN LETTER AIN")
(7462 . "GREEK LETTER SMALL CAPITAL GAMMA")
(7463 . "GREEK LETTER SMALL CAPITAL LAMDA")
(7464 . "GREEK LETTER SMALL CAPITAL PI")
(7465 . "GREEK LETTER SMALL CAPITAL RHO")
(7466 . "GREEK LETTER SMALL CAPITAL PSI")
(7467 . "CYRILLIC LETTER SMALL CAPITAL EL")
(7468 . "MODIFIER LETTER CAPITAL A")
(7469 . "MODIFIER LETTER CAPITAL AE")
(7470 . "MODIFIER LETTER CAPITAL B")
(7471 . "MODIFIER LETTER CAPITAL BARRED B")
(7472 . "MODIFIER LETTER CAPITAL D")
(7473 . "MODIFIER LETTER CAPITAL E")
(7474 . "MODIFIER LETTER CAPITAL REVERSED E")
(7475 . "MODIFIER LETTER CAPITAL G")
(7476 . "MODIFIER LETTER CAPITAL H")
(7477 . "MODIFIER LETTER CAPITAL I")
(7478 . "MODIFIER LETTER CAPITAL J")
(7479 . "MODIFIER LETTER CAPITAL K")
(7480 . "MODIFIER LETTER CAPITAL L")
(7481 . "MODIFIER LETTER CAPITAL M")
(7482 . "MODIFIER LETTER CAPITAL N")
(7483 . "MODIFIER LETTER CAPITAL REVERSED N")
(7484 . "MODIFIER LETTER CAPITAL O")
(7485 . "MODIFIER LETTER CAPITAL OU")
(7486 . "MODIFIER LETTER CAPITAL P")
(7487 . "MODIFIER LETTER CAPITAL R")
(7488 . "MODIFIER LETTER CAPITAL T")
(7489 . "MODIFIER LETTER CAPITAL U")
(7490 . "MODIFIER LETTER CAPITAL W")
(7491 . "MODIFIER LETTER SMALL A")
(7492 . "MODIFIER LETTER SMALL TURNED A")
(7493 . "MODIFIER LETTER SMALL ALPHA")
(7494 . "MODIFIER LETTER SMALL TURNED AE")
(7495 . "MODIFIER LETTER SMALL B")
(7496 . "MODIFIER LETTER SMALL D")
(7497 . "MODIFIER LETTER SMALL E")
(7498 . "MODIFIER LETTER SMALL SCHWA")
(7499 . "MODIFIER LETTER SMALL OPEN E")
(7500 . "MODIFIER LETTER SMALL TURNED OPEN E")
(7501 . "MODIFIER LETTER SMALL G")
(7502 . "MODIFIER LETTER SMALL TURNED I")
(7503 . "MODIFIER LETTER SMALL K")
(7504 . "MODIFIER LETTER SMALL M")
(7505 . "MODIFIER LETTER SMALL ENG")
(7506 . "MODIFIER LETTER SMALL O")
(7507 . "MODIFIER LETTER SMALL OPEN O")
(7508 . "MODIFIER LETTER SMALL TOP HALF O")
(7509 . "MODIFIER LETTER SMALL BOTTOM HALF O")
(7510 . "MODIFIER LETTER SMALL P")
(7511 . "MODIFIER LETTER SMALL T")
(7512 . "MODIFIER LETTER SMALL U")
(7513 . "MODIFIER LETTER SMALL SIDEWAYS U")
(7514 . "MODIFIER LETTER SMALL TURNED M")
(7515 . "MODIFIER LETTER SMALL V")
(7516 . "MODIFIER LETTER SMALL AIN")
(7517 . "MODIFIER LETTER SMALL BETA")
(7518 . "MODIFIER LETTER SMALL GREEK GAMMA")
(7519 . "MODIFIER LETTER SMALL DELTA")
(7520 . "MODIFIER LETTER SMALL GREEK PHI")
(7521 . "MODIFIER LETTER SMALL CHI")
(7522 . "LATIN SUBSCRIPT SMALL LETTER I")
(7523 . "LATIN SUBSCRIPT SMALL LETTER R")
(7524 . "LATIN SUBSCRIPT SMALL LETTER U")
(7525 . "LATIN SUBSCRIPT SMALL LETTER V")
(7526 . "GREEK SUBSCRIPT SMALL LETTER BETA")
(7527 . "GREEK SUBSCRIPT SMALL LETTER GAMMA")
(7528 . "GREEK SUBSCRIPT SMALL LETTER RHO")
(7529 . "GREEK SUBSCRIPT SMALL LETTER PHI")
(7530 . "GREEK SUBSCRIPT SMALL LETTER CHI")
(7531 . "LATIN SMALL LETTER UE")
(7532 . "LATIN SMALL LETTER B WITH MIDDLE TILDE")
(7533 . "LATIN SMALL LETTER D WITH MIDDLE TILDE")
(7534 . "LATIN SMALL LETTER F WITH MIDDLE TILDE")
(7535 . "LATIN SMALL LETTER M WITH MIDDLE TILDE")
(7536 . "LATIN SMALL LETTER N WITH MIDDLE TILDE")
(7537 . "LATIN SMALL LETTER P WITH MIDDLE TILDE")
(7538 . "LATIN SMALL LETTER R WITH MIDDLE TILDE")
(7539 . "LATIN SMALL LETTER R WITH FISHHOOK AND MIDDLE TILDE")
(7540 . "LATIN SMALL LETTER S WITH MIDDLE TILDE")
(7541 . "LATIN SMALL LETTER T WITH MIDDLE TILDE")
(7542 . "LATIN SMALL LETTER Z WITH MIDDLE TILDE")
(7543 . "LATIN SMALL LETTER TURNED G")
(7544 . "MODIFIER LETTER CYRILLIC EN")
(7545 . "LATIN SMALL LETTER INSULAR G")
(7546 . "LATIN SMALL LETTER TH WITH STRIKETHROUGH")
(7547 . "LATIN SMALL CAPITAL LETTER I WITH STROKE")
(7548 . "LATIN SMALL LETTER IOTA WITH STROKE")
(7549 . "LATIN SMALL LETTER P WITH STROKE")
(7550 . "LATIN SMALL CAPITAL LETTER U WITH STROKE")
(7551 . "LATIN SMALL LETTER UPSILON WITH STROKE")
(7552 . "LATIN SMALL LETTER B WITH PALATAL HOOK")
(7553 . "LATIN SMALL LETTER D WITH PALATAL HOOK")
(7554 . "LATIN SMALL LETTER F WITH PALATAL HOOK")
(7555 . "LATIN SMALL LETTER G WITH PALATAL HOOK")
(7556 . "LATIN SMALL LETTER K WITH PALATAL HOOK")
(7557 . "LATIN SMALL LETTER L WITH PALATAL HOOK")
(7558 . "LATIN SMALL LETTER M WITH PALATAL HOOK")
(7559 . "LATIN SMALL LETTER N WITH PALATAL HOOK")
(7560 . "LATIN SMALL LETTER P WITH PALATAL HOOK")
(7561 . "LATIN SMALL LETTER R WITH PALATAL HOOK")
(7562 . "LATIN SMALL LETTER S WITH PALATAL HOOK")
(7563 . "LATIN SMALL LETTER ESH WITH PALATAL HOOK")
(7564 . "LATIN SMALL LETTER V WITH PALATAL HOOK")
(7565 . "LATIN SMALL LETTER X WITH PALATAL HOOK")
(7566 . "LATIN SMALL LETTER Z WITH PALATAL HOOK")
(7567 . "LATIN SMALL LETTER A WITH RETROFLEX HOOK")
(7568 . "LATIN SMALL LETTER ALPHA WITH RETROFLEX HOOK")
(7569 . "LATIN SMALL LETTER D WITH HOOK AND TAIL")
(7570 . "LATIN SMALL LETTER E WITH RETROFLEX HOOK")
(7571 . "LATIN SMALL LETTER OPEN E WITH RETROFLEX HOOK")
(7572 . "LATIN SMALL LETTER REVERSED OPEN E WITH RETROFLEX HOOK")
(7573 . "LATIN SMALL LETTER SCHWA WITH RETROFLEX HOOK")
(7574 . "LATIN SMALL LETTER I WITH RETROFLEX HOOK")
(7575 . "LATIN SMALL LETTER OPEN O WITH RETROFLEX HOOK")
(7576 . "LATIN SMALL LETTER ESH WITH RETROFLEX HOOK")
(7577 . "LATIN SMALL LETTER U WITH RETROFLEX HOOK")
(7578 . "LATIN SMALL LETTER EZH WITH RETROFLEX HOOK")
(7579 . "MODIFIER LETTER SMALL TURNED ALPHA")
(7580 . "MODIFIER LETTER SMALL C")
(7581 . "MODIFIER LETTER SMALL C WITH CURL")
(7582 . "MODIFIER LETTER SMALL ETH")
(7583 . "MODIFIER LETTER SMALL REVERSED OPEN E")
(7584 . "MODIFIER LETTER SMALL F")
(7585 . "MODIFIER LETTER SMALL DOTLESS J WITH STROKE")
(7586 . "MODIFIER LETTER SMALL SCRIPT G")
(7587 . "MODIFIER LETTER SMALL TURNED H")
(7588 . "MODIFIER LETTER SMALL I WITH STROKE")
(7589 . "MODIFIER LETTER SMALL IOTA")
(7590 . "MODIFIER LETTER SMALL CAPITAL I")
(7591 . "MODIFIER LETTER SMALL CAPITAL I WITH STROKE")
(7592 . "MODIFIER LETTER SMALL J WITH CROSSED-TAIL")
(7593 . "MODIFIER LETTER SMALL L WITH RETROFLEX HOOK")
(7594 . "MODIFIER LETTER SMALL L WITH PALATAL HOOK")
(7595 . "MODIFIER LETTER SMALL CAPITAL L")
(7596 . "MODIFIER LETTER SMALL M WITH HOOK")
(7597 . "MODIFIER LETTER SMALL TURNED M WITH LONG LEG")
(7598 . "MODIFIER LETTER SMALL N WITH LEFT HOOK")
(7599 . "MODIFIER LETTER SMALL N WITH RETROFLEX HOOK")
(7600 . "MODIFIER LETTER SMALL CAPITAL N")
(7601 . "MODIFIER LETTER SMALL BARRED O")
(7602 . "MODIFIER LETTER SMALL PHI")
(7603 . "MODIFIER LETTER SMALL S WITH HOOK")
(7604 . "MODIFIER LETTER SMALL ESH")
(7605 . "MODIFIER LETTER SMALL T WITH PALATAL HOOK")
(7606 . "MODIFIER LETTER SMALL U BAR")
(7607 . "MODIFIER LETTER SMALL UPSILON")
(7608 . "MODIFIER LETTER SMALL CAPITAL U")
(7609 . "MODIFIER LETTER SMALL V WITH HOOK")
(7610 . "MODIFIER LETTER SMALL TURNED V")
(7611 . "MODIFIER LETTER SMALL Z")
(7612 . "MODIFIER LETTER SMALL Z WITH RETROFLEX HOOK")
(7613 . "MODIFIER LETTER SMALL Z WITH CURL")
(7614 . "MODIFIER LETTER SMALL EZH")
(7615 . "MODIFIER LETTER SMALL THETA")
(7616 . "COMBINING DOTTED GRAVE ACCENT")
(7617 . "COMBINING DOTTED ACUTE ACCENT")
(7618 . "COMBINING SNAKE BELOW")
(7619 . "COMBINING SUSPENSION MARK")
(7620 . "COMBINING MACRON-ACUTE")
(7621 . "COMBINING GRAVE-MACRON")
(7622 . "COMBINING MACRON-GRAVE")
(7623 . "COMBINING ACUTE-MACRON")
(7624 . "COMBINING GRAVE-ACUTE-GRAVE")
(7625 . "COMBINING ACUTE-GRAVE-ACUTE")
(7626 . "COMBINING LATIN SMALL LETTER R BELOW")
(7627 . "COMBINING BREVE-MACRON")
(7628 . "COMBINING MACRON-BREVE")
(7629 . "COMBINING DOUBLE CIRCUMFLEX ABOVE")
(7630 . "COMBINING OGONEK ABOVE")
(7631 . "COMBINING ZIGZAG BELOW")
(7632 . "COMBINING IS BELOW")
(7633 . "COMBINING UR ABOVE")
(7634 . "COMBINING US ABOVE")
(7635 . "COMBINING LATIN SMALL LETTER FLATTENED OPEN A ABOVE")
(7636 . "COMBINING LATIN SMALL LETTER AE")
(7637 . "COMBINING LATIN SMALL LETTER AO")
(7638 . "COMBINING LATIN SMALL LETTER AV")
(7639 . "COMBINING LATIN SMALL LETTER C CEDILLA")
(7640 . "COMBINING LATIN SMALL LETTER INSULAR D")
(7641 . "COMBINING LATIN SMALL LETTER ETH")
(7642 . "COMBINING LATIN SMALL LETTER G")
(7643 . "COMBINING LATIN LETTER SMALL CAPITAL G")
(7644 . "COMBINING LATIN SMALL LETTER K")
(7645 . "COMBINING LATIN SMALL LETTER L")
(7646 . "COMBINING LATIN LETTER SMALL CAPITAL L")
(7647 . "COMBINING LATIN LETTER SMALL CAPITAL M")
(7648 . "COMBINING LATIN SMALL LETTER N")
(7649 . "COMBINING LATIN LETTER SMALL CAPITAL N")
(7650 . "COMBINING LATIN LETTER SMALL CAPITAL R")
(7651 . "COMBINING LATIN SMALL LETTER R ROTUNDA")
(7652 . "COMBINING LATIN SMALL LETTER S")
(7653 . "COMBINING LATIN SMALL LETTER LONG S")
(7654 . "COMBINING LATIN SMALL LETTER Z")
(7655 . "COMBINING LATIN SMALL LETTER ALPHA")
(7656 . "COMBINING LATIN SMALL LETTER B")
(7657 . "COMBINING LATIN SMALL LETTER BETA")
(7658 . "COMBINING LATIN SMALL LETTER SCHWA")
(7659 . "COMBINING LATIN SMALL LETTER F")
(7660 . "COMBINING LATIN SMALL LETTER L WITH DOUBLE MIDDLE TILDE")
(7661 . "COMBINING LATIN SMALL LETTER O WITH LIGHT CENTRALIZATION STROKE")
(7662 . "COMBINING LATIN SMALL LETTER P")
(7663 . "COMBINING LATIN SMALL LETTER ESH")
(7664 . "COMBINING LATIN SMALL LETTER U WITH LIGHT CENTRALIZATION STROKE")
(7665 . "COMBINING LATIN SMALL LETTER W")
(7666 . "COMBINING LATIN SMALL LETTER A WITH DIAERESIS")
(7667 . "COMBINING LATIN SMALL LETTER O WITH DIAERESIS")
(7668 . "COMBINING LATIN SMALL LETTER U WITH DIAERESIS")
(7669 . "COMBINING UP TACK ABOVE")
((7670 . 7675) . #f)
(7675 . "COMBINING DELETION MARK")
(7676 . "COMBINING DOUBLE INVERTED BREVE BELOW")
(7677 . "COMBINING ALMOST EQUAL TO BELOW")
(7678 . "COMBINING LEFT ARROWHEAD ABOVE")
(7679 . "COMBINING RIGHT ARROWHEAD AND DOWN ARROWHEAD BELOW")
(7680 . "LATIN CAPITAL LETTER A WITH RING BELOW")
(7681 . "LATIN SMALL LETTER A WITH RING BELOW")
(7682 . "LATIN CAPITAL LETTER B WITH DOT ABOVE")
(7683 . "LATIN SMALL LETTER B WITH DOT ABOVE")
(7684 . "LATIN CAPITAL LETTER B WITH DOT BELOW")
(7685 . "LATIN SMALL LETTER B WITH DOT BELOW")
(7686 . "LATIN CAPITAL LETTER B WITH LINE BELOW")
(7687 . "LATIN SMALL LETTER B WITH LINE BELOW")
(7688 . "LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE")
(7689 . "LATIN SMALL LETTER C WITH CEDILLA AND ACUTE")
(7690 . "LATIN CAPITAL LETTER D WITH DOT ABOVE")
(7691 . "LATIN SMALL LETTER D WITH DOT ABOVE")
(7692 . "LATIN CAPITAL LETTER D WITH DOT BELOW")
(7693 . "LATIN SMALL LETTER D WITH DOT BELOW")
(7694 . "LATIN CAPITAL LETTER D WITH LINE BELOW")
(7695 . "LATIN SMALL LETTER D WITH LINE BELOW")
(7696 . "LATIN CAPITAL LETTER D WITH CEDILLA")
(7697 . "LATIN SMALL LETTER D WITH CEDILLA")
(7698 . "LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW")
(7699 . "LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW")
(7700 . "LATIN CAPITAL LETTER E WITH MACRON AND GRAVE")
(7701 . "LATIN SMALL LETTER E WITH MACRON AND GRAVE")
(7702 . "LATIN CAPITAL LETTER E WITH MACRON AND ACUTE")
(7703 . "LATIN SMALL LETTER E WITH MACRON AND ACUTE")
(7704 . "LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW")
(7705 . "LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW")
(7706 . "LATIN CAPITAL LETTER E WITH TILDE BELOW")
(7707 . "LATIN SMALL LETTER E WITH TILDE BELOW")
(7708 . "LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE")
(7709 . "LATIN SMALL LETTER E WITH CEDILLA AND BREVE")
(7710 . "LATIN CAPITAL LETTER F WITH DOT ABOVE")
(7711 . "LATIN SMALL LETTER F WITH DOT ABOVE")
(7712 . "LATIN CAPITAL LETTER G WITH MACRON")
(7713 . "LATIN SMALL LETTER G WITH MACRON")
(7714 . "LATIN CAPITAL LETTER H WITH DOT ABOVE")
(7715 . "LATIN SMALL LETTER H WITH DOT ABOVE")
(7716 . "LATIN CAPITAL LETTER H WITH DOT BELOW")
(7717 . "LATIN SMALL LETTER H WITH DOT BELOW")
(7718 . "LATIN CAPITAL LETTER H WITH DIAERESIS")
(7719 . "LATIN SMALL LETTER H WITH DIAERESIS")
(7720 . "LATIN CAPITAL LETTER H WITH CEDILLA")
(7721 . "LATIN SMALL LETTER H WITH CEDILLA")
(7722 . "LATIN CAPITAL LETTER H WITH BREVE BELOW")
(7723 . "LATIN SMALL LETTER H WITH BREVE BELOW")
(7724 . "LATIN CAPITAL LETTER I WITH TILDE BELOW")
(7725 . "LATIN SMALL LETTER I WITH TILDE BELOW")
(7726 . "LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE")
(7727 . "LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE")
(7728 . "LATIN CAPITAL LETTER K WITH ACUTE")
(7729 . "LATIN SMALL LETTER K WITH ACUTE")
(7730 . "LATIN CAPITAL LETTER K WITH DOT BELOW")
(7731 . "LATIN SMALL LETTER K WITH DOT BELOW")
(7732 . "LATIN CAPITAL LETTER K WITH LINE BELOW")
(7733 . "LATIN SMALL LETTER K WITH LINE BELOW")
(7734 . "LATIN CAPITAL LETTER L WITH DOT BELOW")
(7735 . "LATIN SMALL LETTER L WITH DOT BELOW")
(7736 . "LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON")
(7737 . "LATIN SMALL LETTER L WITH DOT BELOW AND MACRON")
(7738 . "LATIN CAPITAL LETTER L WITH LINE BELOW")
(7739 . "LATIN SMALL LETTER L WITH LINE BELOW")
(7740 . "LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW")
(7741 . "LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW")
(7742 . "LATIN CAPITAL LETTER M WITH ACUTE")
(7743 . "LATIN SMALL LETTER M WITH ACUTE")
(7744 . "LATIN CAPITAL LETTER M WITH DOT ABOVE")
(7745 . "LATIN SMALL LETTER M WITH DOT ABOVE")
(7746 . "LATIN CAPITAL LETTER M WITH DOT BELOW")
(7747 . "LATIN SMALL LETTER M WITH DOT BELOW")
(7748 . "LATIN CAPITAL LETTER N WITH DOT ABOVE")
(7749 . "LATIN SMALL LETTER N WITH DOT ABOVE")
(7750 . "LATIN CAPITAL LETTER N WITH DOT BELOW")
(7751 . "LATIN SMALL LETTER N WITH DOT BELOW")
(7752 . "LATIN CAPITAL LETTER N WITH LINE BELOW")
(7753 . "LATIN SMALL LETTER N WITH LINE BELOW")
(7754 . "LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW")
(7755 . "LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW")
(7756 . "LATIN CAPITAL LETTER O WITH TILDE AND ACUTE")
(7757 . "LATIN SMALL LETTER O WITH TILDE AND ACUTE")
(7758 . "LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS")
(7759 . "LATIN SMALL LETTER O WITH TILDE AND DIAERESIS")
(7760 . "LATIN CAPITAL LETTER O WITH MACRON AND GRAVE")
(7761 . "LATIN SMALL LETTER O WITH MACRON AND GRAVE")
(7762 . "LATIN CAPITAL LETTER O WITH MACRON AND ACUTE")
(7763 . "LATIN SMALL LETTER O WITH MACRON AND ACUTE")
(7764 . "LATIN CAPITAL LETTER P WITH ACUTE")
(7765 . "LATIN SMALL LETTER P WITH ACUTE")
(7766 . "LATIN CAPITAL LETTER P WITH DOT ABOVE")
(7767 . "LATIN SMALL LETTER P WITH DOT ABOVE")
(7768 . "LATIN CAPITAL LETTER R WITH DOT ABOVE")
(7769 . "LATIN SMALL LETTER R WITH DOT ABOVE")
(7770 . "LATIN CAPITAL LETTER R WITH DOT BELOW")
(7771 . "LATIN SMALL LETTER R WITH DOT BELOW")
(7772 . "LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON")
(7773 . "LATIN SMALL LETTER R WITH DOT BELOW AND MACRON")
(7774 . "LATIN CAPITAL LETTER R WITH LINE BELOW")
(7775 . "LATIN SMALL LETTER R WITH LINE BELOW")
(7776 . "LATIN CAPITAL LETTER S WITH DOT ABOVE")
(7777 . "LATIN SMALL LETTER S WITH DOT ABOVE")
(7778 . "LATIN CAPITAL LETTER S WITH DOT BELOW")
(7779 . "LATIN SMALL LETTER S WITH DOT BELOW")
(7780 . "LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE")
(7781 . "LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE")
(7782 . "LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE")
(7783 . "LATIN SMALL LETTER S WITH CARON AND DOT ABOVE")
(7784 . "LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE")
(7785 . "LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE")
(7786 . "LATIN CAPITAL LETTER T WITH DOT ABOVE")
(7787 . "LATIN SMALL LETTER T WITH DOT ABOVE")
(7788 . "LATIN CAPITAL LETTER T WITH DOT BELOW")
(7789 . "LATIN SMALL LETTER T WITH DOT BELOW")
(7790 . "LATIN CAPITAL LETTER T WITH LINE BELOW")
(7791 . "LATIN SMALL LETTER T WITH LINE BELOW")
(7792 . "LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW")
(7793 . "LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW")
(7794 . "LATIN CAPITAL LETTER U WITH DIAERESIS BELOW")
(7795 . "LATIN SMALL LETTER U WITH DIAERESIS BELOW")
(7796 . "LATIN CAPITAL LETTER U WITH TILDE BELOW")
(7797 . "LATIN SMALL LETTER U WITH TILDE BELOW")
(7798 . "LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW")
(7799 . "LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW")
(7800 . "LATIN CAPITAL LETTER U WITH TILDE AND ACUTE")
(7801 . "LATIN SMALL LETTER U WITH TILDE AND ACUTE")
(7802 . "LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS")
(7803 . "LATIN SMALL LETTER U WITH MACRON AND DIAERESIS")
(7804 . "LATIN CAPITAL LETTER V WITH TILDE")
(7805 . "LATIN SMALL LETTER V WITH TILDE")
(7806 . "LATIN CAPITAL LETTER V WITH DOT BELOW")
(7807 . "LATIN SMALL LETTER V WITH DOT BELOW")
(7808 . "LATIN CAPITAL LETTER W WITH GRAVE")
(7809 . "LATIN SMALL LETTER W WITH GRAVE")
(7810 . "LATIN CAPITAL LETTER W WITH ACUTE")
(7811 . "LATIN SMALL LETTER W WITH ACUTE")
(7812 . "LATIN CAPITAL LETTER W WITH DIAERESIS")
(7813 . "LATIN SMALL LETTER W WITH DIAERESIS")
(7814 . "LATIN CAPITAL LETTER W WITH DOT ABOVE")
(7815 . "LATIN SMALL LETTER W WITH DOT ABOVE")
(7816 . "LATIN CAPITAL LETTER W WITH DOT BELOW")
(7817 . "LATIN SMALL LETTER W WITH DOT BELOW")
(7818 . "LATIN CAPITAL LETTER X WITH DOT ABOVE")
(7819 . "LATIN SMALL LETTER X WITH DOT ABOVE")
(7820 . "LATIN CAPITAL LETTER X WITH DIAERESIS")
(7821 . "LATIN SMALL LETTER X WITH DIAERESIS")
(7822 . "LATIN CAPITAL LETTER Y WITH DOT ABOVE")
(7823 . "LATIN SMALL LETTER Y WITH DOT ABOVE")
(7824 . "LATIN CAPITAL LETTER Z WITH CIRCUMFLEX")
(7825 . "LATIN SMALL LETTER Z WITH CIRCUMFLEX")
(7826 . "LATIN CAPITAL LETTER Z WITH DOT BELOW")
(7827 . "LATIN SMALL LETTER Z WITH DOT BELOW")
(7828 . "LATIN CAPITAL LETTER Z WITH LINE BELOW")
(7829 . "LATIN SMALL LETTER Z WITH LINE BELOW")
(7830 . "LATIN SMALL LETTER H WITH LINE BELOW")
(7831 . "LATIN SMALL LETTER T WITH DIAERESIS")
(7832 . "LATIN SMALL LETTER W WITH RING ABOVE")
(7833 . "LATIN SMALL LETTER Y WITH RING ABOVE")
(7834 . "LATIN SMALL LETTER A WITH RIGHT HALF RING")
(7835 . "LATIN SMALL LETTER LONG S WITH DOT ABOVE")
(7836 . "LATIN SMALL LETTER LONG S WITH DIAGONAL STROKE")
(7837 . "LATIN SMALL LETTER LONG S WITH HIGH STROKE")
(7838 . "LATIN CAPITAL LETTER SHARP S")
(7839 . "LATIN SMALL LETTER DELTA")
(7840 . "LATIN CAPITAL LETTER A WITH DOT BELOW")
(7841 . "LATIN SMALL LETTER A WITH DOT BELOW")
(7842 . "LATIN CAPITAL LETTER A WITH HOOK ABOVE")
(7843 . "LATIN SMALL LETTER A WITH HOOK ABOVE")
(7844 . "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE")
(7845 . "LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE")
(7846 . "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE")
(7847 . "LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE")
(7848 . "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE")
(7849 . "LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE")
(7850 . "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE")
(7851 . "LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE")
(7852 . "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW")
(7853 . "LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW")
(7854 . "LATIN CAPITAL LETTER A WITH BREVE AND ACUTE")
(7855 . "LATIN SMALL LETTER A WITH BREVE AND ACUTE")
(7856 . "LATIN CAPITAL LETTER A WITH BREVE AND GRAVE")
(7857 . "LATIN SMALL LETTER A WITH BREVE AND GRAVE")
(7858 . "LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE")
(7859 . "LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE")
(7860 . "LATIN CAPITAL LETTER A WITH BREVE AND TILDE")
(7861 . "LATIN SMALL LETTER A WITH BREVE AND TILDE")
(7862 . "LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW")
(7863 . "LATIN SMALL LETTER A WITH BREVE AND DOT BELOW")
(7864 . "LATIN CAPITAL LETTER E WITH DOT BELOW")
(7865 . "LATIN SMALL LETTER E WITH DOT BELOW")
(7866 . "LATIN CAPITAL LETTER E WITH HOOK ABOVE")
(7867 . "LATIN SMALL LETTER E WITH HOOK ABOVE")
(7868 . "LATIN CAPITAL LETTER E WITH TILDE")
(7869 . "LATIN SMALL LETTER E WITH TILDE")
(7870 . "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE")
(7871 . "LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE")
(7872 . "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE")
(7873 . "LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE")
(7874 . "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE")
(7875 . "LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE")
(7876 . "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE")
(7877 . "LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE")
(7878 . "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW")
(7879 . "LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW")
(7880 . "LATIN CAPITAL LETTER I WITH HOOK ABOVE")
(7881 . "LATIN SMALL LETTER I WITH HOOK ABOVE")
(7882 . "LATIN CAPITAL LETTER I WITH DOT BELOW")
(7883 . "LATIN SMALL LETTER I WITH DOT BELOW")
(7884 . "LATIN CAPITAL LETTER O WITH DOT BELOW")
(7885 . "LATIN SMALL LETTER O WITH DOT BELOW")
(7886 . "LATIN CAPITAL LETTER O WITH HOOK ABOVE")
(7887 . "LATIN SMALL LETTER O WITH HOOK ABOVE")
(7888 . "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE")
(7889 . "LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE")
(7890 . "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE")
(7891 . "LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE")
(7892 . "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE")
(7893 . "LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE")
(7894 . "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE")
(7895 . "LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE")
(7896 . "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW")
(7897 . "LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW")
(7898 . "LATIN CAPITAL LETTER O WITH HORN AND ACUTE")
(7899 . "LATIN SMALL LETTER O WITH HORN AND ACUTE")
(7900 . "LATIN CAPITAL LETTER O WITH HORN AND GRAVE")
(7901 . "LATIN SMALL LETTER O WITH HORN AND GRAVE")
(7902 . "LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE")
(7903 . "LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE")
(7904 . "LATIN CAPITAL LETTER O WITH HORN AND TILDE")
(7905 . "LATIN SMALL LETTER O WITH HORN AND TILDE")
(7906 . "LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW")
(7907 . "LATIN SMALL LETTER O WITH HORN AND DOT BELOW")
(7908 . "LATIN CAPITAL LETTER U WITH DOT BELOW")
(7909 . "LATIN SMALL LETTER U WITH DOT BELOW")
(7910 . "LATIN CAPITAL LETTER U WITH HOOK ABOVE")
(7911 . "LATIN SMALL LETTER U WITH HOOK ABOVE")
(7912 . "LATIN CAPITAL LETTER U WITH HORN AND ACUTE")
(7913 . "LATIN SMALL LETTER U WITH HORN AND ACUTE")
(7914 . "LATIN CAPITAL LETTER U WITH HORN AND GRAVE")
(7915 . "LATIN SMALL LETTER U WITH HORN AND GRAVE")
(7916 . "LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE")
(7917 . "LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE")
(7918 . "LATIN CAPITAL LETTER U WITH HORN AND TILDE")
(7919 . "LATIN SMALL LETTER U WITH HORN AND TILDE")
(7920 . "LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW")
(7921 . "LATIN SMALL LETTER U WITH HORN AND DOT BELOW")
(7922 . "LATIN CAPITAL LETTER Y WITH GRAVE")
(7923 . "LATIN SMALL LETTER Y WITH GRAVE")
(7924 . "LATIN CAPITAL LETTER Y WITH DOT BELOW")
(7925 . "LATIN SMALL LETTER Y WITH DOT BELOW")
(7926 . "LATIN CAPITAL LETTER Y WITH HOOK ABOVE")
(7927 . "LATIN SMALL LETTER Y WITH HOOK ABOVE")
(7928 . "LATIN CAPITAL LETTER Y WITH TILDE")
(7929 . "LATIN SMALL LETTER Y WITH TILDE")
(7930 . "LATIN CAPITAL LETTER MIDDLE-WELSH LL")
(7931 . "LATIN SMALL LETTER MIDDLE-WELSH LL")
(7932 . "LATIN CAPITAL LETTER MIDDLE-WELSH V")
(7933 . "LATIN SMALL LETTER MIDDLE-WELSH V")
(7934 . "LATIN CAPITAL LETTER Y WITH LOOP")
(7935 . "LATIN SMALL LETTER Y WITH LOOP")
(7936 . "GREEK SMALL LETTER ALPHA WITH PSILI")
(7937 . "GREEK SMALL LETTER ALPHA WITH DASIA")
(7938 . "GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA")
(7939 . "GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA")
(7940 . "GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA")
(7941 . "GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA")
(7942 . "GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI")
(7943 . "GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI")
(7944 . "GREEK CAPITAL LETTER ALPHA WITH PSILI")
(7945 . "GREEK CAPITAL LETTER ALPHA WITH DASIA")
(7946 . "GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA")
(7947 . "GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA")
(7948 . "GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA")
(7949 . "GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA")
(7950 . "GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI")
(7951 . "GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI")
(7952 . "GREEK SMALL LETTER EPSILON WITH PSILI")
(7953 . "GREEK SMALL LETTER EPSILON WITH DASIA")
(7954 . "GREEK SMALL LETTER EPSILON WITH PSILI AND VARIA")
(7955 . "GREEK SMALL LETTER EPSILON WITH DASIA AND VARIA")
(7956 . "GREEK SMALL LETTER EPSILON WITH PSILI AND OXIA")
(7957 . "GREEK SMALL LETTER EPSILON WITH DASIA AND OXIA")
((7958 . 7960) . #f)
(7960 . "GREEK CAPITAL LETTER EPSILON WITH PSILI")
(7961 . "GREEK CAPITAL LETTER EPSILON WITH DASIA")
(7962 . "GREEK CAPITAL LETTER EPSILON WITH PSILI AND VARIA")
(7963 . "GREEK CAPITAL LETTER EPSILON WITH DASIA AND VARIA")
(7964 . "GREEK CAPITAL LETTER EPSILON WITH PSILI AND OXIA")
(7965 . "GREEK CAPITAL LETTER EPSILON WITH DASIA AND OXIA")
((7966 . 7968) . #f)
(7968 . "GREEK SMALL LETTER ETA WITH PSILI")
(7969 . "GREEK SMALL LETTER ETA WITH DASIA")
(7970 . "GREEK SMALL LETTER ETA WITH PSILI AND VARIA")
(7971 . "GREEK SMALL LETTER ETA WITH DASIA AND VARIA")
(7972 . "GREEK SMALL LETTER ETA WITH PSILI AND OXIA")
(7973 . "GREEK SMALL LETTER ETA WITH DASIA AND OXIA")
(7974 . "GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI")
(7975 . "GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI")
(7976 . "GREEK CAPITAL LETTER ETA WITH PSILI")
(7977 . "GREEK CAPITAL LETTER ETA WITH DASIA")
(7978 . "GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA")
(7979 . "GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA")
(7980 . "GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA")
(7981 . "GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA")
(7982 . "GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI")
(7983 . "GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI")
(7984 . "GREEK SMALL LETTER IOTA WITH PSILI")
(7985 . "GREEK SMALL LETTER IOTA WITH DASIA")
(7986 . "GREEK SMALL LETTER IOTA WITH PSILI AND VARIA")
(7987 . "GREEK SMALL LETTER IOTA WITH DASIA AND VARIA")
(7988 . "GREEK SMALL LETTER IOTA WITH PSILI AND OXIA")
(7989 . "GREEK SMALL LETTER IOTA WITH DASIA AND OXIA")
(7990 . "GREEK SMALL LETTER IOTA WITH PSILI AND PERISPOMENI")
(7991 . "GREEK SMALL LETTER IOTA WITH DASIA AND PERISPOMENI")
(7992 . "GREEK CAPITAL LETTER IOTA WITH PSILI")
(7993 . "GREEK CAPITAL LETTER IOTA WITH DASIA")
(7994 . "GREEK CAPITAL LETTER IOTA WITH PSILI AND VARIA")
(7995 . "GREEK CAPITAL LETTER IOTA WITH DASIA AND VARIA")
(7996 . "GREEK CAPITAL LETTER IOTA WITH PSILI AND OXIA")
(7997 . "GREEK CAPITAL LETTER IOTA WITH DASIA AND OXIA")
(7998 . "GREEK CAPITAL LETTER IOTA WITH PSILI AND PERISPOMENI")
(7999 . "GREEK CAPITAL LETTER IOTA WITH DASIA AND PERISPOMENI")
(8000 . "GREEK SMALL LETTER OMICRON WITH PSILI")
(8001 . "GREEK SMALL LETTER OMICRON WITH DASIA")
(8002 . "GREEK SMALL LETTER OMICRON WITH PSILI AND VARIA")
(8003 . "GREEK SMALL LETTER OMICRON WITH DASIA AND VARIA")
(8004 . "GREEK SMALL LETTER OMICRON WITH PSILI AND OXIA")
(8005 . "GREEK SMALL LETTER OMICRON WITH DASIA AND OXIA")
((8006 . 8008) . #f)
(8008 . "GREEK CAPITAL LETTER OMICRON WITH PSILI")
(8009 . "GREEK CAPITAL LETTER OMICRON WITH DASIA")
(8010 . "GREEK CAPITAL LETTER OMICRON WITH PSILI AND VARIA")
(8011 . "GREEK CAPITAL LETTER OMICRON WITH DASIA AND VARIA")
(8012 . "GREEK CAPITAL LETTER OMICRON WITH PSILI AND OXIA")
(8013 . "GREEK CAPITAL LETTER OMICRON WITH DASIA AND OXIA")
((8014 . 8016) . #f)
(8016 . "GREEK SMALL LETTER UPSILON WITH PSILI")
(8017 . "GREEK SMALL LETTER UPSILON WITH DASIA")
(8018 . "GREEK SMALL LETTER UPSILON WITH PSILI AND VARIA")
(8019 . "GREEK SMALL LETTER UPSILON WITH DASIA AND VARIA")
(8020 . "GREEK SMALL LETTER UPSILON WITH PSILI AND OXIA")
(8021 . "GREEK SMALL LETTER UPSILON WITH DASIA AND OXIA")
(8022 . "GREEK SMALL LETTER UPSILON WITH PSILI AND PERISPOMENI")
(8023 . "GREEK SMALL LETTER UPSILON WITH DASIA AND PERISPOMENI")
(8024 . #f)
(8025 . "GREEK CAPITAL LETTER UPSILON WITH DASIA")
(8026 . #f)
(8027 . "GREEK CAPITAL LETTER UPSILON WITH DASIA AND VARIA")
(8028 . #f)
(8029 . "GREEK CAPITAL LETTER UPSILON WITH DASIA AND OXIA")
(8030 . #f)
(8031 . "GREEK CAPITAL LETTER UPSILON WITH DASIA AND PERISPOMENI")
(8032 . "GREEK SMALL LETTER OMEGA WITH PSILI")
(8033 . "GREEK SMALL LETTER OMEGA WITH DASIA")
(8034 . "GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA")
(8035 . "GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA")
(8036 . "GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA")
(8037 . "GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA")
(8038 . "GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI")
(8039 . "GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI")
(8040 . "GREEK CAPITAL LETTER OMEGA WITH PSILI")
(8041 . "GREEK CAPITAL LETTER OMEGA WITH DASIA")
(8042 . "GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA")
(8043 . "GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA")
(8044 . "GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA")
(8045 . "GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA")
(8046 . "GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI")
(8047 . "GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI")
(8048 . "GREEK SMALL LETTER ALPHA WITH VARIA")
(8049 . "GREEK SMALL LETTER ALPHA WITH OXIA")
(8050 . "GREEK SMALL LETTER EPSILON WITH VARIA")
(8051 . "GREEK SMALL LETTER EPSILON WITH OXIA")
(8052 . "GREEK SMALL LETTER ETA WITH VARIA")
(8053 . "GREEK SMALL LETTER ETA WITH OXIA")
(8054 . "GREEK SMALL LETTER IOTA WITH VARIA")
(8055 . "GREEK SMALL LETTER IOTA WITH OXIA")
(8056 . "GREEK SMALL LETTER OMICRON WITH VARIA")
(8057 . "GREEK SMALL LETTER OMICRON WITH OXIA")
(8058 . "GREEK SMALL LETTER UPSILON WITH VARIA")
(8059 . "GREEK SMALL LETTER UPSILON WITH OXIA")
(8060 . "GREEK SMALL LETTER OMEGA WITH VARIA")
(8061 . "GREEK SMALL LETTER OMEGA WITH OXIA")
((8062 . 8064) . #f)
(8064 . "GREEK SMALL LETTER ALPHA WITH PSILI AND YPOGEGRAMMENI")
(8065 . "GREEK SMALL LETTER ALPHA WITH DASIA AND YPOGEGRAMMENI")
(8066 . "GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA AND YPOGEGRAMMENI")
(8067 . "GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA AND YPOGEGRAMMENI")
(8068 . "GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA AND YPOGEGRAMMENI")
(8069 . "GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA AND YPOGEGRAMMENI")
(8070 . "GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI")
(8071 . "GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI")
(8072 . "GREEK CAPITAL LETTER ALPHA WITH PSILI AND PROSGEGRAMMENI")
(8073 . "GREEK CAPITAL LETTER ALPHA WITH DASIA AND PROSGEGRAMMENI")
(8074 . "GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA AND PROSGEGRAMMENI")
(8075 . "GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA AND PROSGEGRAMMENI")
(8076 . "GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA AND PROSGEGRAMMENI")
(8077 . "GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA AND PROSGEGRAMMENI")
(8078 . "GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI")
(8079 . "GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI")
(8080 . "GREEK SMALL LETTER ETA WITH PSILI AND YPOGEGRAMMENI")
(8081 . "GREEK SMALL LETTER ETA WITH DASIA AND YPOGEGRAMMENI")
(8082 . "GREEK SMALL LETTER ETA WITH PSILI AND VARIA AND YPOGEGRAMMENI")
(8083 . "GREEK SMALL LETTER ETA WITH DASIA AND VARIA AND YPOGEGRAMMENI")
(8084 . "GREEK SMALL LETTER ETA WITH PSILI AND OXIA AND YPOGEGRAMMENI")
(8085 . "GREEK SMALL LETTER ETA WITH DASIA AND OXIA AND YPOGEGRAMMENI")
(8086 . "GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI")
(8087 . "GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI")
(8088 . "GREEK CAPITAL LETTER ETA WITH PSILI AND PROSGEGRAMMENI")
(8089 . "GREEK CAPITAL LETTER ETA WITH DASIA AND PROSGEGRAMMENI")
(8090 . "GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA AND PROSGEGRAMMENI")
(8091 . "GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA AND PROSGEGRAMMENI")
(8092 . "GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA AND PROSGEGRAMMENI")
(8093 . "GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA AND PROSGEGRAMMENI")
(8094 . "GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI")
(8095 . "GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI")
(8096 . "GREEK SMALL LETTER OMEGA WITH PSILI AND YPOGEGRAMMENI")
(8097 . "GREEK SMALL LETTER OMEGA WITH DASIA AND YPOGEGRAMMENI")
(8098 . "GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA AND YPOGEGRAMMENI")
(8099 . "GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA AND YPOGEGRAMMENI")
(8100 . "GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA AND YPOGEGRAMMENI")
(8101 . "GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA AND YPOGEGRAMMENI")
(8102 . "GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI")
(8103 . "GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI")
(8104 . "GREEK CAPITAL LETTER OMEGA WITH PSILI AND PROSGEGRAMMENI")
(8105 . "GREEK CAPITAL LETTER OMEGA WITH DASIA AND PROSGEGRAMMENI")
(8106 . "GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA AND PROSGEGRAMMENI")
(8107 . "GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA AND PROSGEGRAMMENI")
(8108 . "GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA AND PROSGEGRAMMENI")
(8109 . "GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA AND PROSGEGRAMMENI")
(8110 . "GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI")
(8111 . "GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI")
(8112 . "GREEK SMALL LETTER ALPHA WITH VRACHY")
(8113 . "GREEK SMALL LETTER ALPHA WITH MACRON")
(8114 . "GREEK SMALL LETTER ALPHA WITH VARIA AND YPOGEGRAMMENI")
(8115 . "GREEK SMALL LETTER ALPHA WITH YPOGEGRAMMENI")
(8116 . "GREEK SMALL LETTER ALPHA WITH OXIA AND YPOGEGRAMMENI")
(8117 . #f)
(8118 . "GREEK SMALL LETTER ALPHA WITH PERISPOMENI")
(8119 . "GREEK SMALL LETTER ALPHA WITH PERISPOMENI AND YPOGEGRAMMENI")
(8120 . "GREEK CAPITAL LETTER ALPHA WITH VRACHY")
(8121 . "GREEK CAPITAL LETTER ALPHA WITH MACRON")
(8122 . "GREEK CAPITAL LETTER ALPHA WITH VARIA")
(8123 . "GREEK CAPITAL LETTER ALPHA WITH OXIA")
(8124 . "GREEK CAPITAL LETTER ALPHA WITH PROSGEGRAMMENI")
(8125 . "GREEK KORONIS")
(8126 . "GREEK PROSGEGRAMMENI")
(8127 . "GREEK PSILI")
(8128 . "GREEK PERISPOMENI")
(8129 . "GREEK DIALYTIKA AND PERISPOMENI")
(8130 . "GREEK SMALL LETTER ETA WITH VARIA AND YPOGEGRAMMENI")
(8131 . "GREEK SMALL LETTER ETA WITH YPOGEGRAMMENI")
(8132 . "GREEK SMALL LETTER ETA WITH OXIA AND YPOGEGRAMMENI")
(8133 . #f)
(8134 . "GREEK SMALL LETTER ETA WITH PERISPOMENI")
(8135 . "GREEK SMALL LETTER ETA WITH PERISPOMENI AND YPOGEGRAMMENI")
(8136 . "GREEK CAPITAL LETTER EPSILON WITH VARIA")
(8137 . "GREEK CAPITAL LETTER EPSILON WITH OXIA")
(8138 . "GREEK CAPITAL LETTER ETA WITH VARIA")
(8139 . "GREEK CAPITAL LETTER ETA WITH OXIA")
(8140 . "GREEK CAPITAL LETTER ETA WITH PROSGEGRAMMENI")
(8141 . "GREEK PSILI AND VARIA")
(8142 . "GREEK PSILI AND OXIA")
(8143 . "GREEK PSILI AND PERISPOMENI")
(8144 . "GREEK SMALL LETTER IOTA WITH VRACHY")
(8145 . "GREEK SMALL LETTER IOTA WITH MACRON")
(8146 . "GREEK SMALL LETTER IOTA WITH DIALYTIKA AND VARIA")
(8147 . "GREEK SMALL LETTER IOTA WITH DIALYTIKA AND OXIA")
((8148 . 8150) . #f)
(8150 . "GREEK SMALL LETTER IOTA WITH PERISPOMENI")
(8151 . "GREEK SMALL LETTER IOTA WITH DIALYTIKA AND PERISPOMENI")
(8152 . "GREEK CAPITAL LETTER IOTA WITH VRACHY")
(8153 . "GREEK CAPITAL LETTER IOTA WITH MACRON")
(8154 . "GREEK CAPITAL LETTER IOTA WITH VARIA")
(8155 . "GREEK CAPITAL LETTER IOTA WITH OXIA")
(8156 . #f)
(8157 . "GREEK DASIA AND VARIA")
(8158 . "GREEK DASIA AND OXIA")
(8159 . "GREEK DASIA AND PERISPOMENI")
(8160 . "GREEK SMALL LETTER UPSILON WITH VRACHY")
(8161 . "GREEK SMALL LETTER UPSILON WITH MACRON")
(8162 . "GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND VARIA")
(8163 . "GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND OXIA")
(8164 . "GREEK SMALL LETTER RHO WITH PSILI")
(8165 . "GREEK SMALL LETTER RHO WITH DASIA")
(8166 . "GREEK SMALL LETTER UPSILON WITH PERISPOMENI")
(8167 . "GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND PERISPOMENI")
(8168 . "GREEK CAPITAL LETTER UPSILON WITH VRACHY")
(8169 . "GREEK CAPITAL LETTER UPSILON WITH MACRON")
(8170 . "GREEK CAPITAL LETTER UPSILON WITH VARIA")
(8171 . "GREEK CAPITAL LETTER UPSILON WITH OXIA")
(8172 . "GREEK CAPITAL LETTER RHO WITH DASIA")
(8173 . "GREEK DIALYTIKA AND VARIA")
(8174 . "GREEK DIALYTIKA AND OXIA")
(8175 . "GREEK VARIA")
((8176 . 8178) . #f)
(8178 . "GREEK SMALL LETTER OMEGA WITH VARIA AND YPOGEGRAMMENI")
(8179 . "GREEK SMALL LETTER OMEGA WITH YPOGEGRAMMENI")
(8180 . "GREEK SMALL LETTER OMEGA WITH OXIA AND YPOGEGRAMMENI")
(8181 . #f)
(8182 . "GREEK SMALL LETTER OMEGA WITH PERISPOMENI")
(8183 . "GREEK SMALL LETTER OMEGA WITH PERISPOMENI AND YPOGEGRAMMENI")
(8184 . "GREEK CAPITAL LETTER OMICRON WITH VARIA")
(8185 . "GREEK CAPITAL LETTER OMICRON WITH OXIA")
(8186 . "GREEK CAPITAL LETTER OMEGA WITH VARIA")
(8187 . "GREEK CAPITAL LETTER OMEGA WITH OXIA")
(8188 . "GREEK CAPITAL LETTER OMEGA WITH PROSGEGRAMMENI")
(8189 . "GREEK OXIA")
(8190 . "GREEK DASIA")
(8191 . #f)
(8192 . "EN QUAD")
(8193 . "EM QUAD")
(8194 . "EN SPACE")
(8195 . "EM SPACE")
(8196 . "THREE-PER-EM SPACE")
(8197 . "FOUR-PER-EM SPACE")
(8198 . "SIX-PER-EM SPACE")
(8199 . "FIGURE SPACE")
(8200 . "PUNCTUATION SPACE")
(8201 . "THIN SPACE")
(8202 . "HAIR SPACE")
(8203 . "ZERO WIDTH SPACE")
(8204 . "ZERO WIDTH NON-JOINER")
(8205 . "ZERO WIDTH JOINER")
(8206 . "LEFT-TO-RIGHT MARK")
(8207 . "RIGHT-TO-LEFT MARK")
(8208 . "HYPHEN")
(8209 . "NON-BREAKING HYPHEN")
(8210 . "FIGURE DASH")
(8211 . "EN DASH")
(8212 . "EM DASH")
(8213 . "HORIZONTAL BAR")
(8214 . "DOUBLE VERTICAL LINE")
(8215 . "DOUBLE LOW LINE")
(8216 . "LEFT SINGLE QUOTATION MARK")
(8217 . "RIGHT SINGLE QUOTATION MARK")
(8218 . "SINGLE LOW-9 QUOTATION MARK")
(8219 . "SINGLE HIGH-REVERSED-9 QUOTATION MARK")
(8220 . "LEFT DOUBLE QUOTATION MARK")
(8221 . "RIGHT DOUBLE QUOTATION MARK")
(8222 . "DOUBLE LOW-9 QUOTATION MARK")
(8223 . "DOUBLE HIGH-REVERSED-9 QUOTATION MARK")
(8224 . "DAGGER")
(8225 . "DOUBLE DAGGER")
(8226 . "BULLET")
(8227 . "TRIANGULAR BULLET")
(8228 . "ONE DOT LEADER")
(8229 . "TWO DOT LEADER")
(8230 . "HORIZONTAL ELLIPSIS")
(8231 . "HYPHENATION POINT")
(8232 . "LINE SEPARATOR")
(8233 . "PARAGRAPH SEPARATOR")
(8234 . "LEFT-TO-RIGHT EMBEDDING")
(8235 . "RIGHT-TO-LEFT EMBEDDING")
(8236 . "POP DIRECTIONAL FORMATTING")
(8237 . "LEFT-TO-RIGHT OVERRIDE")
(8238 . "RIGHT-TO-LEFT OVERRIDE")
(8239 . "NARROW NO-BREAK SPACE")
(8240 . "PER MILLE SIGN")
(8241 . "PER TEN THOUSAND SIGN")
(8242 . "PRIME")
(8243 . "DOUBLE PRIME")
(8244 . "TRIPLE PRIME")
(8245 . "REVERSED PRIME")
(8246 . "REVERSED DOUBLE PRIME")
(8247 . "REVERSED TRIPLE PRIME")
(8248 . "CARET")
(8249 . "SINGLE LEFT-POINTING ANGLE QUOTATION MARK")
(8250 . "SINGLE RIGHT-POINTING ANGLE QUOTATION MARK")
(8251 . "REFERENCE MARK")
(8252 . "DOUBLE EXCLAMATION MARK")
(8253 . "INTERROBANG")
(8254 . "OVERLINE")
(8255 . "UNDERTIE")
(8256 . "CHARACTER TIE")
(8257 . "CARET INSERTION POINT")
(8258 . "ASTERISM")
(8259 . "HYPHEN BULLET")
(8260 . "FRACTION SLASH")
(8261 . "LEFT SQUARE BRACKET WITH QUILL")
(8262 . "RIGHT SQUARE BRACKET WITH QUILL")
(8263 . "DOUBLE QUESTION MARK")
(8264 . "QUESTION EXCLAMATION MARK")
(8265 . "EXCLAMATION QUESTION MARK")
(8266 . "TIRONIAN SIGN ET")
(8267 . "REVERSED PILCROW SIGN")
(8268 . "BLACK LEFTWARDS BULLET")
(8269 . "BLACK RIGHTWARDS BULLET")
(8270 . "LOW ASTERISK")
(8271 . "REVERSED SEMICOLON")
(8272 . "CLOSE UP")
(8273 . "TWO ASTERISKS ALIGNED VERTICALLY")
(8274 . "COMMERCIAL MINUS SIGN")
(8275 . "SWUNG DASH")
(8276 . "INVERTED UNDERTIE")
(8277 . "FLOWER PUNCTUATION MARK")
(8278 . "THREE DOT PUNCTUATION")
(8279 . "QUADRUPLE PRIME")
(8280 . "FOUR DOT PUNCTUATION")
(8281 . "FIVE DOT PUNCTUATION")
(8282 . "TWO DOT PUNCTUATION")
(8283 . "FOUR DOT MARK")
(8284 . "DOTTED CROSS")
(8285 . "TRICOLON")
(8286 . "VERTICAL FOUR DOTS")
(8287 . "MEDIUM MATHEMATICAL SPACE")
(8288 . "WORD JOINER")
(8289 . "FUNCTION APPLICATION")
(8290 . "INVISIBLE TIMES")
(8291 . "INVISIBLE SEPARATOR")
(8292 . "INVISIBLE PLUS")
(8293 . #f)
(8294 . "LEFT-TO-RIGHT ISOLATE")
(8295 . "RIGHT-TO-LEFT ISOLATE")
(8296 . "FIRST STRONG ISOLATE")
(8297 . "POP DIRECTIONAL ISOLATE")
(8298 . "INHIBIT SYMMETRIC SWAPPING")
(8299 . "ACTIVATE SYMMETRIC SWAPPING")
(8300 . "INHIBIT ARABIC FORM SHAPING")
(8301 . "ACTIVATE ARABIC FORM SHAPING")
(8302 . "NATIONAL DIGIT SHAPES")
(8303 . "NOMINAL DIGIT SHAPES")
(8304 . "SUPERSCRIPT ZERO")
(8305 . "SUPERSCRIPT LATIN SMALL LETTER I")
((8306 . 8308) . #f)
(8308 . "SUPERSCRIPT FOUR")
(8309 . "SUPERSCRIPT FIVE")
(8310 . "SUPERSCRIPT SIX")
(8311 . "SUPERSCRIPT SEVEN")
(8312 . "SUPERSCRIPT EIGHT")
(8313 . "SUPERSCRIPT NINE")
(8314 . "SUPERSCRIPT PLUS SIGN")
(8315 . "SUPERSCRIPT MINUS")
(8316 . "SUPERSCRIPT EQUALS SIGN")
(8317 . "SUPERSCRIPT LEFT PARENTHESIS")
(8318 . "SUPERSCRIPT RIGHT PARENTHESIS")
(8319 . "SUPERSCRIPT LATIN SMALL LETTER N")
(8320 . "SUBSCRIPT ZERO")
(8321 . "SUBSCRIPT ONE")
(8322 . "SUBSCRIPT TWO")
(8323 . "SUBSCRIPT THREE")
(8324 . "SUBSCRIPT FOUR")
(8325 . "SUBSCRIPT FIVE")
(8326 . "SUBSCRIPT SIX")
(8327 . "SUBSCRIPT SEVEN")
(8328 . "SUBSCRIPT EIGHT")
(8329 . "SUBSCRIPT NINE")
(8330 . "SUBSCRIPT PLUS SIGN")
(8331 . "SUBSCRIPT MINUS")
(8332 . "SUBSCRIPT EQUALS SIGN")
(8333 . "SUBSCRIPT LEFT PARENTHESIS")
(8334 . "SUBSCRIPT RIGHT PARENTHESIS")
(8335 . #f)
(8336 . "LATIN SUBSCRIPT SMALL LETTER A")
(8337 . "LATIN SUBSCRIPT SMALL LETTER E")
(8338 . "LATIN SUBSCRIPT SMALL LETTER O")
(8339 . "LATIN SUBSCRIPT SMALL LETTER X")
(8340 . "LATIN SUBSCRIPT SMALL LETTER SCHWA")
(8341 . "LATIN SUBSCRIPT SMALL LETTER H")
(8342 . "LATIN SUBSCRIPT SMALL LETTER K")
(8343 . "LATIN SUBSCRIPT SMALL LETTER L")
(8344 . "LATIN SUBSCRIPT SMALL LETTER M")
(8345 . "LATIN SUBSCRIPT SMALL LETTER N")
(8346 . "LATIN SUBSCRIPT SMALL LETTER P")
(8347 . "LATIN SUBSCRIPT SMALL LETTER S")
(8348 . "LATIN SUBSCRIPT SMALL LETTER T")
((8349 . 8352) . #f)
(8352 . "EURO-CURRENCY SIGN")
(8353 . "COLON SIGN")
(8354 . "CRUZEIRO SIGN")
(8355 . "FRENCH FRANC SIGN")
(8356 . "LIRA SIGN")
(8357 . "MILL SIGN")
(8358 . "NAIRA SIGN")
(8359 . "PESETA SIGN")
(8360 . "RUPEE SIGN")
(8361 . "WON SIGN")
(8362 . "NEW SHEQEL SIGN")
(8363 . "DONG SIGN")
(8364 . "EURO SIGN")
(8365 . "KIP SIGN")
(8366 . "TUGRIK SIGN")
(8367 . "DRACHMA SIGN")
(8368 . "GERMAN PENNY SIGN")
(8369 . "PESO SIGN")
(8370 . "GUARANI SIGN")
(8371 . "AUSTRAL SIGN")
(8372 . "HRYVNIA SIGN")
(8373 . "CEDI SIGN")
(8374 . "LIVRE TOURNOIS SIGN")
(8375 . "SPESMILO SIGN")
(8376 . "TENGE SIGN")
(8377 . "INDIAN RUPEE SIGN")
(8378 . "TURKISH LIRA SIGN")
(8379 . "NORDIC MARK SIGN")
(8380 . "MANAT SIGN")
(8381 . "RUBLE SIGN")
(8382 . "LARI SIGN")
((8383 . 8400) . #f)
(8400 . "COMBINING LEFT HARPOON ABOVE")
(8401 . "COMBINING RIGHT HARPOON ABOVE")
(8402 . "COMBINING LONG VERTICAL LINE OVERLAY")
(8403 . "COMBINING SHORT VERTICAL LINE OVERLAY")
(8404 . "COMBINING ANTICLOCKWISE ARROW ABOVE")
(8405 . "COMBINING CLOCKWISE ARROW ABOVE")
(8406 . "COMBINING LEFT ARROW ABOVE")
(8407 . "COMBINING RIGHT ARROW ABOVE")
(8408 . "COMBINING RING OVERLAY")
(8409 . "COMBINING CLOCKWISE RING OVERLAY")
(8410 . "COMBINING ANTICLOCKWISE RING OVERLAY")
(8411 . "COMBINING THREE DOTS ABOVE")
(8412 . "COMBINING FOUR DOTS ABOVE")
(8413 . "COMBINING ENCLOSING CIRCLE")
(8414 . "COMBINING ENCLOSING SQUARE")
(8415 . "COMBINING ENCLOSING DIAMOND")
(8416 . "COMBINING ENCLOSING CIRCLE BACKSLASH")
(8417 . "COMBINING LEFT RIGHT ARROW ABOVE")
(8418 . "COMBINING ENCLOSING SCREEN")
(8419 . "COMBINING ENCLOSING KEYCAP")
(8420 . "COMBINING ENCLOSING UPWARD POINTING TRIANGLE")
(8421 . "COMBINING REVERSE SOLIDUS OVERLAY")
(8422 . "COMBINING DOUBLE VERTICAL STROKE OVERLAY")
(8423 . "COMBINING ANNUITY SYMBOL")
(8424 . "COMBINING TRIPLE UNDERDOT")
(8425 . "COMBINING WIDE BRIDGE ABOVE")
(8426 . "COMBINING LEFTWARDS ARROW OVERLAY")
(8427 . "COMBINING LONG DOUBLE SOLIDUS OVERLAY")
(8428 . "COMBINING RIGHTWARDS HARPOON WITH BARB DOWNWARDS")
(8429 . "COMBINING LEFTWARDS HARPOON WITH BARB DOWNWARDS")
(8430 . "COMBINING LEFT ARROW BELOW")
(8431 . "COMBINING RIGHT ARROW BELOW")
(8432 . "COMBINING ASTERISK ABOVE")
((8433 . 8448) . #f)
(8448 . "ACCOUNT OF")
(8449 . "ADDRESSED TO THE SUBJECT")
(8450 . "DOUBLE-STRUCK CAPITAL C")
(8451 . "DEGREE CELSIUS")
(8452 . "CENTRE LINE SYMBOL")
(8453 . "CARE OF")
(8454 . "CADA UNA")
(8455 . "EULER CONSTANT")
(8456 . "SCRUPLE")
(8457 . "DEGREE FAHRENHEIT")
(8458 . "SCRIPT SMALL G")
(8459 . "SCRIPT CAPITAL H")
(8460 . "BLACK-LETTER CAPITAL H")
(8461 . "DOUBLE-STRUCK CAPITAL H")
(8462 . "PLANCK CONSTANT")
(8463 . "PLANCK CONSTANT OVER TWO PI")
(8464 . "SCRIPT CAPITAL I")
(8465 . "BLACK-LETTER CAPITAL I")
(8466 . "SCRIPT CAPITAL L")
(8467 . "SCRIPT SMALL L")
(8468 . "L B BAR SYMBOL")
(8469 . "DOUBLE-STRUCK CAPITAL N")
(8470 . "NUMERO SIGN")
(8471 . "SOUND RECORDING COPYRIGHT")
(8472 . "SCRIPT CAPITAL P")
(8473 . "DOUBLE-STRUCK CAPITAL P")
(8474 . "DOUBLE-STRUCK CAPITAL Q")
(8475 . "SCRIPT CAPITAL R")
(8476 . "BLACK-LETTER CAPITAL R")
(8477 . "DOUBLE-STRUCK CAPITAL R")
(8478 . "PRESCRIPTION TAKE")
(8479 . "RESPONSE")
(8480 . "SERVICE MARK")
(8481 . "TELEPHONE SIGN")
(8482 . "TRADE MARK SIGN")
(8483 . "VERSICLE")
(8484 . "DOUBLE-STRUCK CAPITAL Z")
(8485 . "OUNCE SIGN")
(8486 . "OHM SIGN")
(8487 . "INVERTED OHM SIGN")
(8488 . "BLACK-LETTER CAPITAL Z")
(8489 . "TURNED GREEK SMALL LETTER IOTA")
(8490 . "KELVIN SIGN")
(8491 . "ANGSTROM SIGN")
(8492 . "SCRIPT CAPITAL B")
(8493 . "BLACK-LETTER CAPITAL C")
(8494 . "ESTIMATED SYMBOL")
(8495 . "SCRIPT SMALL E")
(8496 . "SCRIPT CAPITAL E")
(8497 . "SCRIPT CAPITAL F")
(8498 . "TURNED CAPITAL F")
(8499 . "SCRIPT CAPITAL M")
(8500 . "SCRIPT SMALL O")
(8501 . "ALEF SYMBOL")
(8502 . "BET SYMBOL")
(8503 . "GIMEL SYMBOL")
(8504 . "DALET SYMBOL")
(8505 . "INFORMATION SOURCE")
(8506 . "ROTATED CAPITAL Q")
(8507 . "FACSIMILE SIGN")
(8508 . "DOUBLE-STRUCK SMALL PI")
(8509 . "DOUBLE-STRUCK SMALL GAMMA")
(8510 . "DOUBLE-STRUCK CAPITAL GAMMA")
(8511 . "DOUBLE-STRUCK CAPITAL PI")
(8512 . "DOUBLE-STRUCK N-ARY SUMMATION")
(8513 . "TURNED SANS-SERIF CAPITAL G")
(8514 . "TURNED SANS-SERIF CAPITAL L")
(8515 . "REVERSED SANS-SERIF CAPITAL L")
(8516 . "TURNED SANS-SERIF CAPITAL Y")
(8517 . "DOUBLE-STRUCK ITALIC CAPITAL D")
(8518 . "DOUBLE-STRUCK ITALIC SMALL D")
(8519 . "DOUBLE-STRUCK ITALIC SMALL E")
(8520 . "DOUBLE-STRUCK ITALIC SMALL I")
(8521 . "DOUBLE-STRUCK ITALIC SMALL J")
(8522 . "PROPERTY LINE")
(8523 . "TURNED AMPERSAND")
(8524 . "PER SIGN")
(8525 . "AKTIESELSKAB")
(8526 . "TURNED SMALL F")
(8527 . "SYMBOL FOR SAMARITAN SOURCE")
(8528 . "VULGAR FRACTION ONE SEVENTH")
(8529 . "VULGAR FRACTION ONE NINTH")
(8530 . "VULGAR FRACTION ONE TENTH")
(8531 . "VULGAR FRACTION ONE THIRD")
(8532 . "VULGAR FRACTION TWO THIRDS")
(8533 . "VULGAR FRACTION ONE FIFTH")
(8534 . "VULGAR FRACTION TWO FIFTHS")
(8535 . "VULGAR FRACTION THREE FIFTHS")
(8536 . "VULGAR FRACTION FOUR FIFTHS")
(8537 . "VULGAR FRACTION ONE SIXTH")
(8538 . "VULGAR FRACTION FIVE SIXTHS")
(8539 . "VULGAR FRACTION ONE EIGHTH")
(8540 . "VULGAR FRACTION THREE EIGHTHS")
(8541 . "VULGAR FRACTION FIVE EIGHTHS")
(8542 . "VULGAR FRACTION SEVEN EIGHTHS")
(8543 . "FRACTION NUMERATOR ONE")
(8544 . "ROMAN NUMERAL ONE")
(8545 . "ROMAN NUMERAL TWO")
(8546 . "ROMAN NUMERAL THREE")
(8547 . "ROMAN NUMERAL FOUR")
(8548 . "ROMAN NUMERAL FIVE")
(8549 . "ROMAN NUMERAL SIX")
(8550 . "ROMAN NUMERAL SEVEN")
(8551 . "ROMAN NUMERAL EIGHT")
(8552 . "ROMAN NUMERAL NINE")
(8553 . "ROMAN NUMERAL TEN")
(8554 . "ROMAN NUMERAL ELEVEN")
(8555 . "ROMAN NUMERAL TWELVE")
(8556 . "ROMAN NUMERAL FIFTY")
(8557 . "ROMAN NUMERAL ONE HUNDRED")
(8558 . "ROMAN NUMERAL FIVE HUNDRED")
(8559 . "ROMAN NUMERAL ONE THOUSAND")
(8560 . "SMALL ROMAN NUMERAL ONE")
(8561 . "SMALL ROMAN NUMERAL TWO")
(8562 . "SMALL ROMAN NUMERAL THREE")
(8563 . "SMALL ROMAN NUMERAL FOUR")
(8564 . "SMALL ROMAN NUMERAL FIVE")
(8565 . "SMALL ROMAN NUMERAL SIX")
(8566 . "SMALL ROMAN NUMERAL SEVEN")
(8567 . "SMALL ROMAN NUMERAL EIGHT")
(8568 . "SMALL ROMAN NUMERAL NINE")
(8569 . "SMALL ROMAN NUMERAL TEN")
(8570 . "SMALL ROMAN NUMERAL ELEVEN")
(8571 . "SMALL ROMAN NUMERAL TWELVE")
(8572 . "SMALL ROMAN NUMERAL FIFTY")
(8573 . "SMALL ROMAN NUMERAL ONE HUNDRED")
(8574 . "SMALL ROMAN NUMERAL FIVE HUNDRED")
(8575 . "SMALL ROMAN NUMERAL ONE THOUSAND")
(8576 . "ROMAN NUMERAL ONE THOUSAND C D")
(8577 . "ROMAN NUMERAL FIVE THOUSAND")
(8578 . "ROMAN NUMERAL TEN THOUSAND")
(8579 . "ROMAN NUMERAL REVERSED ONE HUNDRED")
(8580 . "LATIN SMALL LETTER REVERSED C")
(8581 . "ROMAN NUMERAL SIX LATE FORM")
(8582 . "ROMAN NUMERAL FIFTY EARLY FORM")
(8583 . "ROMAN NUMERAL FIFTY THOUSAND")
(8584 . "ROMAN NUMERAL ONE HUNDRED THOUSAND")
(8585 . "VULGAR FRACTION ZERO THIRDS")
(8586 . "TURNED DIGIT TWO")
(8587 . "TURNED DIGIT THREE")
((8588 . 8592) . #f)
(8592 . "LEFTWARDS ARROW")
(8593 . "UPWARDS ARROW")
(8594 . "RIGHTWARDS ARROW")
(8595 . "DOWNWARDS ARROW")
(8596 . "LEFT RIGHT ARROW")
(8597 . "UP DOWN ARROW")
(8598 . "NORTH WEST ARROW")
(8599 . "NORTH EAST ARROW")
(8600 . "SOUTH EAST ARROW")
(8601 . "SOUTH WEST ARROW")
(8602 . "LEFTWARDS ARROW WITH STROKE")
(8603 . "RIGHTWARDS ARROW WITH STROKE")
(8604 . "LEFTWARDS WAVE ARROW")
(8605 . "RIGHTWARDS WAVE ARROW")
(8606 . "LEFTWARDS TWO HEADED ARROW")
(8607 . "UPWARDS TWO HEADED ARROW")
(8608 . "RIGHTWARDS TWO HEADED ARROW")
(8609 . "DOWNWARDS TWO HEADED ARROW")
(8610 . "LEFTWARDS ARROW WITH TAIL")
(8611 . "RIGHTWARDS ARROW WITH TAIL")
(8612 . "LEFTWARDS ARROW FROM BAR")
(8613 . "UPWARDS ARROW FROM BAR")
(8614 . "RIGHTWARDS ARROW FROM BAR")
(8615 . "DOWNWARDS ARROW FROM BAR")
(8616 . "UP DOWN ARROW WITH BASE")
(8617 . "LEFTWARDS ARROW WITH HOOK")
(8618 . "RIGHTWARDS ARROW WITH HOOK")
(8619 . "LEFTWARDS ARROW WITH LOOP")
(8620 . "RIGHTWARDS ARROW WITH LOOP")
(8621 . "LEFT RIGHT WAVE ARROW")
(8622 . "LEFT RIGHT ARROW WITH STROKE")
(8623 . "DOWNWARDS ZIGZAG ARROW")
(8624 . "UPWARDS ARROW WITH TIP LEFTWARDS")
(8625 . "UPWARDS ARROW WITH TIP RIGHTWARDS")
(8626 . "DOWNWARDS ARROW WITH TIP LEFTWARDS")
(8627 . "DOWNWARDS ARROW WITH TIP RIGHTWARDS")
(8628 . "RIGHTWARDS ARROW WITH CORNER DOWNWARDS")
(8629 . "DOWNWARDS ARROW WITH CORNER LEFTWARDS")
(8630 . "ANTICLOCKWISE TOP SEMICIRCLE ARROW")
(8631 . "CLOCKWISE TOP SEMICIRCLE ARROW")
(8632 . "NORTH WEST ARROW TO LONG BAR")
(8633 . "LEFTWARDS ARROW TO BAR OVER RIGHTWARDS ARROW TO BAR")
(8634 . "ANTICLOCKWISE OPEN CIRCLE ARROW")
(8635 . "CLOCKWISE OPEN CIRCLE ARROW")
(8636 . "LEFTWARDS HARPOON WITH BARB UPWARDS")
(8637 . "LEFTWARDS HARPOON WITH BARB DOWNWARDS")
(8638 . "UPWARDS HARPOON WITH BARB RIGHTWARDS")
(8639 . "UPWARDS HARPOON WITH BARB LEFTWARDS")
(8640 . "RIGHTWARDS HARPOON WITH BARB UPWARDS")
(8641 . "RIGHTWARDS HARPOON WITH BARB DOWNWARDS")
(8642 . "DOWNWARDS HARPOON WITH BARB RIGHTWARDS")
(8643 . "DOWNWARDS HARPOON WITH BARB LEFTWARDS")
(8644 . "RIGHTWARDS ARROW OVER LEFTWARDS ARROW")
(8645 . "UPWARDS ARROW LEFTWARDS OF DOWNWARDS ARROW")
(8646 . "LEFTWARDS ARROW OVER RIGHTWARDS ARROW")
(8647 . "LEFTWARDS PAIRED ARROWS")
(8648 . "UPWARDS PAIRED ARROWS")
(8649 . "RIGHTWARDS PAIRED ARROWS")
(8650 . "DOWNWARDS PAIRED ARROWS")
(8651 . "LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON")
(8652 . "RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON")
(8653 . "LEFTWARDS DOUBLE ARROW WITH STROKE")
(8654 . "LEFT RIGHT DOUBLE ARROW WITH STROKE")
(8655 . "RIGHTWARDS DOUBLE ARROW WITH STROKE")
(8656 . "LEFTWARDS DOUBLE ARROW")
(8657 . "UPWARDS DOUBLE ARROW")
(8658 . "RIGHTWARDS DOUBLE ARROW")
(8659 . "DOWNWARDS DOUBLE ARROW")
(8660 . "LEFT RIGHT DOUBLE ARROW")
(8661 . "UP DOWN DOUBLE ARROW")
(8662 . "NORTH WEST DOUBLE ARROW")
(8663 . "NORTH EAST DOUBLE ARROW")
(8664 . "SOUTH EAST DOUBLE ARROW")
(8665 . "SOUTH WEST DOUBLE ARROW")
(8666 . "LEFTWARDS TRIPLE ARROW")
(8667 . "RIGHTWARDS TRIPLE ARROW")
(8668 . "LEFTWARDS SQUIGGLE ARROW")
(8669 . "RIGHTWARDS SQUIGGLE ARROW")
(8670 . "UPWARDS ARROW WITH DOUBLE STROKE")
(8671 . "DOWNWARDS ARROW WITH DOUBLE STROKE")
(8672 . "LEFTWARDS DASHED ARROW")
(8673 . "UPWARDS DASHED ARROW")
(8674 . "RIGHTWARDS DASHED ARROW")
(8675 . "DOWNWARDS DASHED ARROW")
(8676 . "LEFTWARDS ARROW TO BAR")
(8677 . "RIGHTWARDS ARROW TO BAR")
(8678 . "LEFTWARDS WHITE ARROW")
(8679 . "UPWARDS WHITE ARROW")
(8680 . "RIGHTWARDS WHITE ARROW")
(8681 . "DOWNWARDS WHITE ARROW")
(8682 . "UPWARDS WHITE ARROW FROM BAR")
(8683 . "UPWARDS WHITE ARROW ON PEDESTAL")
(8684 . "UPWARDS WHITE ARROW ON PEDESTAL WITH HORIZONTAL BAR")
(8685 . "UPWARDS WHITE ARROW ON PEDESTAL WITH VERTICAL BAR")
(8686 . "UPWARDS WHITE DOUBLE ARROW")
(8687 . "UPWARDS WHITE DOUBLE ARROW ON PEDESTAL")
(8688 . "RIGHTWARDS WHITE ARROW FROM WALL")
(8689 . "NORTH WEST ARROW TO CORNER")
(8690 . "SOUTH EAST ARROW TO CORNER")
(8691 . "UP DOWN WHITE ARROW")
(8692 . "RIGHT ARROW WITH SMALL CIRCLE")
(8693 . "DOWNWARDS ARROW LEFTWARDS OF UPWARDS ARROW")
(8694 . "THREE RIGHTWARDS ARROWS")
(8695 . "LEFTWARDS ARROW WITH VERTICAL STROKE")
(8696 . "RIGHTWARDS ARROW WITH VERTICAL STROKE")
(8697 . "LEFT RIGHT ARROW WITH VERTICAL STROKE")
(8698 . "LEFTWARDS ARROW WITH DOUBLE VERTICAL STROKE")
(8699 . "RIGHTWARDS ARROW WITH DOUBLE VERTICAL STROKE")
(8700 . "LEFT RIGHT ARROW WITH DOUBLE VERTICAL STROKE")
(8701 . "LEFTWARDS OPEN-HEADED ARROW")
(8702 . "RIGHTWARDS OPEN-HEADED ARROW")
(8703 . "LEFT RIGHT OPEN-HEADED ARROW")
(8704 . "FOR ALL")
(8705 . "COMPLEMENT")
(8706 . "PARTIAL DIFFERENTIAL")
(8707 . "THERE EXISTS")
(8708 . "THERE DOES NOT EXIST")
(8709 . "EMPTY SET")
(8710 . "INCREMENT")
(8711 . "NABLA")
(8712 . "ELEMENT OF")
(8713 . "NOT AN ELEMENT OF")
(8714 . "SMALL ELEMENT OF")
(8715 . "CONTAINS AS MEMBER")
(8716 . "DOES NOT CONTAIN AS MEMBER")
(8717 . "SMALL CONTAINS AS MEMBER")
(8718 . "END OF PROOF")
(8719 . "N-ARY PRODUCT")
(8720 . "N-ARY COPRODUCT")
(8721 . "N-ARY SUMMATION")
(8722 . "MINUS SIGN")
(8723 . "MINUS-OR-PLUS SIGN")
(8724 . "DOT PLUS")
(8725 . "DIVISION SLASH")
(8726 . "SET MINUS")
(8727 . "ASTERISK OPERATOR")
(8728 . "RING OPERATOR")
(8729 . "BULLET OPERATOR")
(8730 . "SQUARE ROOT")
(8731 . "CUBE ROOT")
(8732 . "FOURTH ROOT")
(8733 . "PROPORTIONAL TO")
(8734 . "INFINITY")
(8735 . "RIGHT ANGLE")
(8736 . "ANGLE")
(8737 . "MEASURED ANGLE")
(8738 . "SPHERICAL ANGLE")
(8739 . "DIVIDES")
(8740 . "DOES NOT DIVIDE")
(8741 . "PARALLEL TO")
(8742 . "NOT PARALLEL TO")
(8743 . "LOGICAL AND")
(8744 . "LOGICAL OR")
(8745 . "INTERSECTION")
(8746 . "UNION")
(8747 . "INTEGRAL")
(8748 . "DOUBLE INTEGRAL")
(8749 . "TRIPLE INTEGRAL")
(8750 . "CONTOUR INTEGRAL")
(8751 . "SURFACE INTEGRAL")
(8752 . "VOLUME INTEGRAL")
(8753 . "CLOCKWISE INTEGRAL")
(8754 . "CLOCKWISE CONTOUR INTEGRAL")
(8755 . "ANTICLOCKWISE CONTOUR INTEGRAL")
(8756 . "THEREFORE")
(8757 . "BECAUSE")
(8758 . "RATIO")
(8759 . "PROPORTION")
(8760 . "DOT MINUS")
(8761 . "EXCESS")
(8762 . "GEOMETRIC PROPORTION")
(8763 . "HOMOTHETIC")
(8764 . "TILDE OPERATOR")
(8765 . "REVERSED TILDE")
(8766 . "INVERTED LAZY S")
(8767 . "SINE WAVE")
(8768 . "WREATH PRODUCT")
(8769 . "NOT TILDE")
(8770 . "MINUS TILDE")
(8771 . "ASYMPTOTICALLY EQUAL TO")
(8772 . "NOT ASYMPTOTICALLY EQUAL TO")
(8773 . "APPROXIMATELY EQUAL TO")
(8774 . "APPROXIMATELY BUT NOT ACTUALLY EQUAL TO")
(8775 . "NEITHER APPROXIMATELY NOR ACTUALLY EQUAL TO")
(8776 . "ALMOST EQUAL TO")
(8777 . "NOT ALMOST EQUAL TO")
(8778 . "ALMOST EQUAL OR EQUAL TO")
(8779 . "TRIPLE TILDE")
(8780 . "ALL EQUAL TO")
(8781 . "EQUIVALENT TO")
(8782 . "GEOMETRICALLY EQUIVALENT TO")
(8783 . "DIFFERENCE BETWEEN")
(8784 . "APPROACHES THE LIMIT")
(8785 . "GEOMETRICALLY EQUAL TO")
(8786 . "APPROXIMATELY EQUAL TO OR THE IMAGE OF")
(8787 . "IMAGE OF OR APPROXIMATELY EQUAL TO")
(8788 . "COLON EQUALS")
(8789 . "EQUALS COLON")
(8790 . "RING IN EQUAL TO")
(8791 . "RING EQUAL TO")
(8792 . "CORRESPONDS TO")
(8793 . "ESTIMATES")
(8794 . "EQUIANGULAR TO")
(8795 . "STAR EQUALS")
(8796 . "DELTA EQUAL TO")
(8797 . "EQUAL TO BY DEFINITION")
(8798 . "MEASURED BY")
(8799 . "QUESTIONED EQUAL TO")
(8800 . "NOT EQUAL TO")
(8801 . "IDENTICAL TO")
(8802 . "NOT IDENTICAL TO")
(8803 . "STRICTLY EQUIVALENT TO")
(8804 . "LESS-THAN OR EQUAL TO")
(8805 . "GREATER-THAN OR EQUAL TO")
(8806 . "LESS-THAN OVER EQUAL TO")
(8807 . "GREATER-THAN OVER EQUAL TO")
(8808 . "LESS-THAN BUT NOT EQUAL TO")
(8809 . "GREATER-THAN BUT NOT EQUAL TO")
(8810 . "MUCH LESS-THAN")
(8811 . "MUCH GREATER-THAN")
(8812 . "BETWEEN")
(8813 . "NOT EQUIVALENT TO")
(8814 . "NOT LESS-THAN")
(8815 . "NOT GREATER-THAN")
(8816 . "NEITHER LESS-THAN NOR EQUAL TO")
(8817 . "NEITHER GREATER-THAN NOR EQUAL TO")
(8818 . "LESS-THAN OR EQUIVALENT TO")
(8819 . "GREATER-THAN OR EQUIVALENT TO")
(8820 . "NEITHER LESS-THAN NOR EQUIVALENT TO")
(8821 . "NEITHER GREATER-THAN NOR EQUIVALENT TO")
(8822 . "LESS-THAN OR GREATER-THAN")
(8823 . "GREATER-THAN OR LESS-THAN")
(8824 . "NEITHER LESS-THAN NOR GREATER-THAN")
(8825 . "NEITHER GREATER-THAN NOR LESS-THAN")
(8826 . "PRECEDES")
(8827 . "SUCCEEDS")
(8828 . "PRECEDES OR EQUAL TO")
(8829 . "SUCCEEDS OR EQUAL TO")
(8830 . "PRECEDES OR EQUIVALENT TO")
(8831 . "SUCCEEDS OR EQUIVALENT TO")
(8832 . "DOES NOT PRECEDE")
(8833 . "DOES NOT SUCCEED")
(8834 . "SUBSET OF")
(8835 . "SUPERSET OF")
(8836 . "NOT A SUBSET OF")
(8837 . "NOT A SUPERSET OF")
(8838 . "SUBSET OF OR EQUAL TO")
(8839 . "SUPERSET OF OR EQUAL TO")
(8840 . "NEITHER A SUBSET OF NOR EQUAL TO")
(8841 . "NEITHER A SUPERSET OF NOR EQUAL TO")
(8842 . "SUBSET OF WITH NOT EQUAL TO")
(8843 . "SUPERSET OF WITH NOT EQUAL TO")
(8844 . "MULTISET")
(8845 . "MULTISET MULTIPLICATION")
(8846 . "MULTISET UNION")
(8847 . "SQUARE IMAGE OF")
(8848 . "SQUARE ORIGINAL OF")
(8849 . "SQUARE IMAGE OF OR EQUAL TO")
(8850 . "SQUARE ORIGINAL OF OR EQUAL TO")
(8851 . "SQUARE CAP")
(8852 . "SQUARE CUP")
(8853 . "CIRCLED PLUS")
(8854 . "CIRCLED MINUS")
(8855 . "CIRCLED TIMES")
(8856 . "CIRCLED DIVISION SLASH")
(8857 . "CIRCLED DOT OPERATOR")
(8858 . "CIRCLED RING OPERATOR")
(8859 . "CIRCLED ASTERISK OPERATOR")
(8860 . "CIRCLED EQUALS")
(8861 . "CIRCLED DASH")
(8862 . "SQUARED PLUS")
(8863 . "SQUARED MINUS")
(8864 . "SQUARED TIMES")
(8865 . "SQUARED DOT OPERATOR")
(8866 . "RIGHT TACK")
(8867 . "LEFT TACK")
(8868 . "DOWN TACK")
(8869 . "UP TACK")
(8870 . "ASSERTION")
(8871 . "MODELS")
(8872 . "TRUE")
(8873 . "FORCES")
(8874 . "TRIPLE VERTICAL BAR RIGHT TURNSTILE")
(8875 . "DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE")
(8876 . "DOES NOT PROVE")
(8877 . "NOT TRUE")
(8878 . "DOES NOT FORCE")
(8879 . "NEGATED DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE")
(8880 . "PRECEDES UNDER RELATION")
(8881 . "SUCCEEDS UNDER RELATION")
(8882 . "NORMAL SUBGROUP OF")
(8883 . "CONTAINS AS NORMAL SUBGROUP")
(8884 . "NORMAL SUBGROUP OF OR EQUAL TO")
(8885 . "CONTAINS AS NORMAL SUBGROUP OR EQUAL TO")
(8886 . "ORIGINAL OF")
(8887 . "IMAGE OF")
(8888 . "MULTIMAP")
(8889 . "HERMITIAN CONJUGATE MATRIX")
(8890 . "INTERCALATE")
(8891 . "XOR")
(8892 . "NAND")
(8893 . "NOR")
(8894 . "RIGHT ANGLE WITH ARC")
(8895 . "RIGHT TRIANGLE")
(8896 . "N-ARY LOGICAL AND")
(8897 . "N-ARY LOGICAL OR")
(8898 . "N-ARY INTERSECTION")
(8899 . "N-ARY UNION")
(8900 . "DIAMOND OPERATOR")
(8901 . "DOT OPERATOR")
(8902 . "STAR OPERATOR")
(8903 . "DIVISION TIMES")
(8904 . "BOWTIE")
(8905 . "LEFT NORMAL FACTOR SEMIDIRECT PRODUCT")
(8906 . "RIGHT NORMAL FACTOR SEMIDIRECT PRODUCT")
(8907 . "LEFT SEMIDIRECT PRODUCT")
(8908 . "RIGHT SEMIDIRECT PRODUCT")
(8909 . "REVERSED TILDE EQUALS")
(8910 . "CURLY LOGICAL OR")
(8911 . "CURLY LOGICAL AND")
(8912 . "DOUBLE SUBSET")
(8913 . "DOUBLE SUPERSET")
(8914 . "DOUBLE INTERSECTION")
(8915 . "DOUBLE UNION")
(8916 . "PITCHFORK")
(8917 . "EQUAL AND PARALLEL TO")
(8918 . "LESS-THAN WITH DOT")
(8919 . "GREATER-THAN WITH DOT")
(8920 . "VERY MUCH LESS-THAN")
(8921 . "VERY MUCH GREATER-THAN")
(8922 . "LESS-THAN EQUAL TO OR GREATER-THAN")
(8923 . "GREATER-THAN EQUAL TO OR LESS-THAN")
(8924 . "EQUAL TO OR LESS-THAN")
(8925 . "EQUAL TO OR GREATER-THAN")
(8926 . "EQUAL TO OR PRECEDES")
(8927 . "EQUAL TO OR SUCCEEDS")
(8928 . "DOES NOT PRECEDE OR EQUAL")
(8929 . "DOES NOT SUCCEED OR EQUAL")
(8930 . "NOT SQUARE IMAGE OF OR EQUAL TO")
(8931 . "NOT SQUARE ORIGINAL OF OR EQUAL TO")
(8932 . "SQUARE IMAGE OF OR NOT EQUAL TO")
(8933 . "SQUARE ORIGINAL OF OR NOT EQUAL TO")
(8934 . "LESS-THAN BUT NOT EQUIVALENT TO")
(8935 . "GREATER-THAN BUT NOT EQUIVALENT TO")
(8936 . "PRECEDES BUT NOT EQUIVALENT TO")
(8937 . "SUCCEEDS BUT NOT EQUIVALENT TO")
(8938 . "NOT NORMAL SUBGROUP OF")
(8939 . "DOES NOT CONTAIN AS NORMAL SUBGROUP")
(8940 . "NOT NORMAL SUBGROUP OF OR EQUAL TO")
(8941 . "DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL")
(8942 . "VERTICAL ELLIPSIS")
(8943 . "MIDLINE HORIZONTAL ELLIPSIS")
(8944 . "UP RIGHT DIAGONAL ELLIPSIS")
(8945 . "DOWN RIGHT DIAGONAL ELLIPSIS")
(8946 . "ELEMENT OF WITH LONG HORIZONTAL STROKE")
(8947 . "ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE")
(8948 . "SMALL ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE")
(8949 . "ELEMENT OF WITH DOT ABOVE")
(8950 . "ELEMENT OF WITH OVERBAR")
(8951 . "SMALL ELEMENT OF WITH OVERBAR")
(8952 . "ELEMENT OF WITH UNDERBAR")
(8953 . "ELEMENT OF WITH TWO HORIZONTAL STROKES")
(8954 . "CONTAINS WITH LONG HORIZONTAL STROKE")
(8955 . "CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE")
(8956 . "SMALL CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE")
(8957 . "CONTAINS WITH OVERBAR")
(8958 . "SMALL CONTAINS WITH OVERBAR")
(8959 . "Z NOTATION BAG MEMBERSHIP")
(8960 . "DIAMETER SIGN")
(8961 . "ELECTRIC ARROW")
(8962 . "HOUSE")
(8963 . "UP ARROWHEAD")
(8964 . "DOWN ARROWHEAD")
(8965 . "PROJECTIVE")
(8966 . "PERSPECTIVE")
(8967 . "WAVY LINE")
(8968 . "LEFT CEILING")
(8969 . "RIGHT CEILING")
(8970 . "LEFT FLOOR")
(8971 . "RIGHT FLOOR")
(8972 . "BOTTOM RIGHT CROP")
(8973 . "BOTTOM LEFT CROP")
(8974 . "TOP RIGHT CROP")
(8975 . "TOP LEFT CROP")
(8976 . "REVERSED NOT SIGN")
(8977 . "SQUARE LOZENGE")
(8978 . "ARC")
(8979 . "SEGMENT")
(8980 . "SECTOR")
(8981 . "TELEPHONE RECORDER")
(8982 . "POSITION INDICATOR")
(8983 . "VIEWDATA SQUARE")
(8984 . "PLACE OF INTEREST SIGN")
(8985 . "TURNED NOT SIGN")
(8986 . "WATCH")
(8987 . "HOURGLASS")
(8988 . "TOP LEFT CORNER")
(8989 . "TOP RIGHT CORNER")
(8990 . "BOTTOM LEFT CORNER")
(8991 . "BOTTOM RIGHT CORNER")
(8992 . "TOP HALF INTEGRAL")
(8993 . "BOTTOM HALF INTEGRAL")
(8994 . "FROWN")
(8995 . "SMILE")
(8996 . "UP ARROWHEAD BETWEEN TWO HORIZONTAL BARS")
(8997 . "OPTION KEY")
(8998 . "ERASE TO THE RIGHT")
(8999 . "X IN A RECTANGLE BOX")
(9000 . "KEYBOARD")
(9001 . "LEFT-POINTING ANGLE BRACKET")
(9002 . "RIGHT-POINTING ANGLE BRACKET")
(9003 . "ERASE TO THE LEFT")
(9004 . "BENZENE RING")
(9005 . "CYLINDRICITY")
(9006 . "ALL AROUND-PROFILE")
(9007 . "SYMMETRY")
(9008 . "TOTAL RUNOUT")
(9009 . "DIMENSION ORIGIN")
(9010 . "CONICAL TAPER")
(9011 . "SLOPE")
(9012 . "COUNTERBORE")
(9013 . "COUNTERSINK")
(9014 . "APL FUNCTIONAL SYMBOL I-BEAM")
(9015 . "APL FUNCTIONAL SYMBOL SQUISH QUAD")
(9016 . "APL FUNCTIONAL SYMBOL QUAD EQUAL")
(9017 . "APL FUNCTIONAL SYMBOL QUAD DIVIDE")
(9018 . "APL FUNCTIONAL SYMBOL QUAD DIAMOND")
(9019 . "APL FUNCTIONAL SYMBOL QUAD JOT")
(9020 . "APL FUNCTIONAL SYMBOL QUAD CIRCLE")
(9021 . "APL FUNCTIONAL SYMBOL CIRCLE STILE")
(9022 . "APL FUNCTIONAL SYMBOL CIRCLE JOT")
(9023 . "APL FUNCTIONAL SYMBOL SLASH BAR")
(9024 . "APL FUNCTIONAL SYMBOL BACKSLASH BAR")
(9025 . "APL FUNCTIONAL SYMBOL QUAD SLASH")
(9026 . "APL FUNCTIONAL SYMBOL QUAD BACKSLASH")
(9027 . "APL FUNCTIONAL SYMBOL QUAD LESS-THAN")
(9028 . "APL FUNCTIONAL SYMBOL QUAD GREATER-THAN")
(9029 . "APL FUNCTIONAL SYMBOL LEFTWARDS VANE")
(9030 . "APL FUNCTIONAL SYMBOL RIGHTWARDS VANE")
(9031 . "APL FUNCTIONAL SYMBOL QUAD LEFTWARDS ARROW")
(9032 . "APL FUNCTIONAL SYMBOL QUAD RIGHTWARDS ARROW")
(9033 . "APL FUNCTIONAL SYMBOL CIRCLE BACKSLASH")
(9034 . "APL FUNCTIONAL SYMBOL DOWN TACK UNDERBAR")
(9035 . "APL FUNCTIONAL SYMBOL DELTA STILE")
(9036 . "APL FUNCTIONAL SYMBOL QUAD DOWN CARET")
(9037 . "APL FUNCTIONAL SYMBOL QUAD DELTA")
(9038 . "APL FUNCTIONAL SYMBOL DOWN TACK JOT")
(9039 . "APL FUNCTIONAL SYMBOL UPWARDS VANE")
(9040 . "APL FUNCTIONAL SYMBOL QUAD UPWARDS ARROW")
(9041 . "APL FUNCTIONAL SYMBOL UP TACK OVERBAR")
(9042 . "APL FUNCTIONAL SYMBOL DEL STILE")
(9043 . "APL FUNCTIONAL SYMBOL QUAD UP CARET")
(9044 . "APL FUNCTIONAL SYMBOL QUAD DEL")
(9045 . "APL FUNCTIONAL SYMBOL UP TACK JOT")
(9046 . "APL FUNCTIONAL SYMBOL DOWNWARDS VANE")
(9047 . "APL FUNCTIONAL SYMBOL QUAD DOWNWARDS ARROW")
(9048 . "APL FUNCTIONAL SYMBOL QUOTE UNDERBAR")
(9049 . "APL FUNCTIONAL SYMBOL DELTA UNDERBAR")
(9050 . "APL FUNCTIONAL SYMBOL DIAMOND UNDERBAR")
(9051 . "APL FUNCTIONAL SYMBOL JOT UNDERBAR")
(9052 . "APL FUNCTIONAL SYMBOL CIRCLE UNDERBAR")
(9053 . "APL FUNCTIONAL SYMBOL UP SHOE JOT")
(9054 . "APL FUNCTIONAL SYMBOL QUOTE QUAD")
(9055 . "APL FUNCTIONAL SYMBOL CIRCLE STAR")
(9056 . "APL FUNCTIONAL SYMBOL QUAD COLON")
(9057 . "APL FUNCTIONAL SYMBOL UP TACK DIAERESIS")
(9058 . "APL FUNCTIONAL SYMBOL DEL DIAERESIS")
(9059 . "APL FUNCTIONAL SYMBOL STAR DIAERESIS")
(9060 . "APL FUNCTIONAL SYMBOL JOT DIAERESIS")
(9061 . "APL FUNCTIONAL SYMBOL CIRCLE DIAERESIS")
(9062 . "APL FUNCTIONAL SYMBOL DOWN SHOE STILE")
(9063 . "APL FUNCTIONAL SYMBOL LEFT SHOE STILE")
(9064 . "APL FUNCTIONAL SYMBOL TILDE DIAERESIS")
(9065 . "APL FUNCTIONAL SYMBOL GREATER-THAN DIAERESIS")
(9066 . "APL FUNCTIONAL SYMBOL COMMA BAR")
(9067 . "APL FUNCTIONAL SYMBOL DEL TILDE")
(9068 . "APL FUNCTIONAL SYMBOL ZILDE")
(9069 . "APL FUNCTIONAL SYMBOL STILE TILDE")
(9070 . "APL FUNCTIONAL SYMBOL SEMICOLON UNDERBAR")
(9071 . "APL FUNCTIONAL SYMBOL QUAD NOT EQUAL")
(9072 . "APL FUNCTIONAL SYMBOL QUAD QUESTION")
(9073 . "APL FUNCTIONAL SYMBOL DOWN CARET TILDE")
(9074 . "APL FUNCTIONAL SYMBOL UP CARET TILDE")
(9075 . "APL FUNCTIONAL SYMBOL IOTA")
(9076 . "APL FUNCTIONAL SYMBOL RHO")
(9077 . "APL FUNCTIONAL SYMBOL OMEGA")
(9078 . "APL FUNCTIONAL SYMBOL ALPHA UNDERBAR")
(9079 . "APL FUNCTIONAL SYMBOL EPSILON UNDERBAR")
(9080 . "APL FUNCTIONAL SYMBOL IOTA UNDERBAR")
(9081 . "APL FUNCTIONAL SYMBOL OMEGA UNDERBAR")
(9082 . "APL FUNCTIONAL SYMBOL ALPHA")
(9083 . "NOT CHECK MARK")
(9084 . "RIGHT ANGLE WITH DOWNWARDS ZIGZAG ARROW")
(9085 . "SHOULDERED OPEN BOX")
(9086 . "BELL SYMBOL")
(9087 . "VERTICAL LINE WITH MIDDLE DOT")
(9088 . "INSERTION SYMBOL")
(9089 . "CONTINUOUS UNDERLINE SYMBOL")
(9090 . "DISCONTINUOUS UNDERLINE SYMBOL")
(9091 . "EMPHASIS SYMBOL")
(9092 . "COMPOSITION SYMBOL")
(9093 . "WHITE SQUARE WITH CENTRE VERTICAL LINE")
(9094 . "ENTER SYMBOL")
(9095 . "ALTERNATIVE KEY SYMBOL")
(9096 . "HELM SYMBOL")
(9097 . "CIRCLED HORIZONTAL BAR WITH NOTCH")
(9098 . "CIRCLED TRIANGLE DOWN")
(9099 . "BROKEN CIRCLE WITH NORTHWEST ARROW")
(9100 . "UNDO SYMBOL")
(9101 . "MONOSTABLE SYMBOL")
(9102 . "HYSTERESIS SYMBOL")
(9103 . "OPEN-CIRCUIT-OUTPUT H-TYPE SYMBOL")
(9104 . "OPEN-CIRCUIT-OUTPUT L-TYPE SYMBOL")
(9105 . "PASSIVE-PULL-DOWN-OUTPUT SYMBOL")
(9106 . "PASSIVE-PULL-UP-OUTPUT SYMBOL")
(9107 . "DIRECT CURRENT SYMBOL FORM TWO")
(9108 . "SOFTWARE-FUNCTION SYMBOL")
(9109 . "APL FUNCTIONAL SYMBOL QUAD")
(9110 . "DECIMAL SEPARATOR KEY SYMBOL")
(9111 . "PREVIOUS PAGE")
(9112 . "NEXT PAGE")
(9113 . "PRINT SCREEN SYMBOL")
(9114 . "CLEAR SCREEN SYMBOL")
(9115 . "LEFT PARENTHESIS UPPER HOOK")
(9116 . "LEFT PARENTHESIS EXTENSION")
(9117 . "LEFT PARENTHESIS LOWER HOOK")
(9118 . "RIGHT PARENTHESIS UPPER HOOK")
(9119 . "RIGHT PARENTHESIS EXTENSION")
(9120 . "RIGHT PARENTHESIS LOWER HOOK")
(9121 . "LEFT SQUARE BRACKET UPPER CORNER")
(9122 . "LEFT SQUARE BRACKET EXTENSION")
(9123 . "LEFT SQUARE BRACKET LOWER CORNER")
(9124 . "RIGHT SQUARE BRACKET UPPER CORNER")
(9125 . "RIGHT SQUARE BRACKET EXTENSION")
(9126 . "RIGHT SQUARE BRACKET LOWER CORNER")
(9127 . "LEFT CURLY BRACKET UPPER HOOK")
(9128 . "LEFT CURLY BRACKET MIDDLE PIECE")
(9129 . "LEFT CURLY BRACKET LOWER HOOK")
(9130 . "CURLY BRACKET EXTENSION")
(9131 . "RIGHT CURLY BRACKET UPPER HOOK")
(9132 . "RIGHT CURLY BRACKET MIDDLE PIECE")
(9133 . "RIGHT CURLY BRACKET LOWER HOOK")
(9134 . "INTEGRAL EXTENSION")
(9135 . "HORIZONTAL LINE EXTENSION")
(9136 . "UPPER LEFT OR LOWER RIGHT CURLY BRACKET SECTION")
(9137 . "UPPER RIGHT OR LOWER LEFT CURLY BRACKET SECTION")
(9138 . "SUMMATION TOP")
(9139 . "SUMMATION BOTTOM")
(9140 . "TOP SQUARE BRACKET")
(9141 . "BOTTOM SQUARE BRACKET")
(9142 . "BOTTOM SQUARE BRACKET OVER TOP SQUARE BRACKET")
(9143 . "RADICAL SYMBOL BOTTOM")
(9144 . "LEFT VERTICAL BOX LINE")
(9145 . "RIGHT VERTICAL BOX LINE")
(9146 . "HORIZONTAL SCAN LINE-1")
(9147 . "HORIZONTAL SCAN LINE-3")
(9148 . "HORIZONTAL SCAN LINE-7")
(9149 . "HORIZONTAL SCAN LINE-9")
(9150 . "DENTISTRY SYMBOL LIGHT VERTICAL AND TOP RIGHT")
(9151 . "DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM RIGHT")
(9152 . "DENTISTRY SYMBOL LIGHT VERTICAL WITH CIRCLE")
(9153 . "DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH CIRCLE")
(9154 . "DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH CIRCLE")
(9155 . "DENTISTRY SYMBOL LIGHT VERTICAL WITH TRIANGLE")
(9156 . "DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH TRIANGLE")
(9157 . "DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH TRIANGLE")
(9158 . "DENTISTRY SYMBOL LIGHT VERTICAL AND WAVE")
(9159 . "DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH WAVE")
(9160 . "DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH WAVE")
(9161 . "DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL")
(9162 . "DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL")
(9163 . "DENTISTRY SYMBOL LIGHT VERTICAL AND TOP LEFT")
(9164 . "DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM LEFT")
(9165 . "SQUARE FOOT")
(9166 . "RETURN SYMBOL")
(9167 . "EJECT SYMBOL")
(9168 . "VERTICAL LINE EXTENSION")
(9169 . "METRICAL BREVE")
(9170 . "METRICAL LONG OVER SHORT")
(9171 . "METRICAL SHORT OVER LONG")
(9172 . "METRICAL LONG OVER TWO SHORTS")
(9173 . "METRICAL TWO SHORTS OVER LONG")
(9174 . "METRICAL TWO SHORTS JOINED")
(9175 . "METRICAL TRISEME")
(9176 . "METRICAL TETRASEME")
(9177 . "METRICAL PENTASEME")
(9178 . "EARTH GROUND")
(9179 . "FUSE")
(9180 . "TOP PARENTHESIS")
(9181 . "BOTTOM PARENTHESIS")
(9182 . "TOP CURLY BRACKET")
(9183 . "BOTTOM CURLY BRACKET")
(9184 . "TOP TORTOISE SHELL BRACKET")
(9185 . "BOTTOM TORTOISE SHELL BRACKET")
(9186 . "WHITE TRAPEZIUM")
(9187 . "BENZENE RING WITH CIRCLE")
(9188 . "STRAIGHTNESS")
(9189 . "FLATNESS")
(9190 . "AC CURRENT")
(9191 . "ELECTRICAL INTERSECTION")
(9192 . "DECIMAL EXPONENT SYMBOL")
(9193 . "BLACK RIGHT-POINTING DOUBLE TRIANGLE")
(9194 . "BLACK LEFT-POINTING DOUBLE TRIANGLE")
(9195 . "BLACK UP-POINTING DOUBLE TRIANGLE")
(9196 . "BLACK DOWN-POINTING DOUBLE TRIANGLE")
(9197 . "BLACK RIGHT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR")
(9198 . "BLACK LEFT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR")
(9199 . "BLACK RIGHT-POINTING TRIANGLE WITH DOUBLE VERTICAL BAR")
(9200 . "ALARM CLOCK")
(9201 . "STOPWATCH")
(9202 . "TIMER CLOCK")
(9203 . "HOURGLASS WITH FLOWING SAND")
(9204 . "BLACK MEDIUM LEFT-POINTING TRIANGLE")
(9205 . "BLACK MEDIUM RIGHT-POINTING TRIANGLE")
(9206 . "BLACK MEDIUM UP-POINTING TRIANGLE")
(9207 . "BLACK MEDIUM DOWN-POINTING TRIANGLE")
(9208 . "DOUBLE VERTICAL BAR")
(9209 . "BLACK SQUARE FOR STOP")
(9210 . "BLACK CIRCLE FOR RECORD")
(9211 . "POWER SYMBOL")
(9212 . "POWER ON-OFF SYMBOL")
(9213 . "POWER ON SYMBOL")
(9214 . "POWER SLEEP SYMBOL")
(9215 . #f)
(9216 . "SYMBOL FOR NULL")
(9217 . "SYMBOL FOR START OF HEADING")
(9218 . "SYMBOL FOR START OF TEXT")
(9219 . "SYMBOL FOR END OF TEXT")
(9220 . "SYMBOL FOR END OF TRANSMISSION")
(9221 . "SYMBOL FOR ENQUIRY")
(9222 . "SYMBOL FOR ACKNOWLEDGE")
(9223 . "SYMBOL FOR BELL")
(9224 . "SYMBOL FOR BACKSPACE")
(9225 . "SYMBOL FOR HORIZONTAL TABULATION")
(9226 . "SYMBOL FOR LINE FEED")
(9227 . "SYMBOL FOR VERTICAL TABULATION")
(9228 . "SYMBOL FOR FORM FEED")
(9229 . "SYMBOL FOR CARRIAGE RETURN")
(9230 . "SYMBOL FOR SHIFT OUT")
(9231 . "SYMBOL FOR SHIFT IN")
(9232 . "SYMBOL FOR DATA LINK ESCAPE")
(9233 . "SYMBOL FOR DEVICE CONTROL ONE")
(9234 . "SYMBOL FOR DEVICE CONTROL TWO")
(9235 . "SYMBOL FOR DEVICE CONTROL THREE")
(9236 . "SYMBOL FOR DEVICE CONTROL FOUR")
(9237 . "SYMBOL FOR NEGATIVE ACKNOWLEDGE")
(9238 . "SYMBOL FOR SYNCHRONOUS IDLE")
(9239 . "SYMBOL FOR END OF TRANSMISSION BLOCK")
(9240 . "SYMBOL FOR CANCEL")
(9241 . "SYMBOL FOR END OF MEDIUM")
(9242 . "SYMBOL FOR SUBSTITUTE")
(9243 . "SYMBOL FOR ESCAPE")
(9244 . "SYMBOL FOR FILE SEPARATOR")
(9245 . "SYMBOL FOR GROUP SEPARATOR")
(9246 . "SYMBOL FOR RECORD SEPARATOR")
(9247 . "SYMBOL FOR UNIT SEPARATOR")
(9248 . "SYMBOL FOR SPACE")
(9249 . "SYMBOL FOR DELETE")
(9250 . "BLANK SYMBOL")
(9251 . "OPEN BOX")
(9252 . "SYMBOL FOR NEWLINE")
(9253 . "SYMBOL FOR DELETE FORM TWO")
(9254 . "SYMBOL FOR SUBSTITUTE FORM TWO")
((9255 . 9280) . #f)
(9280 . "OCR HOOK")
(9281 . "OCR CHAIR")
(9282 . "OCR FORK")
(9283 . "OCR INVERTED FORK")
(9284 . "OCR BELT BUCKLE")
(9285 . "OCR BOW TIE")
(9286 . "OCR BRANCH BANK IDENTIFICATION")
(9287 . "OCR AMOUNT OF CHECK")
(9288 . "OCR DASH")
(9289 . "OCR CUSTOMER ACCOUNT NUMBER")
(9290 . "OCR DOUBLE BACKSLASH")
((9291 . 9312) . #f)
(9312 . "CIRCLED DIGIT ONE")
(9313 . "CIRCLED DIGIT TWO")
(9314 . "CIRCLED DIGIT THREE")
(9315 . "CIRCLED DIGIT FOUR")
(9316 . "CIRCLED DIGIT FIVE")
(9317 . "CIRCLED DIGIT SIX")
(9318 . "CIRCLED DIGIT SEVEN")
(9319 . "CIRCLED DIGIT EIGHT")
(9320 . "CIRCLED DIGIT NINE")
(9321 . "CIRCLED NUMBER TEN")
(9322 . "CIRCLED NUMBER ELEVEN")
(9323 . "CIRCLED NUMBER TWELVE")
(9324 . "CIRCLED NUMBER THIRTEEN")
(9325 . "CIRCLED NUMBER FOURTEEN")
(9326 . "CIRCLED NUMBER FIFTEEN")
(9327 . "CIRCLED NUMBER SIXTEEN")
(9328 . "CIRCLED NUMBER SEVENTEEN")
(9329 . "CIRCLED NUMBER EIGHTEEN")
(9330 . "CIRCLED NUMBER NINETEEN")
(9331 . "CIRCLED NUMBER TWENTY")
(9332 . "PARENTHESIZED DIGIT ONE")
(9333 . "PARENTHESIZED DIGIT TWO")
(9334 . "PARENTHESIZED DIGIT THREE")
(9335 . "PARENTHESIZED DIGIT FOUR")
(9336 . "PARENTHESIZED DIGIT FIVE")
(9337 . "PARENTHESIZED DIGIT SIX")
(9338 . "PARENTHESIZED DIGIT SEVEN")
(9339 . "PARENTHESIZED DIGIT EIGHT")
(9340 . "PARENTHESIZED DIGIT NINE")
(9341 . "PARENTHESIZED NUMBER TEN")
(9342 . "PARENTHESIZED NUMBER ELEVEN")
(9343 . "PARENTHESIZED NUMBER TWELVE")
(9344 . "PARENTHESIZED NUMBER THIRTEEN")
(9345 . "PARENTHESIZED NUMBER FOURTEEN")
(9346 . "PARENTHESIZED NUMBER FIFTEEN")
(9347 . "PARENTHESIZED NUMBER SIXTEEN")
(9348 . "PARENTHESIZED NUMBER SEVENTEEN")
(9349 . "PARENTHESIZED NUMBER EIGHTEEN")
(9350 . "PARENTHESIZED NUMBER NINETEEN")
(9351 . "PARENTHESIZED NUMBER TWENTY")
(9352 . "DIGIT ONE FULL STOP")
(9353 . "DIGIT TWO FULL STOP")
(9354 . "DIGIT THREE FULL STOP")
(9355 . "DIGIT FOUR FULL STOP")
(9356 . "DIGIT FIVE FULL STOP")
(9357 . "DIGIT SIX FULL STOP")
(9358 . "DIGIT SEVEN FULL STOP")
(9359 . "DIGIT EIGHT FULL STOP")
(9360 . "DIGIT NINE FULL STOP")
(9361 . "NUMBER TEN FULL STOP")
(9362 . "NUMBER ELEVEN FULL STOP")
(9363 . "NUMBER TWELVE FULL STOP")
(9364 . "NUMBER THIRTEEN FULL STOP")
(9365 . "NUMBER FOURTEEN FULL STOP")
(9366 . "NUMBER FIFTEEN FULL STOP")
(9367 . "NUMBER SIXTEEN FULL STOP")
(9368 . "NUMBER SEVENTEEN FULL STOP")
(9369 . "NUMBER EIGHTEEN FULL STOP")
(9370 . "NUMBER NINETEEN FULL STOP")
(9371 . "NUMBER TWENTY FULL STOP")
(9372 . "PARENTHESIZED LATIN SMALL LETTER A")
(9373 . "PARENTHESIZED LATIN SMALL LETTER B")
(9374 . "PARENTHESIZED LATIN SMALL LETTER C")
(9375 . "PARENTHESIZED LATIN SMALL LETTER D")
(9376 . "PARENTHESIZED LATIN SMALL LETTER E")
(9377 . "PARENTHESIZED LATIN SMALL LETTER F")
(9378 . "PARENTHESIZED LATIN SMALL LETTER G")
(9379 . "PARENTHESIZED LATIN SMALL LETTER H")
(9380 . "PARENTHESIZED LATIN SMALL LETTER I")
(9381 . "PARENTHESIZED LATIN SMALL LETTER J")
(9382 . "PARENTHESIZED LATIN SMALL LETTER K")
(9383 . "PARENTHESIZED LATIN SMALL LETTER L")
(9384 . "PARENTHESIZED LATIN SMALL LETTER M")
(9385 . "PARENTHESIZED LATIN SMALL LETTER N")
(9386 . "PARENTHESIZED LATIN SMALL LETTER O")
(9387 . "PARENTHESIZED LATIN SMALL LETTER P")
(9388 . "PARENTHESIZED LATIN SMALL LETTER Q")
(9389 . "PARENTHESIZED LATIN SMALL LETTER R")
(9390 . "PARENTHESIZED LATIN SMALL LETTER S")
(9391 . "PARENTHESIZED LATIN SMALL LETTER T")
(9392 . "PARENTHESIZED LATIN SMALL LETTER U")
(9393 . "PARENTHESIZED LATIN SMALL LETTER V")
(9394 . "PARENTHESIZED LATIN SMALL LETTER W")
(9395 . "PARENTHESIZED LATIN SMALL LETTER X")
(9396 . "PARENTHESIZED LATIN SMALL LETTER Y")
(9397 . "PARENTHESIZED LATIN SMALL LETTER Z")
(9398 . "CIRCLED LATIN CAPITAL LETTER A")
(9399 . "CIRCLED LATIN CAPITAL LETTER B")
(9400 . "CIRCLED LATIN CAPITAL LETTER C")
(9401 . "CIRCLED LATIN CAPITAL LETTER D")
(9402 . "CIRCLED LATIN CAPITAL LETTER E")
(9403 . "CIRCLED LATIN CAPITAL LETTER F")
(9404 . "CIRCLED LATIN CAPITAL LETTER G")
(9405 . "CIRCLED LATIN CAPITAL LETTER H")
(9406 . "CIRCLED LATIN CAPITAL LETTER I")
(9407 . "CIRCLED LATIN CAPITAL LETTER J")
(9408 . "CIRCLED LATIN CAPITAL LETTER K")
(9409 . "CIRCLED LATIN CAPITAL LETTER L")
(9410 . "CIRCLED LATIN CAPITAL LETTER M")
(9411 . "CIRCLED LATIN CAPITAL LETTER N")
(9412 . "CIRCLED LATIN CAPITAL LETTER O")
(9413 . "CIRCLED LATIN CAPITAL LETTER P")
(9414 . "CIRCLED LATIN CAPITAL LETTER Q")
(9415 . "CIRCLED LATIN CAPITAL LETTER R")
(9416 . "CIRCLED LATIN CAPITAL LETTER S")
(9417 . "CIRCLED LATIN CAPITAL LETTER T")
(9418 . "CIRCLED LATIN CAPITAL LETTER U")
(9419 . "CIRCLED LATIN CAPITAL LETTER V")
(9420 . "CIRCLED LATIN CAPITAL LETTER W")
(9421 . "CIRCLED LATIN CAPITAL LETTER X")
(9422 . "CIRCLED LATIN CAPITAL LETTER Y")
(9423 . "CIRCLED LATIN CAPITAL LETTER Z")
(9424 . "CIRCLED LATIN SMALL LETTER A")
(9425 . "CIRCLED LATIN SMALL LETTER B")
(9426 . "CIRCLED LATIN SMALL LETTER C")
(9427 . "CIRCLED LATIN SMALL LETTER D")
(9428 . "CIRCLED LATIN SMALL LETTER E")
(9429 . "CIRCLED LATIN SMALL LETTER F")
(9430 . "CIRCLED LATIN SMALL LETTER G")
(9431 . "CIRCLED LATIN SMALL LETTER H")
(9432 . "CIRCLED LATIN SMALL LETTER I")
(9433 . "CIRCLED LATIN SMALL LETTER J")
(9434 . "CIRCLED LATIN SMALL LETTER K")
(9435 . "CIRCLED LATIN SMALL LETTER L")
(9436 . "CIRCLED LATIN SMALL LETTER M")
(9437 . "CIRCLED LATIN SMALL LETTER N")
(9438 . "CIRCLED LATIN SMALL LETTER O")
(9439 . "CIRCLED LATIN SMALL LETTER P")
(9440 . "CIRCLED LATIN SMALL LETTER Q")
(9441 . "CIRCLED LATIN SMALL LETTER R")
(9442 . "CIRCLED LATIN SMALL LETTER S")
(9443 . "CIRCLED LATIN SMALL LETTER T")
(9444 . "CIRCLED LATIN SMALL LETTER U")
(9445 . "CIRCLED LATIN SMALL LETTER V")
(9446 . "CIRCLED LATIN SMALL LETTER W")
(9447 . "CIRCLED LATIN SMALL LETTER X")
(9448 . "CIRCLED LATIN SMALL LETTER Y")
(9449 . "CIRCLED LATIN SMALL LETTER Z")
(9450 . "CIRCLED DIGIT ZERO")
(9451 . "NEGATIVE CIRCLED NUMBER ELEVEN")
(9452 . "NEGATIVE CIRCLED NUMBER TWELVE")
(9453 . "NEGATIVE CIRCLED NUMBER THIRTEEN")
(9454 . "NEGATIVE CIRCLED NUMBER FOURTEEN")
(9455 . "NEGATIVE CIRCLED NUMBER FIFTEEN")
(9456 . "NEGATIVE CIRCLED NUMBER SIXTEEN")
(9457 . "NEGATIVE CIRCLED NUMBER SEVENTEEN")
(9458 . "NEGATIVE CIRCLED NUMBER EIGHTEEN")
(9459 . "NEGATIVE CIRCLED NUMBER NINETEEN")
(9460 . "NEGATIVE CIRCLED NUMBER TWENTY")
(9461 . "DOUBLE CIRCLED DIGIT ONE")
(9462 . "DOUBLE CIRCLED DIGIT TWO")
(9463 . "DOUBLE CIRCLED DIGIT THREE")
(9464 . "DOUBLE CIRCLED DIGIT FOUR")
(9465 . "DOUBLE CIRCLED DIGIT FIVE")
(9466 . "DOUBLE CIRCLED DIGIT SIX")
(9467 . "DOUBLE CIRCLED DIGIT SEVEN")
(9468 . "DOUBLE CIRCLED DIGIT EIGHT")
(9469 . "DOUBLE CIRCLED DIGIT NINE")
(9470 . "DOUBLE CIRCLED NUMBER TEN")
(9471 . "NEGATIVE CIRCLED DIGIT ZERO")
(9472 . "BOX DRAWINGS LIGHT HORIZONTAL")
(9473 . "BOX DRAWINGS HEAVY HORIZONTAL")
(9474 . "BOX DRAWINGS LIGHT VERTICAL")
(9475 . "BOX DRAWINGS HEAVY VERTICAL")
(9476 . "BOX DRAWINGS LIGHT TRIPLE DASH HORIZONTAL")
(9477 . "BOX DRAWINGS HEAVY TRIPLE DASH HORIZONTAL")
(9478 . "BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL")
(9479 . "BOX DRAWINGS HEAVY TRIPLE DASH VERTICAL")
(9480 . "BOX DRAWINGS LIGHT QUADRUPLE DASH HORIZONTAL")
(9481 . "BOX DRAWINGS HEAVY QUADRUPLE DASH HORIZONTAL")
(9482 . "BOX DRAWINGS LIGHT QUADRUPLE DASH VERTICAL")
(9483 . "BOX DRAWINGS HEAVY QUADRUPLE DASH VERTICAL")
(9484 . "BOX DRAWINGS LIGHT DOWN AND RIGHT")
(9485 . "BOX DRAWINGS DOWN LIGHT AND RIGHT HEAVY")
(9486 . "BOX DRAWINGS DOWN HEAVY AND RIGHT LIGHT")
(9487 . "BOX DRAWINGS HEAVY DOWN AND RIGHT")
(9488 . "BOX DRAWINGS LIGHT DOWN AND LEFT")
(9489 . "BOX DRAWINGS DOWN LIGHT AND LEFT HEAVY")
(9490 . "BOX DRAWINGS DOWN HEAVY AND LEFT LIGHT")
(9491 . "BOX DRAWINGS HEAVY DOWN AND LEFT")
(9492 . "BOX DRAWINGS LIGHT UP AND RIGHT")
(9493 . "BOX DRAWINGS UP LIGHT AND RIGHT HEAVY")
(9494 . "BOX DRAWINGS UP HEAVY AND RIGHT LIGHT")
(9495 . "BOX DRAWINGS HEAVY UP AND RIGHT")
(9496 . "BOX DRAWINGS LIGHT UP AND LEFT")
(9497 . "BOX DRAWINGS UP LIGHT AND LEFT HEAVY")
(9498 . "BOX DRAWINGS UP HEAVY AND LEFT LIGHT")
(9499 . "BOX DRAWINGS HEAVY UP AND LEFT")
(9500 . "BOX DRAWINGS LIGHT VERTICAL AND RIGHT")
(9501 . "BOX DRAWINGS VERTICAL LIGHT AND RIGHT HEAVY")
(9502 . "BOX DRAWINGS UP HEAVY AND RIGHT DOWN LIGHT")
(9503 . "BOX DRAWINGS DOWN HEAVY AND RIGHT UP LIGHT")
(9504 . "BOX DRAWINGS VERTICAL HEAVY AND RIGHT LIGHT")
(9505 . "BOX DRAWINGS DOWN LIGHT AND RIGHT UP HEAVY")
(9506 . "BOX DRAWINGS UP LIGHT AND RIGHT DOWN HEAVY")
(9507 . "BOX DRAWINGS HEAVY VERTICAL AND RIGHT")
(9508 . "BOX DRAWINGS LIGHT VERTICAL AND LEFT")
(9509 . "BOX DRAWINGS VERTICAL LIGHT AND LEFT HEAVY")
(9510 . "BOX DRAWINGS UP HEAVY AND LEFT DOWN LIGHT")
(9511 . "BOX DRAWINGS DOWN HEAVY AND LEFT UP LIGHT")
(9512 . "BOX DRAWINGS VERTICAL HEAVY AND LEFT LIGHT")
(9513 . "BOX DRAWINGS DOWN LIGHT AND LEFT UP HEAVY")
(9514 . "BOX DRAWINGS UP LIGHT AND LEFT DOWN HEAVY")
(9515 . "BOX DRAWINGS HEAVY VERTICAL AND LEFT")
(9516 . "BOX DRAWINGS LIGHT DOWN AND HORIZONTAL")
(9517 . "BOX DRAWINGS LEFT HEAVY AND RIGHT DOWN LIGHT")
(9518 . "BOX DRAWINGS RIGHT HEAVY AND LEFT DOWN LIGHT")
(9519 . "BOX DRAWINGS DOWN LIGHT AND HORIZONTAL HEAVY")
(9520 . "BOX DRAWINGS DOWN HEAVY AND HORIZONTAL LIGHT")
(9521 . "BOX DRAWINGS RIGHT LIGHT AND LEFT DOWN HEAVY")
(9522 . "BOX DRAWINGS LEFT LIGHT AND RIGHT DOWN HEAVY")
(9523 . "BOX DRAWINGS HEAVY DOWN AND HORIZONTAL")
(9524 . "BOX DRAWINGS LIGHT UP AND HORIZONTAL")
(9525 . "BOX DRAWINGS LEFT HEAVY AND RIGHT UP LIGHT")
(9526 . "BOX DRAWINGS RIGHT HEAVY AND LEFT UP LIGHT")
(9527 . "BOX DRAWINGS UP LIGHT AND HORIZONTAL HEAVY")
(9528 . "BOX DRAWINGS UP HEAVY AND HORIZONTAL LIGHT")
(9529 . "BOX DRAWINGS RIGHT LIGHT AND LEFT UP HEAVY")
(9530 . "BOX DRAWINGS LEFT LIGHT AND RIGHT UP HEAVY")
(9531 . "BOX DRAWINGS HEAVY UP AND HORIZONTAL")
(9532 . "BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL")
(9533 . "BOX DRAWINGS LEFT HEAVY AND RIGHT VERTICAL LIGHT")
(9534 . "BOX DRAWINGS RIGHT HEAVY AND LEFT VERTICAL LIGHT")
(9535 . "BOX DRAWINGS VERTICAL LIGHT AND HORIZONTAL HEAVY")
(9536 . "BOX DRAWINGS UP HEAVY AND DOWN HORIZONTAL LIGHT")
(9537 . "BOX DRAWINGS DOWN HEAVY AND UP HORIZONTAL LIGHT")
(9538 . "BOX DRAWINGS VERTICAL HEAVY AND HORIZONTAL LIGHT")
(9539 . "BOX DRAWINGS LEFT UP HEAVY AND RIGHT DOWN LIGHT")
(9540 . "BOX DRAWINGS RIGHT UP HEAVY AND LEFT DOWN LIGHT")
(9541 . "BOX DRAWINGS LEFT DOWN HEAVY AND RIGHT UP LIGHT")
(9542 . "BOX DRAWINGS RIGHT DOWN HEAVY AND LEFT UP LIGHT")
(9543 . "BOX DRAWINGS DOWN LIGHT AND UP HORIZONTAL HEAVY")
(9544 . "BOX DRAWINGS UP LIGHT AND DOWN HORIZONTAL HEAVY")
(9545 . "BOX DRAWINGS RIGHT LIGHT AND LEFT VERTICAL HEAVY")
(9546 . "BOX DRAWINGS LEFT LIGHT AND RIGHT VERTICAL HEAVY")
(9547 . "BOX DRAWINGS HEAVY VERTICAL AND HORIZONTAL")
(9548 . "BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL")
(9549 . "BOX DRAWINGS HEAVY DOUBLE DASH HORIZONTAL")
(9550 . "BOX DRAWINGS LIGHT DOUBLE DASH VERTICAL")
(9551 . "BOX DRAWINGS HEAVY DOUBLE DASH VERTICAL")
(9552 . "BOX DRAWINGS DOUBLE HORIZONTAL")
(9553 . "BOX DRAWINGS DOUBLE VERTICAL")
(9554 . "BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE")
(9555 . "BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE")
(9556 . "BOX DRAWINGS DOUBLE DOWN AND RIGHT")
(9557 . "BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE")
(9558 . "BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE")
(9559 . "BOX DRAWINGS DOUBLE DOWN AND LEFT")
(9560 . "BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE")
(9561 . "BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE")
(9562 . "BOX DRAWINGS DOUBLE UP AND RIGHT")
(9563 . "BOX DRAWINGS UP SINGLE AND LEFT DOUBLE")
(9564 . "BOX DRAWINGS UP DOUBLE AND LEFT SINGLE")
(9565 . "BOX DRAWINGS DOUBLE UP AND LEFT")
(9566 . "BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE")
(9567 . "BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE")
(9568 . "BOX DRAWINGS DOUBLE VERTICAL AND RIGHT")
(9569 . "BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE")
(9570 . "BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE")
(9571 . "BOX DRAWINGS DOUBLE VERTICAL AND LEFT")
(9572 . "BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE")
(9573 . "BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE")
(9574 . "BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL")
(9575 . "BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE")
(9576 . "BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE")
(9577 . "BOX DRAWINGS DOUBLE UP AND HORIZONTAL")
(9578 . "BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE")
(9579 . "BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE")
(9580 . "BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL")
(9581 . "BOX DRAWINGS LIGHT ARC DOWN AND RIGHT")
(9582 . "BOX DRAWINGS LIGHT ARC DOWN AND LEFT")
(9583 . "BOX DRAWINGS LIGHT ARC UP AND LEFT")
(9584 . "BOX DRAWINGS LIGHT ARC UP AND RIGHT")
(9585 . "BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT")
(9586 . "BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT")
(9587 . "BOX DRAWINGS LIGHT DIAGONAL CROSS")
(9588 . "BOX DRAWINGS LIGHT LEFT")
(9589 . "BOX DRAWINGS LIGHT UP")
(9590 . "BOX DRAWINGS LIGHT RIGHT")
(9591 . "BOX DRAWINGS LIGHT DOWN")
(9592 . "BOX DRAWINGS HEAVY LEFT")
(9593 . "BOX DRAWINGS HEAVY UP")
(9594 . "BOX DRAWINGS HEAVY RIGHT")
(9595 . "BOX DRAWINGS HEAVY DOWN")
(9596 . "BOX DRAWINGS LIGHT LEFT AND HEAVY RIGHT")
(9597 . "BOX DRAWINGS LIGHT UP AND HEAVY DOWN")
(9598 . "BOX DRAWINGS HEAVY LEFT AND LIGHT RIGHT")
(9599 . "BOX DRAWINGS HEAVY UP AND LIGHT DOWN")
(9600 . "UPPER HALF BLOCK")
(9601 . "LOWER ONE EIGHTH BLOCK")
(9602 . "LOWER ONE QUARTER BLOCK")
(9603 . "LOWER THREE EIGHTHS BLOCK")
(9604 . "LOWER HALF BLOCK")
(9605 . "LOWER FIVE EIGHTHS BLOCK")
(9606 . "LOWER THREE QUARTERS BLOCK")
(9607 . "LOWER SEVEN EIGHTHS BLOCK")
(9608 . "FULL BLOCK")
(9609 . "LEFT SEVEN EIGHTHS BLOCK")
(9610 . "LEFT THREE QUARTERS BLOCK")
(9611 . "LEFT FIVE EIGHTHS BLOCK")
(9612 . "LEFT HALF BLOCK")
(9613 . "LEFT THREE EIGHTHS BLOCK")
(9614 . "LEFT ONE QUARTER BLOCK")
(9615 . "LEFT ONE EIGHTH BLOCK")
(9616 . "RIGHT HALF BLOCK")
(9617 . "LIGHT SHADE")
(9618 . "MEDIUM SHADE")
(9619 . "DARK SHADE")
(9620 . "UPPER ONE EIGHTH BLOCK")
(9621 . "RIGHT ONE EIGHTH BLOCK")
(9622 . "QUADRANT LOWER LEFT")
(9623 . "QUADRANT LOWER RIGHT")
(9624 . "QUADRANT UPPER LEFT")
(9625 . "QUADRANT UPPER LEFT AND LOWER LEFT AND LOWER RIGHT")
(9626 . "QUADRANT UPPER LEFT AND LOWER RIGHT")
(9627 . "QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER LEFT")
(9628 . "QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER RIGHT")
(9629 . "QUADRANT UPPER RIGHT")
(9630 . "QUADRANT UPPER RIGHT AND LOWER LEFT")
(9631 . "QUADRANT UPPER RIGHT AND LOWER LEFT AND LOWER RIGHT")
(9632 . "BLACK SQUARE")
(9633 . "WHITE SQUARE")
(9634 . "WHITE SQUARE WITH ROUNDED CORNERS")
(9635 . "WHITE SQUARE CONTAINING BLACK SMALL SQUARE")
(9636 . "SQUARE WITH HORIZONTAL FILL")
(9637 . "SQUARE WITH VERTICAL FILL")
(9638 . "SQUARE WITH ORTHOGONAL CROSSHATCH FILL")
(9639 . "SQUARE WITH UPPER LEFT TO LOWER RIGHT FILL")
(9640 . "SQUARE WITH UPPER RIGHT TO LOWER LEFT FILL")
(9641 . "SQUARE WITH DIAGONAL CROSSHATCH FILL")
(9642 . "BLACK SMALL SQUARE")
(9643 . "WHITE SMALL SQUARE")
(9644 . "BLACK RECTANGLE")
(9645 . "WHITE RECTANGLE")
(9646 . "BLACK VERTICAL RECTANGLE")
(9647 . "WHITE VERTICAL RECTANGLE")
(9648 . "BLACK PARALLELOGRAM")
(9649 . "WHITE PARALLELOGRAM")
(9650 . "BLACK UP-POINTING TRIANGLE")
(9651 . "WHITE UP-POINTING TRIANGLE")
(9652 . "BLACK UP-POINTING SMALL TRIANGLE")
(9653 . "WHITE UP-POINTING SMALL TRIANGLE")
(9654 . "BLACK RIGHT-POINTING TRIANGLE")
(9655 . "WHITE RIGHT-POINTING TRIANGLE")
(9656 . "BLACK RIGHT-POINTING SMALL TRIANGLE")
(9657 . "WHITE RIGHT-POINTING SMALL TRIANGLE")
(9658 . "BLACK RIGHT-POINTING POINTER")
(9659 . "WHITE RIGHT-POINTING POINTER")
(9660 . "BLACK DOWN-POINTING TRIANGLE")
(9661 . "WHITE DOWN-POINTING TRIANGLE")
(9662 . "BLACK DOWN-POINTING SMALL TRIANGLE")
(9663 . "WHITE DOWN-POINTING SMALL TRIANGLE")
(9664 . "BLACK LEFT-POINTING TRIANGLE")
(9665 . "WHITE LEFT-POINTING TRIANGLE")
(9666 . "BLACK LEFT-POINTING SMALL TRIANGLE")
(9667 . "WHITE LEFT-POINTING SMALL TRIANGLE")
(9668 . "BLACK LEFT-POINTING POINTER")
(9669 . "WHITE LEFT-POINTING POINTER")
(9670 . "BLACK DIAMOND")
(9671 . "WHITE DIAMOND")
(9672 . "WHITE DIAMOND CONTAINING BLACK SMALL DIAMOND")
(9673 . "FISHEYE")
(9674 . "LOZENGE")
(9675 . "WHITE CIRCLE")
(9676 . "DOTTED CIRCLE")
(9677 . "CIRCLE WITH VERTICAL FILL")
(9678 . "BULLSEYE")
(9679 . "BLACK CIRCLE")
(9680 . "CIRCLE WITH LEFT HALF BLACK")
(9681 . "CIRCLE WITH RIGHT HALF BLACK")
(9682 . "CIRCLE WITH LOWER HALF BLACK")
(9683 . "CIRCLE WITH UPPER HALF BLACK")
(9684 . "CIRCLE WITH UPPER RIGHT QUADRANT BLACK")
(9685 . "CIRCLE WITH ALL BUT UPPER LEFT QUADRANT BLACK")
(9686 . "LEFT HALF BLACK CIRCLE")
(9687 . "RIGHT HALF BLACK CIRCLE")
(9688 . "INVERSE BULLET")
(9689 . "INVERSE WHITE CIRCLE")
(9690 . "UPPER HALF INVERSE WHITE CIRCLE")
(9691 . "LOWER HALF INVERSE WHITE CIRCLE")
(9692 . "UPPER LEFT QUADRANT CIRCULAR ARC")
(9693 . "UPPER RIGHT QUADRANT CIRCULAR ARC")
(9694 . "LOWER RIGHT QUADRANT CIRCULAR ARC")
(9695 . "LOWER LEFT QUADRANT CIRCULAR ARC")
(9696 . "UPPER HALF CIRCLE")
(9697 . "LOWER HALF CIRCLE")
(9698 . "BLACK LOWER RIGHT TRIANGLE")
(9699 . "BLACK LOWER LEFT TRIANGLE")
(9700 . "BLACK UPPER LEFT TRIANGLE")
(9701 . "BLACK UPPER RIGHT TRIANGLE")
(9702 . "WHITE BULLET")
(9703 . "SQUARE WITH LEFT HALF BLACK")
(9704 . "SQUARE WITH RIGHT HALF BLACK")
(9705 . "SQUARE WITH UPPER LEFT DIAGONAL HALF BLACK")
(9706 . "SQUARE WITH LOWER RIGHT DIAGONAL HALF BLACK")
(9707 . "WHITE SQUARE WITH VERTICAL BISECTING LINE")
(9708 . "WHITE UP-POINTING TRIANGLE WITH DOT")
(9709 . "UP-POINTING TRIANGLE WITH LEFT HALF BLACK")
(9710 . "UP-POINTING TRIANGLE WITH RIGHT HALF BLACK")
(9711 . "LARGE CIRCLE")
(9712 . "WHITE SQUARE WITH UPPER LEFT QUADRANT")
(9713 . "WHITE SQUARE WITH LOWER LEFT QUADRANT")
(9714 . "WHITE SQUARE WITH LOWER RIGHT QUADRANT")
(9715 . "WHITE SQUARE WITH UPPER RIGHT QUADRANT")
(9716 . "WHITE CIRCLE WITH UPPER LEFT QUADRANT")
(9717 . "WHITE CIRCLE WITH LOWER LEFT QUADRANT")
(9718 . "WHITE CIRCLE WITH LOWER RIGHT QUADRANT")
(9719 . "WHITE CIRCLE WITH UPPER RIGHT QUADRANT")
(9720 . "UPPER LEFT TRIANGLE")
(9721 . "UPPER RIGHT TRIANGLE")
(9722 . "LOWER LEFT TRIANGLE")
(9723 . "WHITE MEDIUM SQUARE")
(9724 . "BLACK MEDIUM SQUARE")
(9725 . "WHITE MEDIUM SMALL SQUARE")
(9726 . "BLACK MEDIUM SMALL SQUARE")
(9727 . "LOWER RIGHT TRIANGLE")
(9728 . "BLACK SUN WITH RAYS")
(9729 . "CLOUD")
(9730 . "UMBRELLA")
(9731 . "SNOWMAN")
(9732 . "COMET")
(9733 . "BLACK STAR")
(9734 . "WHITE STAR")
(9735 . "LIGHTNING")
(9736 . "THUNDERSTORM")
(9737 . "SUN")
(9738 . "ASCENDING NODE")
(9739 . "DESCENDING NODE")
(9740 . "CONJUNCTION")
(9741 . "OPPOSITION")
(9742 . "BLACK TELEPHONE")
(9743 . "WHITE TELEPHONE")
(9744 . "BALLOT BOX")
(9745 . "BALLOT BOX WITH CHECK")
(9746 . "BALLOT BOX WITH X")
(9747 . "SALTIRE")
(9748 . "UMBRELLA WITH RAIN DROPS")
(9749 . "HOT BEVERAGE")
(9750 . "WHITE SHOGI PIECE")
(9751 . "BLACK SHOGI PIECE")
(9752 . "SHAMROCK")
(9753 . "REVERSED ROTATED FLORAL HEART BULLET")
(9754 . "BLACK LEFT POINTING INDEX")
(9755 . "BLACK RIGHT POINTING INDEX")
(9756 . "WHITE LEFT POINTING INDEX")
(9757 . "WHITE UP POINTING INDEX")
(9758 . "WHITE RIGHT POINTING INDEX")
(9759 . "WHITE DOWN POINTING INDEX")
(9760 . "SKULL AND CROSSBONES")
(9761 . "CAUTION SIGN")
(9762 . "RADIOACTIVE SIGN")
(9763 . "BIOHAZARD SIGN")
(9764 . "CADUCEUS")
(9765 . "ANKH")
(9766 . "ORTHODOX CROSS")
(9767 . "CHI RHO")
(9768 . "CROSS OF LORRAINE")
(9769 . "CROSS OF JERUSALEM")
(9770 . "STAR AND CRESCENT")
(9771 . "FARSI SYMBOL")
(9772 . "ADI SHAKTI")
(9773 . "HAMMER AND SICKLE")
(9774 . "PEACE SYMBOL")
(9775 . "YIN YANG")
(9776 . "TRIGRAM FOR HEAVEN")
(9777 . "TRIGRAM FOR LAKE")
(9778 . "TRIGRAM FOR FIRE")
(9779 . "TRIGRAM FOR THUNDER")
(9780 . "TRIGRAM FOR WIND")
(9781 . "TRIGRAM FOR WATER")
(9782 . "TRIGRAM FOR MOUNTAIN")
(9783 . "TRIGRAM FOR EARTH")
(9784 . "WHEEL OF DHARMA")
(9785 . "WHITE FROWNING FACE")
(9786 . "WHITE SMILING FACE")
(9787 . "BLACK SMILING FACE")
(9788 . "WHITE SUN WITH RAYS")
(9789 . "FIRST QUARTER MOON")
(9790 . "LAST QUARTER MOON")
(9791 . "MERCURY")
(9792 . "FEMALE SIGN")
(9793 . "EARTH")
(9794 . "MALE SIGN")
(9795 . "JUPITER")
(9796 . "SATURN")
(9797 . "URANUS")
(9798 . "NEPTUNE")
(9799 . "PLUTO")
(9800 . "ARIES")
(9801 . "TAURUS")
(9802 . "GEMINI")
(9803 . "CANCER")
(9804 . "LEO")
(9805 . "VIRGO")
(9806 . "LIBRA")
(9807 . "SCORPIUS")
(9808 . "SAGITTARIUS")
(9809 . "CAPRICORN")
(9810 . "AQUARIUS")
(9811 . "PISCES")
(9812 . "WHITE CHESS KING")
(9813 . "WHITE CHESS QUEEN")
(9814 . "WHITE CHESS ROOK")
(9815 . "WHITE CHESS BISHOP")
(9816 . "WHITE CHESS KNIGHT")
(9817 . "WHITE CHESS PAWN")
(9818 . "BLACK CHESS KING")
(9819 . "BLACK CHESS QUEEN")
(9820 . "BLACK CHESS ROOK")
(9821 . "BLACK CHESS BISHOP")
(9822 . "BLACK CHESS KNIGHT")
(9823 . "BLACK CHESS PAWN")
(9824 . "BLACK SPADE SUIT")
(9825 . "WHITE HEART SUIT")
(9826 . "WHITE DIAMOND SUIT")
(9827 . "BLACK CLUB SUIT")
(9828 . "WHITE SPADE SUIT")
(9829 . "BLACK HEART SUIT")
(9830 . "BLACK DIAMOND SUIT")
(9831 . "WHITE CLUB SUIT")
(9832 . "HOT SPRINGS")
(9833 . "QUARTER NOTE")
(9834 . "EIGHTH NOTE")
(9835 . "BEAMED EIGHTH NOTES")
(9836 . "BEAMED SIXTEENTH NOTES")
(9837 . "MUSIC FLAT SIGN")
(9838 . "MUSIC NATURAL SIGN")
(9839 . "MUSIC SHARP SIGN")
(9840 . "WEST SYRIAC CROSS")
(9841 . "EAST SYRIAC CROSS")
(9842 . "UNIVERSAL RECYCLING SYMBOL")
(9843 . "RECYCLING SYMBOL FOR TYPE-1 PLASTICS")
(9844 . "RECYCLING SYMBOL FOR TYPE-2 PLASTICS")
(9845 . "RECYCLING SYMBOL FOR TYPE-3 PLASTICS")
(9846 . "RECYCLING SYMBOL FOR TYPE-4 PLASTICS")
(9847 . "RECYCLING SYMBOL FOR TYPE-5 PLASTICS")
(9848 . "RECYCLING SYMBOL FOR TYPE-6 PLASTICS")
(9849 . "RECYCLING SYMBOL FOR TYPE-7 PLASTICS")
(9850 . "RECYCLING SYMBOL FOR GENERIC MATERIALS")
(9851 . "BLACK UNIVERSAL RECYCLING SYMBOL")
(9852 . "RECYCLED PAPER SYMBOL")
(9853 . "PARTIALLY-RECYCLED PAPER SYMBOL")
(9854 . "PERMANENT PAPER SIGN")
(9855 . "WHEELCHAIR SYMBOL")
(9856 . "DIE FACE-1")
(9857 . "DIE FACE-2")
(9858 . "DIE FACE-3")
(9859 . "DIE FACE-4")
(9860 . "DIE FACE-5")
(9861 . "DIE FACE-6")
(9862 . "WHITE CIRCLE WITH DOT RIGHT")
(9863 . "WHITE CIRCLE WITH TWO DOTS")
(9864 . "BLACK CIRCLE WITH WHITE DOT RIGHT")
(9865 . "BLACK CIRCLE WITH TWO WHITE DOTS")
(9866 . "MONOGRAM FOR YANG")
(9867 . "MONOGRAM FOR YIN")
(9868 . "DIGRAM FOR GREATER YANG")
(9869 . "DIGRAM FOR LESSER YIN")
(9870 . "DIGRAM FOR LESSER YANG")
(9871 . "DIGRAM FOR GREATER YIN")
(9872 . "WHITE FLAG")
(9873 . "BLACK FLAG")
(9874 . "HAMMER AND PICK")
(9875 . "ANCHOR")
(9876 . "CROSSED SWORDS")
(9877 . "STAFF OF AESCULAPIUS")
(9878 . "SCALES")
(9879 . "ALEMBIC")
(9880 . "FLOWER")
(9881 . "GEAR")
(9882 . "STAFF OF HERMES")
(9883 . "ATOM SYMBOL")
(9884 . "FLEUR-DE-LIS")
(9885 . "OUTLINED WHITE STAR")
(9886 . "THREE LINES CONVERGING RIGHT")
(9887 . "THREE LINES CONVERGING LEFT")
(9888 . "WARNING SIGN")
(9889 . "HIGH VOLTAGE SIGN")
(9890 . "DOUBLED FEMALE SIGN")
(9891 . "DOUBLED MALE SIGN")
(9892 . "INTERLOCKED FEMALE AND MALE SIGN")
(9893 . "MALE AND FEMALE SIGN")
(9894 . "MALE WITH STROKE SIGN")
(9895 . "MALE WITH STROKE AND MALE AND FEMALE SIGN")
(9896 . "VERTICAL MALE WITH STROKE SIGN")
(9897 . "HORIZONTAL MALE WITH STROKE SIGN")
(9898 . "MEDIUM WHITE CIRCLE")
(9899 . "MEDIUM BLACK CIRCLE")
(9900 . "MEDIUM SMALL WHITE CIRCLE")
(9901 . "MARRIAGE SYMBOL")
(9902 . "DIVORCE SYMBOL")
(9903 . "UNMARRIED PARTNERSHIP SYMBOL")
(9904 . "COFFIN")
(9905 . "FUNERAL URN")
(9906 . "NEUTER")
(9907 . "CERES")
(9908 . "PALLAS")
(9909 . "JUNO")
(9910 . "VESTA")
(9911 . "CHIRON")
(9912 . "BLACK MOON LILITH")
(9913 . "SEXTILE")
(9914 . "SEMISEXTILE")
(9915 . "QUINCUNX")
(9916 . "SESQUIQUADRATE")
(9917 . "SOCCER BALL")
(9918 . "BASEBALL")
(9919 . "SQUARED KEY")
(9920 . "WHITE DRAUGHTS MAN")
(9921 . "WHITE DRAUGHTS KING")
(9922 . "BLACK DRAUGHTS MAN")
(9923 . "BLACK DRAUGHTS KING")
(9924 . "SNOWMAN WITHOUT SNOW")
(9925 . "SUN BEHIND CLOUD")
(9926 . "RAIN")
(9927 . "BLACK SNOWMAN")
(9928 . "THUNDER CLOUD AND RAIN")
(9929 . "TURNED WHITE SHOGI PIECE")
(9930 . "TURNED BLACK SHOGI PIECE")
(9931 . "WHITE DIAMOND IN SQUARE")
(9932 . "CROSSING LANES")
(9933 . "DISABLED CAR")
(9934 . "OPHIUCHUS")
(9935 . "PICK")
(9936 . "CAR SLIDING")
(9937 . "HELMET WITH WHITE CROSS")
(9938 . "CIRCLED CROSSING LANES")
(9939 . "CHAINS")
(9940 . "NO ENTRY")
(9941 . "ALTERNATE ONE-WAY LEFT WAY TRAFFIC")
(9942 . "BLACK TWO-WAY LEFT WAY TRAFFIC")
(9943 . "WHITE TWO-WAY LEFT WAY TRAFFIC")
(9944 . "BLACK LEFT LANE MERGE")
(9945 . "WHITE LEFT LANE MERGE")
(9946 . "DRIVE SLOW SIGN")
(9947 . "HEAVY WHITE DOWN-POINTING TRIANGLE")
(9948 . "LEFT CLOSED ENTRY")
(9949 . "SQUARED SALTIRE")
(9950 . "FALLING DIAGONAL IN WHITE CIRCLE IN BLACK SQUARE")
(9951 . "BLACK TRUCK")
(9952 . "RESTRICTED LEFT ENTRY-1")
(9953 . "RESTRICTED LEFT ENTRY-2")
(9954 . "ASTRONOMICAL SYMBOL FOR URANUS")
(9955 . "HEAVY CIRCLE WITH STROKE AND TWO DOTS ABOVE")
(9956 . "PENTAGRAM")
(9957 . "RIGHT-HANDED INTERLACED PENTAGRAM")
(9958 . "LEFT-HANDED INTERLACED PENTAGRAM")
(9959 . "INVERTED PENTAGRAM")
(9960 . "BLACK CROSS ON SHIELD")
(9961 . "SHINTO SHRINE")
(9962 . "CHURCH")
(9963 . "CASTLE")
(9964 . "HISTORIC SITE")
(9965 . "GEAR WITHOUT HUB")
(9966 . "GEAR WITH HANDLES")
(9967 . "MAP SYMBOL FOR LIGHTHOUSE")
(9968 . "MOUNTAIN")
(9969 . "UMBRELLA ON GROUND")
(9970 . "FOUNTAIN")
(9971 . "FLAG IN HOLE")
(9972 . "FERRY")
(9973 . "SAILBOAT")
(9974 . "SQUARE FOUR CORNERS")
(9975 . "SKIER")
(9976 . "ICE SKATE")
(9977 . "PERSON WITH BALL")
(9978 . "TENT")
(9979 . "JAPANESE BANK SYMBOL")
(9980 . "HEADSTONE GRAVEYARD SYMBOL")
(9981 . "FUEL PUMP")
(9982 . "CUP ON BLACK SQUARE")
(9983 . "WHITE FLAG WITH HORIZONTAL MIDDLE BLACK STRIPE")
(9984 . "BLACK SAFETY SCISSORS")
(9985 . "UPPER BLADE SCISSORS")
(9986 . "BLACK SCISSORS")
(9987 . "LOWER BLADE SCISSORS")
(9988 . "WHITE SCISSORS")
(9989 . "WHITE HEAVY CHECK MARK")
(9990 . "TELEPHONE LOCATION SIGN")
(9991 . "TAPE DRIVE")
(9992 . "AIRPLANE")
(9993 . "ENVELOPE")
(9994 . "RAISED FIST")
(9995 . "RAISED HAND")
(9996 . "VICTORY HAND")
(9997 . "WRITING HAND")
(9998 . "LOWER RIGHT PENCIL")
(9999 . "PENCIL")
(10000 . "UPPER RIGHT PENCIL")
(10001 . "WHITE NIB")
(10002 . "BLACK NIB")
(10003 . "CHECK MARK")
(10004 . "HEAVY CHECK MARK")
(10005 . "MULTIPLICATION X")
(10006 . "HEAVY MULTIPLICATION X")
(10007 . "BALLOT X")
(10008 . "HEAVY BALLOT X")
(10009 . "OUTLINED GREEK CROSS")
(10010 . "HEAVY GREEK CROSS")
(10011 . "OPEN CENTRE CROSS")
(10012 . "HEAVY OPEN CENTRE CROSS")
(10013 . "LATIN CROSS")
(10014 . "SHADOWED WHITE LATIN CROSS")
(10015 . "OUTLINED LATIN CROSS")
(10016 . "MALTESE CROSS")
(10017 . "STAR OF DAVID")
(10018 . "FOUR TEARDROP-SPOKED ASTERISK")
(10019 . "FOUR BALLOON-SPOKED ASTERISK")
(10020 . "HEAVY FOUR BALLOON-SPOKED ASTERISK")
(10021 . "FOUR CLUB-SPOKED ASTERISK")
(10022 . "BLACK FOUR POINTED STAR")
(10023 . "WHITE FOUR POINTED STAR")
(10024 . "SPARKLES")
(10025 . "STRESS OUTLINED WHITE STAR")
(10026 . "CIRCLED WHITE STAR")
(10027 . "OPEN CENTRE BLACK STAR")
(10028 . "BLACK CENTRE WHITE STAR")
(10029 . "OUTLINED BLACK STAR")
(10030 . "HEAVY OUTLINED BLACK STAR")
(10031 . "PINWHEEL STAR")
(10032 . "SHADOWED WHITE STAR")
(10033 . "HEAVY ASTERISK")
(10034 . "OPEN CENTRE ASTERISK")
(10035 . "EIGHT SPOKED ASTERISK")
(10036 . "EIGHT POINTED BLACK STAR")
(10037 . "EIGHT POINTED PINWHEEL STAR")
(10038 . "SIX POINTED BLACK STAR")
(10039 . "EIGHT POINTED RECTILINEAR BLACK STAR")
(10040 . "HEAVY EIGHT POINTED RECTILINEAR BLACK STAR")
(10041 . "TWELVE POINTED BLACK STAR")
(10042 . "SIXTEEN POINTED ASTERISK")
(10043 . "TEARDROP-SPOKED ASTERISK")
(10044 . "OPEN CENTRE TEARDROP-SPOKED ASTERISK")
(10045 . "HEAVY TEARDROP-SPOKED ASTERISK")
(10046 . "SIX PETALLED BLACK AND WHITE FLORETTE")
(10047 . "BLACK FLORETTE")
(10048 . "WHITE FLORETTE")
(10049 . "EIGHT PETALLED OUTLINED BLACK FLORETTE")
(10050 . "CIRCLED OPEN CENTRE EIGHT POINTED STAR")
(10051 . "HEAVY TEARDROP-SPOKED PINWHEEL ASTERISK")
(10052 . "SNOWFLAKE")
(10053 . "TIGHT TRIFOLIATE SNOWFLAKE")
(10054 . "HEAVY CHEVRON SNOWFLAKE")
(10055 . "SPARKLE")
(10056 . "HEAVY SPARKLE")
(10057 . "BALLOON-SPOKED ASTERISK")
(10058 . "EIGHT TEARDROP-SPOKED PROPELLER ASTERISK")
(10059 . "HEAVY EIGHT TEARDROP-SPOKED PROPELLER ASTERISK")
(10060 . "CROSS MARK")
(10061 . "SHADOWED WHITE CIRCLE")
(10062 . "NEGATIVE SQUARED CROSS MARK")
(10063 . "LOWER RIGHT DROP-SHADOWED WHITE SQUARE")
(10064 . "UPPER RIGHT DROP-SHADOWED WHITE SQUARE")
(10065 . "LOWER RIGHT SHADOWED WHITE SQUARE")
(10066 . "UPPER RIGHT SHADOWED WHITE SQUARE")
(10067 . "BLACK QUESTION MARK ORNAMENT")
(10068 . "WHITE QUESTION MARK ORNAMENT")
(10069 . "WHITE EXCLAMATION MARK ORNAMENT")
(10070 . "BLACK DIAMOND MINUS WHITE X")
(10071 . "HEAVY EXCLAMATION MARK SYMBOL")
(10072 . "LIGHT VERTICAL BAR")
(10073 . "MEDIUM VERTICAL BAR")
(10074 . "HEAVY VERTICAL BAR")
(10075 . "HEAVY SINGLE TURNED COMMA QUOTATION MARK ORNAMENT")
(10076 . "HEAVY SINGLE COMMA QUOTATION MARK ORNAMENT")
(10077 . "HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT")
(10078 . "HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT")
(10079 . "HEAVY LOW SINGLE COMMA QUOTATION MARK ORNAMENT")
(10080 . "HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT")
(10081 . "CURVED STEM PARAGRAPH SIGN ORNAMENT")
(10082 . "HEAVY EXCLAMATION MARK ORNAMENT")
(10083 . "HEAVY HEART EXCLAMATION MARK ORNAMENT")
(10084 . "HEAVY BLACK HEART")
(10085 . "ROTATED HEAVY BLACK HEART BULLET")
(10086 . "FLORAL HEART")
(10087 . "ROTATED FLORAL HEART BULLET")
(10088 . "MEDIUM LEFT PARENTHESIS ORNAMENT")
(10089 . "MEDIUM RIGHT PARENTHESIS ORNAMENT")
(10090 . "MEDIUM FLATTENED LEFT PARENTHESIS ORNAMENT")
(10091 . "MEDIUM FLATTENED RIGHT PARENTHESIS ORNAMENT")
(10092 . "MEDIUM LEFT-POINTING ANGLE BRACKET ORNAMENT")
(10093 . "MEDIUM RIGHT-POINTING ANGLE BRACKET ORNAMENT")
(10094 . "HEAVY LEFT-POINTING ANGLE QUOTATION MARK ORNAMENT")
(10095 . "HEAVY RIGHT-POINTING ANGLE QUOTATION MARK ORNAMENT")
(10096 . "HEAVY LEFT-POINTING ANGLE BRACKET ORNAMENT")
(10097 . "HEAVY RIGHT-POINTING ANGLE BRACKET ORNAMENT")
(10098 . "LIGHT LEFT TORTOISE SHELL BRACKET ORNAMENT")
(10099 . "LIGHT RIGHT TORTOISE SHELL BRACKET ORNAMENT")
(10100 . "MEDIUM LEFT CURLY BRACKET ORNAMENT")
(10101 . "MEDIUM RIGHT CURLY BRACKET ORNAMENT")
(10102 . "DINGBAT NEGATIVE CIRCLED DIGIT ONE")
(10103 . "DINGBAT NEGATIVE CIRCLED DIGIT TWO")
(10104 . "DINGBAT NEGATIVE CIRCLED DIGIT THREE")
(10105 . "DINGBAT NEGATIVE CIRCLED DIGIT FOUR")
(10106 . "DINGBAT NEGATIVE CIRCLED DIGIT FIVE")
(10107 . "DINGBAT NEGATIVE CIRCLED DIGIT SIX")
(10108 . "DINGBAT NEGATIVE CIRCLED DIGIT SEVEN")
(10109 . "DINGBAT NEGATIVE CIRCLED DIGIT EIGHT")
(10110 . "DINGBAT NEGATIVE CIRCLED DIGIT NINE")
(10111 . "DINGBAT NEGATIVE CIRCLED NUMBER TEN")
(10112 . "DINGBAT CIRCLED SANS-SERIF DIGIT ONE")
(10113 . "DINGBAT CIRCLED SANS-SERIF DIGIT TWO")
(10114 . "DINGBAT CIRCLED SANS-SERIF DIGIT THREE")
(10115 . "DINGBAT CIRCLED SANS-SERIF DIGIT FOUR")
(10116 . "DINGBAT CIRCLED SANS-SERIF DIGIT FIVE")
(10117 . "DINGBAT CIRCLED SANS-SERIF DIGIT SIX")
(10118 . "DINGBAT CIRCLED SANS-SERIF DIGIT SEVEN")
(10119 . "DINGBAT CIRCLED SANS-SERIF DIGIT EIGHT")
(10120 . "DINGBAT CIRCLED SANS-SERIF DIGIT NINE")
(10121 . "DINGBAT CIRCLED SANS-SERIF NUMBER TEN")
(10122 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ONE")
(10123 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT TWO")
(10124 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT THREE")
(10125 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FOUR")
(10126 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FIVE")
(10127 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SIX")
(10128 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SEVEN")
(10129 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT EIGHT")
(10130 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT NINE")
(10131 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF NUMBER TEN")
(10132 . "HEAVY WIDE-HEADED RIGHTWARDS ARROW")
(10133 . "HEAVY PLUS SIGN")
(10134 . "HEAVY MINUS SIGN")
(10135 . "HEAVY DIVISION SIGN")
(10136 . "HEAVY SOUTH EAST ARROW")
(10137 . "HEAVY RIGHTWARDS ARROW")
(10138 . "HEAVY NORTH EAST ARROW")
(10139 . "DRAFTING POINT RIGHTWARDS ARROW")
(10140 . "HEAVY ROUND-TIPPED RIGHTWARDS ARROW")
(10141 . "TRIANGLE-HEADED RIGHTWARDS ARROW")
(10142 . "HEAVY TRIANGLE-HEADED RIGHTWARDS ARROW")
(10143 . "DASHED TRIANGLE-HEADED RIGHTWARDS ARROW")
(10144 . "HEAVY DASHED TRIANGLE-HEADED RIGHTWARDS ARROW")
(10145 . "BLACK RIGHTWARDS ARROW")
(10146 . "THREE-D TOP-LIGHTED RIGHTWARDS ARROWHEAD")
(10147 . "THREE-D BOTTOM-LIGHTED RIGHTWARDS ARROWHEAD")
(10148 . "BLACK RIGHTWARDS ARROWHEAD")
(10149 . "HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW")
(10150 . "HEAVY BLACK CURVED UPWARDS AND RIGHTWARDS ARROW")
(10151 . "SQUAT BLACK RIGHTWARDS ARROW")
(10152 . "HEAVY CONCAVE-POINTED BLACK RIGHTWARDS ARROW")
(10153 . "RIGHT-SHADED WHITE RIGHTWARDS ARROW")
(10154 . "LEFT-SHADED WHITE RIGHTWARDS ARROW")
(10155 . "BACK-TILTED SHADOWED WHITE RIGHTWARDS ARROW")
(10156 . "FRONT-TILTED SHADOWED WHITE RIGHTWARDS ARROW")
(10157 . "HEAVY LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW")
(10158 . "HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW")
(10159 . "NOTCHED LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW")
(10160 . "CURLY LOOP")
(10161 . "NOTCHED UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW")
(10162 . "CIRCLED HEAVY WHITE RIGHTWARDS ARROW")
(10163 . "WHITE-FEATHERED RIGHTWARDS ARROW")
(10164 . "BLACK-FEATHERED SOUTH EAST ARROW")
(10165 . "BLACK-FEATHERED RIGHTWARDS ARROW")
(10166 . "BLACK-FEATHERED NORTH EAST ARROW")
(10167 . "HEAVY BLACK-FEATHERED SOUTH EAST ARROW")
(10168 . "HEAVY BLACK-FEATHERED RIGHTWARDS ARROW")
(10169 . "HEAVY BLACK-FEATHERED NORTH EAST ARROW")
(10170 . "TEARDROP-BARBED RIGHTWARDS ARROW")
(10171 . "HEAVY TEARDROP-SHANKED RIGHTWARDS ARROW")
(10172 . "WEDGE-TAILED RIGHTWARDS ARROW")
(10173 . "HEAVY WEDGE-TAILED RIGHTWARDS ARROW")
(10174 . "OPEN-OUTLINED RIGHTWARDS ARROW")
(10175 . "DOUBLE CURLY LOOP")
(10176 . "THREE DIMENSIONAL ANGLE")
(10177 . "WHITE TRIANGLE CONTAINING SMALL WHITE TRIANGLE")
(10178 . "PERPENDICULAR")
(10179 . "OPEN SUBSET")
(10180 . "OPEN SUPERSET")
(10181 . "LEFT S-SHAPED BAG DELIMITER")
(10182 . "RIGHT S-SHAPED BAG DELIMITER")
(10183 . "OR WITH DOT INSIDE")
(10184 . "REVERSE SOLIDUS PRECEDING SUBSET")
(10185 . "SUPERSET PRECEDING SOLIDUS")
(10186 . "VERTICAL BAR WITH HORIZONTAL STROKE")
(10187 . "MATHEMATICAL RISING DIAGONAL")
(10188 . "LONG DIVISION")
(10189 . "MATHEMATICAL FALLING DIAGONAL")
(10190 . "SQUARED LOGICAL AND")
(10191 . "SQUARED LOGICAL OR")
(10192 . "WHITE DIAMOND WITH CENTRED DOT")
(10193 . "AND WITH DOT")
(10194 . "ELEMENT OF OPENING UPWARDS")
(10195 . "LOWER RIGHT CORNER WITH DOT")
(10196 . "UPPER LEFT CORNER WITH DOT")
(10197 . "LEFT OUTER JOIN")
(10198 . "RIGHT OUTER JOIN")
(10199 . "FULL OUTER JOIN")
(10200 . "LARGE UP TACK")
(10201 . "LARGE DOWN TACK")
(10202 . "LEFT AND RIGHT DOUBLE TURNSTILE")
(10203 . "LEFT AND RIGHT TACK")
(10204 . "LEFT MULTIMAP")
(10205 . "LONG RIGHT TACK")
(10206 . "LONG LEFT TACK")
(10207 . "UP TACK WITH CIRCLE ABOVE")
(10208 . "LOZENGE DIVIDED BY HORIZONTAL RULE")
(10209 . "WHITE CONCAVE-SIDED DIAMOND")
(10210 . "WHITE CONCAVE-SIDED DIAMOND WITH LEFTWARDS TICK")
(10211 . "WHITE CONCAVE-SIDED DIAMOND WITH RIGHTWARDS TICK")
(10212 . "WHITE SQUARE WITH LEFTWARDS TICK")
(10213 . "WHITE SQUARE WITH RIGHTWARDS TICK")
(10214 . "MATHEMATICAL LEFT WHITE SQUARE BRACKET")
(10215 . "MATHEMATICAL RIGHT WHITE SQUARE BRACKET")
(10216 . "MATHEMATICAL LEFT ANGLE BRACKET")
(10217 . "MATHEMATICAL RIGHT ANGLE BRACKET")
(10218 . "MATHEMATICAL LEFT DOUBLE ANGLE BRACKET")
(10219 . "MATHEMATICAL RIGHT DOUBLE ANGLE BRACKET")
(10220 . "MATHEMATICAL LEFT WHITE TORTOISE SHELL BRACKET")
(10221 . "MATHEMATICAL RIGHT WHITE TORTOISE SHELL BRACKET")
(10222 . "MATHEMATICAL LEFT FLATTENED PARENTHESIS")
(10223 . "MATHEMATICAL RIGHT FLATTENED PARENTHESIS")
(10224 . "UPWARDS QUADRUPLE ARROW")
(10225 . "DOWNWARDS QUADRUPLE ARROW")
(10226 . "ANTICLOCKWISE GAPPED CIRCLE ARROW")
(10227 . "CLOCKWISE GAPPED CIRCLE ARROW")
(10228 . "RIGHT ARROW WITH CIRCLED PLUS")
(10229 . "LONG LEFTWARDS ARROW")
(10230 . "LONG RIGHTWARDS ARROW")
(10231 . "LONG LEFT RIGHT ARROW")
(10232 . "LONG LEFTWARDS DOUBLE ARROW")
(10233 . "LONG RIGHTWARDS DOUBLE ARROW")
(10234 . "LONG LEFT RIGHT DOUBLE ARROW")
(10235 . "LONG LEFTWARDS ARROW FROM BAR")
(10236 . "LONG RIGHTWARDS ARROW FROM BAR")
(10237 . "LONG LEFTWARDS DOUBLE ARROW FROM BAR")
(10238 . "LONG RIGHTWARDS DOUBLE ARROW FROM BAR")
(10239 . "LONG RIGHTWARDS SQUIGGLE ARROW")
(10240 . "BRAILLE PATTERN BLANK")
(10241 . "BRAILLE PATTERN DOTS-1")
(10242 . "BRAILLE PATTERN DOTS-2")
(10243 . "BRAILLE PATTERN DOTS-12")
(10244 . "BRAILLE PATTERN DOTS-3")
(10245 . "BRAILLE PATTERN DOTS-13")
(10246 . "BRAILLE PATTERN DOTS-23")
(10247 . "BRAILLE PATTERN DOTS-123")
(10248 . "BRAILLE PATTERN DOTS-4")
(10249 . "BRAILLE PATTERN DOTS-14")
(10250 . "BRAILLE PATTERN DOTS-24")
(10251 . "BRAILLE PATTERN DOTS-124")
(10252 . "BRAILLE PATTERN DOTS-34")
(10253 . "BRAILLE PATTERN DOTS-134")
(10254 . "BRAILLE PATTERN DOTS-234")
(10255 . "BRAILLE PATTERN DOTS-1234")
(10256 . "BRAILLE PATTERN DOTS-5")
(10257 . "BRAILLE PATTERN DOTS-15")
(10258 . "BRAILLE PATTERN DOTS-25")
(10259 . "BRAILLE PATTERN DOTS-125")
(10260 . "BRAILLE PATTERN DOTS-35")
(10261 . "BRAILLE PATTERN DOTS-135")
(10262 . "BRAILLE PATTERN DOTS-235")
(10263 . "BRAILLE PATTERN DOTS-1235")
(10264 . "BRAILLE PATTERN DOTS-45")
(10265 . "BRAILLE PATTERN DOTS-145")
(10266 . "BRAILLE PATTERN DOTS-245")
(10267 . "BRAILLE PATTERN DOTS-1245")
(10268 . "BRAILLE PATTERN DOTS-345")
(10269 . "BRAILLE PATTERN DOTS-1345")
(10270 . "BRAILLE PATTERN DOTS-2345")
(10271 . "BRAILLE PATTERN DOTS-12345")
(10272 . "BRAILLE PATTERN DOTS-6")
(10273 . "BRAILLE PATTERN DOTS-16")
(10274 . "BRAILLE PATTERN DOTS-26")
(10275 . "BRAILLE PATTERN DOTS-126")
(10276 . "BRAILLE PATTERN DOTS-36")
(10277 . "BRAILLE PATTERN DOTS-136")
(10278 . "BRAILLE PATTERN DOTS-236")
(10279 . "BRAILLE PATTERN DOTS-1236")
(10280 . "BRAILLE PATTERN DOTS-46")
(10281 . "BRAILLE PATTERN DOTS-146")
(10282 . "BRAILLE PATTERN DOTS-246")
(10283 . "BRAILLE PATTERN DOTS-1246")
(10284 . "BRAILLE PATTERN DOTS-346")
(10285 . "BRAILLE PATTERN DOTS-1346")
(10286 . "BRAILLE PATTERN DOTS-2346")
(10287 . "BRAILLE PATTERN DOTS-12346")
(10288 . "BRAILLE PATTERN DOTS-56")
(10289 . "BRAILLE PATTERN DOTS-156")
(10290 . "BRAILLE PATTERN DOTS-256")
(10291 . "BRAILLE PATTERN DOTS-1256")
(10292 . "BRAILLE PATTERN DOTS-356")
(10293 . "BRAILLE PATTERN DOTS-1356")
(10294 . "BRAILLE PATTERN DOTS-2356")
(10295 . "BRAILLE PATTERN DOTS-12356")
(10296 . "BRAILLE PATTERN DOTS-456")
(10297 . "BRAILLE PATTERN DOTS-1456")
(10298 . "BRAILLE PATTERN DOTS-2456")
(10299 . "BRAILLE PATTERN DOTS-12456")
(10300 . "BRAILLE PATTERN DOTS-3456")
(10301 . "BRAILLE PATTERN DOTS-13456")
(10302 . "BRAILLE PATTERN DOTS-23456")
(10303 . "BRAILLE PATTERN DOTS-123456")
(10304 . "BRAILLE PATTERN DOTS-7")
(10305 . "BRAILLE PATTERN DOTS-17")
(10306 . "BRAILLE PATTERN DOTS-27")
(10307 . "BRAILLE PATTERN DOTS-127")
(10308 . "BRAILLE PATTERN DOTS-37")
(10309 . "BRAILLE PATTERN DOTS-137")
(10310 . "BRAILLE PATTERN DOTS-237")
(10311 . "BRAILLE PATTERN DOTS-1237")
(10312 . "BRAILLE PATTERN DOTS-47")
(10313 . "BRAILLE PATTERN DOTS-147")
(10314 . "BRAILLE PATTERN DOTS-247")
(10315 . "BRAILLE PATTERN DOTS-1247")
(10316 . "BRAILLE PATTERN DOTS-347")
(10317 . "BRAILLE PATTERN DOTS-1347")
(10318 . "BRAILLE PATTERN DOTS-2347")
(10319 . "BRAILLE PATTERN DOTS-12347")
(10320 . "BRAILLE PATTERN DOTS-57")
(10321 . "BRAILLE PATTERN DOTS-157")
(10322 . "BRAILLE PATTERN DOTS-257")
(10323 . "BRAILLE PATTERN DOTS-1257")
(10324 . "BRAILLE PATTERN DOTS-357")
(10325 . "BRAILLE PATTERN DOTS-1357")
(10326 . "BRAILLE PATTERN DOTS-2357")
(10327 . "BRAILLE PATTERN DOTS-12357")
(10328 . "BRAILLE PATTERN DOTS-457")
(10329 . "BRAILLE PATTERN DOTS-1457")
(10330 . "BRAILLE PATTERN DOTS-2457")
(10331 . "BRAILLE PATTERN DOTS-12457")
(10332 . "BRAILLE PATTERN DOTS-3457")
(10333 . "BRAILLE PATTERN DOTS-13457")
(10334 . "BRAILLE PATTERN DOTS-23457")
(10335 . "BRAILLE PATTERN DOTS-123457")
(10336 . "BRAILLE PATTERN DOTS-67")
(10337 . "BRAILLE PATTERN DOTS-167")
(10338 . "BRAILLE PATTERN DOTS-267")
(10339 . "BRAILLE PATTERN DOTS-1267")
(10340 . "BRAILLE PATTERN DOTS-367")
(10341 . "BRAILLE PATTERN DOTS-1367")
(10342 . "BRAILLE PATTERN DOTS-2367")
(10343 . "BRAILLE PATTERN DOTS-12367")
(10344 . "BRAILLE PATTERN DOTS-467")
(10345 . "BRAILLE PATTERN DOTS-1467")
(10346 . "BRAILLE PATTERN DOTS-2467")
(10347 . "BRAILLE PATTERN DOTS-12467")
(10348 . "BRAILLE PATTERN DOTS-3467")
(10349 . "BRAILLE PATTERN DOTS-13467")
(10350 . "BRAILLE PATTERN DOTS-23467")
(10351 . "BRAILLE PATTERN DOTS-123467")
(10352 . "BRAILLE PATTERN DOTS-567")
(10353 . "BRAILLE PATTERN DOTS-1567")
(10354 . "BRAILLE PATTERN DOTS-2567")
(10355 . "BRAILLE PATTERN DOTS-12567")
(10356 . "BRAILLE PATTERN DOTS-3567")
(10357 . "BRAILLE PATTERN DOTS-13567")
(10358 . "BRAILLE PATTERN DOTS-23567")
(10359 . "BRAILLE PATTERN DOTS-123567")
(10360 . "BRAILLE PATTERN DOTS-4567")
(10361 . "BRAILLE PATTERN DOTS-14567")
(10362 . "BRAILLE PATTERN DOTS-24567")
(10363 . "BRAILLE PATTERN DOTS-124567")
(10364 . "BRAILLE PATTERN DOTS-34567")
(10365 . "BRAILLE PATTERN DOTS-134567")
(10366 . "BRAILLE PATTERN DOTS-234567")
(10367 . "BRAILLE PATTERN DOTS-1234567")
(10368 . "BRAILLE PATTERN DOTS-8")
(10369 . "BRAILLE PATTERN DOTS-18")
(10370 . "BRAILLE PATTERN DOTS-28")
(10371 . "BRAILLE PATTERN DOTS-128")
(10372 . "BRAILLE PATTERN DOTS-38")
(10373 . "BRAILLE PATTERN DOTS-138")
(10374 . "BRAILLE PATTERN DOTS-238")
(10375 . "BRAILLE PATTERN DOTS-1238")
(10376 . "BRAILLE PATTERN DOTS-48")
(10377 . "BRAILLE PATTERN DOTS-148")
(10378 . "BRAILLE PATTERN DOTS-248")
(10379 . "BRAILLE PATTERN DOTS-1248")
(10380 . "BRAILLE PATTERN DOTS-348")
(10381 . "BRAILLE PATTERN DOTS-1348")
(10382 . "BRAILLE PATTERN DOTS-2348")
(10383 . "BRAILLE PATTERN DOTS-12348")
(10384 . "BRAILLE PATTERN DOTS-58")
(10385 . "BRAILLE PATTERN DOTS-158")
(10386 . "BRAILLE PATTERN DOTS-258")
(10387 . "BRAILLE PATTERN DOTS-1258")
(10388 . "BRAILLE PATTERN DOTS-358")
(10389 . "BRAILLE PATTERN DOTS-1358")
(10390 . "BRAILLE PATTERN DOTS-2358")
(10391 . "BRAILLE PATTERN DOTS-12358")
(10392 . "BRAILLE PATTERN DOTS-458")
(10393 . "BRAILLE PATTERN DOTS-1458")
(10394 . "BRAILLE PATTERN DOTS-2458")
(10395 . "BRAILLE PATTERN DOTS-12458")
(10396 . "BRAILLE PATTERN DOTS-3458")
(10397 . "BRAILLE PATTERN DOTS-13458")
(10398 . "BRAILLE PATTERN DOTS-23458")
(10399 . "BRAILLE PATTERN DOTS-123458")
(10400 . "BRAILLE PATTERN DOTS-68")
(10401 . "BRAILLE PATTERN DOTS-168")
(10402 . "BRAILLE PATTERN DOTS-268")
(10403 . "BRAILLE PATTERN DOTS-1268")
(10404 . "BRAILLE PATTERN DOTS-368")
(10405 . "BRAILLE PATTERN DOTS-1368")
(10406 . "BRAILLE PATTERN DOTS-2368")
(10407 . "BRAILLE PATTERN DOTS-12368")
(10408 . "BRAILLE PATTERN DOTS-468")
(10409 . "BRAILLE PATTERN DOTS-1468")
(10410 . "BRAILLE PATTERN DOTS-2468")
(10411 . "BRAILLE PATTERN DOTS-12468")
(10412 . "BRAILLE PATTERN DOTS-3468")
(10413 . "BRAILLE PATTERN DOTS-13468")
(10414 . "BRAILLE PATTERN DOTS-23468")
(10415 . "BRAILLE PATTERN DOTS-123468")
(10416 . "BRAILLE PATTERN DOTS-568")
(10417 . "BRAILLE PATTERN DOTS-1568")
(10418 . "BRAILLE PATTERN DOTS-2568")
(10419 . "BRAILLE PATTERN DOTS-12568")
(10420 . "BRAILLE PATTERN DOTS-3568")
(10421 . "BRAILLE PATTERN DOTS-13568")
(10422 . "BRAILLE PATTERN DOTS-23568")
(10423 . "BRAILLE PATTERN DOTS-123568")
(10424 . "BRAILLE PATTERN DOTS-4568")
(10425 . "BRAILLE PATTERN DOTS-14568")
(10426 . "BRAILLE PATTERN DOTS-24568")
(10427 . "BRAILLE PATTERN DOTS-124568")
(10428 . "BRAILLE PATTERN DOTS-34568")
(10429 . "BRAILLE PATTERN DOTS-134568")
(10430 . "BRAILLE PATTERN DOTS-234568")
(10431 . "BRAILLE PATTERN DOTS-1234568")
(10432 . "BRAILLE PATTERN DOTS-78")
(10433 . "BRAILLE PATTERN DOTS-178")
(10434 . "BRAILLE PATTERN DOTS-278")
(10435 . "BRAILLE PATTERN DOTS-1278")
(10436 . "BRAILLE PATTERN DOTS-378")
(10437 . "BRAILLE PATTERN DOTS-1378")
(10438 . "BRAILLE PATTERN DOTS-2378")
(10439 . "BRAILLE PATTERN DOTS-12378")
(10440 . "BRAILLE PATTERN DOTS-478")
(10441 . "BRAILLE PATTERN DOTS-1478")
(10442 . "BRAILLE PATTERN DOTS-2478")
(10443 . "BRAILLE PATTERN DOTS-12478")
(10444 . "BRAILLE PATTERN DOTS-3478")
(10445 . "BRAILLE PATTERN DOTS-13478")
(10446 . "BRAILLE PATTERN DOTS-23478")
(10447 . "BRAILLE PATTERN DOTS-123478")
(10448 . "BRAILLE PATTERN DOTS-578")
(10449 . "BRAILLE PATTERN DOTS-1578")
(10450 . "BRAILLE PATTERN DOTS-2578")
(10451 . "BRAILLE PATTERN DOTS-12578")
(10452 . "BRAILLE PATTERN DOTS-3578")
(10453 . "BRAILLE PATTERN DOTS-13578")
(10454 . "BRAILLE PATTERN DOTS-23578")
(10455 . "BRAILLE PATTERN DOTS-123578")
(10456 . "BRAILLE PATTERN DOTS-4578")
(10457 . "BRAILLE PATTERN DOTS-14578")
(10458 . "BRAILLE PATTERN DOTS-24578")
(10459 . "BRAILLE PATTERN DOTS-124578")
(10460 . "BRAILLE PATTERN DOTS-34578")
(10461 . "BRAILLE PATTERN DOTS-134578")
(10462 . "BRAILLE PATTERN DOTS-234578")
(10463 . "BRAILLE PATTERN DOTS-1234578")
(10464 . "BRAILLE PATTERN DOTS-678")
(10465 . "BRAILLE PATTERN DOTS-1678")
(10466 . "BRAILLE PATTERN DOTS-2678")
(10467 . "BRAILLE PATTERN DOTS-12678")
(10468 . "BRAILLE PATTERN DOTS-3678")
(10469 . "BRAILLE PATTERN DOTS-13678")
(10470 . "BRAILLE PATTERN DOTS-23678")
(10471 . "BRAILLE PATTERN DOTS-123678")
(10472 . "BRAILLE PATTERN DOTS-4678")
(10473 . "BRAILLE PATTERN DOTS-14678")
(10474 . "BRAILLE PATTERN DOTS-24678")
(10475 . "BRAILLE PATTERN DOTS-124678")
(10476 . "BRAILLE PATTERN DOTS-34678")
(10477 . "BRAILLE PATTERN DOTS-134678")
(10478 . "BRAILLE PATTERN DOTS-234678")
(10479 . "BRAILLE PATTERN DOTS-1234678")
(10480 . "BRAILLE PATTERN DOTS-5678")
(10481 . "BRAILLE PATTERN DOTS-15678")
(10482 . "BRAILLE PATTERN DOTS-25678")
(10483 . "BRAILLE PATTERN DOTS-125678")
(10484 . "BRAILLE PATTERN DOTS-35678")
(10485 . "BRAILLE PATTERN DOTS-135678")
(10486 . "BRAILLE PATTERN DOTS-235678")
(10487 . "BRAILLE PATTERN DOTS-1235678")
(10488 . "BRAILLE PATTERN DOTS-45678")
(10489 . "BRAILLE PATTERN DOTS-145678")
(10490 . "BRAILLE PATTERN DOTS-245678")
(10491 . "BRAILLE PATTERN DOTS-1245678")
(10492 . "BRAILLE PATTERN DOTS-345678")
(10493 . "BRAILLE PATTERN DOTS-1345678")
(10494 . "BRAILLE PATTERN DOTS-2345678")
(10495 . "BRAILLE PATTERN DOTS-12345678")
(10496 . "RIGHTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE")
(10497 . "RIGHTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE")
(10498 . "LEFTWARDS DOUBLE ARROW WITH VERTICAL STROKE")
(10499 . "RIGHTWARDS DOUBLE ARROW WITH VERTICAL STROKE")
(10500 . "LEFT RIGHT DOUBLE ARROW WITH VERTICAL STROKE")
(10501 . "RIGHTWARDS TWO-HEADED ARROW FROM BAR")
(10502 . "LEFTWARDS DOUBLE ARROW FROM BAR")
(10503 . "RIGHTWARDS DOUBLE ARROW FROM BAR")
(10504 . "DOWNWARDS ARROW WITH HORIZONTAL STROKE")
(10505 . "UPWARDS ARROW WITH HORIZONTAL STROKE")
(10506 . "UPWARDS TRIPLE ARROW")
(10507 . "DOWNWARDS TRIPLE ARROW")
(10508 . "LEFTWARDS DOUBLE DASH ARROW")
(10509 . "RIGHTWARDS DOUBLE DASH ARROW")
(10510 . "LEFTWARDS TRIPLE DASH ARROW")
(10511 . "RIGHTWARDS TRIPLE DASH ARROW")
(10512 . "RIGHTWARDS TWO-HEADED TRIPLE DASH ARROW")
(10513 . "RIGHTWARDS ARROW WITH DOTTED STEM")
(10514 . "UPWARDS ARROW TO BAR")
(10515 . "DOWNWARDS ARROW TO BAR")
(10516 . "RIGHTWARDS ARROW WITH TAIL WITH VERTICAL STROKE")
(10517 . "RIGHTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE")
(10518 . "RIGHTWARDS TWO-HEADED ARROW WITH TAIL")
(10519 . "RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE")
(10520 . "RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE")
(10521 . "LEFTWARDS ARROW-TAIL")
(10522 . "RIGHTWARDS ARROW-TAIL")
(10523 . "LEFTWARDS DOUBLE ARROW-TAIL")
(10524 . "RIGHTWARDS DOUBLE ARROW-TAIL")
(10525 . "LEFTWARDS ARROW TO BLACK DIAMOND")
(10526 . "RIGHTWARDS ARROW TO BLACK DIAMOND")
(10527 . "LEFTWARDS ARROW FROM BAR TO BLACK DIAMOND")
(10528 . "RIGHTWARDS ARROW FROM BAR TO BLACK DIAMOND")
(10529 . "NORTH WEST AND SOUTH EAST ARROW")
(10530 . "NORTH EAST AND SOUTH WEST ARROW")
(10531 . "NORTH WEST ARROW WITH HOOK")
(10532 . "NORTH EAST ARROW WITH HOOK")
(10533 . "SOUTH EAST ARROW WITH HOOK")
(10534 . "SOUTH WEST ARROW WITH HOOK")
(10535 . "NORTH WEST ARROW AND NORTH EAST ARROW")
(10536 . "NORTH EAST ARROW AND SOUTH EAST ARROW")
(10537 . "SOUTH EAST ARROW AND SOUTH WEST ARROW")
(10538 . "SOUTH WEST ARROW AND NORTH WEST ARROW")
(10539 . "RISING DIAGONAL CROSSING FALLING DIAGONAL")
(10540 . "FALLING DIAGONAL CROSSING RISING DIAGONAL")
(10541 . "SOUTH EAST ARROW CROSSING NORTH EAST ARROW")
(10542 . "NORTH EAST ARROW CROSSING SOUTH EAST ARROW")
(10543 . "FALLING DIAGONAL CROSSING NORTH EAST ARROW")
(10544 . "RISING DIAGONAL CROSSING SOUTH EAST ARROW")
(10545 . "NORTH EAST ARROW CROSSING NORTH WEST ARROW")
(10546 . "NORTH WEST ARROW CROSSING NORTH EAST ARROW")
(10547 . "WAVE ARROW POINTING DIRECTLY RIGHT")
(10548 . "ARROW POINTING RIGHTWARDS THEN CURVING UPWARDS")
(10549 . "ARROW POINTING RIGHTWARDS THEN CURVING DOWNWARDS")
(10550 . "ARROW POINTING DOWNWARDS THEN CURVING LEFTWARDS")
(10551 . "ARROW POINTING DOWNWARDS THEN CURVING RIGHTWARDS")
(10552 . "RIGHT-SIDE ARC CLOCKWISE ARROW")
(10553 . "LEFT-SIDE ARC ANTICLOCKWISE ARROW")
(10554 . "TOP ARC ANTICLOCKWISE ARROW")
(10555 . "BOTTOM ARC ANTICLOCKWISE ARROW")
(10556 . "TOP ARC CLOCKWISE ARROW WITH MINUS")
(10557 . "TOP ARC ANTICLOCKWISE ARROW WITH PLUS")
(10558 . "LOWER RIGHT SEMICIRCULAR CLOCKWISE ARROW")
(10559 . "LOWER LEFT SEMICIRCULAR ANTICLOCKWISE ARROW")
(10560 . "ANTICLOCKWISE CLOSED CIRCLE ARROW")
(10561 . "CLOCKWISE CLOSED CIRCLE ARROW")
(10562 . "RIGHTWARDS ARROW ABOVE SHORT LEFTWARDS ARROW")
(10563 . "LEFTWARDS ARROW ABOVE SHORT RIGHTWARDS ARROW")
(10564 . "SHORT RIGHTWARDS ARROW ABOVE LEFTWARDS ARROW")
(10565 . "RIGHTWARDS ARROW WITH PLUS BELOW")
(10566 . "LEFTWARDS ARROW WITH PLUS BELOW")
(10567 . "RIGHTWARDS ARROW THROUGH X")
(10568 . "LEFT RIGHT ARROW THROUGH SMALL CIRCLE")
(10569 . "UPWARDS TWO-HEADED ARROW FROM SMALL CIRCLE")
(10570 . "LEFT BARB UP RIGHT BARB DOWN HARPOON")
(10571 . "LEFT BARB DOWN RIGHT BARB UP HARPOON")
(10572 . "UP BARB RIGHT DOWN BARB LEFT HARPOON")
(10573 . "UP BARB LEFT DOWN BARB RIGHT HARPOON")
(10574 . "LEFT BARB UP RIGHT BARB UP HARPOON")
(10575 . "UP BARB RIGHT DOWN BARB RIGHT HARPOON")
(10576 . "LEFT BARB DOWN RIGHT BARB DOWN HARPOON")
(10577 . "UP BARB LEFT DOWN BARB LEFT HARPOON")
(10578 . "LEFTWARDS HARPOON WITH BARB UP TO BAR")
(10579 . "RIGHTWARDS HARPOON WITH BARB UP TO BAR")
(10580 . "UPWARDS HARPOON WITH BARB RIGHT TO BAR")
(10581 . "DOWNWARDS HARPOON WITH BARB RIGHT TO BAR")
(10582 . "LEFTWARDS HARPOON WITH BARB DOWN TO BAR")
(10583 . "RIGHTWARDS HARPOON WITH BARB DOWN TO BAR")
(10584 . "UPWARDS HARPOON WITH BARB LEFT TO BAR")
(10585 . "DOWNWARDS HARPOON WITH BARB LEFT TO BAR")
(10586 . "LEFTWARDS HARPOON WITH BARB UP FROM BAR")
(10587 . "RIGHTWARDS HARPOON WITH BARB UP FROM BAR")
(10588 . "UPWARDS HARPOON WITH BARB RIGHT FROM BAR")
(10589 . "DOWNWARDS HARPOON WITH BARB RIGHT FROM BAR")
(10590 . "LEFTWARDS HARPOON WITH BARB DOWN FROM BAR")
(10591 . "RIGHTWARDS HARPOON WITH BARB DOWN FROM BAR")
(10592 . "UPWARDS HARPOON WITH BARB LEFT FROM BAR")
(10593 . "DOWNWARDS HARPOON WITH BARB LEFT FROM BAR")
(10594 . "LEFTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB DOWN")
(10595 . "UPWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT")
(10596 . "RIGHTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB DOWN")
(10597 . "DOWNWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT")
(10598 . "LEFTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB UP")
(10599 . "LEFTWARDS HARPOON WITH BARB DOWN ABOVE RIGHTWARDS HARPOON WITH BARB DOWN")
(10600 . "RIGHTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB UP")
(10601 . "RIGHTWARDS HARPOON WITH BARB DOWN ABOVE LEFTWARDS HARPOON WITH BARB DOWN")
(10602 . "LEFTWARDS HARPOON WITH BARB UP ABOVE LONG DASH")
(10603 . "LEFTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH")
(10604 . "RIGHTWARDS HARPOON WITH BARB UP ABOVE LONG DASH")
(10605 . "RIGHTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH")
(10606 . "UPWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT")
(10607 . "DOWNWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT")
(10608 . "RIGHT DOUBLE ARROW WITH ROUNDED HEAD")
(10609 . "EQUALS SIGN ABOVE RIGHTWARDS ARROW")
(10610 . "TILDE OPERATOR ABOVE RIGHTWARDS ARROW")
(10611 . "LEFTWARDS ARROW ABOVE TILDE OPERATOR")
(10612 . "RIGHTWARDS ARROW ABOVE TILDE OPERATOR")
(10613 . "RIGHTWARDS ARROW ABOVE ALMOST EQUAL TO")
(10614 . "LESS-THAN ABOVE LEFTWARDS ARROW")
(10615 . "LEFTWARDS ARROW THROUGH LESS-THAN")
(10616 . "GREATER-THAN ABOVE RIGHTWARDS ARROW")
(10617 . "SUBSET ABOVE RIGHTWARDS ARROW")
(10618 . "LEFTWARDS ARROW THROUGH SUBSET")
(10619 . "SUPERSET ABOVE LEFTWARDS ARROW")
(10620 . "LEFT FISH TAIL")
(10621 . "RIGHT FISH TAIL")
(10622 . "UP FISH TAIL")
(10623 . "DOWN FISH TAIL")
(10624 . "TRIPLE VERTICAL BAR DELIMITER")
(10625 . "Z NOTATION SPOT")
(10626 . "Z NOTATION TYPE COLON")
(10627 . "LEFT WHITE CURLY BRACKET")
(10628 . "RIGHT WHITE CURLY BRACKET")
(10629 . "LEFT WHITE PARENTHESIS")
(10630 . "RIGHT WHITE PARENTHESIS")
(10631 . "Z NOTATION LEFT IMAGE BRACKET")
(10632 . "Z NOTATION RIGHT IMAGE BRACKET")
(10633 . "Z NOTATION LEFT BINDING BRACKET")
(10634 . "Z NOTATION RIGHT BINDING BRACKET")
(10635 . "LEFT SQUARE BRACKET WITH UNDERBAR")
(10636 . "RIGHT SQUARE BRACKET WITH UNDERBAR")
(10637 . "LEFT SQUARE BRACKET WITH TICK IN TOP CORNER")
(10638 . "RIGHT SQUARE BRACKET WITH TICK IN BOTTOM CORNER")
(10639 . "LEFT SQUARE BRACKET WITH TICK IN BOTTOM CORNER")
(10640 . "RIGHT SQUARE BRACKET WITH TICK IN TOP CORNER")
(10641 . "LEFT ANGLE BRACKET WITH DOT")
(10642 . "RIGHT ANGLE BRACKET WITH DOT")
(10643 . "LEFT ARC LESS-THAN BRACKET")
(10644 . "RIGHT ARC GREATER-THAN BRACKET")
(10645 . "DOUBLE LEFT ARC GREATER-THAN BRACKET")
(10646 . "DOUBLE RIGHT ARC LESS-THAN BRACKET")
(10647 . "LEFT BLACK TORTOISE SHELL BRACKET")
(10648 . "RIGHT BLACK TORTOISE SHELL BRACKET")
(10649 . "DOTTED FENCE")
(10650 . "VERTICAL ZIGZAG LINE")
(10651 . "MEASURED ANGLE OPENING LEFT")
(10652 . "RIGHT ANGLE VARIANT WITH SQUARE")
(10653 . "MEASURED RIGHT ANGLE WITH DOT")
(10654 . "ANGLE WITH S INSIDE")
(10655 . "ACUTE ANGLE")
(10656 . "SPHERICAL ANGLE OPENING LEFT")
(10657 . "SPHERICAL ANGLE OPENING UP")
(10658 . "TURNED ANGLE")
(10659 . "REVERSED ANGLE")
(10660 . "ANGLE WITH UNDERBAR")
(10661 . "REVERSED ANGLE WITH UNDERBAR")
(10662 . "OBLIQUE ANGLE OPENING UP")
(10663 . "OBLIQUE ANGLE OPENING DOWN")
(10664 . "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND RIGHT")
(10665 . "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND LEFT")
(10666 . "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND RIGHT")
(10667 . "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND LEFT")
(10668 . "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND UP")
(10669 . "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND UP")
(10670 . "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND DOWN")
(10671 . "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND DOWN")
(10672 . "REVERSED EMPTY SET")
(10673 . "EMPTY SET WITH OVERBAR")
(10674 . "EMPTY SET WITH SMALL CIRCLE ABOVE")
(10675 . "EMPTY SET WITH RIGHT ARROW ABOVE")
(10676 . "EMPTY SET WITH LEFT ARROW ABOVE")
(10677 . "CIRCLE WITH HORIZONTAL BAR")
(10678 . "CIRCLED VERTICAL BAR")
(10679 . "CIRCLED PARALLEL")
(10680 . "CIRCLED REVERSE SOLIDUS")
(10681 . "CIRCLED PERPENDICULAR")
(10682 . "CIRCLE DIVIDED BY HORIZONTAL BAR AND TOP HALF DIVIDED BY VERTICAL BAR")
(10683 . "CIRCLE WITH SUPERIMPOSED X")
(10684 . "CIRCLED ANTICLOCKWISE-ROTATED DIVISION SIGN")
(10685 . "UP ARROW THROUGH CIRCLE")
(10686 . "CIRCLED WHITE BULLET")
(10687 . "CIRCLED BULLET")
(10688 . "CIRCLED LESS-THAN")
(10689 . "CIRCLED GREATER-THAN")
(10690 . "CIRCLE WITH SMALL CIRCLE TO THE RIGHT")
(10691 . "CIRCLE WITH TWO HORIZONTAL STROKES TO THE RIGHT")
(10692 . "SQUARED RISING DIAGONAL SLASH")
(10693 . "SQUARED FALLING DIAGONAL SLASH")
(10694 . "SQUARED ASTERISK")
(10695 . "SQUARED SMALL CIRCLE")
(10696 . "SQUARED SQUARE")
(10697 . "TWO JOINED SQUARES")
(10698 . "TRIANGLE WITH DOT ABOVE")
(10699 . "TRIANGLE WITH UNDERBAR")
(10700 . "S IN TRIANGLE")
(10701 . "TRIANGLE WITH SERIFS AT BOTTOM")
(10702 . "RIGHT TRIANGLE ABOVE LEFT TRIANGLE")
(10703 . "LEFT TRIANGLE BESIDE VERTICAL BAR")
(10704 . "VERTICAL BAR BESIDE RIGHT TRIANGLE")
(10705 . "BOWTIE WITH LEFT HALF BLACK")
(10706 . "BOWTIE WITH RIGHT HALF BLACK")
(10707 . "BLACK BOWTIE")
(10708 . "TIMES WITH LEFT HALF BLACK")
(10709 . "TIMES WITH RIGHT HALF BLACK")
(10710 . "WHITE HOURGLASS")
(10711 . "BLACK HOURGLASS")
(10712 . "LEFT WIGGLY FENCE")
(10713 . "RIGHT WIGGLY FENCE")
(10714 . "LEFT DOUBLE WIGGLY FENCE")
(10715 . "RIGHT DOUBLE WIGGLY FENCE")
(10716 . "INCOMPLETE INFINITY")
(10717 . "TIE OVER INFINITY")
(10718 . "INFINITY NEGATED WITH VERTICAL BAR")
(10719 . "DOUBLE-ENDED MULTIMAP")
(10720 . "SQUARE WITH CONTOURED OUTLINE")
(10721 . "INCREASES AS")
(10722 . "SHUFFLE PRODUCT")
(10723 . "EQUALS SIGN AND SLANTED PARALLEL")
(10724 . "EQUALS SIGN AND SLANTED PARALLEL WITH TILDE ABOVE")
(10725 . "IDENTICAL TO AND SLANTED PARALLEL")
(10726 . "GLEICH STARK")
(10727 . "THERMODYNAMIC")
(10728 . "DOWN-POINTING TRIANGLE WITH LEFT HALF BLACK")
(10729 . "DOWN-POINTING TRIANGLE WITH RIGHT HALF BLACK")
(10730 . "BLACK DIAMOND WITH DOWN ARROW")
(10731 . "BLACK LOZENGE")
(10732 . "WHITE CIRCLE WITH DOWN ARROW")
(10733 . "BLACK CIRCLE WITH DOWN ARROW")
(10734 . "ERROR-BARRED WHITE SQUARE")
(10735 . "ERROR-BARRED BLACK SQUARE")
(10736 . "ERROR-BARRED WHITE DIAMOND")
(10737 . "ERROR-BARRED BLACK DIAMOND")
(10738 . "ERROR-BARRED WHITE CIRCLE")
(10739 . "ERROR-BARRED BLACK CIRCLE")
(10740 . "RULE-DELAYED")
(10741 . "REVERSE SOLIDUS OPERATOR")
(10742 . "SOLIDUS WITH OVERBAR")
(10743 . "REVERSE SOLIDUS WITH HORIZONTAL STROKE")
(10744 . "BIG SOLIDUS")
(10745 . "BIG REVERSE SOLIDUS")
(10746 . "DOUBLE PLUS")
(10747 . "TRIPLE PLUS")
(10748 . "LEFT-POINTING CURVED ANGLE BRACKET")
(10749 . "RIGHT-POINTING CURVED ANGLE BRACKET")
(10750 . "TINY")
(10751 . "MINY")
(10752 . "N-ARY CIRCLED DOT OPERATOR")
(10753 . "N-ARY CIRCLED PLUS OPERATOR")
(10754 . "N-ARY CIRCLED TIMES OPERATOR")
(10755 . "N-ARY UNION OPERATOR WITH DOT")
(10756 . "N-ARY UNION OPERATOR WITH PLUS")
(10757 . "N-ARY SQUARE INTERSECTION OPERATOR")
(10758 . "N-ARY SQUARE UNION OPERATOR")
(10759 . "TWO LOGICAL AND OPERATOR")
(10760 . "TWO LOGICAL OR OPERATOR")
(10761 . "N-ARY TIMES OPERATOR")
(10762 . "MODULO TWO SUM")
(10763 . "SUMMATION WITH INTEGRAL")
(10764 . "QUADRUPLE INTEGRAL OPERATOR")
(10765 . "FINITE PART INTEGRAL")
(10766 . "INTEGRAL WITH DOUBLE STROKE")
(10767 . "INTEGRAL AVERAGE WITH SLASH")
(10768 . "CIRCULATION FUNCTION")
(10769 . "ANTICLOCKWISE INTEGRATION")
(10770 . "LINE INTEGRATION WITH RECTANGULAR PATH AROUND POLE")
(10771 . "LINE INTEGRATION WITH SEMICIRCULAR PATH AROUND POLE")
(10772 . "LINE INTEGRATION NOT INCLUDING THE POLE")
(10773 . "INTEGRAL AROUND A POINT OPERATOR")
(10774 . "QUATERNION INTEGRAL OPERATOR")
(10775 . "INTEGRAL WITH LEFTWARDS ARROW WITH HOOK")
(10776 . "INTEGRAL WITH TIMES SIGN")
(10777 . "INTEGRAL WITH INTERSECTION")
(10778 . "INTEGRAL WITH UNION")
(10779 . "INTEGRAL WITH OVERBAR")
(10780 . "INTEGRAL WITH UNDERBAR")
(10781 . "JOIN")
(10782 . "LARGE LEFT TRIANGLE OPERATOR")
(10783 . "Z NOTATION SCHEMA COMPOSITION")
(10784 . "Z NOTATION SCHEMA PIPING")
(10785 . "Z NOTATION SCHEMA PROJECTION")
(10786 . "PLUS SIGN WITH SMALL CIRCLE ABOVE")
(10787 . "PLUS SIGN WITH CIRCUMFLEX ACCENT ABOVE")
(10788 . "PLUS SIGN WITH TILDE ABOVE")
(10789 . "PLUS SIGN WITH DOT BELOW")
(10790 . "PLUS SIGN WITH TILDE BELOW")
(10791 . "PLUS SIGN WITH SUBSCRIPT TWO")
(10792 . "PLUS SIGN WITH BLACK TRIANGLE")
(10793 . "MINUS SIGN WITH COMMA ABOVE")
(10794 . "MINUS SIGN WITH DOT BELOW")
(10795 . "MINUS SIGN WITH FALLING DOTS")
(10796 . "MINUS SIGN WITH RISING DOTS")
(10797 . "PLUS SIGN IN LEFT HALF CIRCLE")
(10798 . "PLUS SIGN IN RIGHT HALF CIRCLE")
(10799 . "VECTOR OR CROSS PRODUCT")
(10800 . "MULTIPLICATION SIGN WITH DOT ABOVE")
(10801 . "MULTIPLICATION SIGN WITH UNDERBAR")
(10802 . "SEMIDIRECT PRODUCT WITH BOTTOM CLOSED")
(10803 . "SMASH PRODUCT")
(10804 . "MULTIPLICATION SIGN IN LEFT HALF CIRCLE")
(10805 . "MULTIPLICATION SIGN IN RIGHT HALF CIRCLE")
(10806 . "CIRCLED MULTIPLICATION SIGN WITH CIRCUMFLEX ACCENT")
(10807 . "MULTIPLICATION SIGN IN DOUBLE CIRCLE")
(10808 . "CIRCLED DIVISION SIGN")
(10809 . "PLUS SIGN IN TRIANGLE")
(10810 . "MINUS SIGN IN TRIANGLE")
(10811 . "MULTIPLICATION SIGN IN TRIANGLE")
(10812 . "INTERIOR PRODUCT")
(10813 . "RIGHTHAND INTERIOR PRODUCT")
(10814 . "Z NOTATION RELATIONAL COMPOSITION")
(10815 . "AMALGAMATION OR COPRODUCT")
(10816 . "INTERSECTION WITH DOT")
(10817 . "UNION WITH MINUS SIGN")
(10818 . "UNION WITH OVERBAR")
(10819 . "INTERSECTION WITH OVERBAR")
(10820 . "INTERSECTION WITH LOGICAL AND")
(10821 . "UNION WITH LOGICAL OR")
(10822 . "UNION ABOVE INTERSECTION")
(10823 . "INTERSECTION ABOVE UNION")
(10824 . "UNION ABOVE BAR ABOVE INTERSECTION")
(10825 . "INTERSECTION ABOVE BAR ABOVE UNION")
(10826 . "UNION BESIDE AND JOINED WITH UNION")
(10827 . "INTERSECTION BESIDE AND JOINED WITH INTERSECTION")
(10828 . "CLOSED UNION WITH SERIFS")
(10829 . "CLOSED INTERSECTION WITH SERIFS")
(10830 . "DOUBLE SQUARE INTERSECTION")
(10831 . "DOUBLE SQUARE UNION")
(10832 . "CLOSED UNION WITH SERIFS AND SMASH PRODUCT")
(10833 . "LOGICAL AND WITH DOT ABOVE")
(10834 . "LOGICAL OR WITH DOT ABOVE")
(10835 . "DOUBLE LOGICAL AND")
(10836 . "DOUBLE LOGICAL OR")
(10837 . "TWO INTERSECTING LOGICAL AND")
(10838 . "TWO INTERSECTING LOGICAL OR")
(10839 . "SLOPING LARGE OR")
(10840 . "SLOPING LARGE AND")
(10841 . "LOGICAL OR OVERLAPPING LOGICAL AND")
(10842 . "LOGICAL AND WITH MIDDLE STEM")
(10843 . "LOGICAL OR WITH MIDDLE STEM")
(10844 . "LOGICAL AND WITH HORIZONTAL DASH")
(10845 . "LOGICAL OR WITH HORIZONTAL DASH")
(10846 . "LOGICAL AND WITH DOUBLE OVERBAR")
(10847 . "LOGICAL AND WITH UNDERBAR")
(10848 . "LOGICAL AND WITH DOUBLE UNDERBAR")
(10849 . "SMALL VEE WITH UNDERBAR")
(10850 . "LOGICAL OR WITH DOUBLE OVERBAR")
(10851 . "LOGICAL OR WITH DOUBLE UNDERBAR")
(10852 . "Z NOTATION DOMAIN ANTIRESTRICTION")
(10853 . "Z NOTATION RANGE ANTIRESTRICTION")
(10854 . "EQUALS SIGN WITH DOT BELOW")
(10855 . "IDENTICAL WITH DOT ABOVE")
(10856 . "TRIPLE HORIZONTAL BAR WITH DOUBLE VERTICAL STROKE")
(10857 . "TRIPLE HORIZONTAL BAR WITH TRIPLE VERTICAL STROKE")
(10858 . "TILDE OPERATOR WITH DOT ABOVE")
(10859 . "TILDE OPERATOR WITH RISING DOTS")
(10860 . "SIMILAR MINUS SIMILAR")
(10861 . "CONGRUENT WITH DOT ABOVE")
(10862 . "EQUALS WITH ASTERISK")
(10863 . "ALMOST EQUAL TO WITH CIRCUMFLEX ACCENT")
(10864 . "APPROXIMATELY EQUAL OR EQUAL TO")
(10865 . "EQUALS SIGN ABOVE PLUS SIGN")
(10866 . "PLUS SIGN ABOVE EQUALS SIGN")
(10867 . "EQUALS SIGN ABOVE TILDE OPERATOR")
(10868 . "DOUBLE COLON EQUAL")
(10869 . "TWO CONSECUTIVE EQUALS SIGNS")
(10870 . "THREE CONSECUTIVE EQUALS SIGNS")
(10871 . "EQUALS SIGN WITH TWO DOTS ABOVE AND TWO DOTS BELOW")
(10872 . "EQUIVALENT WITH FOUR DOTS ABOVE")
(10873 . "LESS-THAN WITH CIRCLE INSIDE")
(10874 . "GREATER-THAN WITH CIRCLE INSIDE")
(10875 . "LESS-THAN WITH QUESTION MARK ABOVE")
(10876 . "GREATER-THAN WITH QUESTION MARK ABOVE")
(10877 . "LESS-THAN OR SLANTED EQUAL TO")
(10878 . "GREATER-THAN OR SLANTED EQUAL TO")
(10879 . "LESS-THAN OR SLANTED EQUAL TO WITH DOT INSIDE")
(10880 . "GREATER-THAN OR SLANTED EQUAL TO WITH DOT INSIDE")
(10881 . "LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE")
(10882 . "GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE")
(10883 . "LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE RIGHT")
(10884 . "GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE LEFT")
(10885 . "LESS-THAN OR APPROXIMATE")
(10886 . "GREATER-THAN OR APPROXIMATE")
(10887 . "LESS-THAN AND SINGLE-LINE NOT EQUAL TO")
(10888 . "GREATER-THAN AND SINGLE-LINE NOT EQUAL TO")
(10889 . "LESS-THAN AND NOT APPROXIMATE")
(10890 . "GREATER-THAN AND NOT APPROXIMATE")
(10891 . "LESS-THAN ABOVE DOUBLE-LINE EQUAL ABOVE GREATER-THAN")
(10892 . "GREATER-THAN ABOVE DOUBLE-LINE EQUAL ABOVE LESS-THAN")
(10893 . "LESS-THAN ABOVE SIMILAR OR EQUAL")
(10894 . "GREATER-THAN ABOVE SIMILAR OR EQUAL")
(10895 . "LESS-THAN ABOVE SIMILAR ABOVE GREATER-THAN")
(10896 . "GREATER-THAN ABOVE SIMILAR ABOVE LESS-THAN")
(10897 . "LESS-THAN ABOVE GREATER-THAN ABOVE DOUBLE-LINE EQUAL")
(10898 . "GREATER-THAN ABOVE LESS-THAN ABOVE DOUBLE-LINE EQUAL")
(10899 . "LESS-THAN ABOVE SLANTED EQUAL ABOVE GREATER-THAN ABOVE SLANTED EQUAL")
(10900 . "GREATER-THAN ABOVE SLANTED EQUAL ABOVE LESS-THAN ABOVE SLANTED EQUAL")
(10901 . "SLANTED EQUAL TO OR LESS-THAN")
(10902 . "SLANTED EQUAL TO OR GREATER-THAN")
(10903 . "SLANTED EQUAL TO OR LESS-THAN WITH DOT INSIDE")
(10904 . "SLANTED EQUAL TO OR GREATER-THAN WITH DOT INSIDE")
(10905 . "DOUBLE-LINE EQUAL TO OR LESS-THAN")
(10906 . "DOUBLE-LINE EQUAL TO OR GREATER-THAN")
(10907 . "DOUBLE-LINE SLANTED EQUAL TO OR LESS-THAN")
(10908 . "DOUBLE-LINE SLANTED EQUAL TO OR GREATER-THAN")
(10909 . "SIMILAR OR LESS-THAN")
(10910 . "SIMILAR OR GREATER-THAN")
(10911 . "SIMILAR ABOVE LESS-THAN ABOVE EQUALS SIGN")
(10912 . "SIMILAR ABOVE GREATER-THAN ABOVE EQUALS SIGN")
(10913 . "DOUBLE NESTED LESS-THAN")
(10914 . "DOUBLE NESTED GREATER-THAN")
(10915 . "DOUBLE NESTED LESS-THAN WITH UNDERBAR")
(10916 . "GREATER-THAN OVERLAPPING LESS-THAN")
(10917 . "GREATER-THAN BESIDE LESS-THAN")
(10918 . "LESS-THAN CLOSED BY CURVE")
(10919 . "GREATER-THAN CLOSED BY CURVE")
(10920 . "LESS-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL")
(10921 . "GREATER-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL")
(10922 . "SMALLER THAN")
(10923 . "LARGER THAN")
(10924 . "SMALLER THAN OR EQUAL TO")
(10925 . "LARGER THAN OR EQUAL TO")
(10926 . "EQUALS SIGN WITH BUMPY ABOVE")
(10927 . "PRECEDES ABOVE SINGLE-LINE EQUALS SIGN")
(10928 . "SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN")
(10929 . "PRECEDES ABOVE SINGLE-LINE NOT EQUAL TO")
(10930 . "SUCCEEDS ABOVE SINGLE-LINE NOT EQUAL TO")
(10931 . "PRECEDES ABOVE EQUALS SIGN")
(10932 . "SUCCEEDS ABOVE EQUALS SIGN")
(10933 . "PRECEDES ABOVE NOT EQUAL TO")
(10934 . "SUCCEEDS ABOVE NOT EQUAL TO")
(10935 . "PRECEDES ABOVE ALMOST EQUAL TO")
(10936 . "SUCCEEDS ABOVE ALMOST EQUAL TO")
(10937 . "PRECEDES ABOVE NOT ALMOST EQUAL TO")
(10938 . "SUCCEEDS ABOVE NOT ALMOST EQUAL TO")
(10939 . "DOUBLE PRECEDES")
(10940 . "DOUBLE SUCCEEDS")
(10941 . "SUBSET WITH DOT")
(10942 . "SUPERSET WITH DOT")
(10943 . "SUBSET WITH PLUS SIGN BELOW")
(10944 . "SUPERSET WITH PLUS SIGN BELOW")
(10945 . "SUBSET WITH MULTIPLICATION SIGN BELOW")
(10946 . "SUPERSET WITH MULTIPLICATION SIGN BELOW")
(10947 . "SUBSET OF OR EQUAL TO WITH DOT ABOVE")
(10948 . "SUPERSET OF OR EQUAL TO WITH DOT ABOVE")
(10949 . "SUBSET OF ABOVE EQUALS SIGN")
(10950 . "SUPERSET OF ABOVE EQUALS SIGN")
(10951 . "SUBSET OF ABOVE TILDE OPERATOR")
(10952 . "SUPERSET OF ABOVE TILDE OPERATOR")
(10953 . "SUBSET OF ABOVE ALMOST EQUAL TO")
(10954 . "SUPERSET OF ABOVE ALMOST EQUAL TO")
(10955 . "SUBSET OF ABOVE NOT EQUAL TO")
(10956 . "SUPERSET OF ABOVE NOT EQUAL TO")
(10957 . "SQUARE LEFT OPEN BOX OPERATOR")
(10958 . "SQUARE RIGHT OPEN BOX OPERATOR")
(10959 . "CLOSED SUBSET")
(10960 . "CLOSED SUPERSET")
(10961 . "CLOSED SUBSET OR EQUAL TO")
(10962 . "CLOSED SUPERSET OR EQUAL TO")
(10963 . "SUBSET ABOVE SUPERSET")
(10964 . "SUPERSET ABOVE SUBSET")
(10965 . "SUBSET ABOVE SUBSET")
(10966 . "SUPERSET ABOVE SUPERSET")
(10967 . "SUPERSET BESIDE SUBSET")
(10968 . "SUPERSET BESIDE AND JOINED BY DASH WITH SUBSET")
(10969 . "ELEMENT OF OPENING DOWNWARDS")
(10970 . "PITCHFORK WITH TEE TOP")
(10971 . "TRANSVERSAL INTERSECTION")
(10972 . "FORKING")
(10973 . "NONFORKING")
(10974 . "SHORT LEFT TACK")
(10975 . "SHORT DOWN TACK")
(10976 . "SHORT UP TACK")
(10977 . "PERPENDICULAR WITH S")
(10978 . "VERTICAL BAR TRIPLE RIGHT TURNSTILE")
(10979 . "DOUBLE VERTICAL BAR LEFT TURNSTILE")
(10980 . "VERTICAL BAR DOUBLE LEFT TURNSTILE")
(10981 . "DOUBLE VERTICAL BAR DOUBLE LEFT TURNSTILE")
(10982 . "LONG DASH FROM LEFT MEMBER OF DOUBLE VERTICAL")
(10983 . "SHORT DOWN TACK WITH OVERBAR")
(10984 . "SHORT UP TACK WITH UNDERBAR")
(10985 . "SHORT UP TACK ABOVE SHORT DOWN TACK")
(10986 . "DOUBLE DOWN TACK")
(10987 . "DOUBLE UP TACK")
(10988 . "DOUBLE STROKE NOT SIGN")
(10989 . "REVERSED DOUBLE STROKE NOT SIGN")
(10990 . "DOES NOT DIVIDE WITH REVERSED NEGATION SLASH")
(10991 . "VERTICAL LINE WITH CIRCLE ABOVE")
(10992 . "VERTICAL LINE WITH CIRCLE BELOW")
(10993 . "DOWN TACK WITH CIRCLE BELOW")
(10994 . "PARALLEL WITH HORIZONTAL STROKE")
(10995 . "PARALLEL WITH TILDE OPERATOR")
(10996 . "TRIPLE VERTICAL BAR BINARY RELATION")
(10997 . "TRIPLE VERTICAL BAR WITH HORIZONTAL STROKE")
(10998 . "TRIPLE COLON OPERATOR")
(10999 . "TRIPLE NESTED LESS-THAN")
(11000 . "TRIPLE NESTED GREATER-THAN")
(11001 . "DOUBLE-LINE SLANTED LESS-THAN OR EQUAL TO")
(11002 . "DOUBLE-LINE SLANTED GREATER-THAN OR EQUAL TO")
(11003 . "TRIPLE SOLIDUS BINARY RELATION")
(11004 . "LARGE TRIPLE VERTICAL BAR OPERATOR")
(11005 . "DOUBLE SOLIDUS OPERATOR")
(11006 . "WHITE VERTICAL BAR")
(11007 . "N-ARY WHITE VERTICAL BAR")
(11008 . "NORTH EAST WHITE ARROW")
(11009 . "NORTH WEST WHITE ARROW")
(11010 . "SOUTH EAST WHITE ARROW")
(11011 . "SOUTH WEST WHITE ARROW")
(11012 . "LEFT RIGHT WHITE ARROW")
(11013 . "LEFTWARDS BLACK ARROW")
(11014 . "UPWARDS BLACK ARROW")
(11015 . "DOWNWARDS BLACK ARROW")
(11016 . "NORTH EAST BLACK ARROW")
(11017 . "NORTH WEST BLACK ARROW")
(11018 . "SOUTH EAST BLACK ARROW")
(11019 . "SOUTH WEST BLACK ARROW")
(11020 . "LEFT RIGHT BLACK ARROW")
(11021 . "UP DOWN BLACK ARROW")
(11022 . "RIGHTWARDS ARROW WITH TIP DOWNWARDS")
(11023 . "RIGHTWARDS ARROW WITH TIP UPWARDS")
(11024 . "LEFTWARDS ARROW WITH TIP DOWNWARDS")
(11025 . "LEFTWARDS ARROW WITH TIP UPWARDS")
(11026 . "SQUARE WITH TOP HALF BLACK")
(11027 . "SQUARE WITH BOTTOM HALF BLACK")
(11028 . "SQUARE WITH UPPER RIGHT DIAGONAL HALF BLACK")
(11029 . "SQUARE WITH LOWER LEFT DIAGONAL HALF BLACK")
(11030 . "DIAMOND WITH LEFT HALF BLACK")
(11031 . "DIAMOND WITH RIGHT HALF BLACK")
(11032 . "DIAMOND WITH TOP HALF BLACK")
(11033 . "DIAMOND WITH BOTTOM HALF BLACK")
(11034 . "DOTTED SQUARE")
(11035 . "BLACK LARGE SQUARE")
(11036 . "WHITE LARGE SQUARE")
(11037 . "BLACK VERY SMALL SQUARE")
(11038 . "WHITE VERY SMALL SQUARE")
(11039 . "BLACK PENTAGON")
(11040 . "WHITE PENTAGON")
(11041 . "WHITE HEXAGON")
(11042 . "BLACK HEXAGON")
(11043 . "HORIZONTAL BLACK HEXAGON")
(11044 . "BLACK LARGE CIRCLE")
(11045 . "BLACK MEDIUM DIAMOND")
(11046 . "WHITE MEDIUM DIAMOND")
(11047 . "BLACK MEDIUM LOZENGE")
(11048 . "WHITE MEDIUM LOZENGE")
(11049 . "BLACK SMALL DIAMOND")
(11050 . "BLACK SMALL LOZENGE")
(11051 . "WHITE SMALL LOZENGE")
(11052 . "BLACK HORIZONTAL ELLIPSE")
(11053 . "WHITE HORIZONTAL ELLIPSE")
(11054 . "BLACK VERTICAL ELLIPSE")
(11055 . "WHITE VERTICAL ELLIPSE")
(11056 . "LEFT ARROW WITH SMALL CIRCLE")
(11057 . "THREE LEFTWARDS ARROWS")
(11058 . "LEFT ARROW WITH CIRCLED PLUS")
(11059 . "LONG LEFTWARDS SQUIGGLE ARROW")
(11060 . "LEFTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE")
(11061 . "LEFTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE")
(11062 . "LEFTWARDS TWO-HEADED ARROW FROM BAR")
(11063 . "LEFTWARDS TWO-HEADED TRIPLE DASH ARROW")
(11064 . "LEFTWARDS ARROW WITH DOTTED STEM")
(11065 . "LEFTWARDS ARROW WITH TAIL WITH VERTICAL STROKE")
(11066 . "LEFTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE")
(11067 . "LEFTWARDS TWO-HEADED ARROW WITH TAIL")
(11068 . "LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE")
(11069 . "LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE")
(11070 . "LEFTWARDS ARROW THROUGH X")
(11071 . "WAVE ARROW POINTING DIRECTLY LEFT")
(11072 . "EQUALS SIGN ABOVE LEFTWARDS ARROW")
(11073 . "REVERSE TILDE OPERATOR ABOVE LEFTWARDS ARROW")
(11074 . "LEFTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO")
(11075 . "RIGHTWARDS ARROW THROUGH GREATER-THAN")
(11076 . "RIGHTWARDS ARROW THROUGH SUPERSET")
(11077 . "LEFTWARDS QUADRUPLE ARROW")
(11078 . "RIGHTWARDS QUADRUPLE ARROW")
(11079 . "REVERSE TILDE OPERATOR ABOVE RIGHTWARDS ARROW")
(11080 . "RIGHTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO")
(11081 . "TILDE OPERATOR ABOVE LEFTWARDS ARROW")
(11082 . "LEFTWARDS ARROW ABOVE ALMOST EQUAL TO")
(11083 . "LEFTWARDS ARROW ABOVE REVERSE TILDE OPERATOR")
(11084 . "RIGHTWARDS ARROW ABOVE REVERSE TILDE OPERATOR")
(11085 . "DOWNWARDS TRIANGLE-HEADED ZIGZAG ARROW")
(11086 . "SHORT SLANTED NORTH ARROW")
(11087 . "SHORT BACKSLANTED SOUTH ARROW")
(11088 . "WHITE MEDIUM STAR")
(11089 . "BLACK SMALL STAR")
(11090 . "WHITE SMALL STAR")
(11091 . "BLACK RIGHT-POINTING PENTAGON")
(11092 . "WHITE RIGHT-POINTING PENTAGON")
(11093 . "HEAVY LARGE CIRCLE")
(11094 . "HEAVY OVAL WITH OVAL INSIDE")
(11095 . "HEAVY CIRCLE WITH CIRCLE INSIDE")
(11096 . "HEAVY CIRCLE")
(11097 . "HEAVY CIRCLED SALTIRE")
(11098 . "SLANTED NORTH ARROW WITH HOOKED HEAD")
(11099 . "BACKSLANTED SOUTH ARROW WITH HOOKED TAIL")
(11100 . "SLANTED NORTH ARROW WITH HORIZONTAL TAIL")
(11101 . "BACKSLANTED SOUTH ARROW WITH HORIZONTAL TAIL")
(11102 . "BENT ARROW POINTING DOWNWARDS THEN NORTH EAST")
(11103 . "SHORT BENT ARROW POINTING DOWNWARDS THEN NORTH EAST")
(11104 . "LEFTWARDS TRIANGLE-HEADED ARROW")
(11105 . "UPWARDS TRIANGLE-HEADED ARROW")
(11106 . "RIGHTWARDS TRIANGLE-HEADED ARROW")
(11107 . "DOWNWARDS TRIANGLE-HEADED ARROW")
(11108 . "LEFT RIGHT TRIANGLE-HEADED ARROW")
(11109 . "UP DOWN TRIANGLE-HEADED ARROW")
(11110 . "NORTH WEST TRIANGLE-HEADED ARROW")
(11111 . "NORTH EAST TRIANGLE-HEADED ARROW")
(11112 . "SOUTH EAST TRIANGLE-HEADED ARROW")
(11113 . "SOUTH WEST TRIANGLE-HEADED ARROW")
(11114 . "LEFTWARDS TRIANGLE-HEADED DASHED ARROW")
(11115 . "UPWARDS TRIANGLE-HEADED DASHED ARROW")
(11116 . "RIGHTWARDS TRIANGLE-HEADED DASHED ARROW")
(11117 . "DOWNWARDS TRIANGLE-HEADED DASHED ARROW")
(11118 . "CLOCKWISE TRIANGLE-HEADED OPEN CIRCLE ARROW")
(11119 . "ANTICLOCKWISE TRIANGLE-HEADED OPEN CIRCLE ARROW")
(11120 . "LEFTWARDS TRIANGLE-HEADED ARROW TO BAR")
(11121 . "UPWARDS TRIANGLE-HEADED ARROW TO BAR")
(11122 . "RIGHTWARDS TRIANGLE-HEADED ARROW TO BAR")
(11123 . "DOWNWARDS TRIANGLE-HEADED ARROW TO BAR")
((11124 . 11126) . #f)
(11126 . "NORTH WEST TRIANGLE-HEADED ARROW TO BAR")
(11127 . "NORTH EAST TRIANGLE-HEADED ARROW TO BAR")
(11128 . "SOUTH EAST TRIANGLE-HEADED ARROW TO BAR")
(11129 . "SOUTH WEST TRIANGLE-HEADED ARROW TO BAR")
(11130 . "LEFTWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE")
(11131 . "UPWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE")
(11132 . "RIGHTWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE")
(11133 . "DOWNWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE")
(11134 . "HORIZONTAL TAB KEY")
(11135 . "VERTICAL TAB KEY")
(11136 . "LEFTWARDS TRIANGLE-HEADED ARROW OVER RIGHTWARDS TRIANGLE-HEADED ARROW")
(11137 . "UPWARDS TRIANGLE-HEADED ARROW LEFTWARDS OF DOWNWARDS TRIANGLE-HEADED ARROW")
(11138 . "RIGHTWARDS TRIANGLE-HEADED ARROW OVER LEFTWARDS TRIANGLE-HEADED ARROW")
(11139 . "DOWNWARDS TRIANGLE-HEADED ARROW LEFTWARDS OF UPWARDS TRIANGLE-HEADED ARROW")
(11140 . "LEFTWARDS TRIANGLE-HEADED PAIRED ARROWS")
(11141 . "UPWARDS TRIANGLE-HEADED PAIRED ARROWS")
(11142 . "RIGHTWARDS TRIANGLE-HEADED PAIRED ARROWS")
(11143 . "DOWNWARDS TRIANGLE-HEADED PAIRED ARROWS")
(11144 . "LEFTWARDS BLACK CIRCLED WHITE ARROW")
(11145 . "UPWARDS BLACK CIRCLED WHITE ARROW")
(11146 . "RIGHTWARDS BLACK CIRCLED WHITE ARROW")
(11147 . "DOWNWARDS BLACK CIRCLED WHITE ARROW")
(11148 . "ANTICLOCKWISE TRIANGLE-HEADED RIGHT U-SHAPED ARROW")
(11149 . "ANTICLOCKWISE TRIANGLE-HEADED BOTTOM U-SHAPED ARROW")
(11150 . "ANTICLOCKWISE TRIANGLE-HEADED LEFT U-SHAPED ARROW")
(11151 . "ANTICLOCKWISE TRIANGLE-HEADED TOP U-SHAPED ARROW")
(11152 . "RETURN LEFT")
(11153 . "RETURN RIGHT")
(11154 . "NEWLINE LEFT")
(11155 . "NEWLINE RIGHT")
(11156 . "FOUR CORNER ARROWS CIRCLING ANTICLOCKWISE")
(11157 . "RIGHTWARDS BLACK ARROW")
((11158 . 11160) . #f)
(11160 . "THREE-D TOP-LIGHTED LEFTWARDS EQUILATERAL ARROWHEAD")
(11161 . "THREE-D RIGHT-LIGHTED UPWARDS EQUILATERAL ARROWHEAD")
(11162 . "THREE-D TOP-LIGHTED RIGHTWARDS EQUILATERAL ARROWHEAD")
(11163 . "THREE-D LEFT-LIGHTED DOWNWARDS EQUILATERAL ARROWHEAD")
(11164 . "BLACK LEFTWARDS EQUILATERAL ARROWHEAD")
(11165 . "BLACK UPWARDS EQUILATERAL ARROWHEAD")
(11166 . "BLACK RIGHTWARDS EQUILATERAL ARROWHEAD")
(11167 . "BLACK DOWNWARDS EQUILATERAL ARROWHEAD")
(11168 . "DOWNWARDS TRIANGLE-HEADED ARROW WITH LONG TIP LEFTWARDS")
(11169 . "DOWNWARDS TRIANGLE-HEADED ARROW WITH LONG TIP RIGHTWARDS")
(11170 . "UPWARDS TRIANGLE-HEADED ARROW WITH LONG TIP LEFTWARDS")
(11171 . "UPWARDS TRIANGLE-HEADED ARROW WITH LONG TIP RIGHTWARDS")
(11172 . "LEFTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP UPWARDS")
(11173 . "RIGHTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP UPWARDS")
(11174 . "LEFTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP DOWNWARDS")
(11175 . "RIGHTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP DOWNWARDS")
(11176 . "BLACK CURVED DOWNWARDS AND LEFTWARDS ARROW")
(11177 . "BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW")
(11178 . "BLACK CURVED UPWARDS AND LEFTWARDS ARROW")
(11179 . "BLACK CURVED UPWARDS AND RIGHTWARDS ARROW")
(11180 . "BLACK CURVED LEFTWARDS AND UPWARDS ARROW")
(11181 . "BLACK CURVED RIGHTWARDS AND UPWARDS ARROW")
(11182 . "BLACK CURVED LEFTWARDS AND DOWNWARDS ARROW")
(11183 . "BLACK CURVED RIGHTWARDS AND DOWNWARDS ARROW")
(11184 . "RIBBON ARROW DOWN LEFT")
(11185 . "RIBBON ARROW DOWN RIGHT")
(11186 . "RIBBON ARROW UP LEFT")
(11187 . "RIBBON ARROW UP RIGHT")
(11188 . "RIBBON ARROW LEFT UP")
(11189 . "RIBBON ARROW RIGHT UP")
(11190 . "RIBBON ARROW LEFT DOWN")
(11191 . "RIBBON ARROW RIGHT DOWN")
(11192 . "UPWARDS WHITE ARROW FROM BAR WITH HORIZONTAL BAR")
(11193 . "UP ARROWHEAD IN A RECTANGLE BOX")
((11194 . 11197) . #f)
(11197 . "BALLOT BOX WITH LIGHT X")
(11198 . "CIRCLED X")
(11199 . "CIRCLED BOLD X")
(11200 . "BLACK SQUARE CENTRED")
(11201 . "BLACK DIAMOND CENTRED")
(11202 . "TURNED BLACK PENTAGON")
(11203 . "HORIZONTAL BLACK OCTAGON")
(11204 . "BLACK OCTAGON")
(11205 . "BLACK MEDIUM UP-POINTING TRIANGLE CENTRED")
(11206 . "BLACK MEDIUM DOWN-POINTING TRIANGLE CENTRED")
(11207 . "BLACK MEDIUM LEFT-POINTING TRIANGLE CENTRED")
(11208 . "BLACK MEDIUM RIGHT-POINTING TRIANGLE CENTRED")
(11209 . #f)
(11210 . "TOP HALF BLACK CIRCLE")
(11211 . "BOTTOM HALF BLACK CIRCLE")
(11212 . "LIGHT FOUR POINTED BLACK CUSP")
(11213 . "ROTATED LIGHT FOUR POINTED BLACK CUSP")
(11214 . "WHITE FOUR POINTED CUSP")
(11215 . "ROTATED WHITE FOUR POINTED CUSP")
(11216 . "SQUARE POSITION INDICATOR")
(11217 . "UNCERTAINTY SIGN")
((11218 . 11244) . #f)
(11244 . "LEFTWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS")
(11245 . "UPWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS")
(11246 . "RIGHTWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS")
(11247 . "DOWNWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS")
((11248 . 11264) . #f)
(11264 . "GLAGOLITIC CAPITAL LETTER AZU")
(11265 . "GLAGOLITIC CAPITAL LETTER BUKY")
(11266 . "GLAGOLITIC CAPITAL LETTER VEDE")
(11267 . "GLAGOLITIC CAPITAL LETTER GLAGOLI")
(11268 . "GLAGOLITIC CAPITAL LETTER DOBRO")
(11269 . "GLAGOLITIC CAPITAL LETTER YESTU")
(11270 . "GLAGOLITIC CAPITAL LETTER ZHIVETE")
(11271 . "GLAGOLITIC CAPITAL LETTER DZELO")
(11272 . "GLAGOLITIC CAPITAL LETTER ZEMLJA")
(11273 . "GLAGOLITIC CAPITAL LETTER IZHE")
(11274 . "GLAGOLITIC CAPITAL LETTER INITIAL IZHE")
(11275 . "GLAGOLITIC CAPITAL LETTER I")
(11276 . "GLAGOLITIC CAPITAL LETTER DJERVI")
(11277 . "GLAGOLITIC CAPITAL LETTER KAKO")
(11278 . "GLAGOLITIC CAPITAL LETTER LJUDIJE")
(11279 . "GLAGOLITIC CAPITAL LETTER MYSLITE")
(11280 . "GLAGOLITIC CAPITAL LETTER NASHI")
(11281 . "GLAGOLITIC CAPITAL LETTER ONU")
(11282 . "GLAGOLITIC CAPITAL LETTER POKOJI")
(11283 . "GLAGOLITIC CAPITAL LETTER RITSI")
(11284 . "GLAGOLITIC CAPITAL LETTER SLOVO")
(11285 . "GLAGOLITIC CAPITAL LETTER TVRIDO")
(11286 . "GLAGOLITIC CAPITAL LETTER UKU")
(11287 . "GLAGOLITIC CAPITAL LETTER FRITU")
(11288 . "GLAGOLITIC CAPITAL LETTER HERU")
(11289 . "GLAGOLITIC CAPITAL LETTER OTU")
(11290 . "GLAGOLITIC CAPITAL LETTER PE")
(11291 . "GLAGOLITIC CAPITAL LETTER SHTA")
(11292 . "GLAGOLITIC CAPITAL LETTER TSI")
(11293 . "GLAGOLITIC CAPITAL LETTER CHRIVI")
(11294 . "GLAGOLITIC CAPITAL LETTER SHA")
(11295 . "GLAGOLITIC CAPITAL LETTER YERU")
(11296 . "GLAGOLITIC CAPITAL LETTER YERI")
(11297 . "GLAGOLITIC CAPITAL LETTER YATI")
(11298 . "GLAGOLITIC CAPITAL LETTER SPIDERY HA")
(11299 . "GLAGOLITIC CAPITAL LETTER YU")
(11300 . "GLAGOLITIC CAPITAL LETTER SMALL YUS")
(11301 . "GLAGOLITIC CAPITAL LETTER SMALL YUS WITH TAIL")
(11302 . "GLAGOLITIC CAPITAL LETTER YO")
(11303 . "GLAGOLITIC CAPITAL LETTER IOTATED SMALL YUS")
(11304 . "GLAGOLITIC CAPITAL LETTER BIG YUS")
(11305 . "GLAGOLITIC CAPITAL LETTER IOTATED BIG YUS")
(11306 . "GLAGOLITIC CAPITAL LETTER FITA")
(11307 . "GLAGOLITIC CAPITAL LETTER IZHITSA")
(11308 . "GLAGOLITIC CAPITAL LETTER SHTAPIC")
(11309 . "GLAGOLITIC CAPITAL LETTER TROKUTASTI A")
(11310 . "GLAGOLITIC CAPITAL LETTER LATINATE MYSLITE")
(11311 . #f)
(11312 . "GLAGOLITIC SMALL LETTER AZU")
(11313 . "GLAGOLITIC SMALL LETTER BUKY")
(11314 . "GLAGOLITIC SMALL LETTER VEDE")
(11315 . "GLAGOLITIC SMALL LETTER GLAGOLI")
(11316 . "GLAGOLITIC SMALL LETTER DOBRO")
(11317 . "GLAGOLITIC SMALL LETTER YESTU")
(11318 . "GLAGOLITIC SMALL LETTER ZHIVETE")
(11319 . "GLAGOLITIC SMALL LETTER DZELO")
(11320 . "GLAGOLITIC SMALL LETTER ZEMLJA")
(11321 . "GLAGOLITIC SMALL LETTER IZHE")
(11322 . "GLAGOLITIC SMALL LETTER INITIAL IZHE")
(11323 . "GLAGOLITIC SMALL LETTER I")
(11324 . "GLAGOLITIC SMALL LETTER DJERVI")
(11325 . "GLAGOLITIC SMALL LETTER KAKO")
(11326 . "GLAGOLITIC SMALL LETTER LJUDIJE")
(11327 . "GLAGOLITIC SMALL LETTER MYSLITE")
(11328 . "GLAGOLITIC SMALL LETTER NASHI")
(11329 . "GLAGOLITIC SMALL LETTER ONU")
(11330 . "GLAGOLITIC SMALL LETTER POKOJI")
(11331 . "GLAGOLITIC SMALL LETTER RITSI")
(11332 . "GLAGOLITIC SMALL LETTER SLOVO")
(11333 . "GLAGOLITIC SMALL LETTER TVRIDO")
(11334 . "GLAGOLITIC SMALL LETTER UKU")
(11335 . "GLAGOLITIC SMALL LETTER FRITU")
(11336 . "GLAGOLITIC SMALL LETTER HERU")
(11337 . "GLAGOLITIC SMALL LETTER OTU")
(11338 . "GLAGOLITIC SMALL LETTER PE")
(11339 . "GLAGOLITIC SMALL LETTER SHTA")
(11340 . "GLAGOLITIC SMALL LETTER TSI")
(11341 . "GLAGOLITIC SMALL LETTER CHRIVI")
(11342 . "GLAGOLITIC SMALL LETTER SHA")
(11343 . "GLAGOLITIC SMALL LETTER YERU")
(11344 . "GLAGOLITIC SMALL LETTER YERI")
(11345 . "GLAGOLITIC SMALL LETTER YATI")
(11346 . "GLAGOLITIC SMALL LETTER SPIDERY HA")
(11347 . "GLAGOLITIC SMALL LETTER YU")
(11348 . "GLAGOLITIC SMALL LETTER SMALL YUS")
(11349 . "GLAGOLITIC SMALL LETTER SMALL YUS WITH TAIL")
(11350 . "GLAGOLITIC SMALL LETTER YO")
(11351 . "GLAGOLITIC SMALL LETTER IOTATED SMALL YUS")
(11352 . "GLAGOLITIC SMALL LETTER BIG YUS")
(11353 . "GLAGOLITIC SMALL LETTER IOTATED BIG YUS")
(11354 . "GLAGOLITIC SMALL LETTER FITA")
(11355 . "GLAGOLITIC SMALL LETTER IZHITSA")
(11356 . "GLAGOLITIC SMALL LETTER SHTAPIC")
(11357 . "GLAGOLITIC SMALL LETTER TROKUTASTI A")
(11358 . "GLAGOLITIC SMALL LETTER LATINATE MYSLITE")
(11359 . #f)
(11360 . "LATIN CAPITAL LETTER L WITH DOUBLE BAR")
(11361 . "LATIN SMALL LETTER L WITH DOUBLE BAR")
(11362 . "LATIN CAPITAL LETTER L WITH MIDDLE TILDE")
(11363 . "LATIN CAPITAL LETTER P WITH STROKE")
(11364 . "LATIN CAPITAL LETTER R WITH TAIL")
(11365 . "LATIN SMALL LETTER A WITH STROKE")
(11366 . "LATIN SMALL LETTER T WITH DIAGONAL STROKE")
(11367 . "LATIN CAPITAL LETTER H WITH DESCENDER")
(11368 . "LATIN SMALL LETTER H WITH DESCENDER")
(11369 . "LATIN CAPITAL LETTER K WITH DESCENDER")
(11370 . "LATIN SMALL LETTER K WITH DESCENDER")
(11371 . "LATIN CAPITAL LETTER Z WITH DESCENDER")
(11372 . "LATIN SMALL LETTER Z WITH DESCENDER")
(11373 . "LATIN CAPITAL LETTER ALPHA")
(11374 . "LATIN CAPITAL LETTER M WITH HOOK")
(11375 . "LATIN CAPITAL LETTER TURNED A")
(11376 . "LATIN CAPITAL LETTER TURNED ALPHA")
(11377 . "LATIN SMALL LETTER V WITH RIGHT HOOK")
(11378 . "LATIN CAPITAL LETTER W WITH HOOK")
(11379 . "LATIN SMALL LETTER W WITH HOOK")
(11380 . "LATIN SMALL LETTER V WITH CURL")
(11381 . "LATIN CAPITAL LETTER HALF H")
(11382 . "LATIN SMALL LETTER HALF H")
(11383 . "LATIN SMALL LETTER TAILLESS PHI")
(11384 . "LATIN SMALL LETTER E WITH NOTCH")
(11385 . "LATIN SMALL LETTER TURNED R WITH TAIL")
(11386 . "LATIN SMALL LETTER O WITH LOW RING INSIDE")
(11387 . "LATIN LETTER SMALL CAPITAL TURNED E")
(11388 . "LATIN SUBSCRIPT SMALL LETTER J")
(11389 . "MODIFIER LETTER CAPITAL V")
(11390 . "LATIN CAPITAL LETTER S WITH SWASH TAIL")
(11391 . "LATIN CAPITAL LETTER Z WITH SWASH TAIL")
(11392 . "COPTIC CAPITAL LETTER ALFA")
(11393 . "COPTIC SMALL LETTER ALFA")
(11394 . "COPTIC CAPITAL LETTER VIDA")
(11395 . "COPTIC SMALL LETTER VIDA")
(11396 . "COPTIC CAPITAL LETTER GAMMA")
(11397 . "COPTIC SMALL LETTER GAMMA")
(11398 . "COPTIC CAPITAL LETTER DALDA")
(11399 . "COPTIC SMALL LETTER DALDA")
(11400 . "COPTIC CAPITAL LETTER EIE")
(11401 . "COPTIC SMALL LETTER EIE")
(11402 . "COPTIC CAPITAL LETTER SOU")
(11403 . "COPTIC SMALL LETTER SOU")
(11404 . "COPTIC CAPITAL LETTER ZATA")
(11405 . "COPTIC SMALL LETTER ZATA")
(11406 . "COPTIC CAPITAL LETTER HATE")
(11407 . "COPTIC SMALL LETTER HATE")
(11408 . "COPTIC CAPITAL LETTER THETHE")
(11409 . "COPTIC SMALL LETTER THETHE")
(11410 . "COPTIC CAPITAL LETTER IAUDA")
(11411 . "COPTIC SMALL LETTER IAUDA")
(11412 . "COPTIC CAPITAL LETTER KAPA")
(11413 . "COPTIC SMALL LETTER KAPA")
(11414 . "COPTIC CAPITAL LETTER LAULA")
(11415 . "COPTIC SMALL LETTER LAULA")
(11416 . "COPTIC CAPITAL LETTER MI")
(11417 . "COPTIC SMALL LETTER MI")
(11418 . "COPTIC CAPITAL LETTER NI")
(11419 . "COPTIC SMALL LETTER NI")
(11420 . "COPTIC CAPITAL LETTER KSI")
(11421 . "COPTIC SMALL LETTER KSI")
(11422 . "COPTIC CAPITAL LETTER O")
(11423 . "COPTIC SMALL LETTER O")
(11424 . "COPTIC CAPITAL LETTER PI")
(11425 . "COPTIC SMALL LETTER PI")
(11426 . "COPTIC CAPITAL LETTER RO")
(11427 . "COPTIC SMALL LETTER RO")
(11428 . "COPTIC CAPITAL LETTER SIMA")
(11429 . "COPTIC SMALL LETTER SIMA")
(11430 . "COPTIC CAPITAL LETTER TAU")
(11431 . "COPTIC SMALL LETTER TAU")
(11432 . "COPTIC CAPITAL LETTER UA")
(11433 . "COPTIC SMALL LETTER UA")
(11434 . "COPTIC CAPITAL LETTER FI")
(11435 . "COPTIC SMALL LETTER FI")
(11436 . "COPTIC CAPITAL LETTER KHI")
(11437 . "COPTIC SMALL LETTER KHI")
(11438 . "COPTIC CAPITAL LETTER PSI")
(11439 . "COPTIC SMALL LETTER PSI")
(11440 . "COPTIC CAPITAL LETTER OOU")
(11441 . "COPTIC SMALL LETTER OOU")
(11442 . "COPTIC CAPITAL LETTER DIALECT-P ALEF")
(11443 . "COPTIC SMALL LETTER DIALECT-P ALEF")
(11444 . "COPTIC CAPITAL LETTER OLD COPTIC AIN")
(11445 . "COPTIC SMALL LETTER OLD COPTIC AIN")
(11446 . "COPTIC CAPITAL LETTER CRYPTOGRAMMIC EIE")
(11447 . "COPTIC SMALL LETTER CRYPTOGRAMMIC EIE")
(11448 . "COPTIC CAPITAL LETTER DIALECT-P KAPA")
(11449 . "COPTIC SMALL LETTER DIALECT-P KAPA")
(11450 . "COPTIC CAPITAL LETTER DIALECT-P NI")
(11451 . "COPTIC SMALL LETTER DIALECT-P NI")
(11452 . "COPTIC CAPITAL LETTER CRYPTOGRAMMIC NI")
(11453 . "COPTIC SMALL LETTER CRYPTOGRAMMIC NI")
(11454 . "COPTIC CAPITAL LETTER OLD COPTIC OOU")
(11455 . "COPTIC SMALL LETTER OLD COPTIC OOU")
(11456 . "COPTIC CAPITAL LETTER SAMPI")
(11457 . "COPTIC SMALL LETTER SAMPI")
(11458 . "COPTIC CAPITAL LETTER CROSSED SHEI")
(11459 . "COPTIC SMALL LETTER CROSSED SHEI")
(11460 . "COPTIC CAPITAL LETTER OLD COPTIC SHEI")
(11461 . "COPTIC SMALL LETTER OLD COPTIC SHEI")
(11462 . "COPTIC CAPITAL LETTER OLD COPTIC ESH")
(11463 . "COPTIC SMALL LETTER OLD COPTIC ESH")
(11464 . "COPTIC CAPITAL LETTER AKHMIMIC KHEI")
(11465 . "COPTIC SMALL LETTER AKHMIMIC KHEI")
(11466 . "COPTIC CAPITAL LETTER DIALECT-P HORI")
(11467 . "COPTIC SMALL LETTER DIALECT-P HORI")
(11468 . "COPTIC CAPITAL LETTER OLD COPTIC HORI")
(11469 . "COPTIC SMALL LETTER OLD COPTIC HORI")
(11470 . "COPTIC CAPITAL LETTER OLD COPTIC HA")
(11471 . "COPTIC SMALL LETTER OLD COPTIC HA")
(11472 . "COPTIC CAPITAL LETTER L-SHAPED HA")
(11473 . "COPTIC SMALL LETTER L-SHAPED HA")
(11474 . "COPTIC CAPITAL LETTER OLD COPTIC HEI")
(11475 . "COPTIC SMALL LETTER OLD COPTIC HEI")
(11476 . "COPTIC CAPITAL LETTER OLD COPTIC HAT")
(11477 . "COPTIC SMALL LETTER OLD COPTIC HAT")
(11478 . "COPTIC CAPITAL LETTER OLD COPTIC GANGIA")
(11479 . "COPTIC SMALL LETTER OLD COPTIC GANGIA")
(11480 . "COPTIC CAPITAL LETTER OLD COPTIC DJA")
(11481 . "COPTIC SMALL LETTER OLD COPTIC DJA")
(11482 . "COPTIC CAPITAL LETTER OLD COPTIC SHIMA")
(11483 . "COPTIC SMALL LETTER OLD COPTIC SHIMA")
(11484 . "COPTIC CAPITAL LETTER OLD NUBIAN SHIMA")
(11485 . "COPTIC SMALL LETTER OLD NUBIAN SHIMA")
(11486 . "COPTIC CAPITAL LETTER OLD NUBIAN NGI")
(11487 . "COPTIC SMALL LETTER OLD NUBIAN NGI")
(11488 . "COPTIC CAPITAL LETTER OLD NUBIAN NYI")
(11489 . "COPTIC SMALL LETTER OLD NUBIAN NYI")
(11490 . "COPTIC CAPITAL LETTER OLD NUBIAN WAU")
(11491 . "COPTIC SMALL LETTER OLD NUBIAN WAU")
(11492 . "COPTIC SYMBOL KAI")
(11493 . "COPTIC SYMBOL MI RO")
(11494 . "COPTIC SYMBOL PI RO")
(11495 . "COPTIC SYMBOL STAUROS")
(11496 . "COPTIC SYMBOL TAU RO")
(11497 . "COPTIC SYMBOL KHI RO")
(11498 . "COPTIC SYMBOL SHIMA SIMA")
(11499 . "COPTIC CAPITAL LETTER CRYPTOGRAMMIC SHEI")
(11500 . "COPTIC SMALL LETTER CRYPTOGRAMMIC SHEI")
(11501 . "COPTIC CAPITAL LETTER CRYPTOGRAMMIC GANGIA")
(11502 . "COPTIC SMALL LETTER CRYPTOGRAMMIC GANGIA")
(11503 . "COPTIC COMBINING NI ABOVE")
(11504 . "COPTIC COMBINING SPIRITUS ASPER")
(11505 . "COPTIC COMBINING SPIRITUS LENIS")
(11506 . "COPTIC CAPITAL LETTER BOHAIRIC KHEI")
(11507 . "COPTIC SMALL LETTER BOHAIRIC KHEI")
((11508 . 11513) . #f)
(11513 . "COPTIC OLD NUBIAN FULL STOP")
(11514 . "COPTIC OLD NUBIAN DIRECT QUESTION MARK")
(11515 . "COPTIC OLD NUBIAN INDIRECT QUESTION MARK")
(11516 . "COPTIC OLD NUBIAN VERSE DIVIDER")
(11517 . "COPTIC FRACTION ONE HALF")
(11518 . "COPTIC FULL STOP")
(11519 . "COPTIC MORPHOLOGICAL DIVIDER")
(11520 . "GEORGIAN SMALL LETTER AN")
(11521 . "GEORGIAN SMALL LETTER BAN")
(11522 . "GEORGIAN SMALL LETTER GAN")
(11523 . "GEORGIAN SMALL LETTER DON")
(11524 . "GEORGIAN SMALL LETTER EN")
(11525 . "GEORGIAN SMALL LETTER VIN")
(11526 . "GEORGIAN SMALL LETTER ZEN")
(11527 . "GEORGIAN SMALL LETTER TAN")
(11528 . "GEORGIAN SMALL LETTER IN")
(11529 . "GEORGIAN SMALL LETTER KAN")
(11530 . "GEORGIAN SMALL LETTER LAS")
(11531 . "GEORGIAN SMALL LETTER MAN")
(11532 . "GEORGIAN SMALL LETTER NAR")
(11533 . "GEORGIAN SMALL LETTER ON")
(11534 . "GEORGIAN SMALL LETTER PAR")
(11535 . "GEORGIAN SMALL LETTER ZHAR")
(11536 . "GEORGIAN SMALL LETTER RAE")
(11537 . "GEORGIAN SMALL LETTER SAN")
(11538 . "GEORGIAN SMALL LETTER TAR")
(11539 . "GEORGIAN SMALL LETTER UN")
(11540 . "GEORGIAN SMALL LETTER PHAR")
(11541 . "GEORGIAN SMALL LETTER KHAR")
(11542 . "GEORGIAN SMALL LETTER GHAN")
(11543 . "GEORGIAN SMALL LETTER QAR")
(11544 . "GEORGIAN SMALL LETTER SHIN")
(11545 . "GEORGIAN SMALL LETTER CHIN")
(11546 . "GEORGIAN SMALL LETTER CAN")
(11547 . "GEORGIAN SMALL LETTER JIL")
(11548 . "GEORGIAN SMALL LETTER CIL")
(11549 . "GEORGIAN SMALL LETTER CHAR")
(11550 . "GEORGIAN SMALL LETTER XAN")
(11551 . "GEORGIAN SMALL LETTER JHAN")
(11552 . "GEORGIAN SMALL LETTER HAE")
(11553 . "GEORGIAN SMALL LETTER HE")
(11554 . "GEORGIAN SMALL LETTER HIE")
(11555 . "GEORGIAN SMALL LETTER WE")
(11556 . "GEORGIAN SMALL LETTER HAR")
(11557 . "GEORGIAN SMALL LETTER HOE")
(11558 . #f)
(11559 . "GEORGIAN SMALL LETTER YN")
((11560 . 11565) . #f)
(11565 . "GEORGIAN SMALL LETTER AEN")
((11566 . 11568) . #f)
(11568 . "TIFINAGH LETTER YA")
(11569 . "TIFINAGH LETTER YAB")
(11570 . "TIFINAGH LETTER YABH")
(11571 . "TIFINAGH LETTER YAG")
(11572 . "TIFINAGH LETTER YAGHH")
(11573 . "TIFINAGH LETTER BERBER ACADEMY YAJ")
(11574 . "TIFINAGH LETTER YAJ")
(11575 . "TIFINAGH LETTER YAD")
(11576 . "TIFINAGH LETTER YADH")
(11577 . "TIFINAGH LETTER YADD")
(11578 . "TIFINAGH LETTER YADDH")
(11579 . "TIFINAGH LETTER YEY")
(11580 . "TIFINAGH LETTER YAF")
(11581 . "TIFINAGH LETTER YAK")
(11582 . "TIFINAGH LETTER TUAREG YAK")
(11583 . "TIFINAGH LETTER YAKHH")
(11584 . "TIFINAGH LETTER YAH")
(11585 . "TIFINAGH LETTER BERBER ACADEMY YAH")
(11586 . "TIFINAGH LETTER TUAREG YAH")
(11587 . "TIFINAGH LETTER YAHH")
(11588 . "TIFINAGH LETTER YAA")
(11589 . "TIFINAGH LETTER YAKH")
(11590 . "TIFINAGH LETTER TUAREG YAKH")
(11591 . "TIFINAGH LETTER YAQ")
(11592 . "TIFINAGH LETTER TUAREG YAQ")
(11593 . "TIFINAGH LETTER YI")
(11594 . "TIFINAGH LETTER YAZH")
(11595 . "TIFINAGH LETTER AHAGGAR YAZH")
(11596 . "TIFINAGH LETTER TUAREG YAZH")
(11597 . "TIFINAGH LETTER YAL")
(11598 . "TIFINAGH LETTER YAM")
(11599 . "TIFINAGH LETTER YAN")
(11600 . "TIFINAGH LETTER TUAREG YAGN")
(11601 . "TIFINAGH LETTER TUAREG YANG")
(11602 . "TIFINAGH LETTER YAP")
(11603 . "TIFINAGH LETTER YU")
(11604 . "TIFINAGH LETTER YAR")
(11605 . "TIFINAGH LETTER YARR")
(11606 . "TIFINAGH LETTER YAGH")
(11607 . "TIFINAGH LETTER TUAREG YAGH")
(11608 . "TIFINAGH LETTER AYER YAGH")
(11609 . "TIFINAGH LETTER YAS")
(11610 . "TIFINAGH LETTER YASS")
(11611 . "TIFINAGH LETTER YASH")
(11612 . "TIFINAGH LETTER YAT")
(11613 . "TIFINAGH LETTER YATH")
(11614 . "TIFINAGH LETTER YACH")
(11615 . "TIFINAGH LETTER YATT")
(11616 . "TIFINAGH LETTER YAV")
(11617 . "TIFINAGH LETTER YAW")
(11618 . "TIFINAGH LETTER YAY")
(11619 . "TIFINAGH LETTER YAZ")
(11620 . "TIFINAGH LETTER TAWELLEMET YAZ")
(11621 . "TIFINAGH LETTER YAZZ")
(11622 . "TIFINAGH LETTER YE")
(11623 . "TIFINAGH LETTER YO")
((11624 . 11631) . #f)
(11631 . "TIFINAGH MODIFIER LETTER LABIALIZATION MARK")
(11632 . "TIFINAGH SEPARATOR MARK")
((11633 . 11647) . #f)
(11647 . "TIFINAGH CONSONANT JOINER")
(11648 . "ETHIOPIC SYLLABLE LOA")
(11649 . "ETHIOPIC SYLLABLE MOA")
(11650 . "ETHIOPIC SYLLABLE ROA")
(11651 . "ETHIOPIC SYLLABLE SOA")
(11652 . "ETHIOPIC SYLLABLE SHOA")
(11653 . "ETHIOPIC SYLLABLE BOA")
(11654 . "ETHIOPIC SYLLABLE TOA")
(11655 . "ETHIOPIC SYLLABLE COA")
(11656 . "ETHIOPIC SYLLABLE NOA")
(11657 . "ETHIOPIC SYLLABLE NYOA")
(11658 . "ETHIOPIC SYLLABLE GLOTTAL OA")
(11659 . "ETHIOPIC SYLLABLE ZOA")
(11660 . "ETHIOPIC SYLLABLE DOA")
(11661 . "ETHIOPIC SYLLABLE DDOA")
(11662 . "ETHIOPIC SYLLABLE JOA")
(11663 . "ETHIOPIC SYLLABLE THOA")
(11664 . "ETHIOPIC SYLLABLE CHOA")
(11665 . "ETHIOPIC SYLLABLE PHOA")
(11666 . "ETHIOPIC SYLLABLE POA")
(11667 . "ETHIOPIC SYLLABLE GGWA")
(11668 . "ETHIOPIC SYLLABLE GGWI")
(11669 . "ETHIOPIC SYLLABLE GGWEE")
(11670 . "ETHIOPIC SYLLABLE GGWE")
((11671 . 11680) . #f)
(11680 . "ETHIOPIC SYLLABLE SSA")
(11681 . "ETHIOPIC SYLLABLE SSU")
(11682 . "ETHIOPIC SYLLABLE SSI")
(11683 . "ETHIOPIC SYLLABLE SSAA")
(11684 . "ETHIOPIC SYLLABLE SSEE")
(11685 . "ETHIOPIC SYLLABLE SSE")
(11686 . "ETHIOPIC SYLLABLE SSO")
(11687 . #f)
(11688 . "ETHIOPIC SYLLABLE CCA")
(11689 . "ETHIOPIC SYLLABLE CCU")
(11690 . "ETHIOPIC SYLLABLE CCI")
(11691 . "ETHIOPIC SYLLABLE CCAA")
(11692 . "ETHIOPIC SYLLABLE CCEE")
(11693 . "ETHIOPIC SYLLABLE CCE")
(11694 . "ETHIOPIC SYLLABLE CCO")
(11695 . #f)
(11696 . "ETHIOPIC SYLLABLE ZZA")
(11697 . "ETHIOPIC SYLLABLE ZZU")
(11698 . "ETHIOPIC SYLLABLE ZZI")
(11699 . "ETHIOPIC SYLLABLE ZZAA")
(11700 . "ETHIOPIC SYLLABLE ZZEE")
(11701 . "ETHIOPIC SYLLABLE ZZE")
(11702 . "ETHIOPIC SYLLABLE ZZO")
(11703 . #f)
(11704 . "ETHIOPIC SYLLABLE CCHA")
(11705 . "ETHIOPIC SYLLABLE CCHU")
(11706 . "ETHIOPIC SYLLABLE CCHI")
(11707 . "ETHIOPIC SYLLABLE CCHAA")
(11708 . "ETHIOPIC SYLLABLE CCHEE")
(11709 . "ETHIOPIC SYLLABLE CCHE")
(11710 . "ETHIOPIC SYLLABLE CCHO")
(11711 . #f)
(11712 . "ETHIOPIC SYLLABLE QYA")
(11713 . "ETHIOPIC SYLLABLE QYU")
(11714 . "ETHIOPIC SYLLABLE QYI")
(11715 . "ETHIOPIC SYLLABLE QYAA")
(11716 . "ETHIOPIC SYLLABLE QYEE")
(11717 . "ETHIOPIC SYLLABLE QYE")
(11718 . "ETHIOPIC SYLLABLE QYO")
(11719 . #f)
(11720 . "ETHIOPIC SYLLABLE KYA")
(11721 . "ETHIOPIC SYLLABLE KYU")
(11722 . "ETHIOPIC SYLLABLE KYI")
(11723 . "ETHIOPIC SYLLABLE KYAA")
(11724 . "ETHIOPIC SYLLABLE KYEE")
(11725 . "ETHIOPIC SYLLABLE KYE")
(11726 . "ETHIOPIC SYLLABLE KYO")
(11727 . #f)
(11728 . "ETHIOPIC SYLLABLE XYA")
(11729 . "ETHIOPIC SYLLABLE XYU")
(11730 . "ETHIOPIC SYLLABLE XYI")
(11731 . "ETHIOPIC SYLLABLE XYAA")
(11732 . "ETHIOPIC SYLLABLE XYEE")
(11733 . "ETHIOPIC SYLLABLE XYE")
(11734 . "ETHIOPIC SYLLABLE XYO")
(11735 . #f)
(11736 . "ETHIOPIC SYLLABLE GYA")
(11737 . "ETHIOPIC SYLLABLE GYU")
(11738 . "ETHIOPIC SYLLABLE GYI")
(11739 . "ETHIOPIC SYLLABLE GYAA")
(11740 . "ETHIOPIC SYLLABLE GYEE")
(11741 . "ETHIOPIC SYLLABLE GYE")
(11742 . "ETHIOPIC SYLLABLE GYO")
(11743 . #f)
(11744 . "COMBINING CYRILLIC LETTER BE")
(11745 . "COMBINING CYRILLIC LETTER VE")
(11746 . "COMBINING CYRILLIC LETTER GHE")
(11747 . "COMBINING CYRILLIC LETTER DE")
(11748 . "COMBINING CYRILLIC LETTER ZHE")
(11749 . "COMBINING CYRILLIC LETTER ZE")
(11750 . "COMBINING CYRILLIC LETTER KA")
(11751 . "COMBINING CYRILLIC LETTER EL")
(11752 . "COMBINING CYRILLIC LETTER EM")
(11753 . "COMBINING CYRILLIC LETTER EN")
(11754 . "COMBINING CYRILLIC LETTER O")
(11755 . "COMBINING CYRILLIC LETTER PE")
(11756 . "COMBINING CYRILLIC LETTER ER")
(11757 . "COMBINING CYRILLIC LETTER ES")
(11758 . "COMBINING CYRILLIC LETTER TE")
(11759 . "COMBINING CYRILLIC LETTER HA")
(11760 . "COMBINING CYRILLIC LETTER TSE")
(11761 . "COMBINING CYRILLIC LETTER CHE")
(11762 . "COMBINING CYRILLIC LETTER SHA")
(11763 . "COMBINING CYRILLIC LETTER SHCHA")
(11764 . "COMBINING CYRILLIC LETTER FITA")
(11765 . "COMBINING CYRILLIC LETTER ES-TE")
(11766 . "COMBINING CYRILLIC LETTER A")
(11767 . "COMBINING CYRILLIC LETTER IE")
(11768 . "COMBINING CYRILLIC LETTER DJERV")
(11769 . "COMBINING CYRILLIC LETTER MONOGRAPH UK")
(11770 . "COMBINING CYRILLIC LETTER YAT")
(11771 . "COMBINING CYRILLIC LETTER YU")
(11772 . "COMBINING CYRILLIC LETTER IOTIFIED A")
(11773 . "COMBINING CYRILLIC LETTER LITTLE YUS")
(11774 . "COMBINING CYRILLIC LETTER BIG YUS")
(11775 . "COMBINING CYRILLIC LETTER IOTIFIED BIG YUS")
(11776 . "RIGHT ANGLE SUBSTITUTION MARKER")
(11777 . "RIGHT ANGLE DOTTED SUBSTITUTION MARKER")
(11778 . "LEFT SUBSTITUTION BRACKET")
(11779 . "RIGHT SUBSTITUTION BRACKET")
(11780 . "LEFT DOTTED SUBSTITUTION BRACKET")
(11781 . "RIGHT DOTTED SUBSTITUTION BRACKET")
(11782 . "RAISED INTERPOLATION MARKER")
(11783 . "RAISED DOTTED INTERPOLATION MARKER")
(11784 . "DOTTED TRANSPOSITION MARKER")
(11785 . "LEFT TRANSPOSITION BRACKET")
(11786 . "RIGHT TRANSPOSITION BRACKET")
(11787 . "RAISED SQUARE")
(11788 . "LEFT RAISED OMISSION BRACKET")
(11789 . "RIGHT RAISED OMISSION BRACKET")
(11790 . "EDITORIAL CORONIS")
(11791 . "PARAGRAPHOS")
(11792 . "FORKED PARAGRAPHOS")
(11793 . "REVERSED FORKED PARAGRAPHOS")
(11794 . "HYPODIASTOLE")
(11795 . "DOTTED OBELOS")
(11796 . "DOWNWARDS ANCORA")
(11797 . "UPWARDS ANCORA")
(11798 . "DOTTED RIGHT-POINTING ANGLE")
(11799 . "DOUBLE OBLIQUE HYPHEN")
(11800 . "INVERTED INTERROBANG")
(11801 . "PALM BRANCH")
(11802 . "HYPHEN WITH DIAERESIS")
(11803 . "TILDE WITH RING ABOVE")
(11804 . "LEFT LOW PARAPHRASE BRACKET")
(11805 . "RIGHT LOW PARAPHRASE BRACKET")
(11806 . "TILDE WITH DOT ABOVE")
(11807 . "TILDE WITH DOT BELOW")
(11808 . "LEFT VERTICAL BAR WITH QUILL")
(11809 . "RIGHT VERTICAL BAR WITH QUILL")
(11810 . "TOP LEFT HALF BRACKET")
(11811 . "TOP RIGHT HALF BRACKET")
(11812 . "BOTTOM LEFT HALF BRACKET")
(11813 . "BOTTOM RIGHT HALF BRACKET")
(11814 . "LEFT SIDEWAYS U BRACKET")
(11815 . "RIGHT SIDEWAYS U BRACKET")
(11816 . "LEFT DOUBLE PARENTHESIS")
(11817 . "RIGHT DOUBLE PARENTHESIS")
(11818 . "TWO DOTS OVER ONE DOT PUNCTUATION")
(11819 . "ONE DOT OVER TWO DOTS PUNCTUATION")
(11820 . "SQUARED FOUR DOT PUNCTUATION")
(11821 . "FIVE DOT MARK")
(11822 . "REVERSED QUESTION MARK")
(11823 . "VERTICAL TILDE")
(11824 . "RING POINT")
(11825 . "WORD SEPARATOR MIDDLE DOT")
(11826 . "TURNED COMMA")
(11827 . "RAISED DOT")
(11828 . "RAISED COMMA")
(11829 . "TURNED SEMICOLON")
(11830 . "DAGGER WITH LEFT GUARD")
(11831 . "DAGGER WITH RIGHT GUARD")
(11832 . "TURNED DAGGER")
(11833 . "TOP HALF SECTION SIGN")
(11834 . "TWO-EM DASH")
(11835 . "THREE-EM DASH")
(11836 . "STENOGRAPHIC FULL STOP")
(11837 . "VERTICAL SIX DOTS")
(11838 . "WIGGLY VERTICAL LINE")
(11839 . "CAPITULUM")
(11840 . "DOUBLE HYPHEN")
(11841 . "REVERSED COMMA")
(11842 . "DOUBLE LOW-REVERSED-9 QUOTATION MARK")
(11843 . "DASH WITH LEFT UPTURN")
(11844 . "DOUBLE SUSPENSION MARK")
((11845 . 11904) . #f)
(11904 . "CJK RADICAL REPEAT")
(11905 . "CJK RADICAL CLIFF")
(11906 . "CJK RADICAL SECOND ONE")
(11907 . "CJK RADICAL SECOND TWO")
(11908 . "CJK RADICAL SECOND THREE")
(11909 . "CJK RADICAL PERSON")
(11910 . "CJK RADICAL BOX")
(11911 . "CJK RADICAL TABLE")
(11912 . "CJK RADICAL KNIFE ONE")
(11913 . "CJK RADICAL KNIFE TWO")
(11914 . "CJK RADICAL DIVINATION")
(11915 . "CJK RADICAL SEAL")
(11916 . "CJK RADICAL SMALL ONE")
(11917 . "CJK RADICAL SMALL TWO")
(11918 . "CJK RADICAL LAME ONE")
(11919 . "CJK RADICAL LAME TWO")
(11920 . "CJK RADICAL LAME THREE")
(11921 . "CJK RADICAL LAME FOUR")
(11922 . "CJK RADICAL SNAKE")
(11923 . "CJK RADICAL THREAD")
(11924 . "CJK RADICAL SNOUT ONE")
(11925 . "CJK RADICAL SNOUT TWO")
(11926 . "CJK RADICAL HEART ONE")
(11927 . "CJK RADICAL HEART TWO")
(11928 . "CJK RADICAL HAND")
(11929 . "CJK RADICAL RAP")
(11930 . #f)
(11931 . "CJK RADICAL CHOKE")
(11932 . "CJK RADICAL SUN")
(11933 . "CJK RADICAL MOON")
(11934 . "CJK RADICAL DEATH")
(11935 . "CJK RADICAL MOTHER")
(11936 . "CJK RADICAL CIVILIAN")
(11937 . "CJK RADICAL WATER ONE")
(11938 . "CJK RADICAL WATER TWO")
(11939 . "CJK RADICAL FIRE")
(11940 . "CJK RADICAL PAW ONE")
(11941 . "CJK RADICAL PAW TWO")
(11942 . "CJK RADICAL SIMPLIFIED HALF TREE TRUNK")
(11943 . "CJK RADICAL COW")
(11944 . "CJK RADICAL DOG")
(11945 . "CJK RADICAL JADE")
(11946 . "CJK RADICAL BOLT OF CLOTH")
(11947 . "CJK RADICAL EYE")
(11948 . "CJK RADICAL SPIRIT ONE")
(11949 . "CJK RADICAL SPIRIT TWO")
(11950 . "CJK RADICAL BAMBOO")
(11951 . "CJK RADICAL SILK")
(11952 . "CJK RADICAL C-SIMPLIFIED SILK")
(11953 . "CJK RADICAL NET ONE")
(11954 . "CJK RADICAL NET TWO")
(11955 . "CJK RADICAL NET THREE")
(11956 . "CJK RADICAL NET FOUR")
(11957 . "CJK RADICAL MESH")
(11958 . "CJK RADICAL SHEEP")
(11959 . "CJK RADICAL RAM")
(11960 . "CJK RADICAL EWE")
(11961 . "CJK RADICAL OLD")
(11962 . "CJK RADICAL BRUSH ONE")
(11963 . "CJK RADICAL BRUSH TWO")
(11964 . "CJK RADICAL MEAT")
(11965 . "CJK RADICAL MORTAR")
(11966 . "CJK RADICAL GRASS ONE")
(11967 . "CJK RADICAL GRASS TWO")
(11968 . "CJK RADICAL GRASS THREE")
(11969 . "CJK RADICAL TIGER")
(11970 . "CJK RADICAL CLOTHES")
(11971 . "CJK RADICAL WEST ONE")
(11972 . "CJK RADICAL WEST TWO")
(11973 . "CJK RADICAL C-SIMPLIFIED SEE")
(11974 . "CJK RADICAL SIMPLIFIED HORN")
(11975 . "CJK RADICAL HORN")
(11976 . "CJK RADICAL C-SIMPLIFIED SPEECH")
(11977 . "CJK RADICAL C-SIMPLIFIED SHELL")
(11978 . "CJK RADICAL FOOT")
(11979 . "CJK RADICAL C-SIMPLIFIED CART")
(11980 . "CJK RADICAL SIMPLIFIED WALK")
(11981 . "CJK RADICAL WALK ONE")
(11982 . "CJK RADICAL WALK TWO")
(11983 . "CJK RADICAL CITY")
(11984 . "CJK RADICAL C-SIMPLIFIED GOLD")
(11985 . "CJK RADICAL LONG ONE")
(11986 . "CJK RADICAL LONG TWO")
(11987 . "CJK RADICAL C-SIMPLIFIED LONG")
(11988 . "CJK RADICAL C-SIMPLIFIED GATE")
(11989 . "CJK RADICAL MOUND ONE")
(11990 . "CJK RADICAL MOUND TWO")
(11991 . "CJK RADICAL RAIN")
(11992 . "CJK RADICAL BLUE")
(11993 . "CJK RADICAL C-SIMPLIFIED TANNED LEATHER")
(11994 . "CJK RADICAL C-SIMPLIFIED LEAF")
(11995 . "CJK RADICAL C-SIMPLIFIED WIND")
(11996 . "CJK RADICAL C-SIMPLIFIED FLY")
(11997 . "CJK RADICAL EAT ONE")
(11998 . "CJK RADICAL EAT TWO")
(11999 . "CJK RADICAL EAT THREE")
(12000 . "CJK RADICAL C-SIMPLIFIED EAT")
(12001 . "CJK RADICAL HEAD")
(12002 . "CJK RADICAL C-SIMPLIFIED HORSE")
(12003 . "CJK RADICAL BONE")
(12004 . "CJK RADICAL GHOST")
(12005 . "CJK RADICAL C-SIMPLIFIED FISH")
(12006 . "CJK RADICAL C-SIMPLIFIED BIRD")
(12007 . "CJK RADICAL C-SIMPLIFIED SALT")
(12008 . "CJK RADICAL SIMPLIFIED WHEAT")
(12009 . "CJK RADICAL SIMPLIFIED YELLOW")
(12010 . "CJK RADICAL C-SIMPLIFIED FROG")
(12011 . "CJK RADICAL J-SIMPLIFIED EVEN")
(12012 . "CJK RADICAL C-SIMPLIFIED EVEN")
(12013 . "CJK RADICAL J-SIMPLIFIED TOOTH")
(12014 . "CJK RADICAL C-SIMPLIFIED TOOTH")
(12015 . "CJK RADICAL J-SIMPLIFIED DRAGON")
(12016 . "CJK RADICAL C-SIMPLIFIED DRAGON")
(12017 . "CJK RADICAL TURTLE")
(12018 . "CJK RADICAL J-SIMPLIFIED TURTLE")
(12019 . "CJK RADICAL C-SIMPLIFIED TURTLE")
((12020 . 12032) . #f)
(12032 . "KANGXI RADICAL ONE")
(12033 . "KANGXI RADICAL LINE")
(12034 . "KANGXI RADICAL DOT")
(12035 . "KANGXI RADICAL SLASH")
(12036 . "KANGXI RADICAL SECOND")
(12037 . "KANGXI RADICAL HOOK")
(12038 . "KANGXI RADICAL TWO")
(12039 . "KANGXI RADICAL LID")
(12040 . "KANGXI RADICAL MAN")
(12041 . "KANGXI RADICAL LEGS")
(12042 . "KANGXI RADICAL ENTER")
(12043 . "KANGXI RADICAL EIGHT")
(12044 . "KANGXI RADICAL DOWN BOX")
(12045 . "KANGXI RADICAL COVER")
(12046 . "KANGXI RADICAL ICE")
(12047 . "KANGXI RADICAL TABLE")
(12048 . "KANGXI RADICAL OPEN BOX")
(12049 . "KANGXI RADICAL KNIFE")
(12050 . "KANGXI RADICAL POWER")
(12051 . "KANGXI RADICAL WRAP")
(12052 . "KANGXI RADICAL SPOON")
(12053 . "KANGXI RADICAL RIGHT OPEN BOX")
(12054 . "KANGXI RADICAL HIDING ENCLOSURE")
(12055 . "KANGXI RADICAL TEN")
(12056 . "KANGXI RADICAL DIVINATION")
(12057 . "KANGXI RADICAL SEAL")
(12058 . "KANGXI RADICAL CLIFF")
(12059 . "KANGXI RADICAL PRIVATE")
(12060 . "KANGXI RADICAL AGAIN")
(12061 . "KANGXI RADICAL MOUTH")
(12062 . "KANGXI RADICAL ENCLOSURE")
(12063 . "KANGXI RADICAL EARTH")
(12064 . "KANGXI RADICAL SCHOLAR")
(12065 . "KANGXI RADICAL GO")
(12066 . "KANGXI RADICAL GO SLOWLY")
(12067 . "KANGXI RADICAL EVENING")
(12068 . "KANGXI RADICAL BIG")
(12069 . "KANGXI RADICAL WOMAN")
(12070 . "KANGXI RADICAL CHILD")
(12071 . "KANGXI RADICAL ROOF")
(12072 . "KANGXI RADICAL INCH")
(12073 . "KANGXI RADICAL SMALL")
(12074 . "KANGXI RADICAL LAME")
(12075 . "KANGXI RADICAL CORPSE")
(12076 . "KANGXI RADICAL SPROUT")
(12077 . "KANGXI RADICAL MOUNTAIN")
(12078 . "KANGXI RADICAL RIVER")
(12079 . "KANGXI RADICAL WORK")
(12080 . "KANGXI RADICAL ONESELF")
(12081 . "KANGXI RADICAL TURBAN")
(12082 . "KANGXI RADICAL DRY")
(12083 . "KANGXI RADICAL SHORT THREAD")
(12084 . "KANGXI RADICAL DOTTED CLIFF")
(12085 . "KANGXI RADICAL LONG STRIDE")
(12086 . "KANGXI RADICAL TWO HANDS")
(12087 . "KANGXI RADICAL SHOOT")
(12088 . "KANGXI RADICAL BOW")
(12089 . "KANGXI RADICAL SNOUT")
(12090 . "KANGXI RADICAL BRISTLE")
(12091 . "KANGXI RADICAL STEP")
(12092 . "KANGXI RADICAL HEART")
(12093 . "KANGXI RADICAL HALBERD")
(12094 . "KANGXI RADICAL DOOR")
(12095 . "KANGXI RADICAL HAND")
(12096 . "KANGXI RADICAL BRANCH")
(12097 . "KANGXI RADICAL RAP")
(12098 . "KANGXI RADICAL SCRIPT")
(12099 . "KANGXI RADICAL DIPPER")
(12100 . "KANGXI RADICAL AXE")
(12101 . "KANGXI RADICAL SQUARE")
(12102 . "KANGXI RADICAL NOT")
(12103 . "KANGXI RADICAL SUN")
(12104 . "KANGXI RADICAL SAY")
(12105 . "KANGXI RADICAL MOON")
(12106 . "KANGXI RADICAL TREE")
(12107 . "KANGXI RADICAL LACK")
(12108 . "KANGXI RADICAL STOP")
(12109 . "KANGXI RADICAL DEATH")
(12110 . "KANGXI RADICAL WEAPON")
(12111 . "KANGXI RADICAL DO NOT")
(12112 . "KANGXI RADICAL COMPARE")
(12113 . "KANGXI RADICAL FUR")
(12114 . "KANGXI RADICAL CLAN")
(12115 . "KANGXI RADICAL STEAM")
(12116 . "KANGXI RADICAL WATER")
(12117 . "KANGXI RADICAL FIRE")
(12118 . "KANGXI RADICAL CLAW")
(12119 . "KANGXI RADICAL FATHER")
(12120 . "KANGXI RADICAL DOUBLE X")
(12121 . "KANGXI RADICAL HALF TREE TRUNK")
(12122 . "KANGXI RADICAL SLICE")
(12123 . "KANGXI RADICAL FANG")
(12124 . "KANGXI RADICAL COW")
(12125 . "KANGXI RADICAL DOG")
(12126 . "KANGXI RADICAL PROFOUND")
(12127 . "KANGXI RADICAL JADE")
(12128 . "KANGXI RADICAL MELON")
(12129 . "KANGXI RADICAL TILE")
(12130 . "KANGXI RADICAL SWEET")
(12131 . "KANGXI RADICAL LIFE")
(12132 . "KANGXI RADICAL USE")
(12133 . "KANGXI RADICAL FIELD")
(12134 . "KANGXI RADICAL BOLT OF CLOTH")
(12135 . "KANGXI RADICAL SICKNESS")
(12136 . "KANGXI RADICAL DOTTED TENT")
(12137 . "KANGXI RADICAL WHITE")
(12138 . "KANGXI RADICAL SKIN")
(12139 . "KANGXI RADICAL DISH")
(12140 . "KANGXI RADICAL EYE")
(12141 . "KANGXI RADICAL SPEAR")
(12142 . "KANGXI RADICAL ARROW")
(12143 . "KANGXI RADICAL STONE")
(12144 . "KANGXI RADICAL SPIRIT")
(12145 . "KANGXI RADICAL TRACK")
(12146 . "KANGXI RADICAL GRAIN")
(12147 . "KANGXI RADICAL CAVE")
(12148 . "KANGXI RADICAL STAND")
(12149 . "KANGXI RADICAL BAMBOO")
(12150 . "KANGXI RADICAL RICE")
(12151 . "KANGXI RADICAL SILK")
(12152 . "KANGXI RADICAL JAR")
(12153 . "KANGXI RADICAL NET")
(12154 . "KANGXI RADICAL SHEEP")
(12155 . "KANGXI RADICAL FEATHER")
(12156 . "KANGXI RADICAL OLD")
(12157 . "KANGXI RADICAL AND")
(12158 . "KANGXI RADICAL PLOW")
(12159 . "KANGXI RADICAL EAR")
(12160 . "KANGXI RADICAL BRUSH")
(12161 . "KANGXI RADICAL MEAT")
(12162 . "KANGXI RADICAL MINISTER")
(12163 . "KANGXI RADICAL SELF")
(12164 . "KANGXI RADICAL ARRIVE")
(12165 . "KANGXI RADICAL MORTAR")
(12166 . "KANGXI RADICAL TONGUE")
(12167 . "KANGXI RADICAL OPPOSE")
(12168 . "KANGXI RADICAL BOAT")
(12169 . "KANGXI RADICAL STOPPING")
(12170 . "KANGXI RADICAL COLOR")
(12171 . "KANGXI RADICAL GRASS")
(12172 . "KANGXI RADICAL TIGER")
(12173 . "KANGXI RADICAL INSECT")
(12174 . "KANGXI RADICAL BLOOD")
(12175 . "KANGXI RADICAL WALK ENCLOSURE")
(12176 . "KANGXI RADICAL CLOTHES")
(12177 . "KANGXI RADICAL WEST")
(12178 . "KANGXI RADICAL SEE")
(12179 . "KANGXI RADICAL HORN")
(12180 . "KANGXI RADICAL SPEECH")
(12181 . "KANGXI RADICAL VALLEY")
(12182 . "KANGXI RADICAL BEAN")
(12183 . "KANGXI RADICAL PIG")
(12184 . "KANGXI RADICAL BADGER")
(12185 . "KANGXI RADICAL SHELL")
(12186 . "KANGXI RADICAL RED")
(12187 . "KANGXI RADICAL RUN")
(12188 . "KANGXI RADICAL FOOT")
(12189 . "KANGXI RADICAL BODY")
(12190 . "KANGXI RADICAL CART")
(12191 . "KANGXI RADICAL BITTER")
(12192 . "KANGXI RADICAL MORNING")
(12193 . "KANGXI RADICAL WALK")
(12194 . "KANGXI RADICAL CITY")
(12195 . "KANGXI RADICAL WINE")
(12196 . "KANGXI RADICAL DISTINGUISH")
(12197 . "KANGXI RADICAL VILLAGE")
(12198 . "KANGXI RADICAL GOLD")
(12199 . "KANGXI RADICAL LONG")
(12200 . "KANGXI RADICAL GATE")
(12201 . "KANGXI RADICAL MOUND")
(12202 . "KANGXI RADICAL SLAVE")
(12203 . "KANGXI RADICAL SHORT TAILED BIRD")
(12204 . "KANGXI RADICAL RAIN")
(12205 . "KANGXI RADICAL BLUE")
(12206 . "KANGXI RADICAL WRONG")
(12207 . "KANGXI RADICAL FACE")
(12208 . "KANGXI RADICAL LEATHER")
(12209 . "KANGXI RADICAL TANNED LEATHER")
(12210 . "KANGXI RADICAL LEEK")
(12211 . "KANGXI RADICAL SOUND")
(12212 . "KANGXI RADICAL LEAF")
(12213 . "KANGXI RADICAL WIND")
(12214 . "KANGXI RADICAL FLY")
(12215 . "KANGXI RADICAL EAT")
(12216 . "KANGXI RADICAL HEAD")
(12217 . "KANGXI RADICAL FRAGRANT")
(12218 . "KANGXI RADICAL HORSE")
(12219 . "KANGXI RADICAL BONE")
(12220 . "KANGXI RADICAL TALL")
(12221 . "KANGXI RADICAL HAIR")
(12222 . "KANGXI RADICAL FIGHT")
(12223 . "KANGXI RADICAL SACRIFICIAL WINE")
(12224 . "KANGXI RADICAL CAULDRON")
(12225 . "KANGXI RADICAL GHOST")
(12226 . "KANGXI RADICAL FISH")
(12227 . "KANGXI RADICAL BIRD")
(12228 . "KANGXI RADICAL SALT")
(12229 . "KANGXI RADICAL DEER")
(12230 . "KANGXI RADICAL WHEAT")
(12231 . "KANGXI RADICAL HEMP")
(12232 . "KANGXI RADICAL YELLOW")
(12233 . "KANGXI RADICAL MILLET")
(12234 . "KANGXI RADICAL BLACK")
(12235 . "KANGXI RADICAL EMBROIDERY")
(12236 . "KANGXI RADICAL FROG")
(12237 . "KANGXI RADICAL TRIPOD")
(12238 . "KANGXI RADICAL DRUM")
(12239 . "KANGXI RADICAL RAT")
(12240 . "KANGXI RADICAL NOSE")
(12241 . "KANGXI RADICAL EVEN")
(12242 . "KANGXI RADICAL TOOTH")
(12243 . "KANGXI RADICAL DRAGON")
(12244 . "KANGXI RADICAL TURTLE")
(12245 . "KANGXI RADICAL FLUTE")
((12246 . 12272) . #f)
(12272 . "IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO RIGHT")
(12273 . "IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO BELOW")
(12274 . "IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO MIDDLE AND RIGHT")
(12275 . "IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO MIDDLE AND BELOW")
(12276 . "IDEOGRAPHIC DESCRIPTION CHARACTER FULL SURROUND")
(12277 . "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM ABOVE")
(12278 . "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM BELOW")
(12279 . "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LEFT")
(12280 . "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER LEFT")
(12281 . "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER RIGHT")
(12282 . "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LOWER LEFT")
(12283 . "IDEOGRAPHIC DESCRIPTION CHARACTER OVERLAID")
((12284 . 12288) . #f)
(12288 . "IDEOGRAPHIC SPACE")
(12289 . "IDEOGRAPHIC COMMA")
(12290 . "IDEOGRAPHIC FULL STOP")
(12291 . "DITTO MARK")
(12292 . "JAPANESE INDUSTRIAL STANDARD SYMBOL")
(12293 . "IDEOGRAPHIC ITERATION MARK")
(12294 . "IDEOGRAPHIC CLOSING MARK")
(12295 . "IDEOGRAPHIC NUMBER ZERO")
(12296 . "LEFT ANGLE BRACKET")
(12297 . "RIGHT ANGLE BRACKET")
(12298 . "LEFT DOUBLE ANGLE BRACKET")
(12299 . "RIGHT DOUBLE ANGLE BRACKET")
(12300 . "LEFT CORNER BRACKET")
(12301 . "RIGHT CORNER BRACKET")
(12302 . "LEFT WHITE CORNER BRACKET")
(12303 . "RIGHT WHITE CORNER BRACKET")
(12304 . "LEFT BLACK LENTICULAR BRACKET")
(12305 . "RIGHT BLACK LENTICULAR BRACKET")
(12306 . "POSTAL MARK")
(12307 . "GETA MARK")
(12308 . "LEFT TORTOISE SHELL BRACKET")
(12309 . "RIGHT TORTOISE SHELL BRACKET")
(12310 . "LEFT WHITE LENTICULAR BRACKET")
(12311 . "RIGHT WHITE LENTICULAR BRACKET")
(12312 . "LEFT WHITE TORTOISE SHELL BRACKET")
(12313 . "RIGHT WHITE TORTOISE SHELL BRACKET")
(12314 . "LEFT WHITE SQUARE BRACKET")
(12315 . "RIGHT WHITE SQUARE BRACKET")
(12316 . "WAVE DASH")
(12317 . "REVERSED DOUBLE PRIME QUOTATION MARK")
(12318 . "DOUBLE PRIME QUOTATION MARK")
(12319 . "LOW DOUBLE PRIME QUOTATION MARK")
(12320 . "POSTAL MARK FACE")
(12321 . "HANGZHOU NUMERAL ONE")
(12322 . "HANGZHOU NUMERAL TWO")
(12323 . "HANGZHOU NUMERAL THREE")
(12324 . "HANGZHOU NUMERAL FOUR")
(12325 . "HANGZHOU NUMERAL FIVE")
(12326 . "HANGZHOU NUMERAL SIX")
(12327 . "HANGZHOU NUMERAL SEVEN")
(12328 . "HANGZHOU NUMERAL EIGHT")
(12329 . "HANGZHOU NUMERAL NINE")
(12330 . "IDEOGRAPHIC LEVEL TONE MARK")
(12331 . "IDEOGRAPHIC RISING TONE MARK")
(12332 . "IDEOGRAPHIC DEPARTING TONE MARK")
(12333 . "IDEOGRAPHIC ENTERING TONE MARK")
(12334 . "HANGUL SINGLE DOT TONE MARK")
(12335 . "HANGUL DOUBLE DOT TONE MARK")
(12336 . "WAVY DASH")
(12337 . "VERTICAL KANA REPEAT MARK")
(12338 . "VERTICAL KANA REPEAT WITH VOICED SOUND MARK")
(12339 . "VERTICAL KANA REPEAT MARK UPPER HALF")
(12340 . "VERTICAL KANA REPEAT WITH VOICED SOUND MARK UPPER HALF")
(12341 . "VERTICAL KANA REPEAT MARK LOWER HALF")
(12342 . "CIRCLED POSTAL MARK")
(12343 . "IDEOGRAPHIC TELEGRAPH LINE FEED SEPARATOR SYMBOL")
(12344 . "HANGZHOU NUMERAL TEN")
(12345 . "HANGZHOU NUMERAL TWENTY")
(12346 . "HANGZHOU NUMERAL THIRTY")
(12347 . "VERTICAL IDEOGRAPHIC ITERATION MARK")
(12348 . "MASU MARK")
(12349 . "PART ALTERNATION MARK")
(12350 . "IDEOGRAPHIC VARIATION INDICATOR")
(12351 . "IDEOGRAPHIC HALF FILL SPACE")
(12352 . #f)
(12353 . "HIRAGANA LETTER SMALL A")
(12354 . "HIRAGANA LETTER A")
(12355 . "HIRAGANA LETTER SMALL I")
(12356 . "HIRAGANA LETTER I")
(12357 . "HIRAGANA LETTER SMALL U")
(12358 . "HIRAGANA LETTER U")
(12359 . "HIRAGANA LETTER SMALL E")
(12360 . "HIRAGANA LETTER E")
(12361 . "HIRAGANA LETTER SMALL O")
(12362 . "HIRAGANA LETTER O")
(12363 . "HIRAGANA LETTER KA")
(12364 . "HIRAGANA LETTER GA")
(12365 . "HIRAGANA LETTER KI")
(12366 . "HIRAGANA LETTER GI")
(12367 . "HIRAGANA LETTER KU")
(12368 . "HIRAGANA LETTER GU")
(12369 . "HIRAGANA LETTER KE")
(12370 . "HIRAGANA LETTER GE")
(12371 . "HIRAGANA LETTER KO")
(12372 . "HIRAGANA LETTER GO")
(12373 . "HIRAGANA LETTER SA")
(12374 . "HIRAGANA LETTER ZA")
(12375 . "HIRAGANA LETTER SI")
(12376 . "HIRAGANA LETTER ZI")
(12377 . "HIRAGANA LETTER SU")
(12378 . "HIRAGANA LETTER ZU")
(12379 . "HIRAGANA LETTER SE")
(12380 . "HIRAGANA LETTER ZE")
(12381 . "HIRAGANA LETTER SO")
(12382 . "HIRAGANA LETTER ZO")
(12383 . "HIRAGANA LETTER TA")
(12384 . "HIRAGANA LETTER DA")
(12385 . "HIRAGANA LETTER TI")
(12386 . "HIRAGANA LETTER DI")
(12387 . "HIRAGANA LETTER SMALL TU")
(12388 . "HIRAGANA LETTER TU")
(12389 . "HIRAGANA LETTER DU")
(12390 . "HIRAGANA LETTER TE")
(12391 . "HIRAGANA LETTER DE")
(12392 . "HIRAGANA LETTER TO")
(12393 . "HIRAGANA LETTER DO")
(12394 . "HIRAGANA LETTER NA")
(12395 . "HIRAGANA LETTER NI")
(12396 . "HIRAGANA LETTER NU")
(12397 . "HIRAGANA LETTER NE")
(12398 . "HIRAGANA LETTER NO")
(12399 . "HIRAGANA LETTER HA")
(12400 . "HIRAGANA LETTER BA")
(12401 . "HIRAGANA LETTER PA")
(12402 . "HIRAGANA LETTER HI")
(12403 . "HIRAGANA LETTER BI")
(12404 . "HIRAGANA LETTER PI")
(12405 . "HIRAGANA LETTER HU")
(12406 . "HIRAGANA LETTER BU")
(12407 . "HIRAGANA LETTER PU")
(12408 . "HIRAGANA LETTER HE")
(12409 . "HIRAGANA LETTER BE")
(12410 . "HIRAGANA LETTER PE")
(12411 . "HIRAGANA LETTER HO")
(12412 . "HIRAGANA LETTER BO")
(12413 . "HIRAGANA LETTER PO")
(12414 . "HIRAGANA LETTER MA")
(12415 . "HIRAGANA LETTER MI")
(12416 . "HIRAGANA LETTER MU")
(12417 . "HIRAGANA LETTER ME")
(12418 . "HIRAGANA LETTER MO")
(12419 . "HIRAGANA LETTER SMALL YA")
(12420 . "HIRAGANA LETTER YA")
(12421 . "HIRAGANA LETTER SMALL YU")
(12422 . "HIRAGANA LETTER YU")
(12423 . "HIRAGANA LETTER SMALL YO")
(12424 . "HIRAGANA LETTER YO")
(12425 . "HIRAGANA LETTER RA")
(12426 . "HIRAGANA LETTER RI")
(12427 . "HIRAGANA LETTER RU")
(12428 . "HIRAGANA LETTER RE")
(12429 . "HIRAGANA LETTER RO")
(12430 . "HIRAGANA LETTER SMALL WA")
(12431 . "HIRAGANA LETTER WA")
(12432 . "HIRAGANA LETTER WI")
(12433 . "HIRAGANA LETTER WE")
(12434 . "HIRAGANA LETTER WO")
(12435 . "HIRAGANA LETTER N")
(12436 . "HIRAGANA LETTER VU")
(12437 . "HIRAGANA LETTER SMALL KA")
(12438 . "HIRAGANA LETTER SMALL KE")
((12439 . 12441) . #f)
(12441 . "COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK")
(12442 . "COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK")
(12443 . "KATAKANA-HIRAGANA VOICED SOUND MARK")
(12444 . "KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK")
(12445 . "HIRAGANA ITERATION MARK")
(12446 . "HIRAGANA VOICED ITERATION MARK")
(12447 . "HIRAGANA DIGRAPH YORI")
(12448 . "KATAKANA-HIRAGANA DOUBLE HYPHEN")
(12449 . "KATAKANA LETTER SMALL A")
(12450 . "KATAKANA LETTER A")
(12451 . "KATAKANA LETTER SMALL I")
(12452 . "KATAKANA LETTER I")
(12453 . "KATAKANA LETTER SMALL U")
(12454 . "KATAKANA LETTER U")
(12455 . "KATAKANA LETTER SMALL E")
(12456 . "KATAKANA LETTER E")
(12457 . "KATAKANA LETTER SMALL O")
(12458 . "KATAKANA LETTER O")
(12459 . "KATAKANA LETTER KA")
(12460 . "KATAKANA LETTER GA")
(12461 . "KATAKANA LETTER KI")
(12462 . "KATAKANA LETTER GI")
(12463 . "KATAKANA LETTER KU")
(12464 . "KATAKANA LETTER GU")
(12465 . "KATAKANA LETTER KE")
(12466 . "KATAKANA LETTER GE")
(12467 . "KATAKANA LETTER KO")
(12468 . "KATAKANA LETTER GO")
(12469 . "KATAKANA LETTER SA")
(12470 . "KATAKANA LETTER ZA")
(12471 . "KATAKANA LETTER SI")
(12472 . "KATAKANA LETTER ZI")
(12473 . "KATAKANA LETTER SU")
(12474 . "KATAKANA LETTER ZU")
(12475 . "KATAKANA LETTER SE")
(12476 . "KATAKANA LETTER ZE")
(12477 . "KATAKANA LETTER SO")
(12478 . "KATAKANA LETTER ZO")
(12479 . "KATAKANA LETTER TA")
(12480 . "KATAKANA LETTER DA")
(12481 . "KATAKANA LETTER TI")
(12482 . "KATAKANA LETTER DI")
(12483 . "KATAKANA LETTER SMALL TU")
(12484 . "KATAKANA LETTER TU")
(12485 . "KATAKANA LETTER DU")
(12486 . "KATAKANA LETTER TE")
(12487 . "KATAKANA LETTER DE")
(12488 . "KATAKANA LETTER TO")
(12489 . "KATAKANA LETTER DO")
(12490 . "KATAKANA LETTER NA")
(12491 . "KATAKANA LETTER NI")
(12492 . "KATAKANA LETTER NU")
(12493 . "KATAKANA LETTER NE")
(12494 . "KATAKANA LETTER NO")
(12495 . "KATAKANA LETTER HA")
(12496 . "KATAKANA LETTER BA")
(12497 . "KATAKANA LETTER PA")
(12498 . "KATAKANA LETTER HI")
(12499 . "KATAKANA LETTER BI")
(12500 . "KATAKANA LETTER PI")
(12501 . "KATAKANA LETTER HU")
(12502 . "KATAKANA LETTER BU")
(12503 . "KATAKANA LETTER PU")
(12504 . "KATAKANA LETTER HE")
(12505 . "KATAKANA LETTER BE")
(12506 . "KATAKANA LETTER PE")
(12507 . "KATAKANA LETTER HO")
(12508 . "KATAKANA LETTER BO")
(12509 . "KATAKANA LETTER PO")
(12510 . "KATAKANA LETTER MA")
(12511 . "KATAKANA LETTER MI")
(12512 . "KATAKANA LETTER MU")
(12513 . "KATAKANA LETTER ME")
(12514 . "KATAKANA LETTER MO")
(12515 . "KATAKANA LETTER SMALL YA")
(12516 . "KATAKANA LETTER YA")
(12517 . "KATAKANA LETTER SMALL YU")
(12518 . "KATAKANA LETTER YU")
(12519 . "KATAKANA LETTER SMALL YO")
(12520 . "KATAKANA LETTER YO")
(12521 . "KATAKANA LETTER RA")
(12522 . "KATAKANA LETTER RI")
(12523 . "KATAKANA LETTER RU")
(12524 . "KATAKANA LETTER RE")
(12525 . "KATAKANA LETTER RO")
(12526 . "KATAKANA LETTER SMALL WA")
(12527 . "KATAKANA LETTER WA")
(12528 . "KATAKANA LETTER WI")
(12529 . "KATAKANA LETTER WE")
(12530 . "KATAKANA LETTER WO")
(12531 . "KATAKANA LETTER N")
(12532 . "KATAKANA LETTER VU")
(12533 . "KATAKANA LETTER SMALL KA")
(12534 . "KATAKANA LETTER SMALL KE")
(12535 . "KATAKANA LETTER VA")
(12536 . "KATAKANA LETTER VI")
(12537 . "KATAKANA LETTER VE")
(12538 . "KATAKANA LETTER VO")
(12539 . "KATAKANA MIDDLE DOT")
(12540 . "KATAKANA-HIRAGANA PROLONGED SOUND MARK")
(12541 . "KATAKANA ITERATION MARK")
(12542 . "KATAKANA VOICED ITERATION MARK")
(12543 . "KATAKANA DIGRAPH KOTO")
((12544 . 12549) . #f)
(12549 . "BOPOMOFO LETTER B")
(12550 . "BOPOMOFO LETTER P")
(12551 . "BOPOMOFO LETTER M")
(12552 . "BOPOMOFO LETTER F")
(12553 . "BOPOMOFO LETTER D")
(12554 . "BOPOMOFO LETTER T")
(12555 . "BOPOMOFO LETTER N")
(12556 . "BOPOMOFO LETTER L")
(12557 . "BOPOMOFO LETTER G")
(12558 . "BOPOMOFO LETTER K")
(12559 . "BOPOMOFO LETTER H")
(12560 . "BOPOMOFO LETTER J")
(12561 . "BOPOMOFO LETTER Q")
(12562 . "BOPOMOFO LETTER X")
(12563 . "BOPOMOFO LETTER ZH")
(12564 . "BOPOMOFO LETTER CH")
(12565 . "BOPOMOFO LETTER SH")
(12566 . "BOPOMOFO LETTER R")
(12567 . "BOPOMOFO LETTER Z")
(12568 . "BOPOMOFO LETTER C")
(12569 . "BOPOMOFO LETTER S")
(12570 . "BOPOMOFO LETTER A")
(12571 . "BOPOMOFO LETTER O")
(12572 . "BOPOMOFO LETTER E")
(12573 . "BOPOMOFO LETTER EH")
(12574 . "BOPOMOFO LETTER AI")
(12575 . "BOPOMOFO LETTER EI")
(12576 . "BOPOMOFO LETTER AU")
(12577 . "BOPOMOFO LETTER OU")
(12578 . "BOPOMOFO LETTER AN")
(12579 . "BOPOMOFO LETTER EN")
(12580 . "BOPOMOFO LETTER ANG")
(12581 . "BOPOMOFO LETTER ENG")
(12582 . "BOPOMOFO LETTER ER")
(12583 . "BOPOMOFO LETTER I")
(12584 . "BOPOMOFO LETTER U")
(12585 . "BOPOMOFO LETTER IU")
(12586 . "BOPOMOFO LETTER V")
(12587 . "BOPOMOFO LETTER NG")
(12588 . "BOPOMOFO LETTER GN")
(12589 . "BOPOMOFO LETTER IH")
((12590 . 12593) . #f)
(12593 . "HANGUL LETTER KIYEOK")
(12594 . "HANGUL LETTER SSANGKIYEOK")
(12595 . "HANGUL LETTER KIYEOK-SIOS")
(12596 . "HANGUL LETTER NIEUN")
(12597 . "HANGUL LETTER NIEUN-CIEUC")
(12598 . "HANGUL LETTER NIEUN-HIEUH")
(12599 . "HANGUL LETTER TIKEUT")
(12600 . "HANGUL LETTER SSANGTIKEUT")
(12601 . "HANGUL LETTER RIEUL")
(12602 . "HANGUL LETTER RIEUL-KIYEOK")
(12603 . "HANGUL LETTER RIEUL-MIEUM")
(12604 . "HANGUL LETTER RIEUL-PIEUP")
(12605 . "HANGUL LETTER RIEUL-SIOS")
(12606 . "HANGUL LETTER RIEUL-THIEUTH")
(12607 . "HANGUL LETTER RIEUL-PHIEUPH")
(12608 . "HANGUL LETTER RIEUL-HIEUH")
(12609 . "HANGUL LETTER MIEUM")
(12610 . "HANGUL LETTER PIEUP")
(12611 . "HANGUL LETTER SSANGPIEUP")
(12612 . "HANGUL LETTER PIEUP-SIOS")
(12613 . "HANGUL LETTER SIOS")
(12614 . "HANGUL LETTER SSANGSIOS")
(12615 . "HANGUL LETTER IEUNG")
(12616 . "HANGUL LETTER CIEUC")
(12617 . "HANGUL LETTER SSANGCIEUC")
(12618 . "HANGUL LETTER CHIEUCH")
(12619 . "HANGUL LETTER KHIEUKH")
(12620 . "HANGUL LETTER THIEUTH")
(12621 . "HANGUL LETTER PHIEUPH")
(12622 . "HANGUL LETTER HIEUH")
(12623 . "HANGUL LETTER A")
(12624 . "HANGUL LETTER AE")
(12625 . "HANGUL LETTER YA")
(12626 . "HANGUL LETTER YAE")
(12627 . "HANGUL LETTER EO")
(12628 . "HANGUL LETTER E")
(12629 . "HANGUL LETTER YEO")
(12630 . "HANGUL LETTER YE")
(12631 . "HANGUL LETTER O")
(12632 . "HANGUL LETTER WA")
(12633 . "HANGUL LETTER WAE")
(12634 . "HANGUL LETTER OE")
(12635 . "HANGUL LETTER YO")
(12636 . "HANGUL LETTER U")
(12637 . "HANGUL LETTER WEO")
(12638 . "HANGUL LETTER WE")
(12639 . "HANGUL LETTER WI")
(12640 . "HANGUL LETTER YU")
(12641 . "HANGUL LETTER EU")
(12642 . "HANGUL LETTER YI")
(12643 . "HANGUL LETTER I")
(12644 . "HANGUL FILLER")
(12645 . "HANGUL LETTER SSANGNIEUN")
(12646 . "HANGUL LETTER NIEUN-TIKEUT")
(12647 . "HANGUL LETTER NIEUN-SIOS")
(12648 . "HANGUL LETTER NIEUN-PANSIOS")
(12649 . "HANGUL LETTER RIEUL-KIYEOK-SIOS")
(12650 . "HANGUL LETTER RIEUL-TIKEUT")
(12651 . "HANGUL LETTER RIEUL-PIEUP-SIOS")
(12652 . "HANGUL LETTER RIEUL-PANSIOS")
(12653 . "HANGUL LETTER RIEUL-YEORINHIEUH")
(12654 . "HANGUL LETTER MIEUM-PIEUP")
(12655 . "HANGUL LETTER MIEUM-SIOS")
(12656 . "HANGUL LETTER MIEUM-PANSIOS")
(12657 . "HANGUL LETTER KAPYEOUNMIEUM")
(12658 . "HANGUL LETTER PIEUP-KIYEOK")
(12659 . "HANGUL LETTER PIEUP-TIKEUT")
(12660 . "HANGUL LETTER PIEUP-SIOS-KIYEOK")
(12661 . "HANGUL LETTER PIEUP-SIOS-TIKEUT")
(12662 . "HANGUL LETTER PIEUP-CIEUC")
(12663 . "HANGUL LETTER PIEUP-THIEUTH")
(12664 . "HANGUL LETTER KAPYEOUNPIEUP")
(12665 . "HANGUL LETTER KAPYEOUNSSANGPIEUP")
(12666 . "HANGUL LETTER SIOS-KIYEOK")
(12667 . "HANGUL LETTER SIOS-NIEUN")
(12668 . "HANGUL LETTER SIOS-TIKEUT")
(12669 . "HANGUL LETTER SIOS-PIEUP")
(12670 . "HANGUL LETTER SIOS-CIEUC")
(12671 . "HANGUL LETTER PANSIOS")
(12672 . "HANGUL LETTER SSANGIEUNG")
(12673 . "HANGUL LETTER YESIEUNG")
(12674 . "HANGUL LETTER YESIEUNG-SIOS")
(12675 . "HANGUL LETTER YESIEUNG-PANSIOS")
(12676 . "HANGUL LETTER KAPYEOUNPHIEUPH")
(12677 . "HANGUL LETTER SSANGHIEUH")
(12678 . "HANGUL LETTER YEORINHIEUH")
(12679 . "HANGUL LETTER YO-YA")
(12680 . "HANGUL LETTER YO-YAE")
(12681 . "HANGUL LETTER YO-I")
(12682 . "HANGUL LETTER YU-YEO")
(12683 . "HANGUL LETTER YU-YE")
(12684 . "HANGUL LETTER YU-I")
(12685 . "HANGUL LETTER ARAEA")
(12686 . "HANGUL LETTER ARAEAE")
(12687 . #f)
(12688 . "IDEOGRAPHIC ANNOTATION LINKING MARK")
(12689 . "IDEOGRAPHIC ANNOTATION REVERSE MARK")
(12690 . "IDEOGRAPHIC ANNOTATION ONE MARK")
(12691 . "IDEOGRAPHIC ANNOTATION TWO MARK")
(12692 . "IDEOGRAPHIC ANNOTATION THREE MARK")
(12693 . "IDEOGRAPHIC ANNOTATION FOUR MARK")
(12694 . "IDEOGRAPHIC ANNOTATION TOP MARK")
(12695 . "IDEOGRAPHIC ANNOTATION MIDDLE MARK")
(12696 . "IDEOGRAPHIC ANNOTATION BOTTOM MARK")
(12697 . "IDEOGRAPHIC ANNOTATION FIRST MARK")
(12698 . "IDEOGRAPHIC ANNOTATION SECOND MARK")
(12699 . "IDEOGRAPHIC ANNOTATION THIRD MARK")
(12700 . "IDEOGRAPHIC ANNOTATION FOURTH MARK")
(12701 . "IDEOGRAPHIC ANNOTATION HEAVEN MARK")
(12702 . "IDEOGRAPHIC ANNOTATION EARTH MARK")
(12703 . "IDEOGRAPHIC ANNOTATION MAN MARK")
(12704 . "BOPOMOFO LETTER BU")
(12705 . "BOPOMOFO LETTER ZI")
(12706 . "BOPOMOFO LETTER JI")
(12707 . "BOPOMOFO LETTER GU")
(12708 . "BOPOMOFO LETTER EE")
(12709 . "BOPOMOFO LETTER ENN")
(12710 . "BOPOMOFO LETTER OO")
(12711 . "BOPOMOFO LETTER ONN")
(12712 . "BOPOMOFO LETTER IR")
(12713 . "BOPOMOFO LETTER ANN")
(12714 . "BOPOMOFO LETTER INN")
(12715 . "BOPOMOFO LETTER UNN")
(12716 . "BOPOMOFO LETTER IM")
(12717 . "BOPOMOFO LETTER NGG")
(12718 . "BOPOMOFO LETTER AINN")
(12719 . "BOPOMOFO LETTER AUNN")
(12720 . "BOPOMOFO LETTER AM")
(12721 . "BOPOMOFO LETTER OM")
(12722 . "BOPOMOFO LETTER ONG")
(12723 . "BOPOMOFO LETTER INNN")
(12724 . "BOPOMOFO FINAL LETTER P")
(12725 . "BOPOMOFO FINAL LETTER T")
(12726 . "BOPOMOFO FINAL LETTER K")
(12727 . "BOPOMOFO FINAL LETTER H")
(12728 . "BOPOMOFO LETTER GH")
(12729 . "BOPOMOFO LETTER LH")
(12730 . "BOPOMOFO LETTER ZY")
((12731 . 12736) . #f)
(12736 . "CJK STROKE T")
(12737 . "CJK STROKE WG")
(12738 . "CJK STROKE XG")
(12739 . "CJK STROKE BXG")
(12740 . "CJK STROKE SW")
(12741 . "CJK STROKE HZZ")
(12742 . "CJK STROKE HZG")
(12743 . "CJK STROKE HP")
(12744 . "CJK STROKE HZWG")
(12745 . "CJK STROKE SZWG")
(12746 . "CJK STROKE HZT")
(12747 . "CJK STROKE HZZP")
(12748 . "CJK STROKE HPWG")
(12749 . "CJK STROKE HZW")
(12750 . "CJK STROKE HZZZ")
(12751 . "CJK STROKE N")
(12752 . "CJK STROKE H")
(12753 . "CJK STROKE S")
(12754 . "CJK STROKE P")
(12755 . "CJK STROKE SP")
(12756 . "CJK STROKE D")
(12757 . "CJK STROKE HZ")
(12758 . "CJK STROKE HG")
(12759 . "CJK STROKE SZ")
(12760 . "CJK STROKE SWZ")
(12761 . "CJK STROKE ST")
(12762 . "CJK STROKE SG")
(12763 . "CJK STROKE PD")
(12764 . "CJK STROKE PZ")
(12765 . "CJK STROKE TN")
(12766 . "CJK STROKE SZZ")
(12767 . "CJK STROKE SWG")
(12768 . "CJK STROKE HXWG")
(12769 . "CJK STROKE HZZZG")
(12770 . "CJK STROKE PG")
(12771 . "CJK STROKE Q")
((12772 . 12784) . #f)
(12784 . "KATAKANA LETTER SMALL KU")
(12785 . "KATAKANA LETTER SMALL SI")
(12786 . "KATAKANA LETTER SMALL SU")
(12787 . "KATAKANA LETTER SMALL TO")
(12788 . "KATAKANA LETTER SMALL NU")
(12789 . "KATAKANA LETTER SMALL HA")
(12790 . "KATAKANA LETTER SMALL HI")
(12791 . "KATAKANA LETTER SMALL HU")
(12792 . "KATAKANA LETTER SMALL HE")
(12793 . "KATAKANA LETTER SMALL HO")
(12794 . "KATAKANA LETTER SMALL MU")
(12795 . "KATAKANA LETTER SMALL RA")
(12796 . "KATAKANA LETTER SMALL RI")
(12797 . "KATAKANA LETTER SMALL RU")
(12798 . "KATAKANA LETTER SMALL RE")
(12799 . "KATAKANA LETTER SMALL RO")
(12800 . "PARENTHESIZED HANGUL KIYEOK")
(12801 . "PARENTHESIZED HANGUL NIEUN")
(12802 . "PARENTHESIZED HANGUL TIKEUT")
(12803 . "PARENTHESIZED HANGUL RIEUL")
(12804 . "PARENTHESIZED HANGUL MIEUM")
(12805 . "PARENTHESIZED HANGUL PIEUP")
(12806 . "PARENTHESIZED HANGUL SIOS")
(12807 . "PARENTHESIZED HANGUL IEUNG")
(12808 . "PARENTHESIZED HANGUL CIEUC")
(12809 . "PARENTHESIZED HANGUL CHIEUCH")
(12810 . "PARENTHESIZED HANGUL KHIEUKH")
(12811 . "PARENTHESIZED HANGUL THIEUTH")
(12812 . "PARENTHESIZED HANGUL PHIEUPH")
(12813 . "PARENTHESIZED HANGUL HIEUH")
(12814 . "PARENTHESIZED HANGUL KIYEOK A")
(12815 . "PARENTHESIZED HANGUL NIEUN A")
(12816 . "PARENTHESIZED HANGUL TIKEUT A")
(12817 . "PARENTHESIZED HANGUL RIEUL A")
(12818 . "PARENTHESIZED HANGUL MIEUM A")
(12819 . "PARENTHESIZED HANGUL PIEUP A")
(12820 . "PARENTHESIZED HANGUL SIOS A")
(12821 . "PARENTHESIZED HANGUL IEUNG A")
(12822 . "PARENTHESIZED HANGUL CIEUC A")
(12823 . "PARENTHESIZED HANGUL CHIEUCH A")
(12824 . "PARENTHESIZED HANGUL KHIEUKH A")
(12825 . "PARENTHESIZED HANGUL THIEUTH A")
(12826 . "PARENTHESIZED HANGUL PHIEUPH A")
(12827 . "PARENTHESIZED HANGUL HIEUH A")
(12828 . "PARENTHESIZED HANGUL CIEUC U")
(12829 . "PARENTHESIZED KOREAN CHARACTER OJEON")
(12830 . "PARENTHESIZED KOREAN CHARACTER O HU")
(12831 . #f)
(12832 . "PARENTHESIZED IDEOGRAPH ONE")
(12833 . "PARENTHESIZED IDEOGRAPH TWO")
(12834 . "PARENTHESIZED IDEOGRAPH THREE")
(12835 . "PARENTHESIZED IDEOGRAPH FOUR")
(12836 . "PARENTHESIZED IDEOGRAPH FIVE")
(12837 . "PARENTHESIZED IDEOGRAPH SIX")
(12838 . "PARENTHESIZED IDEOGRAPH SEVEN")
(12839 . "PARENTHESIZED IDEOGRAPH EIGHT")
(12840 . "PARENTHESIZED IDEOGRAPH NINE")
(12841 . "PARENTHESIZED IDEOGRAPH TEN")
(12842 . "PARENTHESIZED IDEOGRAPH MOON")
(12843 . "PARENTHESIZED IDEOGRAPH FIRE")
(12844 . "PARENTHESIZED IDEOGRAPH WATER")
(12845 . "PARENTHESIZED IDEOGRAPH WOOD")
(12846 . "PARENTHESIZED IDEOGRAPH METAL")
(12847 . "PARENTHESIZED IDEOGRAPH EARTH")
(12848 . "PARENTHESIZED IDEOGRAPH SUN")
(12849 . "PARENTHESIZED IDEOGRAPH STOCK")
(12850 . "PARENTHESIZED IDEOGRAPH HAVE")
(12851 . "PARENTHESIZED IDEOGRAPH SOCIETY")
(12852 . "PARENTHESIZED IDEOGRAPH NAME")
(12853 . "PARENTHESIZED IDEOGRAPH SPECIAL")
(12854 . "PARENTHESIZED IDEOGRAPH FINANCIAL")
(12855 . "PARENTHESIZED IDEOGRAPH CONGRATULATION")
(12856 . "PARENTHESIZED IDEOGRAPH LABOR")
(12857 . "PARENTHESIZED IDEOGRAPH REPRESENT")
(12858 . "PARENTHESIZED IDEOGRAPH CALL")
(12859 . "PARENTHESIZED IDEOGRAPH STUDY")
(12860 . "PARENTHESIZED IDEOGRAPH SUPERVISE")
(12861 . "PARENTHESIZED IDEOGRAPH ENTERPRISE")
(12862 . "PARENTHESIZED IDEOGRAPH RESOURCE")
(12863 . "PARENTHESIZED IDEOGRAPH ALLIANCE")
(12864 . "PARENTHESIZED IDEOGRAPH FESTIVAL")
(12865 . "PARENTHESIZED IDEOGRAPH REST")
(12866 . "PARENTHESIZED IDEOGRAPH SELF")
(12867 . "PARENTHESIZED IDEOGRAPH REACH")
(12868 . "CIRCLED IDEOGRAPH QUESTION")
(12869 . "CIRCLED IDEOGRAPH KINDERGARTEN")
(12870 . "CIRCLED IDEOGRAPH SCHOOL")
(12871 . "CIRCLED IDEOGRAPH KOTO")
(12872 . "CIRCLED NUMBER TEN ON BLACK SQUARE")
(12873 . "CIRCLED NUMBER TWENTY ON BLACK SQUARE")
(12874 . "CIRCLED NUMBER THIRTY ON BLACK SQUARE")
(12875 . "CIRCLED NUMBER FORTY ON BLACK SQUARE")
(12876 . "CIRCLED NUMBER FIFTY ON BLACK SQUARE")
(12877 . "CIRCLED NUMBER SIXTY ON BLACK SQUARE")
(12878 . "CIRCLED NUMBER SEVENTY ON BLACK SQUARE")
(12879 . "CIRCLED NUMBER EIGHTY ON BLACK SQUARE")
(12880 . "PARTNERSHIP SIGN")
(12881 . "CIRCLED NUMBER TWENTY ONE")
(12882 . "CIRCLED NUMBER TWENTY TWO")
(12883 . "CIRCLED NUMBER TWENTY THREE")
(12884 . "CIRCLED NUMBER TWENTY FOUR")
(12885 . "CIRCLED NUMBER TWENTY FIVE")
(12886 . "CIRCLED NUMBER TWENTY SIX")
(12887 . "CIRCLED NUMBER TWENTY SEVEN")
(12888 . "CIRCLED NUMBER TWENTY EIGHT")
(12889 . "CIRCLED NUMBER TWENTY NINE")
(12890 . "CIRCLED NUMBER THIRTY")
(12891 . "CIRCLED NUMBER THIRTY ONE")
(12892 . "CIRCLED NUMBER THIRTY TWO")
(12893 . "CIRCLED NUMBER THIRTY THREE")
(12894 . "CIRCLED NUMBER THIRTY FOUR")
(12895 . "CIRCLED NUMBER THIRTY FIVE")
(12896 . "CIRCLED HANGUL KIYEOK")
(12897 . "CIRCLED HANGUL NIEUN")
(12898 . "CIRCLED HANGUL TIKEUT")
(12899 . "CIRCLED HANGUL RIEUL")
(12900 . "CIRCLED HANGUL MIEUM")
(12901 . "CIRCLED HANGUL PIEUP")
(12902 . "CIRCLED HANGUL SIOS")
(12903 . "CIRCLED HANGUL IEUNG")
(12904 . "CIRCLED HANGUL CIEUC")
(12905 . "CIRCLED HANGUL CHIEUCH")
(12906 . "CIRCLED HANGUL KHIEUKH")
(12907 . "CIRCLED HANGUL THIEUTH")
(12908 . "CIRCLED HANGUL PHIEUPH")
(12909 . "CIRCLED HANGUL HIEUH")
(12910 . "CIRCLED HANGUL KIYEOK A")
(12911 . "CIRCLED HANGUL NIEUN A")
(12912 . "CIRCLED HANGUL TIKEUT A")
(12913 . "CIRCLED HANGUL RIEUL A")
(12914 . "CIRCLED HANGUL MIEUM A")
(12915 . "CIRCLED HANGUL PIEUP A")
(12916 . "CIRCLED HANGUL SIOS A")
(12917 . "CIRCLED HANGUL IEUNG A")
(12918 . "CIRCLED HANGUL CIEUC A")
(12919 . "CIRCLED HANGUL CHIEUCH A")
(12920 . "CIRCLED HANGUL KHIEUKH A")
(12921 . "CIRCLED HANGUL THIEUTH A")
(12922 . "CIRCLED HANGUL PHIEUPH A")
(12923 . "CIRCLED HANGUL HIEUH A")
(12924 . "CIRCLED KOREAN CHARACTER CHAMKO")
(12925 . "CIRCLED KOREAN CHARACTER JUEUI")
(12926 . "CIRCLED HANGUL IEUNG U")
(12927 . "KOREAN STANDARD SYMBOL")
(12928 . "CIRCLED IDEOGRAPH ONE")
(12929 . "CIRCLED IDEOGRAPH TWO")
(12930 . "CIRCLED IDEOGRAPH THREE")
(12931 . "CIRCLED IDEOGRAPH FOUR")
(12932 . "CIRCLED IDEOGRAPH FIVE")
(12933 . "CIRCLED IDEOGRAPH SIX")
(12934 . "CIRCLED IDEOGRAPH SEVEN")
(12935 . "CIRCLED IDEOGRAPH EIGHT")
(12936 . "CIRCLED IDEOGRAPH NINE")
(12937 . "CIRCLED IDEOGRAPH TEN")
(12938 . "CIRCLED IDEOGRAPH MOON")
(12939 . "CIRCLED IDEOGRAPH FIRE")
(12940 . "CIRCLED IDEOGRAPH WATER")
(12941 . "CIRCLED IDEOGRAPH WOOD")
(12942 . "CIRCLED IDEOGRAPH METAL")
(12943 . "CIRCLED IDEOGRAPH EARTH")
(12944 . "CIRCLED IDEOGRAPH SUN")
(12945 . "CIRCLED IDEOGRAPH STOCK")
(12946 . "CIRCLED IDEOGRAPH HAVE")
(12947 . "CIRCLED IDEOGRAPH SOCIETY")
(12948 . "CIRCLED IDEOGRAPH NAME")
(12949 . "CIRCLED IDEOGRAPH SPECIAL")
(12950 . "CIRCLED IDEOGRAPH FINANCIAL")
(12951 . "CIRCLED IDEOGRAPH CONGRATULATION")
(12952 . "CIRCLED IDEOGRAPH LABOR")
(12953 . "CIRCLED IDEOGRAPH SECRET")
(12954 . "CIRCLED IDEOGRAPH MALE")
(12955 . "CIRCLED IDEOGRAPH FEMALE")
(12956 . "CIRCLED IDEOGRAPH SUITABLE")
(12957 . "CIRCLED IDEOGRAPH EXCELLENT")
(12958 . "CIRCLED IDEOGRAPH PRINT")
(12959 . "CIRCLED IDEOGRAPH ATTENTION")
(12960 . "CIRCLED IDEOGRAPH ITEM")
(12961 . "CIRCLED IDEOGRAPH REST")
(12962 . "CIRCLED IDEOGRAPH COPY")
(12963 . "CIRCLED IDEOGRAPH CORRECT")
(12964 . "CIRCLED IDEOGRAPH HIGH")
(12965 . "CIRCLED IDEOGRAPH CENTRE")
(12966 . "CIRCLED IDEOGRAPH LOW")
(12967 . "CIRCLED IDEOGRAPH LEFT")
(12968 . "CIRCLED IDEOGRAPH RIGHT")
(12969 . "CIRCLED IDEOGRAPH MEDICINE")
(12970 . "CIRCLED IDEOGRAPH RELIGION")
(12971 . "CIRCLED IDEOGRAPH STUDY")
(12972 . "CIRCLED IDEOGRAPH SUPERVISE")
(12973 . "CIRCLED IDEOGRAPH ENTERPRISE")
(12974 . "CIRCLED IDEOGRAPH RESOURCE")
(12975 . "CIRCLED IDEOGRAPH ALLIANCE")
(12976 . "CIRCLED IDEOGRAPH NIGHT")
(12977 . "CIRCLED NUMBER THIRTY SIX")
(12978 . "CIRCLED NUMBER THIRTY SEVEN")
(12979 . "CIRCLED NUMBER THIRTY EIGHT")
(12980 . "CIRCLED NUMBER THIRTY NINE")
(12981 . "CIRCLED NUMBER FORTY")
(12982 . "CIRCLED NUMBER FORTY ONE")
(12983 . "CIRCLED NUMBER FORTY TWO")
(12984 . "CIRCLED NUMBER FORTY THREE")
(12985 . "CIRCLED NUMBER FORTY FOUR")
(12986 . "CIRCLED NUMBER FORTY FIVE")
(12987 . "CIRCLED NUMBER FORTY SIX")
(12988 . "CIRCLED NUMBER FORTY SEVEN")
(12989 . "CIRCLED NUMBER FORTY EIGHT")
(12990 . "CIRCLED NUMBER FORTY NINE")
(12991 . "CIRCLED NUMBER FIFTY")
(12992 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR JANUARY")
(12993 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR FEBRUARY")
(12994 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR MARCH")
(12995 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR APRIL")
(12996 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR MAY")
(12997 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR JUNE")
(12998 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR JULY")
(12999 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR AUGUST")
(13000 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR SEPTEMBER")
(13001 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR OCTOBER")
(13002 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR NOVEMBER")
(13003 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DECEMBER")
(13004 . "SQUARE HG")
(13005 . "SQUARE ERG")
(13006 . "SQUARE EV")
(13007 . "LIMITED LIABILITY SIGN")
(13008 . "CIRCLED KATAKANA A")
(13009 . "CIRCLED KATAKANA I")
(13010 . "CIRCLED KATAKANA U")
(13011 . "CIRCLED KATAKANA E")
(13012 . "CIRCLED KATAKANA O")
(13013 . "CIRCLED KATAKANA KA")
(13014 . "CIRCLED KATAKANA KI")
(13015 . "CIRCLED KATAKANA KU")
(13016 . "CIRCLED KATAKANA KE")
(13017 . "CIRCLED KATAKANA KO")
(13018 . "CIRCLED KATAKANA SA")
(13019 . "CIRCLED KATAKANA SI")
(13020 . "CIRCLED KATAKANA SU")
(13021 . "CIRCLED KATAKANA SE")
(13022 . "CIRCLED KATAKANA SO")
(13023 . "CIRCLED KATAKANA TA")
(13024 . "CIRCLED KATAKANA TI")
(13025 . "CIRCLED KATAKANA TU")
(13026 . "CIRCLED KATAKANA TE")
(13027 . "CIRCLED KATAKANA TO")
(13028 . "CIRCLED KATAKANA NA")
(13029 . "CIRCLED KATAKANA NI")
(13030 . "CIRCLED KATAKANA NU")
(13031 . "CIRCLED KATAKANA NE")
(13032 . "CIRCLED KATAKANA NO")
(13033 . "CIRCLED KATAKANA HA")
(13034 . "CIRCLED KATAKANA HI")
(13035 . "CIRCLED KATAKANA HU")
(13036 . "CIRCLED KATAKANA HE")
(13037 . "CIRCLED KATAKANA HO")
(13038 . "CIRCLED KATAKANA MA")
(13039 . "CIRCLED KATAKANA MI")
(13040 . "CIRCLED KATAKANA MU")
(13041 . "CIRCLED KATAKANA ME")
(13042 . "CIRCLED KATAKANA MO")
(13043 . "CIRCLED KATAKANA YA")
(13044 . "CIRCLED KATAKANA YU")
(13045 . "CIRCLED KATAKANA YO")
(13046 . "CIRCLED KATAKANA RA")
(13047 . "CIRCLED KATAKANA RI")
(13048 . "CIRCLED KATAKANA RU")
(13049 . "CIRCLED KATAKANA RE")
(13050 . "CIRCLED KATAKANA RO")
(13051 . "CIRCLED KATAKANA WA")
(13052 . "CIRCLED KATAKANA WI")
(13053 . "CIRCLED KATAKANA WE")
(13054 . "CIRCLED KATAKANA WO")
(13055 . #f)
(13056 . "SQUARE APAATO")
(13057 . "SQUARE ARUHUA")
(13058 . "SQUARE ANPEA")
(13059 . "SQUARE AARU")
(13060 . "SQUARE ININGU")
(13061 . "SQUARE INTI")
(13062 . "SQUARE UON")
(13063 . "SQUARE ESUKUUDO")
(13064 . "SQUARE EEKAA")
(13065 . "SQUARE ONSU")
(13066 . "SQUARE OOMU")
(13067 . "SQUARE KAIRI")
(13068 . "SQUARE KARATTO")
(13069 . "SQUARE KARORII")
(13070 . "SQUARE GARON")
(13071 . "SQUARE GANMA")
(13072 . "SQUARE GIGA")
(13073 . "SQUARE GINII")
(13074 . "SQUARE KYURII")
(13075 . "SQUARE GIRUDAA")
(13076 . "SQUARE KIRO")
(13077 . "SQUARE KIROGURAMU")
(13078 . "SQUARE KIROMEETORU")
(13079 . "SQUARE KIROWATTO")
(13080 . "SQUARE GURAMU")
(13081 . "SQUARE GURAMUTON")
(13082 . "SQUARE KURUZEIRO")
(13083 . "SQUARE KUROONE")
(13084 . "SQUARE KEESU")
(13085 . "SQUARE KORUNA")
(13086 . "SQUARE KOOPO")
(13087 . "SQUARE SAIKURU")
(13088 . "SQUARE SANTIIMU")
(13089 . "SQUARE SIRINGU")
(13090 . "SQUARE SENTI")
(13091 . "SQUARE SENTO")
(13092 . "SQUARE DAASU")
(13093 . "SQUARE DESI")
(13094 . "SQUARE DORU")
(13095 . "SQUARE TON")
(13096 . "SQUARE NANO")
(13097 . "SQUARE NOTTO")
(13098 . "SQUARE HAITU")
(13099 . "SQUARE PAASENTO")
(13100 . "SQUARE PAATU")
(13101 . "SQUARE BAARERU")
(13102 . "SQUARE PIASUTORU")
(13103 . "SQUARE PIKURU")
(13104 . "SQUARE PIKO")
(13105 . "SQUARE BIRU")
(13106 . "SQUARE HUARADDO")
(13107 . "SQUARE HUIITO")
(13108 . "SQUARE BUSSYERU")
(13109 . "SQUARE HURAN")
(13110 . "SQUARE HEKUTAARU")
(13111 . "SQUARE PESO")
(13112 . "SQUARE PENIHI")
(13113 . "SQUARE HERUTU")
(13114 . "SQUARE PENSU")
(13115 . "SQUARE PEEZI")
(13116 . "SQUARE BEETA")
(13117 . "SQUARE POINTO")
(13118 . "SQUARE BORUTO")
(13119 . "SQUARE HON")
(13120 . "SQUARE PONDO")
(13121 . "SQUARE HOORU")
(13122 . "SQUARE HOON")
(13123 . "SQUARE MAIKURO")
(13124 . "SQUARE MAIRU")
(13125 . "SQUARE MAHHA")
(13126 . "SQUARE MARUKU")
(13127 . "SQUARE MANSYON")
(13128 . "SQUARE MIKURON")
(13129 . "SQUARE MIRI")
(13130 . "SQUARE MIRIBAARU")
(13131 . "SQUARE MEGA")
(13132 . "SQUARE MEGATON")
(13133 . "SQUARE MEETORU")
(13134 . "SQUARE YAADO")
(13135 . "SQUARE YAARU")
(13136 . "SQUARE YUAN")
(13137 . "SQUARE RITTORU")
(13138 . "SQUARE RIRA")
(13139 . "SQUARE RUPII")
(13140 . "SQUARE RUUBURU")
(13141 . "SQUARE REMU")
(13142 . "SQUARE RENTOGEN")
(13143 . "SQUARE WATTO")
(13144 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ZERO")
(13145 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ONE")
(13146 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWO")
(13147 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THREE")
(13148 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOUR")
(13149 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIVE")
(13150 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIX")
(13151 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVEN")
(13152 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHT")
(13153 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINE")
(13154 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TEN")
(13155 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ELEVEN")
(13156 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWELVE")
(13157 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THIRTEEN")
(13158 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOURTEEN")
(13159 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIFTEEN")
(13160 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIXTEEN")
(13161 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVENTEEN")
(13162 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHTEEN")
(13163 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINETEEN")
(13164 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY")
(13165 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-ONE")
(13166 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-TWO")
(13167 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-THREE")
(13168 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-FOUR")
(13169 . "SQUARE HPA")
(13170 . "SQUARE DA")
(13171 . "SQUARE AU")
(13172 . "SQUARE BAR")
(13173 . "SQUARE OV")
(13174 . "SQUARE PC")
(13175 . "SQUARE DM")
(13176 . "SQUARE DM SQUARED")
(13177 . "SQUARE DM CUBED")
(13178 . "SQUARE IU")
(13179 . "SQUARE ERA NAME HEISEI")
(13180 . "SQUARE ERA NAME SYOUWA")
(13181 . "SQUARE ERA NAME TAISYOU")
(13182 . "SQUARE ERA NAME MEIZI")
(13183 . "SQUARE CORPORATION")
(13184 . "SQUARE PA AMPS")
(13185 . "SQUARE NA")
(13186 . "SQUARE MU A")
(13187 . "SQUARE MA")
(13188 . "SQUARE KA")
(13189 . "SQUARE KB")
(13190 . "SQUARE MB")
(13191 . "SQUARE GB")
(13192 . "SQUARE CAL")
(13193 . "SQUARE KCAL")
(13194 . "SQUARE PF")
(13195 . "SQUARE NF")
(13196 . "SQUARE MU F")
(13197 . "SQUARE MU G")
(13198 . "SQUARE MG")
(13199 . "SQUARE KG")
(13200 . "SQUARE HZ")
(13201 . "SQUARE KHZ")
(13202 . "SQUARE MHZ")
(13203 . "SQUARE GHZ")
(13204 . "SQUARE THZ")
(13205 . "SQUARE MU L")
(13206 . "SQUARE ML")
(13207 . "SQUARE DL")
(13208 . "SQUARE KL")
(13209 . "SQUARE FM")
(13210 . "SQUARE NM")
(13211 . "SQUARE MU M")
(13212 . "SQUARE MM")
(13213 . "SQUARE CM")
(13214 . "SQUARE KM")
(13215 . "SQUARE MM SQUARED")
(13216 . "SQUARE CM SQUARED")
(13217 . "SQUARE M SQUARED")
(13218 . "SQUARE KM SQUARED")
(13219 . "SQUARE MM CUBED")
(13220 . "SQUARE CM CUBED")
(13221 . "SQUARE M CUBED")
(13222 . "SQUARE KM CUBED")
(13223 . "SQUARE M OVER S")
(13224 . "SQUARE M OVER S SQUARED")
(13225 . "SQUARE PA")
(13226 . "SQUARE KPA")
(13227 . "SQUARE MPA")
(13228 . "SQUARE GPA")
(13229 . "SQUARE RAD")
(13230 . "SQUARE RAD OVER S")
(13231 . "SQUARE RAD OVER S SQUARED")
(13232 . "SQUARE PS")
(13233 . "SQUARE NS")
(13234 . "SQUARE MU S")
(13235 . "SQUARE MS")
(13236 . "SQUARE PV")
(13237 . "SQUARE NV")
(13238 . "SQUARE MU V")
(13239 . "SQUARE MV")
(13240 . "SQUARE KV")
(13241 . "SQUARE MV MEGA")
(13242 . "SQUARE PW")
(13243 . "SQUARE NW")
(13244 . "SQUARE MU W")
(13245 . "SQUARE MW")
(13246 . "SQUARE KW")
(13247 . "SQUARE MW MEGA")
(13248 . "SQUARE K OHM")
(13249 . "SQUARE M OHM")
(13250 . "SQUARE AM")
(13251 . "SQUARE BQ")
(13252 . "SQUARE CC")
(13253 . "SQUARE CD")
(13254 . "SQUARE C OVER KG")
(13255 . "SQUARE CO")
(13256 . "SQUARE DB")
(13257 . "SQUARE GY")
(13258 . "SQUARE HA")
(13259 . "SQUARE HP")
(13260 . "SQUARE IN")
(13261 . "SQUARE KK")
(13262 . "SQUARE KM CAPITAL")
(13263 . "SQUARE KT")
(13264 . "SQUARE LM")
(13265 . "SQUARE LN")
(13266 . "SQUARE LOG")
(13267 . "SQUARE LX")
(13268 . "SQUARE MB SMALL")
(13269 . "SQUARE MIL")
(13270 . "SQUARE MOL")
(13271 . "SQUARE PH")
(13272 . "SQUARE PM")
(13273 . "SQUARE PPM")
(13274 . "SQUARE PR")
(13275 . "SQUARE SR")
(13276 . "SQUARE SV")
(13277 . "SQUARE WB")
(13278 . "SQUARE V OVER M")
(13279 . "SQUARE A OVER M")
(13280 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ONE")
(13281 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWO")
(13282 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THREE")
(13283 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOUR")
(13284 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIVE")
(13285 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIX")
(13286 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVEN")
(13287 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHT")
(13288 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINE")
(13289 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TEN")
(13290 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ELEVEN")
(13291 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWELVE")
(13292 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTEEN")
(13293 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOURTEEN")
(13294 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIFTEEN")
(13295 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIXTEEN")
(13296 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVENTEEN")
(13297 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHTEEN")
(13298 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINETEEN")
(13299 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY")
(13300 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-ONE")
(13301 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-TWO")
(13302 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-THREE")
(13303 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FOUR")
(13304 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FIVE")
(13305 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SIX")
(13306 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SEVEN")
(13307 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-EIGHT")
(13308 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-NINE")
(13309 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY")
(13310 . "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY-ONE")
(13311 . "SQUARE GAL")
((13312 . 19904) . "CJK UNIFIED IDEOGRAPH-#")
(19904 . "HEXAGRAM FOR THE CREATIVE HEAVEN")
(19905 . "HEXAGRAM FOR THE RECEPTIVE EARTH")
(19906 . "HEXAGRAM FOR DIFFICULTY AT THE BEGINNING")
(19907 . "HEXAGRAM FOR YOUTHFUL FOLLY")
(19908 . "HEXAGRAM FOR WAITING")
(19909 . "HEXAGRAM FOR CONFLICT")
(19910 . "HEXAGRAM FOR THE ARMY")
(19911 . "HEXAGRAM FOR HOLDING TOGETHER")
(19912 . "HEXAGRAM FOR SMALL TAMING")
(19913 . "HEXAGRAM FOR TREADING")
(19914 . "HEXAGRAM FOR PEACE")
(19915 . "HEXAGRAM FOR STANDSTILL")
(19916 . "HEXAGRAM FOR FELLOWSHIP")
(19917 . "HEXAGRAM FOR GREAT POSSESSION")
(19918 . "HEXAGRAM FOR MODESTY")
(19919 . "HEXAGRAM FOR ENTHUSIASM")
(19920 . "HEXAGRAM FOR FOLLOWING")
(19921 . "HEXAGRAM FOR WORK ON THE DECAYED")
(19922 . "HEXAGRAM FOR APPROACH")
(19923 . "HEXAGRAM FOR CONTEMPLATION")
(19924 . "HEXAGRAM FOR BITING THROUGH")
(19925 . "HEXAGRAM FOR GRACE")
(19926 . "HEXAGRAM FOR SPLITTING APART")
(19927 . "HEXAGRAM FOR RETURN")
(19928 . "HEXAGRAM FOR INNOCENCE")
(19929 . "HEXAGRAM FOR GREAT TAMING")
(19930 . "HEXAGRAM FOR MOUTH CORNERS")
(19931 . "HEXAGRAM FOR GREAT PREPONDERANCE")
(19932 . "HEXAGRAM FOR THE ABYSMAL WATER")
(19933 . "HEXAGRAM FOR THE CLINGING FIRE")
(19934 . "HEXAGRAM FOR INFLUENCE")
(19935 . "HEXAGRAM FOR DURATION")
(19936 . "HEXAGRAM FOR RETREAT")
(19937 . "HEXAGRAM FOR GREAT POWER")
(19938 . "HEXAGRAM FOR PROGRESS")
(19939 . "HEXAGRAM FOR DARKENING OF THE LIGHT")
(19940 . "HEXAGRAM FOR THE FAMILY")
(19941 . "HEXAGRAM FOR OPPOSITION")
(19942 . "HEXAGRAM FOR OBSTRUCTION")
(19943 . "HEXAGRAM FOR DELIVERANCE")
(19944 . "HEXAGRAM FOR DECREASE")
(19945 . "HEXAGRAM FOR INCREASE")
(19946 . "HEXAGRAM FOR BREAKTHROUGH")
(19947 . "HEXAGRAM FOR COMING TO MEET")
(19948 . "HEXAGRAM FOR GATHERING TOGETHER")
(19949 . "HEXAGRAM FOR PUSHING UPWARD")
(19950 . "HEXAGRAM FOR OPPRESSION")
(19951 . "HEXAGRAM FOR THE WELL")
(19952 . "HEXAGRAM FOR REVOLUTION")
(19953 . "HEXAGRAM FOR THE CAULDRON")
(19954 . "HEXAGRAM FOR THE AROUSING THUNDER")
(19955 . "HEXAGRAM FOR THE KEEPING STILL MOUNTAIN")
(19956 . "HEXAGRAM FOR DEVELOPMENT")
(19957 . "HEXAGRAM FOR THE MARRYING MAIDEN")
(19958 . "HEXAGRAM FOR ABUNDANCE")
(19959 . "HEXAGRAM FOR THE WANDERER")
(19960 . "HEXAGRAM FOR THE GENTLE WIND")
(19961 . "HEXAGRAM FOR THE JOYOUS LAKE")
(19962 . "HEXAGRAM FOR DISPERSION")
(19963 . "HEXAGRAM FOR LIMITATION")
(19964 . "HEXAGRAM FOR INNER TRUTH")
(19965 . "HEXAGRAM FOR SMALL PREPONDERANCE")
(19966 . "HEXAGRAM FOR AFTER COMPLETION")
(19967 . "HEXAGRAM FOR BEFORE COMPLETION")
((19968 . 40960) . "CJK UNIFIED IDEOGRAPH-#")
(40960 . "YI SYLLABLE IT")
(40961 . "YI SYLLABLE IX")
(40962 . "YI SYLLABLE I")
(40963 . "YI SYLLABLE IP")
(40964 . "YI SYLLABLE IET")
(40965 . "YI SYLLABLE IEX")
(40966 . "YI SYLLABLE IE")
(40967 . "YI SYLLABLE IEP")
(40968 . "YI SYLLABLE AT")
(40969 . "YI SYLLABLE AX")
(40970 . "YI SYLLABLE A")
(40971 . "YI SYLLABLE AP")
(40972 . "YI SYLLABLE UOX")
(40973 . "YI SYLLABLE UO")
(40974 . "YI SYLLABLE UOP")
(40975 . "YI SYLLABLE OT")
(40976 . "YI SYLLABLE OX")
(40977 . "YI SYLLABLE O")
(40978 . "YI SYLLABLE OP")
(40979 . "YI SYLLABLE EX")
(40980 . "YI SYLLABLE E")
(40981 . "YI SYLLABLE WU")
(40982 . "YI SYLLABLE BIT")
(40983 . "YI SYLLABLE BIX")
(40984 . "YI SYLLABLE BI")
(40985 . "YI SYLLABLE BIP")
(40986 . "YI SYLLABLE BIET")
(40987 . "YI SYLLABLE BIEX")
(40988 . "YI SYLLABLE BIE")
(40989 . "YI SYLLABLE BIEP")
(40990 . "YI SYLLABLE BAT")
(40991 . "YI SYLLABLE BAX")
(40992 . "YI SYLLABLE BA")
(40993 . "YI SYLLABLE BAP")
(40994 . "YI SYLLABLE BUOX")
(40995 . "YI SYLLABLE BUO")
(40996 . "YI SYLLABLE BUOP")
(40997 . "YI SYLLABLE BOT")
(40998 . "YI SYLLABLE BOX")
(40999 . "YI SYLLABLE BO")
(41000 . "YI SYLLABLE BOP")
(41001 . "YI SYLLABLE BEX")
(41002 . "YI SYLLABLE BE")
(41003 . "YI SYLLABLE BEP")
(41004 . "YI SYLLABLE BUT")
(41005 . "YI SYLLABLE BUX")
(41006 . "YI SYLLABLE BU")
(41007 . "YI SYLLABLE BUP")
(41008 . "YI SYLLABLE BURX")
(41009 . "YI SYLLABLE BUR")
(41010 . "YI SYLLABLE BYT")
(41011 . "YI SYLLABLE BYX")
(41012 . "YI SYLLABLE BY")
(41013 . "YI SYLLABLE BYP")
(41014 . "YI SYLLABLE BYRX")
(41015 . "YI SYLLABLE BYR")
(41016 . "YI SYLLABLE PIT")
(41017 . "YI SYLLABLE PIX")
(41018 . "YI SYLLABLE PI")
(41019 . "YI SYLLABLE PIP")
(41020 . "YI SYLLABLE PIEX")
(41021 . "YI SYLLABLE PIE")
(41022 . "YI SYLLABLE PIEP")
(41023 . "YI SYLLABLE PAT")
(41024 . "YI SYLLABLE PAX")
(41025 . "YI SYLLABLE PA")
(41026 . "YI SYLLABLE PAP")
(41027 . "YI SYLLABLE PUOX")
(41028 . "YI SYLLABLE PUO")
(41029 . "YI SYLLABLE PUOP")
(41030 . "YI SYLLABLE POT")
(41031 . "YI SYLLABLE POX")
(41032 . "YI SYLLABLE PO")
(41033 . "YI SYLLABLE POP")
(41034 . "YI SYLLABLE PUT")
(41035 . "YI SYLLABLE PUX")
(41036 . "YI SYLLABLE PU")
(41037 . "YI SYLLABLE PUP")
(41038 . "YI SYLLABLE PURX")
(41039 . "YI SYLLABLE PUR")
(41040 . "YI SYLLABLE PYT")
(41041 . "YI SYLLABLE PYX")
(41042 . "YI SYLLABLE PY")
(41043 . "YI SYLLABLE PYP")
(41044 . "YI SYLLABLE PYRX")
(41045 . "YI SYLLABLE PYR")
(41046 . "YI SYLLABLE BBIT")
(41047 . "YI SYLLABLE BBIX")
(41048 . "YI SYLLABLE BBI")
(41049 . "YI SYLLABLE BBIP")
(41050 . "YI SYLLABLE BBIET")
(41051 . "YI SYLLABLE BBIEX")
(41052 . "YI SYLLABLE BBIE")
(41053 . "YI SYLLABLE BBIEP")
(41054 . "YI SYLLABLE BBAT")
(41055 . "YI SYLLABLE BBAX")
(41056 . "YI SYLLABLE BBA")
(41057 . "YI SYLLABLE BBAP")
(41058 . "YI SYLLABLE BBUOX")
(41059 . "YI SYLLABLE BBUO")
(41060 . "YI SYLLABLE BBUOP")
(41061 . "YI SYLLABLE BBOT")
(41062 . "YI SYLLABLE BBOX")
(41063 . "YI SYLLABLE BBO")
(41064 . "YI SYLLABLE BBOP")
(41065 . "YI SYLLABLE BBEX")
(41066 . "YI SYLLABLE BBE")
(41067 . "YI SYLLABLE BBEP")
(41068 . "YI SYLLABLE BBUT")
(41069 . "YI SYLLABLE BBUX")
(41070 . "YI SYLLABLE BBU")
(41071 . "YI SYLLABLE BBUP")
(41072 . "YI SYLLABLE BBURX")
(41073 . "YI SYLLABLE BBUR")
(41074 . "YI SYLLABLE BBYT")
(41075 . "YI SYLLABLE BBYX")
(41076 . "YI SYLLABLE BBY")
(41077 . "YI SYLLABLE BBYP")
(41078 . "YI SYLLABLE NBIT")
(41079 . "YI SYLLABLE NBIX")
(41080 . "YI SYLLABLE NBI")
(41081 . "YI SYLLABLE NBIP")
(41082 . "YI SYLLABLE NBIEX")
(41083 . "YI SYLLABLE NBIE")
(41084 . "YI SYLLABLE NBIEP")
(41085 . "YI SYLLABLE NBAT")
(41086 . "YI SYLLABLE NBAX")
(41087 . "YI SYLLABLE NBA")
(41088 . "YI SYLLABLE NBAP")
(41089 . "YI SYLLABLE NBOT")
(41090 . "YI SYLLABLE NBOX")
(41091 . "YI SYLLABLE NBO")
(41092 . "YI SYLLABLE NBOP")
(41093 . "YI SYLLABLE NBUT")
(41094 . "YI SYLLABLE NBUX")
(41095 . "YI SYLLABLE NBU")
(41096 . "YI SYLLABLE NBUP")
(41097 . "YI SYLLABLE NBURX")
(41098 . "YI SYLLABLE NBUR")
(41099 . "YI SYLLABLE NBYT")
(41100 . "YI SYLLABLE NBYX")
(41101 . "YI SYLLABLE NBY")
(41102 . "YI SYLLABLE NBYP")
(41103 . "YI SYLLABLE NBYRX")
(41104 . "YI SYLLABLE NBYR")
(41105 . "YI SYLLABLE HMIT")
(41106 . "YI SYLLABLE HMIX")
(41107 . "YI SYLLABLE HMI")
(41108 . "YI SYLLABLE HMIP")
(41109 . "YI SYLLABLE HMIEX")
(41110 . "YI SYLLABLE HMIE")
(41111 . "YI SYLLABLE HMIEP")
(41112 . "YI SYLLABLE HMAT")
(41113 . "YI SYLLABLE HMAX")
(41114 . "YI SYLLABLE HMA")
(41115 . "YI SYLLABLE HMAP")
(41116 . "YI SYLLABLE HMUOX")
(41117 . "YI SYLLABLE HMUO")
(41118 . "YI SYLLABLE HMUOP")
(41119 . "YI SYLLABLE HMOT")
(41120 . "YI SYLLABLE HMOX")
(41121 . "YI SYLLABLE HMO")
(41122 . "YI SYLLABLE HMOP")
(41123 . "YI SYLLABLE HMUT")
(41124 . "YI SYLLABLE HMUX")
(41125 . "YI SYLLABLE HMU")
(41126 . "YI SYLLABLE HMUP")
(41127 . "YI SYLLABLE HMURX")
(41128 . "YI SYLLABLE HMUR")
(41129 . "YI SYLLABLE HMYX")
(41130 . "YI SYLLABLE HMY")
(41131 . "YI SYLLABLE HMYP")
(41132 . "YI SYLLABLE HMYRX")
(41133 . "YI SYLLABLE HMYR")
(41134 . "YI SYLLABLE MIT")
(41135 . "YI SYLLABLE MIX")
(41136 . "YI SYLLABLE MI")
(41137 . "YI SYLLABLE MIP")
(41138 . "YI SYLLABLE MIEX")
(41139 . "YI SYLLABLE MIE")
(41140 . "YI SYLLABLE MIEP")
(41141 . "YI SYLLABLE MAT")
(41142 . "YI SYLLABLE MAX")
(41143 . "YI SYLLABLE MA")
(41144 . "YI SYLLABLE MAP")
(41145 . "YI SYLLABLE MUOT")
(41146 . "YI SYLLABLE MUOX")
(41147 . "YI SYLLABLE MUO")
(41148 . "YI SYLLABLE MUOP")
(41149 . "YI SYLLABLE MOT")
(41150 . "YI SYLLABLE MOX")
(41151 . "YI SYLLABLE MO")
(41152 . "YI SYLLABLE MOP")
(41153 . "YI SYLLABLE MEX")
(41154 . "YI SYLLABLE ME")
(41155 . "YI SYLLABLE MUT")
(41156 . "YI SYLLABLE MUX")
(41157 . "YI SYLLABLE MU")
(41158 . "YI SYLLABLE MUP")
(41159 . "YI SYLLABLE MURX")
(41160 . "YI SYLLABLE MUR")
(41161 . "YI SYLLABLE MYT")
(41162 . "YI SYLLABLE MYX")
(41163 . "YI SYLLABLE MY")
(41164 . "YI SYLLABLE MYP")
(41165 . "YI SYLLABLE FIT")
(41166 . "YI SYLLABLE FIX")
(41167 . "YI SYLLABLE FI")
(41168 . "YI SYLLABLE FIP")
(41169 . "YI SYLLABLE FAT")
(41170 . "YI SYLLABLE FAX")
(41171 . "YI SYLLABLE FA")
(41172 . "YI SYLLABLE FAP")
(41173 . "YI SYLLABLE FOX")
(41174 . "YI SYLLABLE FO")
(41175 . "YI SYLLABLE FOP")
(41176 . "YI SYLLABLE FUT")
(41177 . "YI SYLLABLE FUX")
(41178 . "YI SYLLABLE FU")
(41179 . "YI SYLLABLE FUP")
(41180 . "YI SYLLABLE FURX")
(41181 . "YI SYLLABLE FUR")
(41182 . "YI SYLLABLE FYT")
(41183 . "YI SYLLABLE FYX")
(41184 . "YI SYLLABLE FY")
(41185 . "YI SYLLABLE FYP")
(41186 . "YI SYLLABLE VIT")
(41187 . "YI SYLLABLE VIX")
(41188 . "YI SYLLABLE VI")
(41189 . "YI SYLLABLE VIP")
(41190 . "YI SYLLABLE VIET")
(41191 . "YI SYLLABLE VIEX")
(41192 . "YI SYLLABLE VIE")
(41193 . "YI SYLLABLE VIEP")
(41194 . "YI SYLLABLE VAT")
(41195 . "YI SYLLABLE VAX")
(41196 . "YI SYLLABLE VA")
(41197 . "YI SYLLABLE VAP")
(41198 . "YI SYLLABLE VOT")
(41199 . "YI SYLLABLE VOX")
(41200 . "YI SYLLABLE VO")
(41201 . "YI SYLLABLE VOP")
(41202 . "YI SYLLABLE VEX")
(41203 . "YI SYLLABLE VEP")
(41204 . "YI SYLLABLE VUT")
(41205 . "YI SYLLABLE VUX")
(41206 . "YI SYLLABLE VU")
(41207 . "YI SYLLABLE VUP")
(41208 . "YI SYLLABLE VURX")
(41209 . "YI SYLLABLE VUR")
(41210 . "YI SYLLABLE VYT")
(41211 . "YI SYLLABLE VYX")
(41212 . "YI SYLLABLE VY")
(41213 . "YI SYLLABLE VYP")
(41214 . "YI SYLLABLE VYRX")
(41215 . "YI SYLLABLE VYR")
(41216 . "YI SYLLABLE DIT")
(41217 . "YI SYLLABLE DIX")
(41218 . "YI SYLLABLE DI")
(41219 . "YI SYLLABLE DIP")
(41220 . "YI SYLLABLE DIEX")
(41221 . "YI SYLLABLE DIE")
(41222 . "YI SYLLABLE DIEP")
(41223 . "YI SYLLABLE DAT")
(41224 . "YI SYLLABLE DAX")
(41225 . "YI SYLLABLE DA")
(41226 . "YI SYLLABLE DAP")
(41227 . "YI SYLLABLE DUOX")
(41228 . "YI SYLLABLE DUO")
(41229 . "YI SYLLABLE DOT")
(41230 . "YI SYLLABLE DOX")
(41231 . "YI SYLLABLE DO")
(41232 . "YI SYLLABLE DOP")
(41233 . "YI SYLLABLE DEX")
(41234 . "YI SYLLABLE DE")
(41235 . "YI SYLLABLE DEP")
(41236 . "YI SYLLABLE DUT")
(41237 . "YI SYLLABLE DUX")
(41238 . "YI SYLLABLE DU")
(41239 . "YI SYLLABLE DUP")
(41240 . "YI SYLLABLE DURX")
(41241 . "YI SYLLABLE DUR")
(41242 . "YI SYLLABLE TIT")
(41243 . "YI SYLLABLE TIX")
(41244 . "YI SYLLABLE TI")
(41245 . "YI SYLLABLE TIP")
(41246 . "YI SYLLABLE TIEX")
(41247 . "YI SYLLABLE TIE")
(41248 . "YI SYLLABLE TIEP")
(41249 . "YI SYLLABLE TAT")
(41250 . "YI SYLLABLE TAX")
(41251 . "YI SYLLABLE TA")
(41252 . "YI SYLLABLE TAP")
(41253 . "YI SYLLABLE TUOT")
(41254 . "YI SYLLABLE TUOX")
(41255 . "YI SYLLABLE TUO")
(41256 . "YI SYLLABLE TUOP")
(41257 . "YI SYLLABLE TOT")
(41258 . "YI SYLLABLE TOX")
(41259 . "YI SYLLABLE TO")
(41260 . "YI SYLLABLE TOP")
(41261 . "YI SYLLABLE TEX")
(41262 . "YI SYLLABLE TE")
(41263 . "YI SYLLABLE TEP")
(41264 . "YI SYLLABLE TUT")
(41265 . "YI SYLLABLE TUX")
(41266 . "YI SYLLABLE TU")
(41267 . "YI SYLLABLE TUP")
(41268 . "YI SYLLABLE TURX")
(41269 . "YI SYLLABLE TUR")
(41270 . "YI SYLLABLE DDIT")
(41271 . "YI SYLLABLE DDIX")
(41272 . "YI SYLLABLE DDI")
(41273 . "YI SYLLABLE DDIP")
(41274 . "YI SYLLABLE DDIEX")
(41275 . "YI SYLLABLE DDIE")
(41276 . "YI SYLLABLE DDIEP")
(41277 . "YI SYLLABLE DDAT")
(41278 . "YI SYLLABLE DDAX")
(41279 . "YI SYLLABLE DDA")
(41280 . "YI SYLLABLE DDAP")
(41281 . "YI SYLLABLE DDUOX")
(41282 . "YI SYLLABLE DDUO")
(41283 . "YI SYLLABLE DDUOP")
(41284 . "YI SYLLABLE DDOT")
(41285 . "YI SYLLABLE DDOX")
(41286 . "YI SYLLABLE DDO")
(41287 . "YI SYLLABLE DDOP")
(41288 . "YI SYLLABLE DDEX")
(41289 . "YI SYLLABLE DDE")
(41290 . "YI SYLLABLE DDEP")
(41291 . "YI SYLLABLE DDUT")
(41292 . "YI SYLLABLE DDUX")
(41293 . "YI SYLLABLE DDU")
(41294 . "YI SYLLABLE DDUP")
(41295 . "YI SYLLABLE DDURX")
(41296 . "YI SYLLABLE DDUR")
(41297 . "YI SYLLABLE NDIT")
(41298 . "YI SYLLABLE NDIX")
(41299 . "YI SYLLABLE NDI")
(41300 . "YI SYLLABLE NDIP")
(41301 . "YI SYLLABLE NDIEX")
(41302 . "YI SYLLABLE NDIE")
(41303 . "YI SYLLABLE NDAT")
(41304 . "YI SYLLABLE NDAX")
(41305 . "YI SYLLABLE NDA")
(41306 . "YI SYLLABLE NDAP")
(41307 . "YI SYLLABLE NDOT")
(41308 . "YI SYLLABLE NDOX")
(41309 . "YI SYLLABLE NDO")
(41310 . "YI SYLLABLE NDOP")
(41311 . "YI SYLLABLE NDEX")
(41312 . "YI SYLLABLE NDE")
(41313 . "YI SYLLABLE NDEP")
(41314 . "YI SYLLABLE NDUT")
(41315 . "YI SYLLABLE NDUX")
(41316 . "YI SYLLABLE NDU")
(41317 . "YI SYLLABLE NDUP")
(41318 . "YI SYLLABLE NDURX")
(41319 . "YI SYLLABLE NDUR")
(41320 . "YI SYLLABLE HNIT")
(41321 . "YI SYLLABLE HNIX")
(41322 . "YI SYLLABLE HNI")
(41323 . "YI SYLLABLE HNIP")
(41324 . "YI SYLLABLE HNIET")
(41325 . "YI SYLLABLE HNIEX")
(41326 . "YI SYLLABLE HNIE")
(41327 . "YI SYLLABLE HNIEP")
(41328 . "YI SYLLABLE HNAT")
(41329 . "YI SYLLABLE HNAX")
(41330 . "YI SYLLABLE HNA")
(41331 . "YI SYLLABLE HNAP")
(41332 . "YI SYLLABLE HNUOX")
(41333 . "YI SYLLABLE HNUO")
(41334 . "YI SYLLABLE HNOT")
(41335 . "YI SYLLABLE HNOX")
(41336 . "YI SYLLABLE HNOP")
(41337 . "YI SYLLABLE HNEX")
(41338 . "YI SYLLABLE HNE")
(41339 . "YI SYLLABLE HNEP")
(41340 . "YI SYLLABLE HNUT")
(41341 . "YI SYLLABLE NIT")
(41342 . "YI SYLLABLE NIX")
(41343 . "YI SYLLABLE NI")
(41344 . "YI SYLLABLE NIP")
(41345 . "YI SYLLABLE NIEX")
(41346 . "YI SYLLABLE NIE")
(41347 . "YI SYLLABLE NIEP")
(41348 . "YI SYLLABLE NAX")
(41349 . "YI SYLLABLE NA")
(41350 . "YI SYLLABLE NAP")
(41351 . "YI SYLLABLE NUOX")
(41352 . "YI SYLLABLE NUO")
(41353 . "YI SYLLABLE NUOP")
(41354 . "YI SYLLABLE NOT")
(41355 . "YI SYLLABLE NOX")
(41356 . "YI SYLLABLE NO")
(41357 . "YI SYLLABLE NOP")
(41358 . "YI SYLLABLE NEX")
(41359 . "YI SYLLABLE NE")
(41360 . "YI SYLLABLE NEP")
(41361 . "YI SYLLABLE NUT")
(41362 . "YI SYLLABLE NUX")
(41363 . "YI SYLLABLE NU")
(41364 . "YI SYLLABLE NUP")
(41365 . "YI SYLLABLE NURX")
(41366 . "YI SYLLABLE NUR")
(41367 . "YI SYLLABLE HLIT")
(41368 . "YI SYLLABLE HLIX")
(41369 . "YI SYLLABLE HLI")
(41370 . "YI SYLLABLE HLIP")
(41371 . "YI SYLLABLE HLIEX")
(41372 . "YI SYLLABLE HLIE")
(41373 . "YI SYLLABLE HLIEP")
(41374 . "YI SYLLABLE HLAT")
(41375 . "YI SYLLABLE HLAX")
(41376 . "YI SYLLABLE HLA")
(41377 . "YI SYLLABLE HLAP")
(41378 . "YI SYLLABLE HLUOX")
(41379 . "YI SYLLABLE HLUO")
(41380 . "YI SYLLABLE HLUOP")
(41381 . "YI SYLLABLE HLOX")
(41382 . "YI SYLLABLE HLO")
(41383 . "YI SYLLABLE HLOP")
(41384 . "YI SYLLABLE HLEX")
(41385 . "YI SYLLABLE HLE")
(41386 . "YI SYLLABLE HLEP")
(41387 . "YI SYLLABLE HLUT")
(41388 . "YI SYLLABLE HLUX")
(41389 . "YI SYLLABLE HLU")
(41390 . "YI SYLLABLE HLUP")
(41391 . "YI SYLLABLE HLURX")
(41392 . "YI SYLLABLE HLUR")
(41393 . "YI SYLLABLE HLYT")
(41394 . "YI SYLLABLE HLYX")
(41395 . "YI SYLLABLE HLY")
(41396 . "YI SYLLABLE HLYP")
(41397 . "YI SYLLABLE HLYRX")
(41398 . "YI SYLLABLE HLYR")
(41399 . "YI SYLLABLE LIT")
(41400 . "YI SYLLABLE LIX")
(41401 . "YI SYLLABLE LI")
(41402 . "YI SYLLABLE LIP")
(41403 . "YI SYLLABLE LIET")
(41404 . "YI SYLLABLE LIEX")
(41405 . "YI SYLLABLE LIE")
(41406 . "YI SYLLABLE LIEP")
(41407 . "YI SYLLABLE LAT")
(41408 . "YI SYLLABLE LAX")
(41409 . "YI SYLLABLE LA")
(41410 . "YI SYLLABLE LAP")
(41411 . "YI SYLLABLE LUOT")
(41412 . "YI SYLLABLE LUOX")
(41413 . "YI SYLLABLE LUO")
(41414 . "YI SYLLABLE LUOP")
(41415 . "YI SYLLABLE LOT")
(41416 . "YI SYLLABLE LOX")
(41417 . "YI SYLLABLE LO")
(41418 . "YI SYLLABLE LOP")
(41419 . "YI SYLLABLE LEX")
(41420 . "YI SYLLABLE LE")
(41421 . "YI SYLLABLE LEP")
(41422 . "YI SYLLABLE LUT")
(41423 . "YI SYLLABLE LUX")
(41424 . "YI SYLLABLE LU")
(41425 . "YI SYLLABLE LUP")
(41426 . "YI SYLLABLE LURX")
(41427 . "YI SYLLABLE LUR")
(41428 . "YI SYLLABLE LYT")
(41429 . "YI SYLLABLE LYX")
(41430 . "YI SYLLABLE LY")
(41431 . "YI SYLLABLE LYP")
(41432 . "YI SYLLABLE LYRX")
(41433 . "YI SYLLABLE LYR")
(41434 . "YI SYLLABLE GIT")
(41435 . "YI SYLLABLE GIX")
(41436 . "YI SYLLABLE GI")
(41437 . "YI SYLLABLE GIP")
(41438 . "YI SYLLABLE GIET")
(41439 . "YI SYLLABLE GIEX")
(41440 . "YI SYLLABLE GIE")
(41441 . "YI SYLLABLE GIEP")
(41442 . "YI SYLLABLE GAT")
(41443 . "YI SYLLABLE GAX")
(41444 . "YI SYLLABLE GA")
(41445 . "YI SYLLABLE GAP")
(41446 . "YI SYLLABLE GUOT")
(41447 . "YI SYLLABLE GUOX")
(41448 . "YI SYLLABLE GUO")
(41449 . "YI SYLLABLE GUOP")
(41450 . "YI SYLLABLE GOT")
(41451 . "YI SYLLABLE GOX")
(41452 . "YI SYLLABLE GO")
(41453 . "YI SYLLABLE GOP")
(41454 . "YI SYLLABLE GET")
(41455 . "YI SYLLABLE GEX")
(41456 . "YI SYLLABLE GE")
(41457 . "YI SYLLABLE GEP")
(41458 . "YI SYLLABLE GUT")
(41459 . "YI SYLLABLE GUX")
(41460 . "YI SYLLABLE GU")
(41461 . "YI SYLLABLE GUP")
(41462 . "YI SYLLABLE GURX")
(41463 . "YI SYLLABLE GUR")
(41464 . "YI SYLLABLE KIT")
(41465 . "YI SYLLABLE KIX")
(41466 . "YI SYLLABLE KI")
(41467 . "YI SYLLABLE KIP")
(41468 . "YI SYLLABLE KIEX")
(41469 . "YI SYLLABLE KIE")
(41470 . "YI SYLLABLE KIEP")
(41471 . "YI SYLLABLE KAT")
(41472 . "YI SYLLABLE KAX")
(41473 . "YI SYLLABLE KA")
(41474 . "YI SYLLABLE KAP")
(41475 . "YI SYLLABLE KUOX")
(41476 . "YI SYLLABLE KUO")
(41477 . "YI SYLLABLE KUOP")
(41478 . "YI SYLLABLE KOT")
(41479 . "YI SYLLABLE KOX")
(41480 . "YI SYLLABLE KO")
(41481 . "YI SYLLABLE KOP")
(41482 . "YI SYLLABLE KET")
(41483 . "YI SYLLABLE KEX")
(41484 . "YI SYLLABLE KE")
(41485 . "YI SYLLABLE KEP")
(41486 . "YI SYLLABLE KUT")
(41487 . "YI SYLLABLE KUX")
(41488 . "YI SYLLABLE KU")
(41489 . "YI SYLLABLE KUP")
(41490 . "YI SYLLABLE KURX")
(41491 . "YI SYLLABLE KUR")
(41492 . "YI SYLLABLE GGIT")
(41493 . "YI SYLLABLE GGIX")
(41494 . "YI SYLLABLE GGI")
(41495 . "YI SYLLABLE GGIEX")
(41496 . "YI SYLLABLE GGIE")
(41497 . "YI SYLLABLE GGIEP")
(41498 . "YI SYLLABLE GGAT")
(41499 . "YI SYLLABLE GGAX")
(41500 . "YI SYLLABLE GGA")
(41501 . "YI SYLLABLE GGAP")
(41502 . "YI SYLLABLE GGUOT")
(41503 . "YI SYLLABLE GGUOX")
(41504 . "YI SYLLABLE GGUO")
(41505 . "YI SYLLABLE GGUOP")
(41506 . "YI SYLLABLE GGOT")
(41507 . "YI SYLLABLE GGOX")
(41508 . "YI SYLLABLE GGO")
(41509 . "YI SYLLABLE GGOP")
(41510 . "YI SYLLABLE GGET")
(41511 . "YI SYLLABLE GGEX")
(41512 . "YI SYLLABLE GGE")
(41513 . "YI SYLLABLE GGEP")
(41514 . "YI SYLLABLE GGUT")
(41515 . "YI SYLLABLE GGUX")
(41516 . "YI SYLLABLE GGU")
(41517 . "YI SYLLABLE GGUP")
(41518 . "YI SYLLABLE GGURX")
(41519 . "YI SYLLABLE GGUR")
(41520 . "YI SYLLABLE MGIEX")
(41521 . "YI SYLLABLE MGIE")
(41522 . "YI SYLLABLE MGAT")
(41523 . "YI SYLLABLE MGAX")
(41524 . "YI SYLLABLE MGA")
(41525 . "YI SYLLABLE MGAP")
(41526 . "YI SYLLABLE MGUOX")
(41527 . "YI SYLLABLE MGUO")
(41528 . "YI SYLLABLE MGUOP")
(41529 . "YI SYLLABLE MGOT")
(41530 . "YI SYLLABLE MGOX")
(41531 . "YI SYLLABLE MGO")
(41532 . "YI SYLLABLE MGOP")
(41533 . "YI SYLLABLE MGEX")
(41534 . "YI SYLLABLE MGE")
(41535 . "YI SYLLABLE MGEP")
(41536 . "YI SYLLABLE MGUT")
(41537 . "YI SYLLABLE MGUX")
(41538 . "YI SYLLABLE MGU")
(41539 . "YI SYLLABLE MGUP")
(41540 . "YI SYLLABLE MGURX")
(41541 . "YI SYLLABLE MGUR")
(41542 . "YI SYLLABLE HXIT")
(41543 . "YI SYLLABLE HXIX")
(41544 . "YI SYLLABLE HXI")
(41545 . "YI SYLLABLE HXIP")
(41546 . "YI SYLLABLE HXIET")
(41547 . "YI SYLLABLE HXIEX")
(41548 . "YI SYLLABLE HXIE")
(41549 . "YI SYLLABLE HXIEP")
(41550 . "YI SYLLABLE HXAT")
(41551 . "YI SYLLABLE HXAX")
(41552 . "YI SYLLABLE HXA")
(41553 . "YI SYLLABLE HXAP")
(41554 . "YI SYLLABLE HXUOT")
(41555 . "YI SYLLABLE HXUOX")
(41556 . "YI SYLLABLE HXUO")
(41557 . "YI SYLLABLE HXUOP")
(41558 . "YI SYLLABLE HXOT")
(41559 . "YI SYLLABLE HXOX")
(41560 . "YI SYLLABLE HXO")
(41561 . "YI SYLLABLE HXOP")
(41562 . "YI SYLLABLE HXEX")
(41563 . "YI SYLLABLE HXE")
(41564 . "YI SYLLABLE HXEP")
(41565 . "YI SYLLABLE NGIEX")
(41566 . "YI SYLLABLE NGIE")
(41567 . "YI SYLLABLE NGIEP")
(41568 . "YI SYLLABLE NGAT")
(41569 . "YI SYLLABLE NGAX")
(41570 . "YI SYLLABLE NGA")
(41571 . "YI SYLLABLE NGAP")
(41572 . "YI SYLLABLE NGUOT")
(41573 . "YI SYLLABLE NGUOX")
(41574 . "YI SYLLABLE NGUO")
(41575 . "YI SYLLABLE NGOT")
(41576 . "YI SYLLABLE NGOX")
(41577 . "YI SYLLABLE NGO")
(41578 . "YI SYLLABLE NGOP")
(41579 . "YI SYLLABLE NGEX")
(41580 . "YI SYLLABLE NGE")
(41581 . "YI SYLLABLE NGEP")
(41582 . "YI SYLLABLE HIT")
(41583 . "YI SYLLABLE HIEX")
(41584 . "YI SYLLABLE HIE")
(41585 . "YI SYLLABLE HAT")
(41586 . "YI SYLLABLE HAX")
(41587 . "YI SYLLABLE HA")
(41588 . "YI SYLLABLE HAP")
(41589 . "YI SYLLABLE HUOT")
(41590 . "YI SYLLABLE HUOX")
(41591 . "YI SYLLABLE HUO")
(41592 . "YI SYLLABLE HUOP")
(41593 . "YI SYLLABLE HOT")
(41594 . "YI SYLLABLE HOX")
(41595 . "YI SYLLABLE HO")
(41596 . "YI SYLLABLE HOP")
(41597 . "YI SYLLABLE HEX")
(41598 . "YI SYLLABLE HE")
(41599 . "YI SYLLABLE HEP")
(41600 . "YI SYLLABLE WAT")
(41601 . "YI SYLLABLE WAX")
(41602 . "YI SYLLABLE WA")
(41603 . "YI SYLLABLE WAP")
(41604 . "YI SYLLABLE WUOX")
(41605 . "YI SYLLABLE WUO")
(41606 . "YI SYLLABLE WUOP")
(41607 . "YI SYLLABLE WOX")
(41608 . "YI SYLLABLE WO")
(41609 . "YI SYLLABLE WOP")
(41610 . "YI SYLLABLE WEX")
(41611 . "YI SYLLABLE WE")
(41612 . "YI SYLLABLE WEP")
(41613 . "YI SYLLABLE ZIT")
(41614 . "YI SYLLABLE ZIX")
(41615 . "YI SYLLABLE ZI")
(41616 . "YI SYLLABLE ZIP")
(41617 . "YI SYLLABLE ZIEX")
(41618 . "YI SYLLABLE ZIE")
(41619 . "YI SYLLABLE ZIEP")
(41620 . "YI SYLLABLE ZAT")
(41621 . "YI SYLLABLE ZAX")
(41622 . "YI SYLLABLE ZA")
(41623 . "YI SYLLABLE ZAP")
(41624 . "YI SYLLABLE ZUOX")
(41625 . "YI SYLLABLE ZUO")
(41626 . "YI SYLLABLE ZUOP")
(41627 . "YI SYLLABLE ZOT")
(41628 . "YI SYLLABLE ZOX")
(41629 . "YI SYLLABLE ZO")
(41630 . "YI SYLLABLE ZOP")
(41631 . "YI SYLLABLE ZEX")
(41632 . "YI SYLLABLE ZE")
(41633 . "YI SYLLABLE ZEP")
(41634 . "YI SYLLABLE ZUT")
(41635 . "YI SYLLABLE ZUX")
(41636 . "YI SYLLABLE ZU")
(41637 . "YI SYLLABLE ZUP")
(41638 . "YI SYLLABLE ZURX")
(41639 . "YI SYLLABLE ZUR")
(41640 . "YI SYLLABLE ZYT")
(41641 . "YI SYLLABLE ZYX")
(41642 . "YI SYLLABLE ZY")
(41643 . "YI SYLLABLE ZYP")
(41644 . "YI SYLLABLE ZYRX")
(41645 . "YI SYLLABLE ZYR")
(41646 . "YI SYLLABLE CIT")
(41647 . "YI SYLLABLE CIX")
(41648 . "YI SYLLABLE CI")
(41649 . "YI SYLLABLE CIP")
(41650 . "YI SYLLABLE CIET")
(41651 . "YI SYLLABLE CIEX")
(41652 . "YI SYLLABLE CIE")
(41653 . "YI SYLLABLE CIEP")
(41654 . "YI SYLLABLE CAT")
(41655 . "YI SYLLABLE CAX")
(41656 . "YI SYLLABLE CA")
(41657 . "YI SYLLABLE CAP")
(41658 . "YI SYLLABLE CUOX")
(41659 . "YI SYLLABLE CUO")
(41660 . "YI SYLLABLE CUOP")
(41661 . "YI SYLLABLE COT")
(41662 . "YI SYLLABLE COX")
(41663 . "YI SYLLABLE CO")
(41664 . "YI SYLLABLE COP")
(41665 . "YI SYLLABLE CEX")
(41666 . "YI SYLLABLE CE")
(41667 . "YI SYLLABLE CEP")
(41668 . "YI SYLLABLE CUT")
(41669 . "YI SYLLABLE CUX")
(41670 . "YI SYLLABLE CU")
(41671 . "YI SYLLABLE CUP")
(41672 . "YI SYLLABLE CURX")
(41673 . "YI SYLLABLE CUR")
(41674 . "YI SYLLABLE CYT")
(41675 . "YI SYLLABLE CYX")
(41676 . "YI SYLLABLE CY")
(41677 . "YI SYLLABLE CYP")
(41678 . "YI SYLLABLE CYRX")
(41679 . "YI SYLLABLE CYR")
(41680 . "YI SYLLABLE ZZIT")
(41681 . "YI SYLLABLE ZZIX")
(41682 . "YI SYLLABLE ZZI")
(41683 . "YI SYLLABLE ZZIP")
(41684 . "YI SYLLABLE ZZIET")
(41685 . "YI SYLLABLE ZZIEX")
(41686 . "YI SYLLABLE ZZIE")
(41687 . "YI SYLLABLE ZZIEP")
(41688 . "YI SYLLABLE ZZAT")
(41689 . "YI SYLLABLE ZZAX")
(41690 . "YI SYLLABLE ZZA")
(41691 . "YI SYLLABLE ZZAP")
(41692 . "YI SYLLABLE ZZOX")
(41693 . "YI SYLLABLE ZZO")
(41694 . "YI SYLLABLE ZZOP")
(41695 . "YI SYLLABLE ZZEX")
(41696 . "YI SYLLABLE ZZE")
(41697 . "YI SYLLABLE ZZEP")
(41698 . "YI SYLLABLE ZZUX")
(41699 . "YI SYLLABLE ZZU")
(41700 . "YI SYLLABLE ZZUP")
(41701 . "YI SYLLABLE ZZURX")
(41702 . "YI SYLLABLE ZZUR")
(41703 . "YI SYLLABLE ZZYT")
(41704 . "YI SYLLABLE ZZYX")
(41705 . "YI SYLLABLE ZZY")
(41706 . "YI SYLLABLE ZZYP")
(41707 . "YI SYLLABLE ZZYRX")
(41708 . "YI SYLLABLE ZZYR")
(41709 . "YI SYLLABLE NZIT")
(41710 . "YI SYLLABLE NZIX")
(41711 . "YI SYLLABLE NZI")
(41712 . "YI SYLLABLE NZIP")
(41713 . "YI SYLLABLE NZIEX")
(41714 . "YI SYLLABLE NZIE")
(41715 . "YI SYLLABLE NZIEP")
(41716 . "YI SYLLABLE NZAT")
(41717 . "YI SYLLABLE NZAX")
(41718 . "YI SYLLABLE NZA")
(41719 . "YI SYLLABLE NZAP")
(41720 . "YI SYLLABLE NZUOX")
(41721 . "YI SYLLABLE NZUO")
(41722 . "YI SYLLABLE NZOX")
(41723 . "YI SYLLABLE NZOP")
(41724 . "YI SYLLABLE NZEX")
(41725 . "YI SYLLABLE NZE")
(41726 . "YI SYLLABLE NZUX")
(41727 . "YI SYLLABLE NZU")
(41728 . "YI SYLLABLE NZUP")
(41729 . "YI SYLLABLE NZURX")
(41730 . "YI SYLLABLE NZUR")
(41731 . "YI SYLLABLE NZYT")
(41732 . "YI SYLLABLE NZYX")
(41733 . "YI SYLLABLE NZY")
(41734 . "YI SYLLABLE NZYP")
(41735 . "YI SYLLABLE NZYRX")
(41736 . "YI SYLLABLE NZYR")
(41737 . "YI SYLLABLE SIT")
(41738 . "YI SYLLABLE SIX")
(41739 . "YI SYLLABLE SI")
(41740 . "YI SYLLABLE SIP")
(41741 . "YI SYLLABLE SIEX")
(41742 . "YI SYLLABLE SIE")
(41743 . "YI SYLLABLE SIEP")
(41744 . "YI SYLLABLE SAT")
(41745 . "YI SYLLABLE SAX")
(41746 . "YI SYLLABLE SA")
(41747 . "YI SYLLABLE SAP")
(41748 . "YI SYLLABLE SUOX")
(41749 . "YI SYLLABLE SUO")
(41750 . "YI SYLLABLE SUOP")
(41751 . "YI SYLLABLE SOT")
(41752 . "YI SYLLABLE SOX")
(41753 . "YI SYLLABLE SO")
(41754 . "YI SYLLABLE SOP")
(41755 . "YI SYLLABLE SEX")
(41756 . "YI SYLLABLE SE")
(41757 . "YI SYLLABLE SEP")
(41758 . "YI SYLLABLE SUT")
(41759 . "YI SYLLABLE SUX")
(41760 . "YI SYLLABLE SU")
(41761 . "YI SYLLABLE SUP")
(41762 . "YI SYLLABLE SURX")
(41763 . "YI SYLLABLE SUR")
(41764 . "YI SYLLABLE SYT")
(41765 . "YI SYLLABLE SYX")
(41766 . "YI SYLLABLE SY")
(41767 . "YI SYLLABLE SYP")
(41768 . "YI SYLLABLE SYRX")
(41769 . "YI SYLLABLE SYR")
(41770 . "YI SYLLABLE SSIT")
(41771 . "YI SYLLABLE SSIX")
(41772 . "YI SYLLABLE SSI")
(41773 . "YI SYLLABLE SSIP")
(41774 . "YI SYLLABLE SSIEX")
(41775 . "YI SYLLABLE SSIE")
(41776 . "YI SYLLABLE SSIEP")
(41777 . "YI SYLLABLE SSAT")
(41778 . "YI SYLLABLE SSAX")
(41779 . "YI SYLLABLE SSA")
(41780 . "YI SYLLABLE SSAP")
(41781 . "YI SYLLABLE SSOT")
(41782 . "YI SYLLABLE SSOX")
(41783 . "YI SYLLABLE SSO")
(41784 . "YI SYLLABLE SSOP")
(41785 . "YI SYLLABLE SSEX")
(41786 . "YI SYLLABLE SSE")
(41787 . "YI SYLLABLE SSEP")
(41788 . "YI SYLLABLE SSUT")
(41789 . "YI SYLLABLE SSUX")
(41790 . "YI SYLLABLE SSU")
(41791 . "YI SYLLABLE SSUP")
(41792 . "YI SYLLABLE SSYT")
(41793 . "YI SYLLABLE SSYX")
(41794 . "YI SYLLABLE SSY")
(41795 . "YI SYLLABLE SSYP")
(41796 . "YI SYLLABLE SSYRX")
(41797 . "YI SYLLABLE SSYR")
(41798 . "YI SYLLABLE ZHAT")
(41799 . "YI SYLLABLE ZHAX")
(41800 . "YI SYLLABLE ZHA")
(41801 . "YI SYLLABLE ZHAP")
(41802 . "YI SYLLABLE ZHUOX")
(41803 . "YI SYLLABLE ZHUO")
(41804 . "YI SYLLABLE ZHUOP")
(41805 . "YI SYLLABLE ZHOT")
(41806 . "YI SYLLABLE ZHOX")
(41807 . "YI SYLLABLE ZHO")
(41808 . "YI SYLLABLE ZHOP")
(41809 . "YI SYLLABLE ZHET")
(41810 . "YI SYLLABLE ZHEX")
(41811 . "YI SYLLABLE ZHE")
(41812 . "YI SYLLABLE ZHEP")
(41813 . "YI SYLLABLE ZHUT")
(41814 . "YI SYLLABLE ZHUX")
(41815 . "YI SYLLABLE ZHU")
(41816 . "YI SYLLABLE ZHUP")
(41817 . "YI SYLLABLE ZHURX")
(41818 . "YI SYLLABLE ZHUR")
(41819 . "YI SYLLABLE ZHYT")
(41820 . "YI SYLLABLE ZHYX")
(41821 . "YI SYLLABLE ZHY")
(41822 . "YI SYLLABLE ZHYP")
(41823 . "YI SYLLABLE ZHYRX")
(41824 . "YI SYLLABLE ZHYR")
(41825 . "YI SYLLABLE CHAT")
(41826 . "YI SYLLABLE CHAX")
(41827 . "YI SYLLABLE CHA")
(41828 . "YI SYLLABLE CHAP")
(41829 . "YI SYLLABLE CHUOT")
(41830 . "YI SYLLABLE CHUOX")
(41831 . "YI SYLLABLE CHUO")
(41832 . "YI SYLLABLE CHUOP")
(41833 . "YI SYLLABLE CHOT")
(41834 . "YI SYLLABLE CHOX")
(41835 . "YI SYLLABLE CHO")
(41836 . "YI SYLLABLE CHOP")
(41837 . "YI SYLLABLE CHET")
(41838 . "YI SYLLABLE CHEX")
(41839 . "YI SYLLABLE CHE")
(41840 . "YI SYLLABLE CHEP")
(41841 . "YI SYLLABLE CHUX")
(41842 . "YI SYLLABLE CHU")
(41843 . "YI SYLLABLE CHUP")
(41844 . "YI SYLLABLE CHURX")
(41845 . "YI SYLLABLE CHUR")
(41846 . "YI SYLLABLE CHYT")
(41847 . "YI SYLLABLE CHYX")
(41848 . "YI SYLLABLE CHY")
(41849 . "YI SYLLABLE CHYP")
(41850 . "YI SYLLABLE CHYRX")
(41851 . "YI SYLLABLE CHYR")
(41852 . "YI SYLLABLE RRAX")
(41853 . "YI SYLLABLE RRA")
(41854 . "YI SYLLABLE RRUOX")
(41855 . "YI SYLLABLE RRUO")
(41856 . "YI SYLLABLE RROT")
(41857 . "YI SYLLABLE RROX")
(41858 . "YI SYLLABLE RRO")
(41859 . "YI SYLLABLE RROP")
(41860 . "YI SYLLABLE RRET")
(41861 . "YI SYLLABLE RREX")
(41862 . "YI SYLLABLE RRE")
(41863 . "YI SYLLABLE RREP")
(41864 . "YI SYLLABLE RRUT")
(41865 . "YI SYLLABLE RRUX")
(41866 . "YI SYLLABLE RRU")
(41867 . "YI SYLLABLE RRUP")
(41868 . "YI SYLLABLE RRURX")
(41869 . "YI SYLLABLE RRUR")
(41870 . "YI SYLLABLE RRYT")
(41871 . "YI SYLLABLE RRYX")
(41872 . "YI SYLLABLE RRY")
(41873 . "YI SYLLABLE RRYP")
(41874 . "YI SYLLABLE RRYRX")
(41875 . "YI SYLLABLE RRYR")
(41876 . "YI SYLLABLE NRAT")
(41877 . "YI SYLLABLE NRAX")
(41878 . "YI SYLLABLE NRA")
(41879 . "YI SYLLABLE NRAP")
(41880 . "YI SYLLABLE NROX")
(41881 . "YI SYLLABLE NRO")
(41882 . "YI SYLLABLE NROP")
(41883 . "YI SYLLABLE NRET")
(41884 . "YI SYLLABLE NREX")
(41885 . "YI SYLLABLE NRE")
(41886 . "YI SYLLABLE NREP")
(41887 . "YI SYLLABLE NRUT")
(41888 . "YI SYLLABLE NRUX")
(41889 . "YI SYLLABLE NRU")
(41890 . "YI SYLLABLE NRUP")
(41891 . "YI SYLLABLE NRURX")
(41892 . "YI SYLLABLE NRUR")
(41893 . "YI SYLLABLE NRYT")
(41894 . "YI SYLLABLE NRYX")
(41895 . "YI SYLLABLE NRY")
(41896 . "YI SYLLABLE NRYP")
(41897 . "YI SYLLABLE NRYRX")
(41898 . "YI SYLLABLE NRYR")
(41899 . "YI SYLLABLE SHAT")
(41900 . "YI SYLLABLE SHAX")
(41901 . "YI SYLLABLE SHA")
(41902 . "YI SYLLABLE SHAP")
(41903 . "YI SYLLABLE SHUOX")
(41904 . "YI SYLLABLE SHUO")
(41905 . "YI SYLLABLE SHUOP")
(41906 . "YI SYLLABLE SHOT")
(41907 . "YI SYLLABLE SHOX")
(41908 . "YI SYLLABLE SHO")
(41909 . "YI SYLLABLE SHOP")
(41910 . "YI SYLLABLE SHET")
(41911 . "YI SYLLABLE SHEX")
(41912 . "YI SYLLABLE SHE")
(41913 . "YI SYLLABLE SHEP")
(41914 . "YI SYLLABLE SHUT")
(41915 . "YI SYLLABLE SHUX")
(41916 . "YI SYLLABLE SHU")
(41917 . "YI SYLLABLE SHUP")
(41918 . "YI SYLLABLE SHURX")
(41919 . "YI SYLLABLE SHUR")
(41920 . "YI SYLLABLE SHYT")
(41921 . "YI SYLLABLE SHYX")
(41922 . "YI SYLLABLE SHY")
(41923 . "YI SYLLABLE SHYP")
(41924 . "YI SYLLABLE SHYRX")
(41925 . "YI SYLLABLE SHYR")
(41926 . "YI SYLLABLE RAT")
(41927 . "YI SYLLABLE RAX")
(41928 . "YI SYLLABLE RA")
(41929 . "YI SYLLABLE RAP")
(41930 . "YI SYLLABLE RUOX")
(41931 . "YI SYLLABLE RUO")
(41932 . "YI SYLLABLE RUOP")
(41933 . "YI SYLLABLE ROT")
(41934 . "YI SYLLABLE ROX")
(41935 . "YI SYLLABLE RO")
(41936 . "YI SYLLABLE ROP")
(41937 . "YI SYLLABLE REX")
(41938 . "YI SYLLABLE RE")
(41939 . "YI SYLLABLE REP")
(41940 . "YI SYLLABLE RUT")
(41941 . "YI SYLLABLE RUX")
(41942 . "YI SYLLABLE RU")
(41943 . "YI SYLLABLE RUP")
(41944 . "YI SYLLABLE RURX")
(41945 . "YI SYLLABLE RUR")
(41946 . "YI SYLLABLE RYT")
(41947 . "YI SYLLABLE RYX")
(41948 . "YI SYLLABLE RY")
(41949 . "YI SYLLABLE RYP")
(41950 . "YI SYLLABLE RYRX")
(41951 . "YI SYLLABLE RYR")
(41952 . "YI SYLLABLE JIT")
(41953 . "YI SYLLABLE JIX")
(41954 . "YI SYLLABLE JI")
(41955 . "YI SYLLABLE JIP")
(41956 . "YI SYLLABLE JIET")
(41957 . "YI SYLLABLE JIEX")
(41958 . "YI SYLLABLE JIE")
(41959 . "YI SYLLABLE JIEP")
(41960 . "YI SYLLABLE JUOT")
(41961 . "YI SYLLABLE JUOX")
(41962 . "YI SYLLABLE JUO")
(41963 . "YI SYLLABLE JUOP")
(41964 . "YI SYLLABLE JOT")
(41965 . "YI SYLLABLE JOX")
(41966 . "YI SYLLABLE JO")
(41967 . "YI SYLLABLE JOP")
(41968 . "YI SYLLABLE JUT")
(41969 . "YI SYLLABLE JUX")
(41970 . "YI SYLLABLE JU")
(41971 . "YI SYLLABLE JUP")
(41972 . "YI SYLLABLE JURX")
(41973 . "YI SYLLABLE JUR")
(41974 . "YI SYLLABLE JYT")
(41975 . "YI SYLLABLE JYX")
(41976 . "YI SYLLABLE JY")
(41977 . "YI SYLLABLE JYP")
(41978 . "YI SYLLABLE JYRX")
(41979 . "YI SYLLABLE JYR")
(41980 . "YI SYLLABLE QIT")
(41981 . "YI SYLLABLE QIX")
(41982 . "YI SYLLABLE QI")
(41983 . "YI SYLLABLE QIP")
(41984 . "YI SYLLABLE QIET")
(41985 . "YI SYLLABLE QIEX")
(41986 . "YI SYLLABLE QIE")
(41987 . "YI SYLLABLE QIEP")
(41988 . "YI SYLLABLE QUOT")
(41989 . "YI SYLLABLE QUOX")
(41990 . "YI SYLLABLE QUO")
(41991 . "YI SYLLABLE QUOP")
(41992 . "YI SYLLABLE QOT")
(41993 . "YI SYLLABLE QOX")
(41994 . "YI SYLLABLE QO")
(41995 . "YI SYLLABLE QOP")
(41996 . "YI SYLLABLE QUT")
(41997 . "YI SYLLABLE QUX")
(41998 . "YI SYLLABLE QU")
(41999 . "YI SYLLABLE QUP")
(42000 . "YI SYLLABLE QURX")
(42001 . "YI SYLLABLE QUR")
(42002 . "YI SYLLABLE QYT")
(42003 . "YI SYLLABLE QYX")
(42004 . "YI SYLLABLE QY")
(42005 . "YI SYLLABLE QYP")
(42006 . "YI SYLLABLE QYRX")
(42007 . "YI SYLLABLE QYR")
(42008 . "YI SYLLABLE JJIT")
(42009 . "YI SYLLABLE JJIX")
(42010 . "YI SYLLABLE JJI")
(42011 . "YI SYLLABLE JJIP")
(42012 . "YI SYLLABLE JJIET")
(42013 . "YI SYLLABLE JJIEX")
(42014 . "YI SYLLABLE JJIE")
(42015 . "YI SYLLABLE JJIEP")
(42016 . "YI SYLLABLE JJUOX")
(42017 . "YI SYLLABLE JJUO")
(42018 . "YI SYLLABLE JJUOP")
(42019 . "YI SYLLABLE JJOT")
(42020 . "YI SYLLABLE JJOX")
(42021 . "YI SYLLABLE JJO")
(42022 . "YI SYLLABLE JJOP")
(42023 . "YI SYLLABLE JJUT")
(42024 . "YI SYLLABLE JJUX")
(42025 . "YI SYLLABLE JJU")
(42026 . "YI SYLLABLE JJUP")
(42027 . "YI SYLLABLE JJURX")
(42028 . "YI SYLLABLE JJUR")
(42029 . "YI SYLLABLE JJYT")
(42030 . "YI SYLLABLE JJYX")
(42031 . "YI SYLLABLE JJY")
(42032 . "YI SYLLABLE JJYP")
(42033 . "YI SYLLABLE NJIT")
(42034 . "YI SYLLABLE NJIX")
(42035 . "YI SYLLABLE NJI")
(42036 . "YI SYLLABLE NJIP")
(42037 . "YI SYLLABLE NJIET")
(42038 . "YI SYLLABLE NJIEX")
(42039 . "YI SYLLABLE NJIE")
(42040 . "YI SYLLABLE NJIEP")
(42041 . "YI SYLLABLE NJUOX")
(42042 . "YI SYLLABLE NJUO")
(42043 . "YI SYLLABLE NJOT")
(42044 . "YI SYLLABLE NJOX")
(42045 . "YI SYLLABLE NJO")
(42046 . "YI SYLLABLE NJOP")
(42047 . "YI SYLLABLE NJUX")
(42048 . "YI SYLLABLE NJU")
(42049 . "YI SYLLABLE NJUP")
(42050 . "YI SYLLABLE NJURX")
(42051 . "YI SYLLABLE NJUR")
(42052 . "YI SYLLABLE NJYT")
(42053 . "YI SYLLABLE NJYX")
(42054 . "YI SYLLABLE NJY")
(42055 . "YI SYLLABLE NJYP")
(42056 . "YI SYLLABLE NJYRX")
(42057 . "YI SYLLABLE NJYR")
(42058 . "YI SYLLABLE NYIT")
(42059 . "YI SYLLABLE NYIX")
(42060 . "YI SYLLABLE NYI")
(42061 . "YI SYLLABLE NYIP")
(42062 . "YI SYLLABLE NYIET")
(42063 . "YI SYLLABLE NYIEX")
(42064 . "YI SYLLABLE NYIE")
(42065 . "YI SYLLABLE NYIEP")
(42066 . "YI SYLLABLE NYUOX")
(42067 . "YI SYLLABLE NYUO")
(42068 . "YI SYLLABLE NYUOP")
(42069 . "YI SYLLABLE NYOT")
(42070 . "YI SYLLABLE NYOX")
(42071 . "YI SYLLABLE NYO")
(42072 . "YI SYLLABLE NYOP")
(42073 . "YI SYLLABLE NYUT")
(42074 . "YI SYLLABLE NYUX")
(42075 . "YI SYLLABLE NYU")
(42076 . "YI SYLLABLE NYUP")
(42077 . "YI SYLLABLE XIT")
(42078 . "YI SYLLABLE XIX")
(42079 . "YI SYLLABLE XI")
(42080 . "YI SYLLABLE XIP")
(42081 . "YI SYLLABLE XIET")
(42082 . "YI SYLLABLE XIEX")
(42083 . "YI SYLLABLE XIE")
(42084 . "YI SYLLABLE XIEP")
(42085 . "YI SYLLABLE XUOX")
(42086 . "YI SYLLABLE XUO")
(42087 . "YI SYLLABLE XOT")
(42088 . "YI SYLLABLE XOX")
(42089 . "YI SYLLABLE XO")
(42090 . "YI SYLLABLE XOP")
(42091 . "YI SYLLABLE XYT")
(42092 . "YI SYLLABLE XYX")
(42093 . "YI SYLLABLE XY")
(42094 . "YI SYLLABLE XYP")
(42095 . "YI SYLLABLE XYRX")
(42096 . "YI SYLLABLE XYR")
(42097 . "YI SYLLABLE YIT")
(42098 . "YI SYLLABLE YIX")
(42099 . "YI SYLLABLE YI")
(42100 . "YI SYLLABLE YIP")
(42101 . "YI SYLLABLE YIET")
(42102 . "YI SYLLABLE YIEX")
(42103 . "YI SYLLABLE YIE")
(42104 . "YI SYLLABLE YIEP")
(42105 . "YI SYLLABLE YUOT")
(42106 . "YI SYLLABLE YUOX")
(42107 . "YI SYLLABLE YUO")
(42108 . "YI SYLLABLE YUOP")
(42109 . "YI SYLLABLE YOT")
(42110 . "YI SYLLABLE YOX")
(42111 . "YI SYLLABLE YO")
(42112 . "YI SYLLABLE YOP")
(42113 . "YI SYLLABLE YUT")
(42114 . "YI SYLLABLE YUX")
(42115 . "YI SYLLABLE YU")
(42116 . "YI SYLLABLE YUP")
(42117 . "YI SYLLABLE YURX")
(42118 . "YI SYLLABLE YUR")
(42119 . "YI SYLLABLE YYT")
(42120 . "YI SYLLABLE YYX")
(42121 . "YI SYLLABLE YY")
(42122 . "YI SYLLABLE YYP")
(42123 . "YI SYLLABLE YYRX")
(42124 . "YI SYLLABLE YYR")
((42125 . 42128) . #f)
(42128 . "YI RADICAL QOT")
(42129 . "YI RADICAL LI")
(42130 . "YI RADICAL KIT")
(42131 . "YI RADICAL NYIP")
(42132 . "YI RADICAL CYP")
(42133 . "YI RADICAL SSI")
(42134 . "YI RADICAL GGOP")
(42135 . "YI RADICAL GEP")
(42136 . "YI RADICAL MI")
(42137 . "YI RADICAL HXIT")
(42138 . "YI RADICAL LYR")
(42139 . "YI RADICAL BBUT")
(42140 . "YI RADICAL MOP")
(42141 . "YI RADICAL YO")
(42142 . "YI RADICAL PUT")
(42143 . "YI RADICAL HXUO")
(42144 . "YI RADICAL TAT")
(42145 . "YI RADICAL GA")
(42146 . "YI RADICAL ZUP")
(42147 . "YI RADICAL CYT")
(42148 . "YI RADICAL DDUR")
(42149 . "YI RADICAL BUR")
(42150 . "YI RADICAL GGUO")
(42151 . "YI RADICAL NYOP")
(42152 . "YI RADICAL TU")
(42153 . "YI RADICAL OP")
(42154 . "YI RADICAL JJUT")
(42155 . "YI RADICAL ZOT")
(42156 . "YI RADICAL PYT")
(42157 . "YI RADICAL HMO")
(42158 . "YI RADICAL YIT")
(42159 . "YI RADICAL VUR")
(42160 . "YI RADICAL SHY")
(42161 . "YI RADICAL VEP")
(42162 . "YI RADICAL ZA")
(42163 . "YI RADICAL JO")
(42164 . "YI RADICAL NZUP")
(42165 . "YI RADICAL JJY")
(42166 . "YI RADICAL GOT")
(42167 . "YI RADICAL JJIE")
(42168 . "YI RADICAL WO")
(42169 . "YI RADICAL DU")
(42170 . "YI RADICAL SHUR")
(42171 . "YI RADICAL LIE")
(42172 . "YI RADICAL CY")
(42173 . "YI RADICAL CUOP")
(42174 . "YI RADICAL CIP")
(42175 . "YI RADICAL HXOP")
(42176 . "YI RADICAL SHAT")
(42177 . "YI RADICAL ZUR")
(42178 . "YI RADICAL SHOP")
(42179 . "YI RADICAL CHE")
(42180 . "YI RADICAL ZZIET")
(42181 . "YI RADICAL NBIE")
(42182 . "YI RADICAL KE")
((42183 . 42192) . #f)
(42192 . "LISU LETTER BA")
(42193 . "LISU LETTER PA")
(42194 . "LISU LETTER PHA")
(42195 . "LISU LETTER DA")
(42196 . "LISU LETTER TA")
(42197 . "LISU LETTER THA")
(42198 . "LISU LETTER GA")
(42199 . "LISU LETTER KA")
(42200 . "LISU LETTER KHA")
(42201 . "LISU LETTER JA")
(42202 . "LISU LETTER CA")
(42203 . "LISU LETTER CHA")
(42204 . "LISU LETTER DZA")
(42205 . "LISU LETTER TSA")
(42206 . "LISU LETTER TSHA")
(42207 . "LISU LETTER MA")
(42208 . "LISU LETTER NA")
(42209 . "LISU LETTER LA")
(42210 . "LISU LETTER SA")
(42211 . "LISU LETTER ZHA")
(42212 . "LISU LETTER ZA")
(42213 . "LISU LETTER NGA")
(42214 . "LISU LETTER HA")
(42215 . "LISU LETTER XA")
(42216 . "LISU LETTER HHA")
(42217 . "LISU LETTER FA")
(42218 . "LISU LETTER WA")
(42219 . "LISU LETTER SHA")
(42220 . "LISU LETTER YA")
(42221 . "LISU LETTER GHA")
(42222 . "LISU LETTER A")
(42223 . "LISU LETTER AE")
(42224 . "LISU LETTER E")
(42225 . "LISU LETTER EU")
(42226 . "LISU LETTER I")
(42227 . "LISU LETTER O")
(42228 . "LISU LETTER U")
(42229 . "LISU LETTER UE")
(42230 . "LISU LETTER UH")
(42231 . "LISU LETTER OE")
(42232 . "LISU LETTER TONE MYA TI")
(42233 . "LISU LETTER TONE NA PO")
(42234 . "LISU LETTER TONE MYA CYA")
(42235 . "LISU LETTER TONE MYA BO")
(42236 . "LISU LETTER TONE MYA NA")
(42237 . "LISU LETTER TONE MYA JEU")
(42238 . "LISU PUNCTUATION COMMA")
(42239 . "LISU PUNCTUATION FULL STOP")
(42240 . "VAI SYLLABLE EE")
(42241 . "VAI SYLLABLE EEN")
(42242 . "VAI SYLLABLE HEE")
(42243 . "VAI SYLLABLE WEE")
(42244 . "VAI SYLLABLE WEEN")
(42245 . "VAI SYLLABLE PEE")
(42246 . "VAI SYLLABLE BHEE")
(42247 . "VAI SYLLABLE BEE")
(42248 . "VAI SYLLABLE MBEE")
(42249 . "VAI SYLLABLE KPEE")
(42250 . "VAI SYLLABLE MGBEE")
(42251 . "VAI SYLLABLE GBEE")
(42252 . "VAI SYLLABLE FEE")
(42253 . "VAI SYLLABLE VEE")
(42254 . "VAI SYLLABLE TEE")
(42255 . "VAI SYLLABLE THEE")
(42256 . "VAI SYLLABLE DHEE")
(42257 . "VAI SYLLABLE DHHEE")
(42258 . "VAI SYLLABLE LEE")
(42259 . "VAI SYLLABLE REE")
(42260 . "VAI SYLLABLE DEE")
(42261 . "VAI SYLLABLE NDEE")
(42262 . "VAI SYLLABLE SEE")
(42263 . "VAI SYLLABLE SHEE")
(42264 . "VAI SYLLABLE ZEE")
(42265 . "VAI SYLLABLE ZHEE")
(42266 . "VAI SYLLABLE CEE")
(42267 . "VAI SYLLABLE JEE")
(42268 . "VAI SYLLABLE NJEE")
(42269 . "VAI SYLLABLE YEE")
(42270 . "VAI SYLLABLE KEE")
(42271 . "VAI SYLLABLE NGGEE")
(42272 . "VAI SYLLABLE GEE")
(42273 . "VAI SYLLABLE MEE")
(42274 . "VAI SYLLABLE NEE")
(42275 . "VAI SYLLABLE NYEE")
(42276 . "VAI SYLLABLE I")
(42277 . "VAI SYLLABLE IN")
(42278 . "VAI SYLLABLE HI")
(42279 . "VAI SYLLABLE HIN")
(42280 . "VAI SYLLABLE WI")
(42281 . "VAI SYLLABLE WIN")
(42282 . "VAI SYLLABLE PI")
(42283 . "VAI SYLLABLE BHI")
(42284 . "VAI SYLLABLE BI")
(42285 . "VAI SYLLABLE MBI")
(42286 . "VAI SYLLABLE KPI")
(42287 . "VAI SYLLABLE MGBI")
(42288 . "VAI SYLLABLE GBI")
(42289 . "VAI SYLLABLE FI")
(42290 . "VAI SYLLABLE VI")
(42291 . "VAI SYLLABLE TI")
(42292 . "VAI SYLLABLE THI")
(42293 . "VAI SYLLABLE DHI")
(42294 . "VAI SYLLABLE DHHI")
(42295 . "VAI SYLLABLE LI")
(42296 . "VAI SYLLABLE RI")
(42297 . "VAI SYLLABLE DI")
(42298 . "VAI SYLLABLE NDI")
(42299 . "VAI SYLLABLE SI")
(42300 . "VAI SYLLABLE SHI")
(42301 . "VAI SYLLABLE ZI")
(42302 . "VAI SYLLABLE ZHI")
(42303 . "VAI SYLLABLE CI")
(42304 . "VAI SYLLABLE JI")
(42305 . "VAI SYLLABLE NJI")
(42306 . "VAI SYLLABLE YI")
(42307 . "VAI SYLLABLE KI")
(42308 . "VAI SYLLABLE NGGI")
(42309 . "VAI SYLLABLE GI")
(42310 . "VAI SYLLABLE MI")
(42311 . "VAI SYLLABLE NI")
(42312 . "VAI SYLLABLE NYI")
(42313 . "VAI SYLLABLE A")
(42314 . "VAI SYLLABLE AN")
(42315 . "VAI SYLLABLE NGAN")
(42316 . "VAI SYLLABLE HA")
(42317 . "VAI SYLLABLE HAN")
(42318 . "VAI SYLLABLE WA")
(42319 . "VAI SYLLABLE WAN")
(42320 . "VAI SYLLABLE PA")
(42321 . "VAI SYLLABLE BHA")
(42322 . "VAI SYLLABLE BA")
(42323 . "VAI SYLLABLE MBA")
(42324 . "VAI SYLLABLE KPA")
(42325 . "VAI SYLLABLE KPAN")
(42326 . "VAI SYLLABLE MGBA")
(42327 . "VAI SYLLABLE GBA")
(42328 . "VAI SYLLABLE FA")
(42329 . "VAI SYLLABLE VA")
(42330 . "VAI SYLLABLE TA")
(42331 . "VAI SYLLABLE THA")
(42332 . "VAI SYLLABLE DHA")
(42333 . "VAI SYLLABLE DHHA")
(42334 . "VAI SYLLABLE LA")
(42335 . "VAI SYLLABLE RA")
(42336 . "VAI SYLLABLE DA")
(42337 . "VAI SYLLABLE NDA")
(42338 . "VAI SYLLABLE SA")
(42339 . "VAI SYLLABLE SHA")
(42340 . "VAI SYLLABLE ZA")
(42341 . "VAI SYLLABLE ZHA")
(42342 . "VAI SYLLABLE CA")
(42343 . "VAI SYLLABLE JA")
(42344 . "VAI SYLLABLE NJA")
(42345 . "VAI SYLLABLE YA")
(42346 . "VAI SYLLABLE KA")
(42347 . "VAI SYLLABLE KAN")
(42348 . "VAI SYLLABLE NGGA")
(42349 . "VAI SYLLABLE GA")
(42350 . "VAI SYLLABLE MA")
(42351 . "VAI SYLLABLE NA")
(42352 . "VAI SYLLABLE NYA")
(42353 . "VAI SYLLABLE OO")
(42354 . "VAI SYLLABLE OON")
(42355 . "VAI SYLLABLE HOO")
(42356 . "VAI SYLLABLE WOO")
(42357 . "VAI SYLLABLE WOON")
(42358 . "VAI SYLLABLE POO")
(42359 . "VAI SYLLABLE BHOO")
(42360 . "VAI SYLLABLE BOO")
(42361 . "VAI SYLLABLE MBOO")
(42362 . "VAI SYLLABLE KPOO")
(42363 . "VAI SYLLABLE MGBOO")
(42364 . "VAI SYLLABLE GBOO")
(42365 . "VAI SYLLABLE FOO")
(42366 . "VAI SYLLABLE VOO")
(42367 . "VAI SYLLABLE TOO")
(42368 . "VAI SYLLABLE THOO")
(42369 . "VAI SYLLABLE DHOO")
(42370 . "VAI SYLLABLE DHHOO")
(42371 . "VAI SYLLABLE LOO")
(42372 . "VAI SYLLABLE ROO")
(42373 . "VAI SYLLABLE DOO")
(42374 . "VAI SYLLABLE NDOO")
(42375 . "VAI SYLLABLE SOO")
(42376 . "VAI SYLLABLE SHOO")
(42377 . "VAI SYLLABLE ZOO")
(42378 . "VAI SYLLABLE ZHOO")
(42379 . "VAI SYLLABLE COO")
(42380 . "VAI SYLLABLE JOO")
(42381 . "VAI SYLLABLE NJOO")
(42382 . "VAI SYLLABLE YOO")
(42383 . "VAI SYLLABLE KOO")
(42384 . "VAI SYLLABLE NGGOO")
(42385 . "VAI SYLLABLE GOO")
(42386 . "VAI SYLLABLE MOO")
(42387 . "VAI SYLLABLE NOO")
(42388 . "VAI SYLLABLE NYOO")
(42389 . "VAI SYLLABLE U")
(42390 . "VAI SYLLABLE UN")
(42391 . "VAI SYLLABLE HU")
(42392 . "VAI SYLLABLE HUN")
(42393 . "VAI SYLLABLE WU")
(42394 . "VAI SYLLABLE WUN")
(42395 . "VAI SYLLABLE PU")
(42396 . "VAI SYLLABLE BHU")
(42397 . "VAI SYLLABLE BU")
(42398 . "VAI SYLLABLE MBU")
(42399 . "VAI SYLLABLE KPU")
(42400 . "VAI SYLLABLE MGBU")
(42401 . "VAI SYLLABLE GBU")
(42402 . "VAI SYLLABLE FU")
(42403 . "VAI SYLLABLE VU")
(42404 . "VAI SYLLABLE TU")
(42405 . "VAI SYLLABLE THU")
(42406 . "VAI SYLLABLE DHU")
(42407 . "VAI SYLLABLE DHHU")
(42408 . "VAI SYLLABLE LU")
(42409 . "VAI SYLLABLE RU")
(42410 . "VAI SYLLABLE DU")
(42411 . "VAI SYLLABLE NDU")
(42412 . "VAI SYLLABLE SU")
(42413 . "VAI SYLLABLE SHU")
(42414 . "VAI SYLLABLE ZU")
(42415 . "VAI SYLLABLE ZHU")
(42416 . "VAI SYLLABLE CU")
(42417 . "VAI SYLLABLE JU")
(42418 . "VAI SYLLABLE NJU")
(42419 . "VAI SYLLABLE YU")
(42420 . "VAI SYLLABLE KU")
(42421 . "VAI SYLLABLE NGGU")
(42422 . "VAI SYLLABLE GU")
(42423 . "VAI SYLLABLE MU")
(42424 . "VAI SYLLABLE NU")
(42425 . "VAI SYLLABLE NYU")
(42426 . "VAI SYLLABLE O")
(42427 . "VAI SYLLABLE ON")
(42428 . "VAI SYLLABLE NGON")
(42429 . "VAI SYLLABLE HO")
(42430 . "VAI SYLLABLE HON")
(42431 . "VAI SYLLABLE WO")
(42432 . "VAI SYLLABLE WON")
(42433 . "VAI SYLLABLE PO")
(42434 . "VAI SYLLABLE BHO")
(42435 . "VAI SYLLABLE BO")
(42436 . "VAI SYLLABLE MBO")
(42437 . "VAI SYLLABLE KPO")
(42438 . "VAI SYLLABLE MGBO")
(42439 . "VAI SYLLABLE GBO")
(42440 . "VAI SYLLABLE GBON")
(42441 . "VAI SYLLABLE FO")
(42442 . "VAI SYLLABLE VO")
(42443 . "VAI SYLLABLE TO")
(42444 . "VAI SYLLABLE THO")
(42445 . "VAI SYLLABLE DHO")
(42446 . "VAI SYLLABLE DHHO")
(42447 . "VAI SYLLABLE LO")
(42448 . "VAI SYLLABLE RO")
(42449 . "VAI SYLLABLE DO")
(42450 . "VAI SYLLABLE NDO")
(42451 . "VAI SYLLABLE SO")
(42452 . "VAI SYLLABLE SHO")
(42453 . "VAI SYLLABLE ZO")
(42454 . "VAI SYLLABLE ZHO")
(42455 . "VAI SYLLABLE CO")
(42456 . "VAI SYLLABLE JO")
(42457 . "VAI SYLLABLE NJO")
(42458 . "VAI SYLLABLE YO")
(42459 . "VAI SYLLABLE KO")
(42460 . "VAI SYLLABLE NGGO")
(42461 . "VAI SYLLABLE GO")
(42462 . "VAI SYLLABLE MO")
(42463 . "VAI SYLLABLE NO")
(42464 . "VAI SYLLABLE NYO")
(42465 . "VAI SYLLABLE E")
(42466 . "VAI SYLLABLE EN")
(42467 . "VAI SYLLABLE NGEN")
(42468 . "VAI SYLLABLE HE")
(42469 . "VAI SYLLABLE HEN")
(42470 . "VAI SYLLABLE WE")
(42471 . "VAI SYLLABLE WEN")
(42472 . "VAI SYLLABLE PE")
(42473 . "VAI SYLLABLE BHE")
(42474 . "VAI SYLLABLE BE")
(42475 . "VAI SYLLABLE MBE")
(42476 . "VAI SYLLABLE KPE")
(42477 . "VAI SYLLABLE KPEN")
(42478 . "VAI SYLLABLE MGBE")
(42479 . "VAI SYLLABLE GBE")
(42480 . "VAI SYLLABLE GBEN")
(42481 . "VAI SYLLABLE FE")
(42482 . "VAI SYLLABLE VE")
(42483 . "VAI SYLLABLE TE")
(42484 . "VAI SYLLABLE THE")
(42485 . "VAI SYLLABLE DHE")
(42486 . "VAI SYLLABLE DHHE")
(42487 . "VAI SYLLABLE LE")
(42488 . "VAI SYLLABLE RE")
(42489 . "VAI SYLLABLE DE")
(42490 . "VAI SYLLABLE NDE")
(42491 . "VAI SYLLABLE SE")
(42492 . "VAI SYLLABLE SHE")
(42493 . "VAI SYLLABLE ZE")
(42494 . "VAI SYLLABLE ZHE")
(42495 . "VAI SYLLABLE CE")
(42496 . "VAI SYLLABLE JE")
(42497 . "VAI SYLLABLE NJE")
(42498 . "VAI SYLLABLE YE")
(42499 . "VAI SYLLABLE KE")
(42500 . "VAI SYLLABLE NGGE")
(42501 . "VAI SYLLABLE NGGEN")
(42502 . "VAI SYLLABLE GE")
(42503 . "VAI SYLLABLE GEN")
(42504 . "VAI SYLLABLE ME")
(42505 . "VAI SYLLABLE NE")
(42506 . "VAI SYLLABLE NYE")
(42507 . "VAI SYLLABLE NG")
(42508 . "VAI SYLLABLE LENGTHENER")
(42509 . "VAI COMMA")
(42510 . "VAI FULL STOP")
(42511 . "VAI QUESTION MARK")
(42512 . "VAI SYLLABLE NDOLE FA")
(42513 . "VAI SYLLABLE NDOLE KA")
(42514 . "VAI SYLLABLE NDOLE SOO")
(42515 . "VAI SYMBOL FEENG")
(42516 . "VAI SYMBOL KEENG")
(42517 . "VAI SYMBOL TING")
(42518 . "VAI SYMBOL NII")
(42519 . "VAI SYMBOL BANG")
(42520 . "VAI SYMBOL FAA")
(42521 . "VAI SYMBOL TAA")
(42522 . "VAI SYMBOL DANG")
(42523 . "VAI SYMBOL DOONG")
(42524 . "VAI SYMBOL KUNG")
(42525 . "VAI SYMBOL TONG")
(42526 . "VAI SYMBOL DO-O")
(42527 . "VAI SYMBOL JONG")
(42528 . "VAI DIGIT ZERO")
(42529 . "VAI DIGIT ONE")
(42530 . "VAI DIGIT TWO")
(42531 . "VAI DIGIT THREE")
(42532 . "VAI DIGIT FOUR")
(42533 . "VAI DIGIT FIVE")
(42534 . "VAI DIGIT SIX")
(42535 . "VAI DIGIT SEVEN")
(42536 . "VAI DIGIT EIGHT")
(42537 . "VAI DIGIT NINE")
(42538 . "VAI SYLLABLE NDOLE MA")
(42539 . "VAI SYLLABLE NDOLE DO")
((42540 . 42560) . #f)
(42560 . "CYRILLIC CAPITAL LETTER ZEMLYA")
(42561 . "CYRILLIC SMALL LETTER ZEMLYA")
(42562 . "CYRILLIC CAPITAL LETTER DZELO")
(42563 . "CYRILLIC SMALL LETTER DZELO")
(42564 . "CYRILLIC CAPITAL LETTER REVERSED DZE")
(42565 . "CYRILLIC SMALL LETTER REVERSED DZE")
(42566 . "CYRILLIC CAPITAL LETTER IOTA")
(42567 . "CYRILLIC SMALL LETTER IOTA")
(42568 . "CYRILLIC CAPITAL LETTER DJERV")
(42569 . "CYRILLIC SMALL LETTER DJERV")
(42570 . "CYRILLIC CAPITAL LETTER MONOGRAPH UK")
(42571 . "CYRILLIC SMALL LETTER MONOGRAPH UK")
(42572 . "CYRILLIC CAPITAL LETTER BROAD OMEGA")
(42573 . "CYRILLIC SMALL LETTER BROAD OMEGA")
(42574 . "CYRILLIC CAPITAL LETTER NEUTRAL YER")
(42575 . "CYRILLIC SMALL LETTER NEUTRAL YER")
(42576 . "CYRILLIC CAPITAL LETTER YERU WITH BACK YER")
(42577 . "CYRILLIC SMALL LETTER YERU WITH BACK YER")
(42578 . "CYRILLIC CAPITAL LETTER IOTIFIED YAT")
(42579 . "CYRILLIC SMALL LETTER IOTIFIED YAT")
(42580 . "CYRILLIC CAPITAL LETTER REVERSED YU")
(42581 . "CYRILLIC SMALL LETTER REVERSED YU")
(42582 . "CYRILLIC CAPITAL LETTER IOTIFIED A")
(42583 . "CYRILLIC SMALL LETTER IOTIFIED A")
(42584 . "CYRILLIC CAPITAL LETTER CLOSED LITTLE YUS")
(42585 . "CYRILLIC SMALL LETTER CLOSED LITTLE YUS")
(42586 . "CYRILLIC CAPITAL LETTER BLENDED YUS")
(42587 . "CYRILLIC SMALL LETTER BLENDED YUS")
(42588 . "CYRILLIC CAPITAL LETTER IOTIFIED CLOSED LITTLE YUS")
(42589 . "CYRILLIC SMALL LETTER IOTIFIED CLOSED LITTLE YUS")
(42590 . "CYRILLIC CAPITAL LETTER YN")
(42591 . "CYRILLIC SMALL LETTER YN")
(42592 . "CYRILLIC CAPITAL LETTER REVERSED TSE")
(42593 . "CYRILLIC SMALL LETTER REVERSED TSE")
(42594 . "CYRILLIC CAPITAL LETTER SOFT DE")
(42595 . "CYRILLIC SMALL LETTER SOFT DE")
(42596 . "CYRILLIC CAPITAL LETTER SOFT EL")
(42597 . "CYRILLIC SMALL LETTER SOFT EL")
(42598 . "CYRILLIC CAPITAL LETTER SOFT EM")
(42599 . "CYRILLIC SMALL LETTER SOFT EM")
(42600 . "CYRILLIC CAPITAL LETTER MONOCULAR O")
(42601 . "CYRILLIC SMALL LETTER MONOCULAR O")
(42602 . "CYRILLIC CAPITAL LETTER BINOCULAR O")
(42603 . "CYRILLIC SMALL LETTER BINOCULAR O")
(42604 . "CYRILLIC CAPITAL LETTER DOUBLE MONOCULAR O")
(42605 . "CYRILLIC SMALL LETTER DOUBLE MONOCULAR O")
(42606 . "CYRILLIC LETTER MULTIOCULAR O")
(42607 . "COMBINING CYRILLIC VZMET")
(42608 . "COMBINING CYRILLIC TEN MILLIONS SIGN")
(42609 . "COMBINING CYRILLIC HUNDRED MILLIONS SIGN")
(42610 . "COMBINING CYRILLIC THOUSAND MILLIONS SIGN")
(42611 . "SLAVONIC ASTERISK")
(42612 . "COMBINING CYRILLIC LETTER UKRAINIAN IE")
(42613 . "COMBINING CYRILLIC LETTER I")
(42614 . "COMBINING CYRILLIC LETTER YI")
(42615 . "COMBINING CYRILLIC LETTER U")
(42616 . "COMBINING CYRILLIC LETTER HARD SIGN")
(42617 . "COMBINING CYRILLIC LETTER YERU")
(42618 . "COMBINING CYRILLIC LETTER SOFT SIGN")
(42619 . "COMBINING CYRILLIC LETTER OMEGA")
(42620 . "COMBINING CYRILLIC KAVYKA")
(42621 . "COMBINING CYRILLIC PAYEROK")
(42622 . "CYRILLIC KAVYKA")
(42623 . "CYRILLIC PAYEROK")
(42624 . "CYRILLIC CAPITAL LETTER DWE")
(42625 . "CYRILLIC SMALL LETTER DWE")
(42626 . "CYRILLIC CAPITAL LETTER DZWE")
(42627 . "CYRILLIC SMALL LETTER DZWE")
(42628 . "CYRILLIC CAPITAL LETTER ZHWE")
(42629 . "CYRILLIC SMALL LETTER ZHWE")
(42630 . "CYRILLIC CAPITAL LETTER CCHE")
(42631 . "CYRILLIC SMALL LETTER CCHE")
(42632 . "CYRILLIC CAPITAL LETTER DZZE")
(42633 . "CYRILLIC SMALL LETTER DZZE")
(42634 . "CYRILLIC CAPITAL LETTER TE WITH MIDDLE HOOK")
(42635 . "CYRILLIC SMALL LETTER TE WITH MIDDLE HOOK")
(42636 . "CYRILLIC CAPITAL LETTER TWE")
(42637 . "CYRILLIC SMALL LETTER TWE")
(42638 . "CYRILLIC CAPITAL LETTER TSWE")
(42639 . "CYRILLIC SMALL LETTER TSWE")
(42640 . "CYRILLIC CAPITAL LETTER TSSE")
(42641 . "CYRILLIC SMALL LETTER TSSE")
(42642 . "CYRILLIC CAPITAL LETTER TCHE")
(42643 . "CYRILLIC SMALL LETTER TCHE")
(42644 . "CYRILLIC CAPITAL LETTER HWE")
(42645 . "CYRILLIC SMALL LETTER HWE")
(42646 . "CYRILLIC CAPITAL LETTER SHWE")
(42647 . "CYRILLIC SMALL LETTER SHWE")
(42648 . "CYRILLIC CAPITAL LETTER DOUBLE O")
(42649 . "CYRILLIC SMALL LETTER DOUBLE O")
(42650 . "CYRILLIC CAPITAL LETTER CROSSED O")
(42651 . "CYRILLIC SMALL LETTER CROSSED O")
(42652 . "MODIFIER LETTER CYRILLIC HARD SIGN")
(42653 . "MODIFIER LETTER CYRILLIC SOFT SIGN")
(42654 . "COMBINING CYRILLIC LETTER EF")
(42655 . "COMBINING CYRILLIC LETTER IOTIFIED E")
(42656 . "BAMUM LETTER A")
(42657 . "BAMUM LETTER KA")
(42658 . "BAMUM LETTER U")
(42659 . "BAMUM LETTER KU")
(42660 . "BAMUM LETTER EE")
(42661 . "BAMUM LETTER REE")
(42662 . "BAMUM LETTER TAE")
(42663 . "BAMUM LETTER O")
(42664 . "BAMUM LETTER NYI")
(42665 . "BAMUM LETTER I")
(42666 . "BAMUM LETTER LA")
(42667 . "BAMUM LETTER PA")
(42668 . "BAMUM LETTER RII")
(42669 . "BAMUM LETTER RIEE")
(42670 . "BAMUM LETTER LEEEE")
(42671 . "BAMUM LETTER MEEEE")
(42672 . "BAMUM LETTER TAA")
(42673 . "BAMUM LETTER NDAA")
(42674 . "BAMUM LETTER NJAEM")
(42675 . "BAMUM LETTER M")
(42676 . "BAMUM LETTER SUU")
(42677 . "BAMUM LETTER MU")
(42678 . "BAMUM LETTER SHII")
(42679 . "BAMUM LETTER SI")
(42680 . "BAMUM LETTER SHEUX")
(42681 . "BAMUM LETTER SEUX")
(42682 . "BAMUM LETTER KYEE")
(42683 . "BAMUM LETTER KET")
(42684 . "BAMUM LETTER NUAE")
(42685 . "BAMUM LETTER NU")
(42686 . "BAMUM LETTER NJUAE")
(42687 . "BAMUM LETTER YOQ")
(42688 . "BAMUM LETTER SHU")
(42689 . "BAMUM LETTER YUQ")
(42690 . "BAMUM LETTER YA")
(42691 . "BAMUM LETTER NSHA")
(42692 . "BAMUM LETTER KEUX")
(42693 . "BAMUM LETTER PEUX")
(42694 . "BAMUM LETTER NJEE")
(42695 . "BAMUM LETTER NTEE")
(42696 . "BAMUM LETTER PUE")
(42697 . "BAMUM LETTER WUE")
(42698 . "BAMUM LETTER PEE")
(42699 . "BAMUM LETTER FEE")
(42700 . "BAMUM LETTER RU")
(42701 . "BAMUM LETTER LU")
(42702 . "BAMUM LETTER MI")
(42703 . "BAMUM LETTER NI")
(42704 . "BAMUM LETTER REUX")
(42705 . "BAMUM LETTER RAE")
(42706 . "BAMUM LETTER KEN")
(42707 . "BAMUM LETTER NGKWAEN")
(42708 . "BAMUM LETTER NGGA")
(42709 . "BAMUM LETTER NGA")
(42710 . "BAMUM LETTER SHO")
(42711 . "BAMUM LETTER PUAE")
(42712 . "BAMUM LETTER FU")
(42713 . "BAMUM LETTER FOM")
(42714 . "BAMUM LETTER WA")
(42715 . "BAMUM LETTER NA")
(42716 . "BAMUM LETTER LI")
(42717 . "BAMUM LETTER PI")
(42718 . "BAMUM LETTER LOQ")
(42719 . "BAMUM LETTER KO")
(42720 . "BAMUM LETTER MBEN")
(42721 . "BAMUM LETTER REN")
(42722 . "BAMUM LETTER MEN")
(42723 . "BAMUM LETTER MA")
(42724 . "BAMUM LETTER TI")
(42725 . "BAMUM LETTER KI")
(42726 . "BAMUM LETTER MO")
(42727 . "BAMUM LETTER MBAA")
(42728 . "BAMUM LETTER TET")
(42729 . "BAMUM LETTER KPA")
(42730 . "BAMUM LETTER TEN")
(42731 . "BAMUM LETTER NTUU")
(42732 . "BAMUM LETTER SAMBA")
(42733 . "BAMUM LETTER FAAMAE")
(42734 . "BAMUM LETTER KOVUU")
(42735 . "BAMUM LETTER KOGHOM")
(42736 . "BAMUM COMBINING MARK KOQNDON")
(42737 . "BAMUM COMBINING MARK TUKWENTIS")
(42738 . "BAMUM NJAEMLI")
(42739 . "BAMUM FULL STOP")
(42740 . "BAMUM COLON")
(42741 . "BAMUM COMMA")
(42742 . "BAMUM SEMICOLON")
(42743 . "BAMUM QUESTION MARK")
((42744 . 42752) . #f)
(42752 . "MODIFIER LETTER CHINESE TONE YIN PING")
(42753 . "MODIFIER LETTER CHINESE TONE YANG PING")
(42754 . "MODIFIER LETTER CHINESE TONE YIN SHANG")
(42755 . "MODIFIER LETTER CHINESE TONE YANG SHANG")
(42756 . "MODIFIER LETTER CHINESE TONE YIN QU")
(42757 . "MODIFIER LETTER CHINESE TONE YANG QU")
(42758 . "MODIFIER LETTER CHINESE TONE YIN RU")
(42759 . "MODIFIER LETTER CHINESE TONE YANG RU")
(42760 . "MODIFIER LETTER EXTRA-HIGH DOTTED TONE BAR")
(42761 . "MODIFIER LETTER HIGH DOTTED TONE BAR")
(42762 . "MODIFIER LETTER MID DOTTED TONE BAR")
(42763 . "MODIFIER LETTER LOW DOTTED TONE BAR")
(42764 . "MODIFIER LETTER EXTRA-LOW DOTTED TONE BAR")
(42765 . "MODIFIER LETTER EXTRA-HIGH DOTTED LEFT-STEM TONE BAR")
(42766 . "MODIFIER LETTER HIGH DOTTED LEFT-STEM TONE BAR")
(42767 . "MODIFIER LETTER MID DOTTED LEFT-STEM TONE BAR")
(42768 . "MODIFIER LETTER LOW DOTTED LEFT-STEM TONE BAR")
(42769 . "MODIFIER LETTER EXTRA-LOW DOTTED LEFT-STEM TONE BAR")
(42770 . "MODIFIER LETTER EXTRA-HIGH LEFT-STEM TONE BAR")
(42771 . "MODIFIER LETTER HIGH LEFT-STEM TONE BAR")
(42772 . "MODIFIER LETTER MID LEFT-STEM TONE BAR")
(42773 . "MODIFIER LETTER LOW LEFT-STEM TONE BAR")
(42774 . "MODIFIER LETTER EXTRA-LOW LEFT-STEM TONE BAR")
(42775 . "MODIFIER LETTER DOT VERTICAL BAR")
(42776 . "MODIFIER LETTER DOT SLASH")
(42777 . "MODIFIER LETTER DOT HORIZONTAL BAR")
(42778 . "MODIFIER LETTER LOWER RIGHT CORNER ANGLE")
(42779 . "MODIFIER LETTER RAISED UP ARROW")
(42780 . "MODIFIER LETTER RAISED DOWN ARROW")
(42781 . "MODIFIER LETTER RAISED EXCLAMATION MARK")
(42782 . "MODIFIER LETTER RAISED INVERTED EXCLAMATION MARK")
(42783 . "MODIFIER LETTER LOW INVERTED EXCLAMATION MARK")
(42784 . "MODIFIER LETTER STRESS AND HIGH TONE")
(42785 . "MODIFIER LETTER STRESS AND LOW TONE")
(42786 . "LATIN CAPITAL LETTER EGYPTOLOGICAL ALEF")
(42787 . "LATIN SMALL LETTER EGYPTOLOGICAL ALEF")
(42788 . "LATIN CAPITAL LETTER EGYPTOLOGICAL AIN")
(42789 . "LATIN SMALL LETTER EGYPTOLOGICAL AIN")
(42790 . "LATIN CAPITAL LETTER HENG")
(42791 . "LATIN SMALL LETTER HENG")
(42792 . "LATIN CAPITAL LETTER TZ")
(42793 . "LATIN SMALL LETTER TZ")
(42794 . "LATIN CAPITAL LETTER TRESILLO")
(42795 . "LATIN SMALL LETTER TRESILLO")
(42796 . "LATIN CAPITAL LETTER CUATRILLO")
(42797 . "LATIN SMALL LETTER CUATRILLO")
(42798 . "LATIN CAPITAL LETTER CUATRILLO WITH COMMA")
(42799 . "LATIN SMALL LETTER CUATRILLO WITH COMMA")
(42800 . "LATIN LETTER SMALL CAPITAL F")
(42801 . "LATIN LETTER SMALL CAPITAL S")
(42802 . "LATIN CAPITAL LETTER AA")
(42803 . "LATIN SMALL LETTER AA")
(42804 . "LATIN CAPITAL LETTER AO")
(42805 . "LATIN SMALL LETTER AO")
(42806 . "LATIN CAPITAL LETTER AU")
(42807 . "LATIN SMALL LETTER AU")
(42808 . "LATIN CAPITAL LETTER AV")
(42809 . "LATIN SMALL LETTER AV")
(42810 . "LATIN CAPITAL LETTER AV WITH HORIZONTAL BAR")
(42811 . "LATIN SMALL LETTER AV WITH HORIZONTAL BAR")
(42812 . "LATIN CAPITAL LETTER AY")
(42813 . "LATIN SMALL LETTER AY")
(42814 . "LATIN CAPITAL LETTER REVERSED C WITH DOT")
(42815 . "LATIN SMALL LETTER REVERSED C WITH DOT")
(42816 . "LATIN CAPITAL LETTER K WITH STROKE")
(42817 . "LATIN SMALL LETTER K WITH STROKE")
(42818 . "LATIN CAPITAL LETTER K WITH DIAGONAL STROKE")
(42819 . "LATIN SMALL LETTER K WITH DIAGONAL STROKE")
(42820 . "LATIN CAPITAL LETTER K WITH STROKE AND DIAGONAL STROKE")
(42821 . "LATIN SMALL LETTER K WITH STROKE AND DIAGONAL STROKE")
(42822 . "LATIN CAPITAL LETTER BROKEN L")
(42823 . "LATIN SMALL LETTER BROKEN L")
(42824 . "LATIN CAPITAL LETTER L WITH HIGH STROKE")
(42825 . "LATIN SMALL LETTER L WITH HIGH STROKE")
(42826 . "LATIN CAPITAL LETTER O WITH LONG STROKE OVERLAY")
(42827 . "LATIN SMALL LETTER O WITH LONG STROKE OVERLAY")
(42828 . "LATIN CAPITAL LETTER O WITH LOOP")
(42829 . "LATIN SMALL LETTER O WITH LOOP")
(42830 . "LATIN CAPITAL LETTER OO")
(42831 . "LATIN SMALL LETTER OO")
(42832 . "LATIN CAPITAL LETTER P WITH STROKE THROUGH DESCENDER")
(42833 . "LATIN SMALL LETTER P WITH STROKE THROUGH DESCENDER")
(42834 . "LATIN CAPITAL LETTER P WITH FLOURISH")
(42835 . "LATIN SMALL LETTER P WITH FLOURISH")
(42836 . "LATIN CAPITAL LETTER P WITH SQUIRREL TAIL")
(42837 . "LATIN SMALL LETTER P WITH SQUIRREL TAIL")
(42838 . "LATIN CAPITAL LETTER Q WITH STROKE THROUGH DESCENDER")
(42839 . "LATIN SMALL LETTER Q WITH STROKE THROUGH DESCENDER")
(42840 . "LATIN CAPITAL LETTER Q WITH DIAGONAL STROKE")
(42841 . "LATIN SMALL LETTER Q WITH DIAGONAL STROKE")
(42842 . "LATIN CAPITAL LETTER R ROTUNDA")
(42843 . "LATIN SMALL LETTER R ROTUNDA")
(42844 . "LATIN CAPITAL LETTER RUM ROTUNDA")
(42845 . "LATIN SMALL LETTER RUM ROTUNDA")
(42846 . "LATIN CAPITAL LETTER V WITH DIAGONAL STROKE")
(42847 . "LATIN SMALL LETTER V WITH DIAGONAL STROKE")
(42848 . "LATIN CAPITAL LETTER VY")
(42849 . "LATIN SMALL LETTER VY")
(42850 . "LATIN CAPITAL LETTER VISIGOTHIC Z")
(42851 . "LATIN SMALL LETTER VISIGOTHIC Z")
(42852 . "LATIN CAPITAL LETTER THORN WITH STROKE")
(42853 . "LATIN SMALL LETTER THORN WITH STROKE")
(42854 . "LATIN CAPITAL LETTER THORN WITH STROKE THROUGH DESCENDER")
(42855 . "LATIN SMALL LETTER THORN WITH STROKE THROUGH DESCENDER")
(42856 . "LATIN CAPITAL LETTER VEND")
(42857 . "LATIN SMALL LETTER VEND")
(42858 . "LATIN CAPITAL LETTER ET")
(42859 . "LATIN SMALL LETTER ET")
(42860 . "LATIN CAPITAL LETTER IS")
(42861 . "LATIN SMALL LETTER IS")
(42862 . "LATIN CAPITAL LETTER CON")
(42863 . "LATIN SMALL LETTER CON")
(42864 . "MODIFIER LETTER US")
(42865 . "LATIN SMALL LETTER DUM")
(42866 . "LATIN SMALL LETTER LUM")
(42867 . "LATIN SMALL LETTER MUM")
(42868 . "LATIN SMALL LETTER NUM")
(42869 . "LATIN SMALL LETTER RUM")
(42870 . "LATIN LETTER SMALL CAPITAL RUM")
(42871 . "LATIN SMALL LETTER TUM")
(42872 . "LATIN SMALL LETTER UM")
(42873 . "LATIN CAPITAL LETTER INSULAR D")
(42874 . "LATIN SMALL LETTER INSULAR D")
(42875 . "LATIN CAPITAL LETTER INSULAR F")
(42876 . "LATIN SMALL LETTER INSULAR F")
(42877 . "LATIN CAPITAL LETTER INSULAR G")
(42878 . "LATIN CAPITAL LETTER TURNED INSULAR G")
(42879 . "LATIN SMALL LETTER TURNED INSULAR G")
(42880 . "LATIN CAPITAL LETTER TURNED L")
(42881 . "LATIN SMALL LETTER TURNED L")
(42882 . "LATIN CAPITAL LETTER INSULAR R")
(42883 . "LATIN SMALL LETTER INSULAR R")
(42884 . "LATIN CAPITAL LETTER INSULAR S")
(42885 . "LATIN SMALL LETTER INSULAR S")
(42886 . "LATIN CAPITAL LETTER INSULAR T")
(42887 . "LATIN SMALL LETTER INSULAR T")
(42888 . "MODIFIER LETTER LOW CIRCUMFLEX ACCENT")
(42889 . "MODIFIER LETTER COLON")
(42890 . "MODIFIER LETTER SHORT EQUALS SIGN")
(42891 . "LATIN CAPITAL LETTER SALTILLO")
(42892 . "LATIN SMALL LETTER SALTILLO")
(42893 . "LATIN CAPITAL LETTER TURNED H")
(42894 . "LATIN SMALL LETTER L WITH RETROFLEX HOOK AND BELT")
(42895 . "LATIN LETTER SINOLOGICAL DOT")
(42896 . "LATIN CAPITAL LETTER N WITH DESCENDER")
(42897 . "LATIN SMALL LETTER N WITH DESCENDER")
(42898 . "LATIN CAPITAL LETTER C WITH BAR")
(42899 . "LATIN SMALL LETTER C WITH BAR")
(42900 . "LATIN SMALL LETTER C WITH PALATAL HOOK")
(42901 . "LATIN SMALL LETTER H WITH PALATAL HOOK")
(42902 . "LATIN CAPITAL LETTER B WITH FLOURISH")
(42903 . "LATIN SMALL LETTER B WITH FLOURISH")
(42904 . "LATIN CAPITAL LETTER F WITH STROKE")
(42905 . "LATIN SMALL LETTER F WITH STROKE")
(42906 . "LATIN CAPITAL LETTER VOLAPUK AE")
(42907 . "LATIN SMALL LETTER VOLAPUK AE")
(42908 . "LATIN CAPITAL LETTER VOLAPUK OE")
(42909 . "LATIN SMALL LETTER VOLAPUK OE")
(42910 . "LATIN CAPITAL LETTER VOLAPUK UE")
(42911 . "LATIN SMALL LETTER VOLAPUK UE")
(42912 . "LATIN CAPITAL LETTER G WITH OBLIQUE STROKE")
(42913 . "LATIN SMALL LETTER G WITH OBLIQUE STROKE")
(42914 . "LATIN CAPITAL LETTER K WITH OBLIQUE STROKE")
(42915 . "LATIN SMALL LETTER K WITH OBLIQUE STROKE")
(42916 . "LATIN CAPITAL LETTER N WITH OBLIQUE STROKE")
(42917 . "LATIN SMALL LETTER N WITH OBLIQUE STROKE")
(42918 . "LATIN CAPITAL LETTER R WITH OBLIQUE STROKE")
(42919 . "LATIN SMALL LETTER R WITH OBLIQUE STROKE")
(42920 . "LATIN CAPITAL LETTER S WITH OBLIQUE STROKE")
(42921 . "LATIN SMALL LETTER S WITH OBLIQUE STROKE")
(42922 . "LATIN CAPITAL LETTER H WITH HOOK")
(42923 . "LATIN CAPITAL LETTER REVERSED OPEN E")
(42924 . "LATIN CAPITAL LETTER SCRIPT G")
(42925 . "LATIN CAPITAL LETTER L WITH BELT")
(42926 . "LATIN CAPITAL LETTER SMALL CAPITAL I")
(42927 . #f)
(42928 . "LATIN CAPITAL LETTER TURNED K")
(42929 . "LATIN CAPITAL LETTER TURNED T")
(42930 . "LATIN CAPITAL LETTER J WITH CROSSED-TAIL")
(42931 . "LATIN CAPITAL LETTER CHI")
(42932 . "LATIN CAPITAL LETTER BETA")
(42933 . "LATIN SMALL LETTER BETA")
(42934 . "LATIN CAPITAL LETTER OMEGA")
(42935 . "LATIN SMALL LETTER OMEGA")
((42936 . 42999) . #f)
(42999 . "LATIN EPIGRAPHIC LETTER SIDEWAYS I")
(43000 . "MODIFIER LETTER CAPITAL H WITH STROKE")
(43001 . "MODIFIER LETTER SMALL LIGATURE OE")
(43002 . "LATIN LETTER SMALL CAPITAL TURNED M")
(43003 . "LATIN EPIGRAPHIC LETTER REVERSED F")
(43004 . "LATIN EPIGRAPHIC LETTER REVERSED P")
(43005 . "LATIN EPIGRAPHIC LETTER INVERTED M")
(43006 . "LATIN EPIGRAPHIC LETTER I LONGA")
(43007 . "LATIN EPIGRAPHIC LETTER ARCHAIC M")
(43008 . "SYLOTI NAGRI LETTER A")
(43009 . "SYLOTI NAGRI LETTER I")
(43010 . "SYLOTI NAGRI SIGN DVISVARA")
(43011 . "SYLOTI NAGRI LETTER U")
(43012 . "SYLOTI NAGRI LETTER E")
(43013 . "SYLOTI NAGRI LETTER O")
(43014 . "SYLOTI NAGRI SIGN HASANTA")
(43015 . "SYLOTI NAGRI LETTER KO")
(43016 . "SYLOTI NAGRI LETTER KHO")
(43017 . "SYLOTI NAGRI LETTER GO")
(43018 . "SYLOTI NAGRI LETTER GHO")
(43019 . "SYLOTI NAGRI SIGN ANUSVARA")
(43020 . "SYLOTI NAGRI LETTER CO")
(43021 . "SYLOTI NAGRI LETTER CHO")
(43022 . "SYLOTI NAGRI LETTER JO")
(43023 . "SYLOTI NAGRI LETTER JHO")
(43024 . "SYLOTI NAGRI LETTER TTO")
(43025 . "SYLOTI NAGRI LETTER TTHO")
(43026 . "SYLOTI NAGRI LETTER DDO")
(43027 . "SYLOTI NAGRI LETTER DDHO")
(43028 . "SYLOTI NAGRI LETTER TO")
(43029 . "SYLOTI NAGRI LETTER THO")
(43030 . "SYLOTI NAGRI LETTER DO")
(43031 . "SYLOTI NAGRI LETTER DHO")
(43032 . "SYLOTI NAGRI LETTER NO")
(43033 . "SYLOTI NAGRI LETTER PO")
(43034 . "SYLOTI NAGRI LETTER PHO")
(43035 . "SYLOTI NAGRI LETTER BO")
(43036 . "SYLOTI NAGRI LETTER BHO")
(43037 . "SYLOTI NAGRI LETTER MO")
(43038 . "SYLOTI NAGRI LETTER RO")
(43039 . "SYLOTI NAGRI LETTER LO")
(43040 . "SYLOTI NAGRI LETTER RRO")
(43041 . "SYLOTI NAGRI LETTER SO")
(43042 . "SYLOTI NAGRI LETTER HO")
(43043 . "SYLOTI NAGRI VOWEL SIGN A")
(43044 . "SYLOTI NAGRI VOWEL SIGN I")
(43045 . "SYLOTI NAGRI VOWEL SIGN U")
(43046 . "SYLOTI NAGRI VOWEL SIGN E")
(43047 . "SYLOTI NAGRI VOWEL SIGN OO")
(43048 . "SYLOTI NAGRI POETRY MARK-1")
(43049 . "SYLOTI NAGRI POETRY MARK-2")
(43050 . "SYLOTI NAGRI POETRY MARK-3")
(43051 . "SYLOTI NAGRI POETRY MARK-4")
((43052 . 43056) . #f)
(43056 . "NORTH INDIC FRACTION ONE QUARTER")
(43057 . "NORTH INDIC FRACTION ONE HALF")
(43058 . "NORTH INDIC FRACTION THREE QUARTERS")
(43059 . "NORTH INDIC FRACTION ONE SIXTEENTH")
(43060 . "NORTH INDIC FRACTION ONE EIGHTH")
(43061 . "NORTH INDIC FRACTION THREE SIXTEENTHS")
(43062 . "NORTH INDIC QUARTER MARK")
(43063 . "NORTH INDIC PLACEHOLDER MARK")
(43064 . "NORTH INDIC RUPEE MARK")
(43065 . "NORTH INDIC QUANTITY MARK")
((43066 . 43072) . #f)
(43072 . "PHAGS-PA LETTER KA")
(43073 . "PHAGS-PA LETTER KHA")
(43074 . "PHAGS-PA LETTER GA")
(43075 . "PHAGS-PA LETTER NGA")
(43076 . "PHAGS-PA LETTER CA")
(43077 . "PHAGS-PA LETTER CHA")
(43078 . "PHAGS-PA LETTER JA")
(43079 . "PHAGS-PA LETTER NYA")
(43080 . "PHAGS-PA LETTER TA")
(43081 . "PHAGS-PA LETTER THA")
(43082 . "PHAGS-PA LETTER DA")
(43083 . "PHAGS-PA LETTER NA")
(43084 . "PHAGS-PA LETTER PA")
(43085 . "PHAGS-PA LETTER PHA")
(43086 . "PHAGS-PA LETTER BA")
(43087 . "PHAGS-PA LETTER MA")
(43088 . "PHAGS-PA LETTER TSA")
(43089 . "PHAGS-PA LETTER TSHA")
(43090 . "PHAGS-PA LETTER DZA")
(43091 . "PHAGS-PA LETTER WA")
(43092 . "PHAGS-PA LETTER ZHA")
(43093 . "PHAGS-PA LETTER ZA")
(43094 . "PHAGS-PA LETTER SMALL A")
(43095 . "PHAGS-PA LETTER YA")
(43096 . "PHAGS-PA LETTER RA")
(43097 . "PHAGS-PA LETTER LA")
(43098 . "PHAGS-PA LETTER SHA")
(43099 . "PHAGS-PA LETTER SA")
(43100 . "PHAGS-PA LETTER HA")
(43101 . "PHAGS-PA LETTER A")
(43102 . "PHAGS-PA LETTER I")
(43103 . "PHAGS-PA LETTER U")
(43104 . "PHAGS-PA LETTER E")
(43105 . "PHAGS-PA LETTER O")
(43106 . "PHAGS-PA LETTER QA")
(43107 . "PHAGS-PA LETTER XA")
(43108 . "PHAGS-PA LETTER FA")
(43109 . "PHAGS-PA LETTER GGA")
(43110 . "PHAGS-PA LETTER EE")
(43111 . "PHAGS-PA SUBJOINED LETTER WA")
(43112 . "PHAGS-PA SUBJOINED LETTER YA")
(43113 . "PHAGS-PA LETTER TTA")
(43114 . "PHAGS-PA LETTER TTHA")
(43115 . "PHAGS-PA LETTER DDA")
(43116 . "PHAGS-PA LETTER NNA")
(43117 . "PHAGS-PA LETTER ALTERNATE YA")
(43118 . "PHAGS-PA LETTER VOICELESS SHA")
(43119 . "PHAGS-PA LETTER VOICED HA")
(43120 . "PHAGS-PA LETTER ASPIRATED FA")
(43121 . "PHAGS-PA SUBJOINED LETTER RA")
(43122 . "PHAGS-PA SUPERFIXED LETTER RA")
(43123 . "PHAGS-PA LETTER CANDRABINDU")
(43124 . "PHAGS-PA SINGLE HEAD MARK")
(43125 . "PHAGS-PA DOUBLE HEAD MARK")
(43126 . "PHAGS-PA MARK SHAD")
(43127 . "PHAGS-PA MARK DOUBLE SHAD")
((43128 . 43136) . #f)
(43136 . "SAURASHTRA SIGN ANUSVARA")
(43137 . "SAURASHTRA SIGN VISARGA")
(43138 . "SAURASHTRA LETTER A")
(43139 . "SAURASHTRA LETTER AA")
(43140 . "SAURASHTRA LETTER I")
(43141 . "SAURASHTRA LETTER II")
(43142 . "SAURASHTRA LETTER U")
(43143 . "SAURASHTRA LETTER UU")
(43144 . "SAURASHTRA LETTER VOCALIC R")
(43145 . "SAURASHTRA LETTER VOCALIC RR")
(43146 . "SAURASHTRA LETTER VOCALIC L")
(43147 . "SAURASHTRA LETTER VOCALIC LL")
(43148 . "SAURASHTRA LETTER E")
(43149 . "SAURASHTRA LETTER EE")
(43150 . "SAURASHTRA LETTER AI")
(43151 . "SAURASHTRA LETTER O")
(43152 . "SAURASHTRA LETTER OO")
(43153 . "SAURASHTRA LETTER AU")
(43154 . "SAURASHTRA LETTER KA")
(43155 . "SAURASHTRA LETTER KHA")
(43156 . "SAURASHTRA LETTER GA")
(43157 . "SAURASHTRA LETTER GHA")
(43158 . "SAURASHTRA LETTER NGA")
(43159 . "SAURASHTRA LETTER CA")
(43160 . "SAURASHTRA LETTER CHA")
(43161 . "SAURASHTRA LETTER JA")
(43162 . "SAURASHTRA LETTER JHA")
(43163 . "SAURASHTRA LETTER NYA")
(43164 . "SAURASHTRA LETTER TTA")
(43165 . "SAURASHTRA LETTER TTHA")
(43166 . "SAURASHTRA LETTER DDA")
(43167 . "SAURASHTRA LETTER DDHA")
(43168 . "SAURASHTRA LETTER NNA")
(43169 . "SAURASHTRA LETTER TA")
(43170 . "SAURASHTRA LETTER THA")
(43171 . "SAURASHTRA LETTER DA")
(43172 . "SAURASHTRA LETTER DHA")
(43173 . "SAURASHTRA LETTER NA")
(43174 . "SAURASHTRA LETTER PA")
(43175 . "SAURASHTRA LETTER PHA")
(43176 . "SAURASHTRA LETTER BA")
(43177 . "SAURASHTRA LETTER BHA")
(43178 . "SAURASHTRA LETTER MA")
(43179 . "SAURASHTRA LETTER YA")
(43180 . "SAURASHTRA LETTER RA")
(43181 . "SAURASHTRA LETTER LA")
(43182 . "SAURASHTRA LETTER VA")
(43183 . "SAURASHTRA LETTER SHA")
(43184 . "SAURASHTRA LETTER SSA")
(43185 . "SAURASHTRA LETTER SA")
(43186 . "SAURASHTRA LETTER HA")
(43187 . "SAURASHTRA LETTER LLA")
(43188 . "SAURASHTRA CONSONANT SIGN HAARU")
(43189 . "SAURASHTRA VOWEL SIGN AA")
(43190 . "SAURASHTRA VOWEL SIGN I")
(43191 . "SAURASHTRA VOWEL SIGN II")
(43192 . "SAURASHTRA VOWEL SIGN U")
(43193 . "SAURASHTRA VOWEL SIGN UU")
(43194 . "SAURASHTRA VOWEL SIGN VOCALIC R")
(43195 . "SAURASHTRA VOWEL SIGN VOCALIC RR")
(43196 . "SAURASHTRA VOWEL SIGN VOCALIC L")
(43197 . "SAURASHTRA VOWEL SIGN VOCALIC LL")
(43198 . "SAURASHTRA VOWEL SIGN E")
(43199 . "SAURASHTRA VOWEL SIGN EE")
(43200 . "SAURASHTRA VOWEL SIGN AI")
(43201 . "SAURASHTRA VOWEL SIGN O")
(43202 . "SAURASHTRA VOWEL SIGN OO")
(43203 . "SAURASHTRA VOWEL SIGN AU")
(43204 . "SAURASHTRA SIGN VIRAMA")
(43205 . "SAURASHTRA SIGN CANDRABINDU")
((43206 . 43214) . #f)
(43214 . "SAURASHTRA DANDA")
(43215 . "SAURASHTRA DOUBLE DANDA")
(43216 . "SAURASHTRA DIGIT ZERO")
(43217 . "SAURASHTRA DIGIT ONE")
(43218 . "SAURASHTRA DIGIT TWO")
(43219 . "SAURASHTRA DIGIT THREE")
(43220 . "SAURASHTRA DIGIT FOUR")
(43221 . "SAURASHTRA DIGIT FIVE")
(43222 . "SAURASHTRA DIGIT SIX")
(43223 . "SAURASHTRA DIGIT SEVEN")
(43224 . "SAURASHTRA DIGIT EIGHT")
(43225 . "SAURASHTRA DIGIT NINE")
((43226 . 43232) . #f)
(43232 . "COMBINING DEVANAGARI DIGIT ZERO")
(43233 . "COMBINING DEVANAGARI DIGIT ONE")
(43234 . "COMBINING DEVANAGARI DIGIT TWO")
(43235 . "COMBINING DEVANAGARI DIGIT THREE")
(43236 . "COMBINING DEVANAGARI DIGIT FOUR")
(43237 . "COMBINING DEVANAGARI DIGIT FIVE")
(43238 . "COMBINING DEVANAGARI DIGIT SIX")
(43239 . "COMBINING DEVANAGARI DIGIT SEVEN")
(43240 . "COMBINING DEVANAGARI DIGIT EIGHT")
(43241 . "COMBINING DEVANAGARI DIGIT NINE")
(43242 . "COMBINING DEVANAGARI LETTER A")
(43243 . "COMBINING DEVANAGARI LETTER U")
(43244 . "COMBINING DEVANAGARI LETTER KA")
(43245 . "COMBINING DEVANAGARI LETTER NA")
(43246 . "COMBINING DEVANAGARI LETTER PA")
(43247 . "COMBINING DEVANAGARI LETTER RA")
(43248 . "COMBINING DEVANAGARI LETTER VI")
(43249 . "COMBINING DEVANAGARI SIGN AVAGRAHA")
(43250 . "DEVANAGARI SIGN SPACING CANDRABINDU")
(43251 . "DEVANAGARI SIGN CANDRABINDU VIRAMA")
(43252 . "DEVANAGARI SIGN DOUBLE CANDRABINDU VIRAMA")
(43253 . "DEVANAGARI SIGN CANDRABINDU TWO")
(43254 . "DEVANAGARI SIGN CANDRABINDU THREE")
(43255 . "DEVANAGARI SIGN CANDRABINDU AVAGRAHA")
(43256 . "DEVANAGARI SIGN PUSHPIKA")
(43257 . "DEVANAGARI GAP FILLER")
(43258 . "DEVANAGARI CARET")
(43259 . "DEVANAGARI HEADSTROKE")
(43260 . "DEVANAGARI SIGN SIDDHAM")
(43261 . "DEVANAGARI JAIN OM")
((43262 . 43264) . #f)
(43264 . "KAYAH LI DIGIT ZERO")
(43265 . "KAYAH LI DIGIT ONE")
(43266 . "KAYAH LI DIGIT TWO")
(43267 . "KAYAH LI DIGIT THREE")
(43268 . "KAYAH LI DIGIT FOUR")
(43269 . "KAYAH LI DIGIT FIVE")
(43270 . "KAYAH LI DIGIT SIX")
(43271 . "KAYAH LI DIGIT SEVEN")
(43272 . "KAYAH LI DIGIT EIGHT")
(43273 . "KAYAH LI DIGIT NINE")
(43274 . "KAYAH LI LETTER KA")
(43275 . "KAYAH LI LETTER KHA")
(43276 . "KAYAH LI LETTER GA")
(43277 . "KAYAH LI LETTER NGA")
(43278 . "KAYAH LI LETTER SA")
(43279 . "KAYAH LI LETTER SHA")
(43280 . "KAYAH LI LETTER ZA")
(43281 . "KAYAH LI LETTER NYA")
(43282 . "KAYAH LI LETTER TA")
(43283 . "KAYAH LI LETTER HTA")
(43284 . "KAYAH LI LETTER NA")
(43285 . "KAYAH LI LETTER PA")
(43286 . "KAYAH LI LETTER PHA")
(43287 . "KAYAH LI LETTER MA")
(43288 . "KAYAH LI LETTER DA")
(43289 . "KAYAH LI LETTER BA")
(43290 . "KAYAH LI LETTER RA")
(43291 . "KAYAH LI LETTER YA")
(43292 . "KAYAH LI LETTER LA")
(43293 . "KAYAH LI LETTER WA")
(43294 . "KAYAH LI LETTER THA")
(43295 . "KAYAH LI LETTER HA")
(43296 . "KAYAH LI LETTER VA")
(43297 . "KAYAH LI LETTER CA")
(43298 . "KAYAH LI LETTER A")
(43299 . "KAYAH LI LETTER OE")
(43300 . "KAYAH LI LETTER I")
(43301 . "KAYAH LI LETTER OO")
(43302 . "KAYAH LI VOWEL UE")
(43303 . "KAYAH LI VOWEL E")
(43304 . "KAYAH LI VOWEL U")
(43305 . "KAYAH LI VOWEL EE")
(43306 . "KAYAH LI VOWEL O")
(43307 . "KAYAH LI TONE PLOPHU")
(43308 . "KAYAH LI TONE CALYA")
(43309 . "KAYAH LI TONE CALYA PLOPHU")
(43310 . "KAYAH LI SIGN CWI")
(43311 . "KAYAH LI SIGN SHYA")
(43312 . "REJANG LETTER KA")
(43313 . "REJANG LETTER GA")
(43314 . "REJANG LETTER NGA")
(43315 . "REJANG LETTER TA")
(43316 . "REJANG LETTER DA")
(43317 . "REJANG LETTER NA")
(43318 . "REJANG LETTER PA")
(43319 . "REJANG LETTER BA")
(43320 . "REJANG LETTER MA")
(43321 . "REJANG LETTER CA")
(43322 . "REJANG LETTER JA")
(43323 . "REJANG LETTER NYA")
(43324 . "REJANG LETTER SA")
(43325 . "REJANG LETTER RA")
(43326 . "REJANG LETTER LA")
(43327 . "REJANG LETTER YA")
(43328 . "REJANG LETTER WA")
(43329 . "REJANG LETTER HA")
(43330 . "REJANG LETTER MBA")
(43331 . "REJANG LETTER NGGA")
(43332 . "REJANG LETTER NDA")
(43333 . "REJANG LETTER NYJA")
(43334 . "REJANG LETTER A")
(43335 . "REJANG VOWEL SIGN I")
(43336 . "REJANG VOWEL SIGN U")
(43337 . "REJANG VOWEL SIGN E")
(43338 . "REJANG VOWEL SIGN AI")
(43339 . "REJANG VOWEL SIGN O")
(43340 . "REJANG VOWEL SIGN AU")
(43341 . "REJANG VOWEL SIGN EU")
(43342 . "REJANG VOWEL SIGN EA")
(43343 . "REJANG CONSONANT SIGN NG")
(43344 . "REJANG CONSONANT SIGN N")
(43345 . "REJANG CONSONANT SIGN R")
(43346 . "REJANG CONSONANT SIGN H")
(43347 . "REJANG VIRAMA")
((43348 . 43359) . #f)
(43359 . "REJANG SECTION MARK")
(43360 . "HANGUL CHOSEONG TIKEUT-MIEUM")
(43361 . "HANGUL CHOSEONG TIKEUT-PIEUP")
(43362 . "HANGUL CHOSEONG TIKEUT-SIOS")
(43363 . "HANGUL CHOSEONG TIKEUT-CIEUC")
(43364 . "HANGUL CHOSEONG RIEUL-KIYEOK")
(43365 . "HANGUL CHOSEONG RIEUL-SSANGKIYEOK")
(43366 . "HANGUL CHOSEONG RIEUL-TIKEUT")
(43367 . "HANGUL CHOSEONG RIEUL-SSANGTIKEUT")
(43368 . "HANGUL CHOSEONG RIEUL-MIEUM")
(43369 . "HANGUL CHOSEONG RIEUL-PIEUP")
(43370 . "HANGUL CHOSEONG RIEUL-SSANGPIEUP")
(43371 . "HANGUL CHOSEONG RIEUL-KAPYEOUNPIEUP")
(43372 . "HANGUL CHOSEONG RIEUL-SIOS")
(43373 . "HANGUL CHOSEONG RIEUL-CIEUC")
(43374 . "HANGUL CHOSEONG RIEUL-KHIEUKH")
(43375 . "HANGUL CHOSEONG MIEUM-KIYEOK")
(43376 . "HANGUL CHOSEONG MIEUM-TIKEUT")
(43377 . "HANGUL CHOSEONG MIEUM-SIOS")
(43378 . "HANGUL CHOSEONG PIEUP-SIOS-THIEUTH")
(43379 . "HANGUL CHOSEONG PIEUP-KHIEUKH")
(43380 . "HANGUL CHOSEONG PIEUP-HIEUH")
(43381 . "HANGUL CHOSEONG SSANGSIOS-PIEUP")
(43382 . "HANGUL CHOSEONG IEUNG-RIEUL")
(43383 . "HANGUL CHOSEONG IEUNG-HIEUH")
(43384 . "HANGUL CHOSEONG SSANGCIEUC-HIEUH")
(43385 . "HANGUL CHOSEONG SSANGTHIEUTH")
(43386 . "HANGUL CHOSEONG PHIEUPH-HIEUH")
(43387 . "HANGUL CHOSEONG HIEUH-SIOS")
(43388 . "HANGUL CHOSEONG SSANGYEORINHIEUH")
((43389 . 43392) . #f)
(43392 . "JAVANESE SIGN PANYANGGA")
(43393 . "JAVANESE SIGN CECAK")
(43394 . "JAVANESE SIGN LAYAR")
(43395 . "JAVANESE SIGN WIGNYAN")
(43396 . "JAVANESE LETTER A")
(43397 . "JAVANESE LETTER I KAWI")
(43398 . "JAVANESE LETTER I")
(43399 . "JAVANESE LETTER II")
(43400 . "JAVANESE LETTER U")
(43401 . "JAVANESE LETTER PA CEREK")
(43402 . "JAVANESE LETTER NGA LELET")
(43403 . "JAVANESE LETTER NGA LELET RASWADI")
(43404 . "JAVANESE LETTER E")
(43405 . "JAVANESE LETTER AI")
(43406 . "JAVANESE LETTER O")
(43407 . "JAVANESE LETTER KA")
(43408 . "JAVANESE LETTER KA SASAK")
(43409 . "JAVANESE LETTER KA MURDA")
(43410 . "JAVANESE LETTER GA")
(43411 . "JAVANESE LETTER GA MURDA")
(43412 . "JAVANESE LETTER NGA")
(43413 . "JAVANESE LETTER CA")
(43414 . "JAVANESE LETTER CA MURDA")
(43415 . "JAVANESE LETTER JA")
(43416 . "JAVANESE LETTER NYA MURDA")
(43417 . "JAVANESE LETTER JA MAHAPRANA")
(43418 . "JAVANESE LETTER NYA")
(43419 . "JAVANESE LETTER TTA")
(43420 . "JAVANESE LETTER TTA MAHAPRANA")
(43421 . "JAVANESE LETTER DDA")
(43422 . "JAVANESE LETTER DDA MAHAPRANA")
(43423 . "JAVANESE LETTER NA MURDA")
(43424 . "JAVANESE LETTER TA")
(43425 . "JAVANESE LETTER TA MURDA")
(43426 . "JAVANESE LETTER DA")
(43427 . "JAVANESE LETTER DA MAHAPRANA")
(43428 . "JAVANESE LETTER NA")
(43429 . "JAVANESE LETTER PA")
(43430 . "JAVANESE LETTER PA MURDA")
(43431 . "JAVANESE LETTER BA")
(43432 . "JAVANESE LETTER BA MURDA")
(43433 . "JAVANESE LETTER MA")
(43434 . "JAVANESE LETTER YA")
(43435 . "JAVANESE LETTER RA")
(43436 . "JAVANESE LETTER RA AGUNG")
(43437 . "JAVANESE LETTER LA")
(43438 . "JAVANESE LETTER WA")
(43439 . "JAVANESE LETTER SA MURDA")
(43440 . "JAVANESE LETTER SA MAHAPRANA")
(43441 . "JAVANESE LETTER SA")
(43442 . "JAVANESE LETTER HA")
(43443 . "JAVANESE SIGN CECAK TELU")
(43444 . "JAVANESE VOWEL SIGN TARUNG")
(43445 . "JAVANESE VOWEL SIGN TOLONG")
(43446 . "JAVANESE VOWEL SIGN WULU")
(43447 . "JAVANESE VOWEL SIGN WULU MELIK")
(43448 . "JAVANESE VOWEL SIGN SUKU")
(43449 . "JAVANESE VOWEL SIGN SUKU MENDUT")
(43450 . "JAVANESE VOWEL SIGN TALING")
(43451 . "JAVANESE VOWEL SIGN DIRGA MURE")
(43452 . "JAVANESE VOWEL SIGN PEPET")
(43453 . "JAVANESE CONSONANT SIGN KERET")
(43454 . "JAVANESE CONSONANT SIGN PENGKAL")
(43455 . "JAVANESE CONSONANT SIGN CAKRA")
(43456 . "JAVANESE PANGKON")
(43457 . "JAVANESE LEFT RERENGGAN")
(43458 . "JAVANESE RIGHT RERENGGAN")
(43459 . "JAVANESE PADA ANDAP")
(43460 . "JAVANESE PADA MADYA")
(43461 . "JAVANESE PADA LUHUR")
(43462 . "JAVANESE PADA WINDU")
(43463 . "JAVANESE PADA PANGKAT")
(43464 . "JAVANESE PADA LINGSA")
(43465 . "JAVANESE PADA LUNGSI")
(43466 . "JAVANESE PADA ADEG")
(43467 . "JAVANESE PADA ADEG ADEG")
(43468 . "JAVANESE PADA PISELEH")
(43469 . "JAVANESE TURNED PADA PISELEH")
(43470 . #f)
(43471 . "JAVANESE PANGRANGKEP")
(43472 . "JAVANESE DIGIT ZERO")
(43473 . "JAVANESE DIGIT ONE")
(43474 . "JAVANESE DIGIT TWO")
(43475 . "JAVANESE DIGIT THREE")
(43476 . "JAVANESE DIGIT FOUR")
(43477 . "JAVANESE DIGIT FIVE")
(43478 . "JAVANESE DIGIT SIX")
(43479 . "JAVANESE DIGIT SEVEN")
(43480 . "JAVANESE DIGIT EIGHT")
(43481 . "JAVANESE DIGIT NINE")
((43482 . 43486) . #f)
(43486 . "JAVANESE PADA TIRTA TUMETES")
(43487 . "JAVANESE PADA ISEN-ISEN")
(43488 . "MYANMAR LETTER SHAN GHA")
(43489 . "MYANMAR LETTER SHAN CHA")
(43490 . "MYANMAR LETTER SHAN JHA")
(43491 . "MYANMAR LETTER SHAN NNA")
(43492 . "MYANMAR LETTER SHAN BHA")
(43493 . "MYANMAR SIGN SHAN SAW")
(43494 . "MYANMAR MODIFIER LETTER SHAN REDUPLICATION")
(43495 . "MYANMAR LETTER TAI LAING NYA")
(43496 . "MYANMAR LETTER TAI LAING FA")
(43497 . "MYANMAR LETTER TAI LAING GA")
(43498 . "MYANMAR LETTER TAI LAING GHA")
(43499 . "MYANMAR LETTER TAI LAING JA")
(43500 . "MYANMAR LETTER TAI LAING JHA")
(43501 . "MYANMAR LETTER TAI LAING DDA")
(43502 . "MYANMAR LETTER TAI LAING DDHA")
(43503 . "MYANMAR LETTER TAI LAING NNA")
(43504 . "MYANMAR TAI LAING DIGIT ZERO")
(43505 . "MYANMAR TAI LAING DIGIT ONE")
(43506 . "MYANMAR TAI LAING DIGIT TWO")
(43507 . "MYANMAR TAI LAING DIGIT THREE")
(43508 . "MYANMAR TAI LAING DIGIT FOUR")
(43509 . "MYANMAR TAI LAING DIGIT FIVE")
(43510 . "MYANMAR TAI LAING DIGIT SIX")
(43511 . "MYANMAR TAI LAING DIGIT SEVEN")
(43512 . "MYANMAR TAI LAING DIGIT EIGHT")
(43513 . "MYANMAR TAI LAING DIGIT NINE")
(43514 . "MYANMAR LETTER TAI LAING LLA")
(43515 . "MYANMAR LETTER TAI LAING DA")
(43516 . "MYANMAR LETTER TAI LAING DHA")
(43517 . "MYANMAR LETTER TAI LAING BA")
(43518 . "MYANMAR LETTER TAI LAING BHA")
(43519 . #f)
(43520 . "CHAM LETTER A")
(43521 . "CHAM LETTER I")
(43522 . "CHAM LETTER U")
(43523 . "CHAM LETTER E")
(43524 . "CHAM LETTER AI")
(43525 . "CHAM LETTER O")
(43526 . "CHAM LETTER KA")
(43527 . "CHAM LETTER KHA")
(43528 . "CHAM LETTER GA")
(43529 . "CHAM LETTER GHA")
(43530 . "CHAM LETTER NGUE")
(43531 . "CHAM LETTER NGA")
(43532 . "CHAM LETTER CHA")
(43533 . "CHAM LETTER CHHA")
(43534 . "CHAM LETTER JA")
(43535 . "CHAM LETTER JHA")
(43536 . "CHAM LETTER NHUE")
(43537 . "CHAM LETTER NHA")
(43538 . "CHAM LETTER NHJA")
(43539 . "CHAM LETTER TA")
(43540 . "CHAM LETTER THA")
(43541 . "CHAM LETTER DA")
(43542 . "CHAM LETTER DHA")
(43543 . "CHAM LETTER NUE")
(43544 . "CHAM LETTER NA")
(43545 . "CHAM LETTER DDA")
(43546 . "CHAM LETTER PA")
(43547 . "CHAM LETTER PPA")
(43548 . "CHAM LETTER PHA")
(43549 . "CHAM LETTER BA")
(43550 . "CHAM LETTER BHA")
(43551 . "CHAM LETTER MUE")
(43552 . "CHAM LETTER MA")
(43553 . "CHAM LETTER BBA")
(43554 . "CHAM LETTER YA")
(43555 . "CHAM LETTER RA")
(43556 . "CHAM LETTER LA")
(43557 . "CHAM LETTER VA")
(43558 . "CHAM LETTER SSA")
(43559 . "CHAM LETTER SA")
(43560 . "CHAM LETTER HA")
(43561 . "CHAM VOWEL SIGN AA")
(43562 . "CHAM VOWEL SIGN I")
(43563 . "CHAM VOWEL SIGN II")
(43564 . "CHAM VOWEL SIGN EI")
(43565 . "CHAM VOWEL SIGN U")
(43566 . "CHAM VOWEL SIGN OE")
(43567 . "CHAM VOWEL SIGN O")
(43568 . "CHAM VOWEL SIGN AI")
(43569 . "CHAM VOWEL SIGN AU")
(43570 . "CHAM VOWEL SIGN UE")
(43571 . "CHAM CONSONANT SIGN YA")
(43572 . "CHAM CONSONANT SIGN RA")
(43573 . "CHAM CONSONANT SIGN LA")
(43574 . "CHAM CONSONANT SIGN WA")
((43575 . 43584) . #f)
(43584 . "CHAM LETTER FINAL K")
(43585 . "CHAM LETTER FINAL G")
(43586 . "CHAM LETTER FINAL NG")
(43587 . "CHAM CONSONANT SIGN FINAL NG")
(43588 . "CHAM LETTER FINAL CH")
(43589 . "CHAM LETTER FINAL T")
(43590 . "CHAM LETTER FINAL N")
(43591 . "CHAM LETTER FINAL P")
(43592 . "CHAM LETTER FINAL Y")
(43593 . "CHAM LETTER FINAL R")
(43594 . "CHAM LETTER FINAL L")
(43595 . "CHAM LETTER FINAL SS")
(43596 . "CHAM CONSONANT SIGN FINAL M")
(43597 . "CHAM CONSONANT SIGN FINAL H")
((43598 . 43600) . #f)
(43600 . "CHAM DIGIT ZERO")
(43601 . "CHAM DIGIT ONE")
(43602 . "CHAM DIGIT TWO")
(43603 . "CHAM DIGIT THREE")
(43604 . "CHAM DIGIT FOUR")
(43605 . "CHAM DIGIT FIVE")
(43606 . "CHAM DIGIT SIX")
(43607 . "CHAM DIGIT SEVEN")
(43608 . "CHAM DIGIT EIGHT")
(43609 . "CHAM DIGIT NINE")
((43610 . 43612) . #f)
(43612 . "CHAM PUNCTUATION SPIRAL")
(43613 . "CHAM PUNCTUATION DANDA")
(43614 . "CHAM PUNCTUATION DOUBLE DANDA")
(43615 . "CHAM PUNCTUATION TRIPLE DANDA")
(43616 . "MYANMAR LETTER KHAMTI GA")
(43617 . "MYANMAR LETTER KHAMTI CA")
(43618 . "MYANMAR LETTER KHAMTI CHA")
(43619 . "MYANMAR LETTER KHAMTI JA")
(43620 . "MYANMAR LETTER KHAMTI JHA")
(43621 . "MYANMAR LETTER KHAMTI NYA")
(43622 . "MYANMAR LETTER KHAMTI TTA")
(43623 . "MYANMAR LETTER KHAMTI TTHA")
(43624 . "MYANMAR LETTER KHAMTI DDA")
(43625 . "MYANMAR LETTER KHAMTI DDHA")
(43626 . "MYANMAR LETTER KHAMTI DHA")
(43627 . "MYANMAR LETTER KHAMTI NA")
(43628 . "MYANMAR LETTER KHAMTI SA")
(43629 . "MYANMAR LETTER KHAMTI HA")
(43630 . "MYANMAR LETTER KHAMTI HHA")
(43631 . "MYANMAR LETTER KHAMTI FA")
(43632 . "MYANMAR MODIFIER LETTER KHAMTI REDUPLICATION")
(43633 . "MYANMAR LETTER KHAMTI XA")
(43634 . "MYANMAR LETTER KHAMTI ZA")
(43635 . "MYANMAR LETTER KHAMTI RA")
(43636 . "MYANMAR LOGOGRAM KHAMTI OAY")
(43637 . "MYANMAR LOGOGRAM KHAMTI QN")
(43638 . "MYANMAR LOGOGRAM KHAMTI HM")
(43639 . "MYANMAR SYMBOL AITON EXCLAMATION")
(43640 . "MYANMAR SYMBOL AITON ONE")
(43641 . "MYANMAR SYMBOL AITON TWO")
(43642 . "MYANMAR LETTER AITON RA")
(43643 . "MYANMAR SIGN PAO KAREN TONE")
(43644 . "MYANMAR SIGN TAI LAING TONE-2")
(43645 . "MYANMAR SIGN TAI LAING TONE-5")
(43646 . "MYANMAR LETTER SHWE PALAUNG CHA")
(43647 . "MYANMAR LETTER SHWE PALAUNG SHA")
(43648 . "TAI VIET LETTER LOW KO")
(43649 . "TAI VIET LETTER HIGH KO")
(43650 . "TAI VIET LETTER LOW KHO")
(43651 . "TAI VIET LETTER HIGH KHO")
(43652 . "TAI VIET LETTER LOW KHHO")
(43653 . "TAI VIET LETTER HIGH KHHO")
(43654 . "TAI VIET LETTER LOW GO")
(43655 . "TAI VIET LETTER HIGH GO")
(43656 . "TAI VIET LETTER LOW NGO")
(43657 . "TAI VIET LETTER HIGH NGO")
(43658 . "TAI VIET LETTER LOW CO")
(43659 . "TAI VIET LETTER HIGH CO")
(43660 . "TAI VIET LETTER LOW CHO")
(43661 . "TAI VIET LETTER HIGH CHO")
(43662 . "TAI VIET LETTER LOW SO")
(43663 . "TAI VIET LETTER HIGH SO")
(43664 . "TAI VIET LETTER LOW NYO")
(43665 . "TAI VIET LETTER HIGH NYO")
(43666 . "TAI VIET LETTER LOW DO")
(43667 . "TAI VIET LETTER HIGH DO")
(43668 . "TAI VIET LETTER LOW TO")
(43669 . "TAI VIET LETTER HIGH TO")
(43670 . "TAI VIET LETTER LOW THO")
(43671 . "TAI VIET LETTER HIGH THO")
(43672 . "TAI VIET LETTER LOW NO")
(43673 . "TAI VIET LETTER HIGH NO")
(43674 . "TAI VIET LETTER LOW BO")
(43675 . "TAI VIET LETTER HIGH BO")
(43676 . "TAI VIET LETTER LOW PO")
(43677 . "TAI VIET LETTER HIGH PO")
(43678 . "TAI VIET LETTER LOW PHO")
(43679 . "TAI VIET LETTER HIGH PHO")
(43680 . "TAI VIET LETTER LOW FO")
(43681 . "TAI VIET LETTER HIGH FO")
(43682 . "TAI VIET LETTER LOW MO")
(43683 . "TAI VIET LETTER HIGH MO")
(43684 . "TAI VIET LETTER LOW YO")
(43685 . "TAI VIET LETTER HIGH YO")
(43686 . "TAI VIET LETTER LOW RO")
(43687 . "TAI VIET LETTER HIGH RO")
(43688 . "TAI VIET LETTER LOW LO")
(43689 . "TAI VIET LETTER HIGH LO")
(43690 . "TAI VIET LETTER LOW VO")
(43691 . "TAI VIET LETTER HIGH VO")
(43692 . "TAI VIET LETTER LOW HO")
(43693 . "TAI VIET LETTER HIGH HO")
(43694 . "TAI VIET LETTER LOW O")
(43695 . "TAI VIET LETTER HIGH O")
(43696 . "TAI VIET MAI KANG")
(43697 . "TAI VIET VOWEL AA")
(43698 . "TAI VIET VOWEL I")
(43699 . "TAI VIET VOWEL UE")
(43700 . "TAI VIET VOWEL U")
(43701 . "TAI VIET VOWEL E")
(43702 . "TAI VIET VOWEL O")
(43703 . "TAI VIET MAI KHIT")
(43704 . "TAI VIET VOWEL IA")
(43705 . "TAI VIET VOWEL UEA")
(43706 . "TAI VIET VOWEL UA")
(43707 . "TAI VIET VOWEL AUE")
(43708 . "TAI VIET VOWEL AY")
(43709 . "TAI VIET VOWEL AN")
(43710 . "TAI VIET VOWEL AM")
(43711 . "TAI VIET TONE MAI EK")
(43712 . "TAI VIET TONE MAI NUENG")
(43713 . "TAI VIET TONE MAI THO")
(43714 . "TAI VIET TONE MAI SONG")
((43715 . 43739) . #f)
(43739 . "TAI VIET SYMBOL KON")
(43740 . "TAI VIET SYMBOL NUENG")
(43741 . "TAI VIET SYMBOL SAM")
(43742 . "TAI VIET SYMBOL HO HOI")
(43743 . "TAI VIET SYMBOL KOI KOI")
(43744 . "MEETEI MAYEK LETTER E")
(43745 . "MEETEI MAYEK LETTER O")
(43746 . "MEETEI MAYEK LETTER CHA")
(43747 . "MEETEI MAYEK LETTER NYA")
(43748 . "MEETEI MAYEK LETTER TTA")
(43749 . "MEETEI MAYEK LETTER TTHA")
(43750 . "MEETEI MAYEK LETTER DDA")
(43751 . "MEETEI MAYEK LETTER DDHA")
(43752 . "MEETEI MAYEK LETTER NNA")
(43753 . "MEETEI MAYEK LETTER SHA")
(43754 . "MEETEI MAYEK LETTER SSA")
(43755 . "MEETEI MAYEK VOWEL SIGN II")
(43756 . "MEETEI MAYEK VOWEL SIGN UU")
(43757 . "MEETEI MAYEK VOWEL SIGN AAI")
(43758 . "MEETEI MAYEK VOWEL SIGN AU")
(43759 . "MEETEI MAYEK VOWEL SIGN AAU")
(43760 . "MEETEI MAYEK CHEIKHAN")
(43761 . "MEETEI MAYEK AHANG KHUDAM")
(43762 . "MEETEI MAYEK ANJI")
(43763 . "MEETEI MAYEK SYLLABLE REPETITION MARK")
(43764 . "MEETEI MAYEK WORD REPETITION MARK")
(43765 . "MEETEI MAYEK VOWEL SIGN VISARGA")
(43766 . "MEETEI MAYEK VIRAMA")
((43767 . 43777) . #f)
(43777 . "ETHIOPIC SYLLABLE TTHU")
(43778 . "ETHIOPIC SYLLABLE TTHI")
(43779 . "ETHIOPIC SYLLABLE TTHAA")
(43780 . "ETHIOPIC SYLLABLE TTHEE")
(43781 . "ETHIOPIC SYLLABLE TTHE")
(43782 . "ETHIOPIC SYLLABLE TTHO")
((43783 . 43785) . #f)
(43785 . "ETHIOPIC SYLLABLE DDHU")
(43786 . "ETHIOPIC SYLLABLE DDHI")
(43787 . "ETHIOPIC SYLLABLE DDHAA")
(43788 . "ETHIOPIC SYLLABLE DDHEE")
(43789 . "ETHIOPIC SYLLABLE DDHE")
(43790 . "ETHIOPIC SYLLABLE DDHO")
((43791 . 43793) . #f)
(43793 . "ETHIOPIC SYLLABLE DZU")
(43794 . "ETHIOPIC SYLLABLE DZI")
(43795 . "ETHIOPIC SYLLABLE DZAA")
(43796 . "ETHIOPIC SYLLABLE DZEE")
(43797 . "ETHIOPIC SYLLABLE DZE")
(43798 . "ETHIOPIC SYLLABLE DZO")
((43799 . 43808) . #f)
(43808 . "ETHIOPIC SYLLABLE CCHHA")
(43809 . "ETHIOPIC SYLLABLE CCHHU")
(43810 . "ETHIOPIC SYLLABLE CCHHI")
(43811 . "ETHIOPIC SYLLABLE CCHHAA")
(43812 . "ETHIOPIC SYLLABLE CCHHEE")
(43813 . "ETHIOPIC SYLLABLE CCHHE")
(43814 . "ETHIOPIC SYLLABLE CCHHO")
(43815 . #f)
(43816 . "ETHIOPIC SYLLABLE BBA")
(43817 . "ETHIOPIC SYLLABLE BBU")
(43818 . "ETHIOPIC SYLLABLE BBI")
(43819 . "ETHIOPIC SYLLABLE BBAA")
(43820 . "ETHIOPIC SYLLABLE BBEE")
(43821 . "ETHIOPIC SYLLABLE BBE")
(43822 . "ETHIOPIC SYLLABLE BBO")
(43823 . #f)
(43824 . "LATIN SMALL LETTER BARRED ALPHA")
(43825 . "LATIN SMALL LETTER A REVERSED-SCHWA")
(43826 . "LATIN SMALL LETTER BLACKLETTER E")
(43827 . "LATIN SMALL LETTER BARRED E")
(43828 . "LATIN SMALL LETTER E WITH FLOURISH")
(43829 . "LATIN SMALL LETTER LENIS F")
(43830 . "LATIN SMALL LETTER SCRIPT G WITH CROSSED-TAIL")
(43831 . "LATIN SMALL LETTER L WITH INVERTED LAZY S")
(43832 . "LATIN SMALL LETTER L WITH DOUBLE MIDDLE TILDE")
(43833 . "LATIN SMALL LETTER L WITH MIDDLE RING")
(43834 . "LATIN SMALL LETTER M WITH CROSSED-TAIL")
(43835 . "LATIN SMALL LETTER N WITH CROSSED-TAIL")
(43836 . "LATIN SMALL LETTER ENG WITH CROSSED-TAIL")
(43837 . "LATIN SMALL LETTER BLACKLETTER O")
(43838 . "LATIN SMALL LETTER BLACKLETTER O WITH STROKE")
(43839 . "LATIN SMALL LETTER OPEN O WITH STROKE")
(43840 . "LATIN SMALL LETTER INVERTED OE")
(43841 . "LATIN SMALL LETTER TURNED OE WITH STROKE")
(43842 . "LATIN SMALL LETTER TURNED OE WITH HORIZONTAL STROKE")
(43843 . "LATIN SMALL LETTER TURNED O OPEN-O")
(43844 . "LATIN SMALL LETTER TURNED O OPEN-O WITH STROKE")
(43845 . "LATIN SMALL LETTER STIRRUP R")
(43846 . "LATIN LETTER SMALL CAPITAL R WITH RIGHT LEG")
(43847 . "LATIN SMALL LETTER R WITHOUT HANDLE")
(43848 . "LATIN SMALL LETTER DOUBLE R")
(43849 . "LATIN SMALL LETTER R WITH CROSSED-TAIL")
(43850 . "LATIN SMALL LETTER DOUBLE R WITH CROSSED-TAIL")
(43851 . "LATIN SMALL LETTER SCRIPT R")
(43852 . "LATIN SMALL LETTER SCRIPT R WITH RING")
(43853 . "LATIN SMALL LETTER BASELINE ESH")
(43854 . "LATIN SMALL LETTER U WITH SHORT RIGHT LEG")
(43855 . "LATIN SMALL LETTER U BAR WITH SHORT RIGHT LEG")
(43856 . "LATIN SMALL LETTER UI")
(43857 . "LATIN SMALL LETTER TURNED UI")
(43858 . "LATIN SMALL LETTER U WITH LEFT HOOK")
(43859 . "LATIN SMALL LETTER CHI")
(43860 . "LATIN SMALL LETTER CHI WITH LOW RIGHT RING")
(43861 . "LATIN SMALL LETTER CHI WITH LOW LEFT SERIF")
(43862 . "LATIN SMALL LETTER X WITH LOW RIGHT RING")
(43863 . "LATIN SMALL LETTER X WITH LONG LEFT LEG")
(43864 . "LATIN SMALL LETTER X WITH LONG LEFT LEG AND LOW RIGHT RING")
(43865 . "LATIN SMALL LETTER X WITH LONG LEFT LEG WITH SERIF")
(43866 . "LATIN SMALL LETTER Y WITH SHORT RIGHT LEG")
(43867 . "MODIFIER BREVE WITH INVERTED BREVE")
(43868 . "MODIFIER LETTER SMALL HENG")
(43869 . "MODIFIER LETTER SMALL L WITH INVERTED LAZY S")
(43870 . "MODIFIER LETTER SMALL L WITH MIDDLE TILDE")
(43871 . "MODIFIER LETTER SMALL U WITH LEFT HOOK")
(43872 . "LATIN SMALL LETTER SAKHA YAT")
(43873 . "LATIN SMALL LETTER IOTIFIED E")
(43874 . "LATIN SMALL LETTER OPEN OE")
(43875 . "LATIN SMALL LETTER UO")
(43876 . "LATIN SMALL LETTER INVERTED ALPHA")
(43877 . "GREEK LETTER SMALL CAPITAL OMEGA")
((43878 . 43888) . #f)
(43888 . "CHEROKEE SMALL LETTER A")
(43889 . "CHEROKEE SMALL LETTER E")
(43890 . "CHEROKEE SMALL LETTER I")
(43891 . "CHEROKEE SMALL LETTER O")
(43892 . "CHEROKEE SMALL LETTER U")
(43893 . "CHEROKEE SMALL LETTER V")
(43894 . "CHEROKEE SMALL LETTER GA")
(43895 . "CHEROKEE SMALL LETTER KA")
(43896 . "CHEROKEE SMALL LETTER GE")
(43897 . "CHEROKEE SMALL LETTER GI")
(43898 . "CHEROKEE SMALL LETTER GO")
(43899 . "CHEROKEE SMALL LETTER GU")
(43900 . "CHEROKEE SMALL LETTER GV")
(43901 . "CHEROKEE SMALL LETTER HA")
(43902 . "CHEROKEE SMALL LETTER HE")
(43903 . "CHEROKEE SMALL LETTER HI")
(43904 . "CHEROKEE SMALL LETTER HO")
(43905 . "CHEROKEE SMALL LETTER HU")
(43906 . "CHEROKEE SMALL LETTER HV")
(43907 . "CHEROKEE SMALL LETTER LA")
(43908 . "CHEROKEE SMALL LETTER LE")
(43909 . "CHEROKEE SMALL LETTER LI")
(43910 . "CHEROKEE SMALL LETTER LO")
(43911 . "CHEROKEE SMALL LETTER LU")
(43912 . "CHEROKEE SMALL LETTER LV")
(43913 . "CHEROKEE SMALL LETTER MA")
(43914 . "CHEROKEE SMALL LETTER ME")
(43915 . "CHEROKEE SMALL LETTER MI")
(43916 . "CHEROKEE SMALL LETTER MO")
(43917 . "CHEROKEE SMALL LETTER MU")
(43918 . "CHEROKEE SMALL LETTER NA")
(43919 . "CHEROKEE SMALL LETTER HNA")
(43920 . "CHEROKEE SMALL LETTER NAH")
(43921 . "CHEROKEE SMALL LETTER NE")
(43922 . "CHEROKEE SMALL LETTER NI")
(43923 . "CHEROKEE SMALL LETTER NO")
(43924 . "CHEROKEE SMALL LETTER NU")
(43925 . "CHEROKEE SMALL LETTER NV")
(43926 . "CHEROKEE SMALL LETTER QUA")
(43927 . "CHEROKEE SMALL LETTER QUE")
(43928 . "CHEROKEE SMALL LETTER QUI")
(43929 . "CHEROKEE SMALL LETTER QUO")
(43930 . "CHEROKEE SMALL LETTER QUU")
(43931 . "CHEROKEE SMALL LETTER QUV")
(43932 . "CHEROKEE SMALL LETTER SA")
(43933 . "CHEROKEE SMALL LETTER S")
(43934 . "CHEROKEE SMALL LETTER SE")
(43935 . "CHEROKEE SMALL LETTER SI")
(43936 . "CHEROKEE SMALL LETTER SO")
(43937 . "CHEROKEE SMALL LETTER SU")
(43938 . "CHEROKEE SMALL LETTER SV")
(43939 . "CHEROKEE SMALL LETTER DA")
(43940 . "CHEROKEE SMALL LETTER TA")
(43941 . "CHEROKEE SMALL LETTER DE")
(43942 . "CHEROKEE SMALL LETTER TE")
(43943 . "CHEROKEE SMALL LETTER DI")
(43944 . "CHEROKEE SMALL LETTER TI")
(43945 . "CHEROKEE SMALL LETTER DO")
(43946 . "CHEROKEE SMALL LETTER DU")
(43947 . "CHEROKEE SMALL LETTER DV")
(43948 . "CHEROKEE SMALL LETTER DLA")
(43949 . "CHEROKEE SMALL LETTER TLA")
(43950 . "CHEROKEE SMALL LETTER TLE")
(43951 . "CHEROKEE SMALL LETTER TLI")
(43952 . "CHEROKEE SMALL LETTER TLO")
(43953 . "CHEROKEE SMALL LETTER TLU")
(43954 . "CHEROKEE SMALL LETTER TLV")
(43955 . "CHEROKEE SMALL LETTER TSA")
(43956 . "CHEROKEE SMALL LETTER TSE")
(43957 . "CHEROKEE SMALL LETTER TSI")
(43958 . "CHEROKEE SMALL LETTER TSO")
(43959 . "CHEROKEE SMALL LETTER TSU")
(43960 . "CHEROKEE SMALL LETTER TSV")
(43961 . "CHEROKEE SMALL LETTER WA")
(43962 . "CHEROKEE SMALL LETTER WE")
(43963 . "CHEROKEE SMALL LETTER WI")
(43964 . "CHEROKEE SMALL LETTER WO")
(43965 . "CHEROKEE SMALL LETTER WU")
(43966 . "CHEROKEE SMALL LETTER WV")
(43967 . "CHEROKEE SMALL LETTER YA")
(43968 . "MEETEI MAYEK LETTER KOK")
(43969 . "MEETEI MAYEK LETTER SAM")
(43970 . "MEETEI MAYEK LETTER LAI")
(43971 . "MEETEI MAYEK LETTER MIT")
(43972 . "MEETEI MAYEK LETTER PA")
(43973 . "MEETEI MAYEK LETTER NA")
(43974 . "MEETEI MAYEK LETTER CHIL")
(43975 . "MEETEI MAYEK LETTER TIL")
(43976 . "MEETEI MAYEK LETTER KHOU")
(43977 . "MEETEI MAYEK LETTER NGOU")
(43978 . "MEETEI MAYEK LETTER THOU")
(43979 . "MEETEI MAYEK LETTER WAI")
(43980 . "MEETEI MAYEK LETTER YANG")
(43981 . "MEETEI MAYEK LETTER HUK")
(43982 . "MEETEI MAYEK LETTER UN")
(43983 . "MEETEI MAYEK LETTER I")
(43984 . "MEETEI MAYEK LETTER PHAM")
(43985 . "MEETEI MAYEK LETTER ATIYA")
(43986 . "MEETEI MAYEK LETTER GOK")
(43987 . "MEETEI MAYEK LETTER JHAM")
(43988 . "MEETEI MAYEK LETTER RAI")
(43989 . "MEETEI MAYEK LETTER BA")
(43990 . "MEETEI MAYEK LETTER JIL")
(43991 . "MEETEI MAYEK LETTER DIL")
(43992 . "MEETEI MAYEK LETTER GHOU")
(43993 . "MEETEI MAYEK LETTER DHOU")
(43994 . "MEETEI MAYEK LETTER BHAM")
(43995 . "MEETEI MAYEK LETTER KOK LONSUM")
(43996 . "MEETEI MAYEK LETTER LAI LONSUM")
(43997 . "MEETEI MAYEK LETTER MIT LONSUM")
(43998 . "MEETEI MAYEK LETTER PA LONSUM")
(43999 . "MEETEI MAYEK LETTER NA LONSUM")
(44000 . "MEETEI MAYEK LETTER TIL LONSUM")
(44001 . "MEETEI MAYEK LETTER NGOU LONSUM")
(44002 . "MEETEI MAYEK LETTER I LONSUM")
(44003 . "MEETEI MAYEK VOWEL SIGN ONAP")
(44004 . "MEETEI MAYEK VOWEL SIGN INAP")
(44005 . "MEETEI MAYEK VOWEL SIGN ANAP")
(44006 . "MEETEI MAYEK VOWEL SIGN YENAP")
(44007 . "MEETEI MAYEK VOWEL SIGN SOUNAP")
(44008 . "MEETEI MAYEK VOWEL SIGN UNAP")
(44009 . "MEETEI MAYEK VOWEL SIGN CHEINAP")
(44010 . "MEETEI MAYEK VOWEL SIGN NUNG")
(44011 . "MEETEI MAYEK CHEIKHEI")
(44012 . "MEETEI MAYEK LUM IYEK")
(44013 . "MEETEI MAYEK APUN IYEK")
((44014 . 44016) . #f)
(44016 . "MEETEI MAYEK DIGIT ZERO")
(44017 . "MEETEI MAYEK DIGIT ONE")
(44018 . "MEETEI MAYEK DIGIT TWO")
(44019 . "MEETEI MAYEK DIGIT THREE")
(44020 . "MEETEI MAYEK DIGIT FOUR")
(44021 . "MEETEI MAYEK DIGIT FIVE")
(44022 . "MEETEI MAYEK DIGIT SIX")
(44023 . "MEETEI MAYEK DIGIT SEVEN")
(44024 . "MEETEI MAYEK DIGIT EIGHT")
(44025 . "MEETEI MAYEK DIGIT NINE")
((44026 . 44032) . #f)
(44032 . "HANGUL SYLLABLE GA")
(44033 . "HANGUL SYLLABLE GAG")
(44034 . "HANGUL SYLLABLE GAGG")
(44035 . "HANGUL SYLLABLE GAGS")
(44036 . "HANGUL SYLLABLE GAN")
(44037 . "HANGUL SYLLABLE GANJ")
(44038 . "HANGUL SYLLABLE GANH")
(44039 . "HANGUL SYLLABLE GAD")
(44040 . "HANGUL SYLLABLE GAL")
(44041 . "HANGUL SYLLABLE GALG")
(44042 . "HANGUL SYLLABLE GALM")
(44043 . "HANGUL SYLLABLE GALB")
(44044 . "HANGUL SYLLABLE GALS")
(44045 . "HANGUL SYLLABLE GALT")
(44046 . "HANGUL SYLLABLE GALP")
(44047 . "HANGUL SYLLABLE GALH")
(44048 . "HANGUL SYLLABLE GAM")
(44049 . "HANGUL SYLLABLE GAB")
(44050 . "HANGUL SYLLABLE GABS")
(44051 . "HANGUL SYLLABLE GAS")
(44052 . "HANGUL SYLLABLE GASS")
(44053 . "HANGUL SYLLABLE GANG")
(44054 . "HANGUL SYLLABLE GAJ")
(44055 . "HANGUL SYLLABLE GAC")
(44056 . "HANGUL SYLLABLE GAK")
(44057 . "HANGUL SYLLABLE GAT")
(44058 . "HANGUL SYLLABLE GAP")
(44059 . "HANGUL SYLLABLE GAH")
(44060 . "HANGUL SYLLABLE GAE")
(44061 . "HANGUL SYLLABLE GAEG")
(44062 . "HANGUL SYLLABLE GAEGG")
(44063 . "HANGUL SYLLABLE GAEGS")
(44064 . "HANGUL SYLLABLE GAEN")
(44065 . "HANGUL SYLLABLE GAENJ")
(44066 . "HANGUL SYLLABLE GAENH")
(44067 . "HANGUL SYLLABLE GAED")
(44068 . "HANGUL SYLLABLE GAEL")
(44069 . "HANGUL SYLLABLE GAELG")
(44070 . "HANGUL SYLLABLE GAELM")
(44071 . "HANGUL SYLLABLE GAELB")
(44072 . "HANGUL SYLLABLE GAELS")
(44073 . "HANGUL SYLLABLE GAELT")
(44074 . "HANGUL SYLLABLE GAELP")
(44075 . "HANGUL SYLLABLE GAELH")
(44076 . "HANGUL SYLLABLE GAEM")
(44077 . "HANGUL SYLLABLE GAEB")
(44078 . "HANGUL SYLLABLE GAEBS")
(44079 . "HANGUL SYLLABLE GAES")
(44080 . "HANGUL SYLLABLE GAESS")
(44081 . "HANGUL SYLLABLE GAENG")
(44082 . "HANGUL SYLLABLE GAEJ")
(44083 . "HANGUL SYLLABLE GAEC")
(44084 . "HANGUL SYLLABLE GAEK")
(44085 . "HANGUL SYLLABLE GAET")
(44086 . "HANGUL SYLLABLE GAEP")
(44087 . "HANGUL SYLLABLE GAEH")
(44088 . "HANGUL SYLLABLE GYA")
(44089 . "HANGUL SYLLABLE GYAG")
(44090 . "HANGUL SYLLABLE GYAGG")
(44091 . "HANGUL SYLLABLE GYAGS")
(44092 . "HANGUL SYLLABLE GYAN")
(44093 . "HANGUL SYLLABLE GYANJ")
(44094 . "HANGUL SYLLABLE GYANH")
(44095 . "HANGUL SYLLABLE GYAD")
(44096 . "HANGUL SYLLABLE GYAL")
(44097 . "HANGUL SYLLABLE GYALG")
(44098 . "HANGUL SYLLABLE GYALM")
(44099 . "HANGUL SYLLABLE GYALB")
(44100 . "HANGUL SYLLABLE GYALS")
(44101 . "HANGUL SYLLABLE GYALT")
(44102 . "HANGUL SYLLABLE GYALP")
(44103 . "HANGUL SYLLABLE GYALH")
(44104 . "HANGUL SYLLABLE GYAM")
(44105 . "HANGUL SYLLABLE GYAB")
(44106 . "HANGUL SYLLABLE GYABS")
(44107 . "HANGUL SYLLABLE GYAS")
(44108 . "HANGUL SYLLABLE GYASS")
(44109 . "HANGUL SYLLABLE GYANG")
(44110 . "HANGUL SYLLABLE GYAJ")
(44111 . "HANGUL SYLLABLE GYAC")
(44112 . "HANGUL SYLLABLE GYAK")
(44113 . "HANGUL SYLLABLE GYAT")
(44114 . "HANGUL SYLLABLE GYAP")
(44115 . "HANGUL SYLLABLE GYAH")
(44116 . "HANGUL SYLLABLE GYAE")
(44117 . "HANGUL SYLLABLE GYAEG")
(44118 . "HANGUL SYLLABLE GYAEGG")
(44119 . "HANGUL SYLLABLE GYAEGS")
(44120 . "HANGUL SYLLABLE GYAEN")
(44121 . "HANGUL SYLLABLE GYAENJ")
(44122 . "HANGUL SYLLABLE GYAENH")
(44123 . "HANGUL SYLLABLE GYAED")
(44124 . "HANGUL SYLLABLE GYAEL")
(44125 . "HANGUL SYLLABLE GYAELG")
(44126 . "HANGUL SYLLABLE GYAELM")
(44127 . "HANGUL SYLLABLE GYAELB")
(44128 . "HANGUL SYLLABLE GYAELS")
(44129 . "HANGUL SYLLABLE GYAELT")
(44130 . "HANGUL SYLLABLE GYAELP")
(44131 . "HANGUL SYLLABLE GYAELH")
(44132 . "HANGUL SYLLABLE GYAEM")
(44133 . "HANGUL SYLLABLE GYAEB")
(44134 . "HANGUL SYLLABLE GYAEBS")
(44135 . "HANGUL SYLLABLE GYAES")
(44136 . "HANGUL SYLLABLE GYAESS")
(44137 . "HANGUL SYLLABLE GYAENG")
(44138 . "HANGUL SYLLABLE GYAEJ")
(44139 . "HANGUL SYLLABLE GYAEC")
(44140 . "HANGUL SYLLABLE GYAEK")
(44141 . "HANGUL SYLLABLE GYAET")
(44142 . "HANGUL SYLLABLE GYAEP")
(44143 . "HANGUL SYLLABLE GYAEH")
(44144 . "HANGUL SYLLABLE GEO")
(44145 . "HANGUL SYLLABLE GEOG")
(44146 . "HANGUL SYLLABLE GEOGG")
(44147 . "HANGUL SYLLABLE GEOGS")
(44148 . "HANGUL SYLLABLE GEON")
(44149 . "HANGUL SYLLABLE GEONJ")
(44150 . "HANGUL SYLLABLE GEONH")
(44151 . "HANGUL SYLLABLE GEOD")
(44152 . "HANGUL SYLLABLE GEOL")
(44153 . "HANGUL SYLLABLE GEOLG")
(44154 . "HANGUL SYLLABLE GEOLM")
(44155 . "HANGUL SYLLABLE GEOLB")
(44156 . "HANGUL SYLLABLE GEOLS")
(44157 . "HANGUL SYLLABLE GEOLT")
(44158 . "HANGUL SYLLABLE GEOLP")
(44159 . "HANGUL SYLLABLE GEOLH")
(44160 . "HANGUL SYLLABLE GEOM")
(44161 . "HANGUL SYLLABLE GEOB")
(44162 . "HANGUL SYLLABLE GEOBS")
(44163 . "HANGUL SYLLABLE GEOS")
(44164 . "HANGUL SYLLABLE GEOSS")
(44165 . "HANGUL SYLLABLE GEONG")
(44166 . "HANGUL SYLLABLE GEOJ")
(44167 . "HANGUL SYLLABLE GEOC")
(44168 . "HANGUL SYLLABLE GEOK")
(44169 . "HANGUL SYLLABLE GEOT")
(44170 . "HANGUL SYLLABLE GEOP")
(44171 . "HANGUL SYLLABLE GEOH")
(44172 . "HANGUL SYLLABLE GE")
(44173 . "HANGUL SYLLABLE GEG")
(44174 . "HANGUL SYLLABLE GEGG")
(44175 . "HANGUL SYLLABLE GEGS")
(44176 . "HANGUL SYLLABLE GEN")
(44177 . "HANGUL SYLLABLE GENJ")
(44178 . "HANGUL SYLLABLE GENH")
(44179 . "HANGUL SYLLABLE GED")
(44180 . "HANGUL SYLLABLE GEL")
(44181 . "HANGUL SYLLABLE GELG")
(44182 . "HANGUL SYLLABLE GELM")
(44183 . "HANGUL SYLLABLE GELB")
(44184 . "HANGUL SYLLABLE GELS")
(44185 . "HANGUL SYLLABLE GELT")
(44186 . "HANGUL SYLLABLE GELP")
(44187 . "HANGUL SYLLABLE GELH")
(44188 . "HANGUL SYLLABLE GEM")
(44189 . "HANGUL SYLLABLE GEB")
(44190 . "HANGUL SYLLABLE GEBS")
(44191 . "HANGUL SYLLABLE GES")
(44192 . "HANGUL SYLLABLE GESS")
(44193 . "HANGUL SYLLABLE GENG")
(44194 . "HANGUL SYLLABLE GEJ")
(44195 . "HANGUL SYLLABLE GEC")
(44196 . "HANGUL SYLLABLE GEK")
(44197 . "HANGUL SYLLABLE GET")
(44198 . "HANGUL SYLLABLE GEP")
(44199 . "HANGUL SYLLABLE GEH")
(44200 . "HANGUL SYLLABLE GYEO")
(44201 . "HANGUL SYLLABLE GYEOG")
(44202 . "HANGUL SYLLABLE GYEOGG")
(44203 . "HANGUL SYLLABLE GYEOGS")
(44204 . "HANGUL SYLLABLE GYEON")
(44205 . "HANGUL SYLLABLE GYEONJ")
(44206 . "HANGUL SYLLABLE GYEONH")
(44207 . "HANGUL SYLLABLE GYEOD")
(44208 . "HANGUL SYLLABLE GYEOL")
(44209 . "HANGUL SYLLABLE GYEOLG")
(44210 . "HANGUL SYLLABLE GYEOLM")
(44211 . "HANGUL SYLLABLE GYEOLB")
(44212 . "HANGUL SYLLABLE GYEOLS")
(44213 . "HANGUL SYLLABLE GYEOLT")
(44214 . "HANGUL SYLLABLE GYEOLP")
(44215 . "HANGUL SYLLABLE GYEOLH")
(44216 . "HANGUL SYLLABLE GYEOM")
(44217 . "HANGUL SYLLABLE GYEOB")
(44218 . "HANGUL SYLLABLE GYEOBS")
(44219 . "HANGUL SYLLABLE GYEOS")
(44220 . "HANGUL SYLLABLE GYEOSS")
(44221 . "HANGUL SYLLABLE GYEONG")
(44222 . "HANGUL SYLLABLE GYEOJ")
(44223 . "HANGUL SYLLABLE GYEOC")
(44224 . "HANGUL SYLLABLE GYEOK")
(44225 . "HANGUL SYLLABLE GYEOT")
(44226 . "HANGUL SYLLABLE GYEOP")
(44227 . "HANGUL SYLLABLE GYEOH")
(44228 . "HANGUL SYLLABLE GYE")
(44229 . "HANGUL SYLLABLE GYEG")
(44230 . "HANGUL SYLLABLE GYEGG")
(44231 . "HANGUL SYLLABLE GYEGS")
(44232 . "HANGUL SYLLABLE GYEN")
(44233 . "HANGUL SYLLABLE GYENJ")
(44234 . "HANGUL SYLLABLE GYENH")
(44235 . "HANGUL SYLLABLE GYED")
(44236 . "HANGUL SYLLABLE GYEL")
(44237 . "HANGUL SYLLABLE GYELG")
(44238 . "HANGUL SYLLABLE GYELM")
(44239 . "HANGUL SYLLABLE GYELB")
(44240 . "HANGUL SYLLABLE GYELS")
(44241 . "HANGUL SYLLABLE GYELT")
(44242 . "HANGUL SYLLABLE GYELP")
(44243 . "HANGUL SYLLABLE GYELH")
(44244 . "HANGUL SYLLABLE GYEM")
(44245 . "HANGUL SYLLABLE GYEB")
(44246 . "HANGUL SYLLABLE GYEBS")
(44247 . "HANGUL SYLLABLE GYES")
(44248 . "HANGUL SYLLABLE GYESS")
(44249 . "HANGUL SYLLABLE GYENG")
(44250 . "HANGUL SYLLABLE GYEJ")
(44251 . "HANGUL SYLLABLE GYEC")
(44252 . "HANGUL SYLLABLE GYEK")
(44253 . "HANGUL SYLLABLE GYET")
(44254 . "HANGUL SYLLABLE GYEP")
(44255 . "HANGUL SYLLABLE GYEH")
(44256 . "HANGUL SYLLABLE GO")
(44257 . "HANGUL SYLLABLE GOG")
(44258 . "HANGUL SYLLABLE GOGG")
(44259 . "HANGUL SYLLABLE GOGS")
(44260 . "HANGUL SYLLABLE GON")
(44261 . "HANGUL SYLLABLE GONJ")
(44262 . "HANGUL SYLLABLE GONH")
(44263 . "HANGUL SYLLABLE GOD")
(44264 . "HANGUL SYLLABLE GOL")
(44265 . "HANGUL SYLLABLE GOLG")
(44266 . "HANGUL SYLLABLE GOLM")
(44267 . "HANGUL SYLLABLE GOLB")
(44268 . "HANGUL SYLLABLE GOLS")
(44269 . "HANGUL SYLLABLE GOLT")
(44270 . "HANGUL SYLLABLE GOLP")
(44271 . "HANGUL SYLLABLE GOLH")
(44272 . "HANGUL SYLLABLE GOM")
(44273 . "HANGUL SYLLABLE GOB")
(44274 . "HANGUL SYLLABLE GOBS")
(44275 . "HANGUL SYLLABLE GOS")
(44276 . "HANGUL SYLLABLE GOSS")
(44277 . "HANGUL SYLLABLE GONG")
(44278 . "HANGUL SYLLABLE GOJ")
(44279 . "HANGUL SYLLABLE GOC")
(44280 . "HANGUL SYLLABLE GOK")
(44281 . "HANGUL SYLLABLE GOT")
(44282 . "HANGUL SYLLABLE GOP")
(44283 . "HANGUL SYLLABLE GOH")
(44284 . "HANGUL SYLLABLE GWA")
(44285 . "HANGUL SYLLABLE GWAG")
(44286 . "HANGUL SYLLABLE GWAGG")
(44287 . "HANGUL SYLLABLE GWAGS")
(44288 . "HANGUL SYLLABLE GWAN")
(44289 . "HANGUL SYLLABLE GWANJ")
(44290 . "HANGUL SYLLABLE GWANH")
(44291 . "HANGUL SYLLABLE GWAD")
(44292 . "HANGUL SYLLABLE GWAL")
(44293 . "HANGUL SYLLABLE GWALG")
(44294 . "HANGUL SYLLABLE GWALM")
(44295 . "HANGUL SYLLABLE GWALB")
(44296 . "HANGUL SYLLABLE GWALS")
(44297 . "HANGUL SYLLABLE GWALT")
(44298 . "HANGUL SYLLABLE GWALP")
(44299 . "HANGUL SYLLABLE GWALH")
(44300 . "HANGUL SYLLABLE GWAM")
(44301 . "HANGUL SYLLABLE GWAB")
(44302 . "HANGUL SYLLABLE GWABS")
(44303 . "HANGUL SYLLABLE GWAS")
(44304 . "HANGUL SYLLABLE GWASS")
(44305 . "HANGUL SYLLABLE GWANG")
(44306 . "HANGUL SYLLABLE GWAJ")
(44307 . "HANGUL SYLLABLE GWAC")
(44308 . "HANGUL SYLLABLE GWAK")
(44309 . "HANGUL SYLLABLE GWAT")
(44310 . "HANGUL SYLLABLE GWAP")
(44311 . "HANGUL SYLLABLE GWAH")
(44312 . "HANGUL SYLLABLE GWAE")
(44313 . "HANGUL SYLLABLE GWAEG")
(44314 . "HANGUL SYLLABLE GWAEGG")
(44315 . "HANGUL SYLLABLE GWAEGS")
(44316 . "HANGUL SYLLABLE GWAEN")
(44317 . "HANGUL SYLLABLE GWAENJ")
(44318 . "HANGUL SYLLABLE GWAENH")
(44319 . "HANGUL SYLLABLE GWAED")
(44320 . "HANGUL SYLLABLE GWAEL")
(44321 . "HANGUL SYLLABLE GWAELG")
(44322 . "HANGUL SYLLABLE GWAELM")
(44323 . "HANGUL SYLLABLE GWAELB")
(44324 . "HANGUL SYLLABLE GWAELS")
(44325 . "HANGUL SYLLABLE GWAELT")
(44326 . "HANGUL SYLLABLE GWAELP")
(44327 . "HANGUL SYLLABLE GWAELH")
(44328 . "HANGUL SYLLABLE GWAEM")
(44329 . "HANGUL SYLLABLE GWAEB")
(44330 . "HANGUL SYLLABLE GWAEBS")
(44331 . "HANGUL SYLLABLE GWAES")
(44332 . "HANGUL SYLLABLE GWAESS")
(44333 . "HANGUL SYLLABLE GWAENG")
(44334 . "HANGUL SYLLABLE GWAEJ")
(44335 . "HANGUL SYLLABLE GWAEC")
(44336 . "HANGUL SYLLABLE GWAEK")
(44337 . "HANGUL SYLLABLE GWAET")
(44338 . "HANGUL SYLLABLE GWAEP")
(44339 . "HANGUL SYLLABLE GWAEH")
(44340 . "HANGUL SYLLABLE GOE")
(44341 . "HANGUL SYLLABLE GOEG")
(44342 . "HANGUL SYLLABLE GOEGG")
(44343 . "HANGUL SYLLABLE GOEGS")
(44344 . "HANGUL SYLLABLE GOEN")
(44345 . "HANGUL SYLLABLE GOENJ")
(44346 . "HANGUL SYLLABLE GOENH")
(44347 . "HANGUL SYLLABLE GOED")
(44348 . "HANGUL SYLLABLE GOEL")
(44349 . "HANGUL SYLLABLE GOELG")
(44350 . "HANGUL SYLLABLE GOELM")
(44351 . "HANGUL SYLLABLE GOELB")
(44352 . "HANGUL SYLLABLE GOELS")
(44353 . "HANGUL SYLLABLE GOELT")
(44354 . "HANGUL SYLLABLE GOELP")
(44355 . "HANGUL SYLLABLE GOELH")
(44356 . "HANGUL SYLLABLE GOEM")
(44357 . "HANGUL SYLLABLE GOEB")
(44358 . "HANGUL SYLLABLE GOEBS")
(44359 . "HANGUL SYLLABLE GOES")
(44360 . "HANGUL SYLLABLE GOESS")
(44361 . "HANGUL SYLLABLE GOENG")
(44362 . "HANGUL SYLLABLE GOEJ")
(44363 . "HANGUL SYLLABLE GOEC")
(44364 . "HANGUL SYLLABLE GOEK")
(44365 . "HANGUL SYLLABLE GOET")
(44366 . "HANGUL SYLLABLE GOEP")
(44367 . "HANGUL SYLLABLE GOEH")
(44368 . "HANGUL SYLLABLE GYO")
(44369 . "HANGUL SYLLABLE GYOG")
(44370 . "HANGUL SYLLABLE GYOGG")
(44371 . "HANGUL SYLLABLE GYOGS")
(44372 . "HANGUL SYLLABLE GYON")
(44373 . "HANGUL SYLLABLE GYONJ")
(44374 . "HANGUL SYLLABLE GYONH")
(44375 . "HANGUL SYLLABLE GYOD")
(44376 . "HANGUL SYLLABLE GYOL")
(44377 . "HANGUL SYLLABLE GYOLG")
(44378 . "HANGUL SYLLABLE GYOLM")
(44379 . "HANGUL SYLLABLE GYOLB")
(44380 . "HANGUL SYLLABLE GYOLS")
(44381 . "HANGUL SYLLABLE GYOLT")
(44382 . "HANGUL SYLLABLE GYOLP")
(44383 . "HANGUL SYLLABLE GYOLH")
(44384 . "HANGUL SYLLABLE GYOM")
(44385 . "HANGUL SYLLABLE GYOB")
(44386 . "HANGUL SYLLABLE GYOBS")
(44387 . "HANGUL SYLLABLE GYOS")
(44388 . "HANGUL SYLLABLE GYOSS")
(44389 . "HANGUL SYLLABLE GYONG")
(44390 . "HANGUL SYLLABLE GYOJ")
(44391 . "HANGUL SYLLABLE GYOC")
(44392 . "HANGUL SYLLABLE GYOK")
(44393 . "HANGUL SYLLABLE GYOT")
(44394 . "HANGUL SYLLABLE GYOP")
(44395 . "HANGUL SYLLABLE GYOH")
(44396 . "HANGUL SYLLABLE GU")
(44397 . "HANGUL SYLLABLE GUG")
(44398 . "HANGUL SYLLABLE GUGG")
(44399 . "HANGUL SYLLABLE GUGS")
(44400 . "HANGUL SYLLABLE GUN")
(44401 . "HANGUL SYLLABLE GUNJ")
(44402 . "HANGUL SYLLABLE GUNH")
(44403 . "HANGUL SYLLABLE GUD")
(44404 . "HANGUL SYLLABLE GUL")
(44405 . "HANGUL SYLLABLE GULG")
(44406 . "HANGUL SYLLABLE GULM")
(44407 . "HANGUL SYLLABLE GULB")
(44408 . "HANGUL SYLLABLE GULS")
(44409 . "HANGUL SYLLABLE GULT")
(44410 . "HANGUL SYLLABLE GULP")
(44411 . "HANGUL SYLLABLE GULH")
(44412 . "HANGUL SYLLABLE GUM")
(44413 . "HANGUL SYLLABLE GUB")
(44414 . "HANGUL SYLLABLE GUBS")
(44415 . "HANGUL SYLLABLE GUS")
(44416 . "HANGUL SYLLABLE GUSS")
(44417 . "HANGUL SYLLABLE GUNG")
(44418 . "HANGUL SYLLABLE GUJ")
(44419 . "HANGUL SYLLABLE GUC")
(44420 . "HANGUL SYLLABLE GUK")
(44421 . "HANGUL SYLLABLE GUT")
(44422 . "HANGUL SYLLABLE GUP")
(44423 . "HANGUL SYLLABLE GUH")
(44424 . "HANGUL SYLLABLE GWEO")
(44425 . "HANGUL SYLLABLE GWEOG")
(44426 . "HANGUL SYLLABLE GWEOGG")
(44427 . "HANGUL SYLLABLE GWEOGS")
(44428 . "HANGUL SYLLABLE GWEON")
(44429 . "HANGUL SYLLABLE GWEONJ")
(44430 . "HANGUL SYLLABLE GWEONH")
(44431 . "HANGUL SYLLABLE GWEOD")
(44432 . "HANGUL SYLLABLE GWEOL")
(44433 . "HANGUL SYLLABLE GWEOLG")
(44434 . "HANGUL SYLLABLE GWEOLM")
(44435 . "HANGUL SYLLABLE GWEOLB")
(44436 . "HANGUL SYLLABLE GWEOLS")
(44437 . "HANGUL SYLLABLE GWEOLT")
(44438 . "HANGUL SYLLABLE GWEOLP")
(44439 . "HANGUL SYLLABLE GWEOLH")
(44440 . "HANGUL SYLLABLE GWEOM")
(44441 . "HANGUL SYLLABLE GWEOB")
(44442 . "HANGUL SYLLABLE GWEOBS")
(44443 . "HANGUL SYLLABLE GWEOS")
(44444 . "HANGUL SYLLABLE GWEOSS")
(44445 . "HANGUL SYLLABLE GWEONG")
(44446 . "HANGUL SYLLABLE GWEOJ")
(44447 . "HANGUL SYLLABLE GWEOC")
(44448 . "HANGUL SYLLABLE GWEOK")
(44449 . "HANGUL SYLLABLE GWEOT")
(44450 . "HANGUL SYLLABLE GWEOP")
(44451 . "HANGUL SYLLABLE GWEOH")
(44452 . "HANGUL SYLLABLE GWE")
(44453 . "HANGUL SYLLABLE GWEG")
(44454 . "HANGUL SYLLABLE GWEGG")
(44455 . "HANGUL SYLLABLE GWEGS")
(44456 . "HANGUL SYLLABLE GWEN")
(44457 . "HANGUL SYLLABLE GWENJ")
(44458 . "HANGUL SYLLABLE GWENH")
(44459 . "HANGUL SYLLABLE GWED")
(44460 . "HANGUL SYLLABLE GWEL")
(44461 . "HANGUL SYLLABLE GWELG")
(44462 . "HANGUL SYLLABLE GWELM")
(44463 . "HANGUL SYLLABLE GWELB")
(44464 . "HANGUL SYLLABLE GWELS")
(44465 . "HANGUL SYLLABLE GWELT")
(44466 . "HANGUL SYLLABLE GWELP")
(44467 . "HANGUL SYLLABLE GWELH")
(44468 . "HANGUL SYLLABLE GWEM")
(44469 . "HANGUL SYLLABLE GWEB")
(44470 . "HANGUL SYLLABLE GWEBS")
(44471 . "HANGUL SYLLABLE GWES")
(44472 . "HANGUL SYLLABLE GWESS")
(44473 . "HANGUL SYLLABLE GWENG")
(44474 . "HANGUL SYLLABLE GWEJ")
(44475 . "HANGUL SYLLABLE GWEC")
(44476 . "HANGUL SYLLABLE GWEK")
(44477 . "HANGUL SYLLABLE GWET")
(44478 . "HANGUL SYLLABLE GWEP")
(44479 . "HANGUL SYLLABLE GWEH")
(44480 . "HANGUL SYLLABLE GWI")
(44481 . "HANGUL SYLLABLE GWIG")
(44482 . "HANGUL SYLLABLE GWIGG")
(44483 . "HANGUL SYLLABLE GWIGS")
(44484 . "HANGUL SYLLABLE GWIN")
(44485 . "HANGUL SYLLABLE GWINJ")
(44486 . "HANGUL SYLLABLE GWINH")
(44487 . "HANGUL SYLLABLE GWID")
(44488 . "HANGUL SYLLABLE GWIL")
(44489 . "HANGUL SYLLABLE GWILG")
(44490 . "HANGUL SYLLABLE GWILM")
(44491 . "HANGUL SYLLABLE GWILB")
(44492 . "HANGUL SYLLABLE GWILS")
(44493 . "HANGUL SYLLABLE GWILT")
(44494 . "HANGUL SYLLABLE GWILP")
(44495 . "HANGUL SYLLABLE GWILH")
(44496 . "HANGUL SYLLABLE GWIM")
(44497 . "HANGUL SYLLABLE GWIB")
(44498 . "HANGUL SYLLABLE GWIBS")
(44499 . "HANGUL SYLLABLE GWIS")
(44500 . "HANGUL SYLLABLE GWISS")
(44501 . "HANGUL SYLLABLE GWING")
(44502 . "HANGUL SYLLABLE GWIJ")
(44503 . "HANGUL SYLLABLE GWIC")
(44504 . "HANGUL SYLLABLE GWIK")
(44505 . "HANGUL SYLLABLE GWIT")
(44506 . "HANGUL SYLLABLE GWIP")
(44507 . "HANGUL SYLLABLE GWIH")
(44508 . "HANGUL SYLLABLE GYU")
(44509 . "HANGUL SYLLABLE GYUG")
(44510 . "HANGUL SYLLABLE GYUGG")
(44511 . "HANGUL SYLLABLE GYUGS")
(44512 . "HANGUL SYLLABLE GYUN")
(44513 . "HANGUL SYLLABLE GYUNJ")
(44514 . "HANGUL SYLLABLE GYUNH")
(44515 . "HANGUL SYLLABLE GYUD")
(44516 . "HANGUL SYLLABLE GYUL")
(44517 . "HANGUL SYLLABLE GYULG")
(44518 . "HANGUL SYLLABLE GYULM")
(44519 . "HANGUL SYLLABLE GYULB")
(44520 . "HANGUL SYLLABLE GYULS")
(44521 . "HANGUL SYLLABLE GYULT")
(44522 . "HANGUL SYLLABLE GYULP")
(44523 . "HANGUL SYLLABLE GYULH")
(44524 . "HANGUL SYLLABLE GYUM")
(44525 . "HANGUL SYLLABLE GYUB")
(44526 . "HANGUL SYLLABLE GYUBS")
(44527 . "HANGUL SYLLABLE GYUS")
(44528 . "HANGUL SYLLABLE GYUSS")
(44529 . "HANGUL SYLLABLE GYUNG")
(44530 . "HANGUL SYLLABLE GYUJ")
(44531 . "HANGUL SYLLABLE GYUC")
(44532 . "HANGUL SYLLABLE GYUK")
(44533 . "HANGUL SYLLABLE GYUT")
(44534 . "HANGUL SYLLABLE GYUP")
(44535 . "HANGUL SYLLABLE GYUH")
(44536 . "HANGUL SYLLABLE GEU")
(44537 . "HANGUL SYLLABLE GEUG")
(44538 . "HANGUL SYLLABLE GEUGG")
(44539 . "HANGUL SYLLABLE GEUGS")
(44540 . "HANGUL SYLLABLE GEUN")
(44541 . "HANGUL SYLLABLE GEUNJ")
(44542 . "HANGUL SYLLABLE GEUNH")
(44543 . "HANGUL SYLLABLE GEUD")
(44544 . "HANGUL SYLLABLE GEUL")
(44545 . "HANGUL SYLLABLE GEULG")
(44546 . "HANGUL SYLLABLE GEULM")
(44547 . "HANGUL SYLLABLE GEULB")
(44548 . "HANGUL SYLLABLE GEULS")
(44549 . "HANGUL SYLLABLE GEULT")
(44550 . "HANGUL SYLLABLE GEULP")
(44551 . "HANGUL SYLLABLE GEULH")
(44552 . "HANGUL SYLLABLE GEUM")
(44553 . "HANGUL SYLLABLE GEUB")
(44554 . "HANGUL SYLLABLE GEUBS")
(44555 . "HANGUL SYLLABLE GEUS")
(44556 . "HANGUL SYLLABLE GEUSS")
(44557 . "HANGUL SYLLABLE GEUNG")
(44558 . "HANGUL SYLLABLE GEUJ")
(44559 . "HANGUL SYLLABLE GEUC")
(44560 . "HANGUL SYLLABLE GEUK")
(44561 . "HANGUL SYLLABLE GEUT")
(44562 . "HANGUL SYLLABLE GEUP")
(44563 . "HANGUL SYLLABLE GEUH")
(44564 . "HANGUL SYLLABLE GYI")
(44565 . "HANGUL SYLLABLE GYIG")
(44566 . "HANGUL SYLLABLE GYIGG")
(44567 . "HANGUL SYLLABLE GYIGS")
(44568 . "HANGUL SYLLABLE GYIN")
(44569 . "HANGUL SYLLABLE GYINJ")
(44570 . "HANGUL SYLLABLE GYINH")
(44571 . "HANGUL SYLLABLE GYID")
(44572 . "HANGUL SYLLABLE GYIL")
(44573 . "HANGUL SYLLABLE GYILG")
(44574 . "HANGUL SYLLABLE GYILM")
(44575 . "HANGUL SYLLABLE GYILB")
(44576 . "HANGUL SYLLABLE GYILS")
(44577 . "HANGUL SYLLABLE GYILT")
(44578 . "HANGUL SYLLABLE GYILP")
(44579 . "HANGUL SYLLABLE GYILH")
(44580 . "HANGUL SYLLABLE GYIM")
(44581 . "HANGUL SYLLABLE GYIB")
(44582 . "HANGUL SYLLABLE GYIBS")
(44583 . "HANGUL SYLLABLE GYIS")
(44584 . "HANGUL SYLLABLE GYISS")
(44585 . "HANGUL SYLLABLE GYING")
(44586 . "HANGUL SYLLABLE GYIJ")
(44587 . "HANGUL SYLLABLE GYIC")
(44588 . "HANGUL SYLLABLE GYIK")
(44589 . "HANGUL SYLLABLE GYIT")
(44590 . "HANGUL SYLLABLE GYIP")
(44591 . "HANGUL SYLLABLE GYIH")
(44592 . "HANGUL SYLLABLE GI")
(44593 . "HANGUL SYLLABLE GIG")
(44594 . "HANGUL SYLLABLE GIGG")
(44595 . "HANGUL SYLLABLE GIGS")
(44596 . "HANGUL SYLLABLE GIN")
(44597 . "HANGUL SYLLABLE GINJ")
(44598 . "HANGUL SYLLABLE GINH")
(44599 . "HANGUL SYLLABLE GID")
(44600 . "HANGUL SYLLABLE GIL")
(44601 . "HANGUL SYLLABLE GILG")
(44602 . "HANGUL SYLLABLE GILM")
(44603 . "HANGUL SYLLABLE GILB")
(44604 . "HANGUL SYLLABLE GILS")
(44605 . "HANGUL SYLLABLE GILT")
(44606 . "HANGUL SYLLABLE GILP")
(44607 . "HANGUL SYLLABLE GILH")
(44608 . "HANGUL SYLLABLE GIM")
(44609 . "HANGUL SYLLABLE GIB")
(44610 . "HANGUL SYLLABLE GIBS")
(44611 . "HANGUL SYLLABLE GIS")
(44612 . "HANGUL SYLLABLE GISS")
(44613 . "HANGUL SYLLABLE GING")
(44614 . "HANGUL SYLLABLE GIJ")
(44615 . "HANGUL SYLLABLE GIC")
(44616 . "HANGUL SYLLABLE GIK")
(44617 . "HANGUL SYLLABLE GIT")
(44618 . "HANGUL SYLLABLE GIP")
(44619 . "HANGUL SYLLABLE GIH")
(44620 . "HANGUL SYLLABLE GGA")
(44621 . "HANGUL SYLLABLE GGAG")
(44622 . "HANGUL SYLLABLE GGAGG")
(44623 . "HANGUL SYLLABLE GGAGS")
(44624 . "HANGUL SYLLABLE GGAN")
(44625 . "HANGUL SYLLABLE GGANJ")
(44626 . "HANGUL SYLLABLE GGANH")
(44627 . "HANGUL SYLLABLE GGAD")
(44628 . "HANGUL SYLLABLE GGAL")
(44629 . "HANGUL SYLLABLE GGALG")
(44630 . "HANGUL SYLLABLE GGALM")
(44631 . "HANGUL SYLLABLE GGALB")
(44632 . "HANGUL SYLLABLE GGALS")
(44633 . "HANGUL SYLLABLE GGALT")
(44634 . "HANGUL SYLLABLE GGALP")
(44635 . "HANGUL SYLLABLE GGALH")
(44636 . "HANGUL SYLLABLE GGAM")
(44637 . "HANGUL SYLLABLE GGAB")
(44638 . "HANGUL SYLLABLE GGABS")
(44639 . "HANGUL SYLLABLE GGAS")
(44640 . "HANGUL SYLLABLE GGASS")
(44641 . "HANGUL SYLLABLE GGANG")
(44642 . "HANGUL SYLLABLE GGAJ")
(44643 . "HANGUL SYLLABLE GGAC")
(44644 . "HANGUL SYLLABLE GGAK")
(44645 . "HANGUL SYLLABLE GGAT")
(44646 . "HANGUL SYLLABLE GGAP")
(44647 . "HANGUL SYLLABLE GGAH")
(44648 . "HANGUL SYLLABLE GGAE")
(44649 . "HANGUL SYLLABLE GGAEG")
(44650 . "HANGUL SYLLABLE GGAEGG")
(44651 . "HANGUL SYLLABLE GGAEGS")
(44652 . "HANGUL SYLLABLE GGAEN")
(44653 . "HANGUL SYLLABLE GGAENJ")
(44654 . "HANGUL SYLLABLE GGAENH")
(44655 . "HANGUL SYLLABLE GGAED")
(44656 . "HANGUL SYLLABLE GGAEL")
(44657 . "HANGUL SYLLABLE GGAELG")
(44658 . "HANGUL SYLLABLE GGAELM")
(44659 . "HANGUL SYLLABLE GGAELB")
(44660 . "HANGUL SYLLABLE GGAELS")
(44661 . "HANGUL SYLLABLE GGAELT")
(44662 . "HANGUL SYLLABLE GGAELP")
(44663 . "HANGUL SYLLABLE GGAELH")
(44664 . "HANGUL SYLLABLE GGAEM")
(44665 . "HANGUL SYLLABLE GGAEB")
(44666 . "HANGUL SYLLABLE GGAEBS")
(44667 . "HANGUL SYLLABLE GGAES")
(44668 . "HANGUL SYLLABLE GGAESS")
(44669 . "HANGUL SYLLABLE GGAENG")
(44670 . "HANGUL SYLLABLE GGAEJ")
(44671 . "HANGUL SYLLABLE GGAEC")
(44672 . "HANGUL SYLLABLE GGAEK")
(44673 . "HANGUL SYLLABLE GGAET")
(44674 . "HANGUL SYLLABLE GGAEP")
(44675 . "HANGUL SYLLABLE GGAEH")
(44676 . "HANGUL SYLLABLE GGYA")
(44677 . "HANGUL SYLLABLE GGYAG")
(44678 . "HANGUL SYLLABLE GGYAGG")
(44679 . "HANGUL SYLLABLE GGYAGS")
(44680 . "HANGUL SYLLABLE GGYAN")
(44681 . "HANGUL SYLLABLE GGYANJ")
(44682 . "HANGUL SYLLABLE GGYANH")
(44683 . "HANGUL SYLLABLE GGYAD")
(44684 . "HANGUL SYLLABLE GGYAL")
(44685 . "HANGUL SYLLABLE GGYALG")
(44686 . "HANGUL SYLLABLE GGYALM")
(44687 . "HANGUL SYLLABLE GGYALB")
(44688 . "HANGUL SYLLABLE GGYALS")
(44689 . "HANGUL SYLLABLE GGYALT")
(44690 . "HANGUL SYLLABLE GGYALP")
(44691 . "HANGUL SYLLABLE GGYALH")
(44692 . "HANGUL SYLLABLE GGYAM")
(44693 . "HANGUL SYLLABLE GGYAB")
(44694 . "HANGUL SYLLABLE GGYABS")
(44695 . "HANGUL SYLLABLE GGYAS")
(44696 . "HANGUL SYLLABLE GGYASS")
(44697 . "HANGUL SYLLABLE GGYANG")
(44698 . "HANGUL SYLLABLE GGYAJ")
(44699 . "HANGUL SYLLABLE GGYAC")
(44700 . "HANGUL SYLLABLE GGYAK")
(44701 . "HANGUL SYLLABLE GGYAT")
(44702 . "HANGUL SYLLABLE GGYAP")
(44703 . "HANGUL SYLLABLE GGYAH")
(44704 . "HANGUL SYLLABLE GGYAE")
(44705 . "HANGUL SYLLABLE GGYAEG")
(44706 . "HANGUL SYLLABLE GGYAEGG")
(44707 . "HANGUL SYLLABLE GGYAEGS")
(44708 . "HANGUL SYLLABLE GGYAEN")
(44709 . "HANGUL SYLLABLE GGYAENJ")
(44710 . "HANGUL SYLLABLE GGYAENH")
(44711 . "HANGUL SYLLABLE GGYAED")
(44712 . "HANGUL SYLLABLE GGYAEL")
(44713 . "HANGUL SYLLABLE GGYAELG")
(44714 . "HANGUL SYLLABLE GGYAELM")
(44715 . "HANGUL SYLLABLE GGYAELB")
(44716 . "HANGUL SYLLABLE GGYAELS")
(44717 . "HANGUL SYLLABLE GGYAELT")
(44718 . "HANGUL SYLLABLE GGYAELP")
(44719 . "HANGUL SYLLABLE GGYAELH")
(44720 . "HANGUL SYLLABLE GGYAEM")
(44721 . "HANGUL SYLLABLE GGYAEB")
(44722 . "HANGUL SYLLABLE GGYAEBS")
(44723 . "HANGUL SYLLABLE GGYAES")
(44724 . "HANGUL SYLLABLE GGYAESS")
(44725 . "HANGUL SYLLABLE GGYAENG")
(44726 . "HANGUL SYLLABLE GGYAEJ")
(44727 . "HANGUL SYLLABLE GGYAEC")
(44728 . "HANGUL SYLLABLE GGYAEK")
(44729 . "HANGUL SYLLABLE GGYAET")
(44730 . "HANGUL SYLLABLE GGYAEP")
(44731 . "HANGUL SYLLABLE GGYAEH")
(44732 . "HANGUL SYLLABLE GGEO")
(44733 . "HANGUL SYLLABLE GGEOG")
(44734 . "HANGUL SYLLABLE GGEOGG")
(44735 . "HANGUL SYLLABLE GGEOGS")
(44736 . "HANGUL SYLLABLE GGEON")
(44737 . "HANGUL SYLLABLE GGEONJ")
(44738 . "HANGUL SYLLABLE GGEONH")
(44739 . "HANGUL SYLLABLE GGEOD")
(44740 . "HANGUL SYLLABLE GGEOL")
(44741 . "HANGUL SYLLABLE GGEOLG")
(44742 . "HANGUL SYLLABLE GGEOLM")
(44743 . "HANGUL SYLLABLE GGEOLB")
(44744 . "HANGUL SYLLABLE GGEOLS")
(44745 . "HANGUL SYLLABLE GGEOLT")
(44746 . "HANGUL SYLLABLE GGEOLP")
(44747 . "HANGUL SYLLABLE GGEOLH")
(44748 . "HANGUL SYLLABLE GGEOM")
(44749 . "HANGUL SYLLABLE GGEOB")
(44750 . "HANGUL SYLLABLE GGEOBS")
(44751 . "HANGUL SYLLABLE GGEOS")
(44752 . "HANGUL SYLLABLE GGEOSS")
(44753 . "HANGUL SYLLABLE GGEONG")
(44754 . "HANGUL SYLLABLE GGEOJ")
(44755 . "HANGUL SYLLABLE GGEOC")
(44756 . "HANGUL SYLLABLE GGEOK")
(44757 . "HANGUL SYLLABLE GGEOT")
(44758 . "HANGUL SYLLABLE GGEOP")
(44759 . "HANGUL SYLLABLE GGEOH")
(44760 . "HANGUL SYLLABLE GGE")
(44761 . "HANGUL SYLLABLE GGEG")
(44762 . "HANGUL SYLLABLE GGEGG")
(44763 . "HANGUL SYLLABLE GGEGS")
(44764 . "HANGUL SYLLABLE GGEN")
(44765 . "HANGUL SYLLABLE GGENJ")
(44766 . "HANGUL SYLLABLE GGENH")
(44767 . "HANGUL SYLLABLE GGED")
(44768 . "HANGUL SYLLABLE GGEL")
(44769 . "HANGUL SYLLABLE GGELG")
(44770 . "HANGUL SYLLABLE GGELM")
(44771 . "HANGUL SYLLABLE GGELB")
(44772 . "HANGUL SYLLABLE GGELS")
(44773 . "HANGUL SYLLABLE GGELT")
(44774 . "HANGUL SYLLABLE GGELP")
(44775 . "HANGUL SYLLABLE GGELH")
(44776 . "HANGUL SYLLABLE GGEM")
(44777 . "HANGUL SYLLABLE GGEB")
(44778 . "HANGUL SYLLABLE GGEBS")
(44779 . "HANGUL SYLLABLE GGES")
(44780 . "HANGUL SYLLABLE GGESS")
(44781 . "HANGUL SYLLABLE GGENG")
(44782 . "HANGUL SYLLABLE GGEJ")
(44783 . "HANGUL SYLLABLE GGEC")
(44784 . "HANGUL SYLLABLE GGEK")
(44785 . "HANGUL SYLLABLE GGET")
(44786 . "HANGUL SYLLABLE GGEP")
(44787 . "HANGUL SYLLABLE GGEH")
(44788 . "HANGUL SYLLABLE GGYEO")
(44789 . "HANGUL SYLLABLE GGYEOG")
(44790 . "HANGUL SYLLABLE GGYEOGG")
(44791 . "HANGUL SYLLABLE GGYEOGS")
(44792 . "HANGUL SYLLABLE GGYEON")
(44793 . "HANGUL SYLLABLE GGYEONJ")
(44794 . "HANGUL SYLLABLE GGYEONH")
(44795 . "HANGUL SYLLABLE GGYEOD")
(44796 . "HANGUL SYLLABLE GGYEOL")
(44797 . "HANGUL SYLLABLE GGYEOLG")
(44798 . "HANGUL SYLLABLE GGYEOLM")
(44799 . "HANGUL SYLLABLE GGYEOLB")
(44800 . "HANGUL SYLLABLE GGYEOLS")
(44801 . "HANGUL SYLLABLE GGYEOLT")
(44802 . "HANGUL SYLLABLE GGYEOLP")
(44803 . "HANGUL SYLLABLE GGYEOLH")
(44804 . "HANGUL SYLLABLE GGYEOM")
(44805 . "HANGUL SYLLABLE GGYEOB")
(44806 . "HANGUL SYLLABLE GGYEOBS")
(44807 . "HANGUL SYLLABLE GGYEOS")
(44808 . "HANGUL SYLLABLE GGYEOSS")
(44809 . "HANGUL SYLLABLE GGYEONG")
(44810 . "HANGUL SYLLABLE GGYEOJ")
(44811 . "HANGUL SYLLABLE GGYEOC")
(44812 . "HANGUL SYLLABLE GGYEOK")
(44813 . "HANGUL SYLLABLE GGYEOT")
(44814 . "HANGUL SYLLABLE GGYEOP")
(44815 . "HANGUL SYLLABLE GGYEOH")
(44816 . "HANGUL SYLLABLE GGYE")
(44817 . "HANGUL SYLLABLE GGYEG")
(44818 . "HANGUL SYLLABLE GGYEGG")
(44819 . "HANGUL SYLLABLE GGYEGS")
(44820 . "HANGUL SYLLABLE GGYEN")
(44821 . "HANGUL SYLLABLE GGYENJ")
(44822 . "HANGUL SYLLABLE GGYENH")
(44823 . "HANGUL SYLLABLE GGYED")
(44824 . "HANGUL SYLLABLE GGYEL")
(44825 . "HANGUL SYLLABLE GGYELG")
(44826 . "HANGUL SYLLABLE GGYELM")
(44827 . "HANGUL SYLLABLE GGYELB")
(44828 . "HANGUL SYLLABLE GGYELS")
(44829 . "HANGUL SYLLABLE GGYELT")
(44830 . "HANGUL SYLLABLE GGYELP")
(44831 . "HANGUL SYLLABLE GGYELH")
(44832 . "HANGUL SYLLABLE GGYEM")
(44833 . "HANGUL SYLLABLE GGYEB")
(44834 . "HANGUL SYLLABLE GGYEBS")
(44835 . "HANGUL SYLLABLE GGYES")
(44836 . "HANGUL SYLLABLE GGYESS")
(44837 . "HANGUL SYLLABLE GGYENG")
(44838 . "HANGUL SYLLABLE GGYEJ")
(44839 . "HANGUL SYLLABLE GGYEC")
(44840 . "HANGUL SYLLABLE GGYEK")
(44841 . "HANGUL SYLLABLE GGYET")
(44842 . "HANGUL SYLLABLE GGYEP")
(44843 . "HANGUL SYLLABLE GGYEH")
(44844 . "HANGUL SYLLABLE GGO")
(44845 . "HANGUL SYLLABLE GGOG")
(44846 . "HANGUL SYLLABLE GGOGG")
(44847 . "HANGUL SYLLABLE GGOGS")
(44848 . "HANGUL SYLLABLE GGON")
(44849 . "HANGUL SYLLABLE GGONJ")
(44850 . "HANGUL SYLLABLE GGONH")
(44851 . "HANGUL SYLLABLE GGOD")
(44852 . "HANGUL SYLLABLE GGOL")
(44853 . "HANGUL SYLLABLE GGOLG")
(44854 . "HANGUL SYLLABLE GGOLM")
(44855 . "HANGUL SYLLABLE GGOLB")
(44856 . "HANGUL SYLLABLE GGOLS")
(44857 . "HANGUL SYLLABLE GGOLT")
(44858 . "HANGUL SYLLABLE GGOLP")
(44859 . "HANGUL SYLLABLE GGOLH")
(44860 . "HANGUL SYLLABLE GGOM")
(44861 . "HANGUL SYLLABLE GGOB")
(44862 . "HANGUL SYLLABLE GGOBS")
(44863 . "HANGUL SYLLABLE GGOS")
(44864 . "HANGUL SYLLABLE GGOSS")
(44865 . "HANGUL SYLLABLE GGONG")
(44866 . "HANGUL SYLLABLE GGOJ")
(44867 . "HANGUL SYLLABLE GGOC")
(44868 . "HANGUL SYLLABLE GGOK")
(44869 . "HANGUL SYLLABLE GGOT")
(44870 . "HANGUL SYLLABLE GGOP")
(44871 . "HANGUL SYLLABLE GGOH")
(44872 . "HANGUL SYLLABLE GGWA")
(44873 . "HANGUL SYLLABLE GGWAG")
(44874 . "HANGUL SYLLABLE GGWAGG")
(44875 . "HANGUL SYLLABLE GGWAGS")
(44876 . "HANGUL SYLLABLE GGWAN")
(44877 . "HANGUL SYLLABLE GGWANJ")
(44878 . "HANGUL SYLLABLE GGWANH")
(44879 . "HANGUL SYLLABLE GGWAD")
(44880 . "HANGUL SYLLABLE GGWAL")
(44881 . "HANGUL SYLLABLE GGWALG")
(44882 . "HANGUL SYLLABLE GGWALM")
(44883 . "HANGUL SYLLABLE GGWALB")
(44884 . "HANGUL SYLLABLE GGWALS")
(44885 . "HANGUL SYLLABLE GGWALT")
(44886 . "HANGUL SYLLABLE GGWALP")
(44887 . "HANGUL SYLLABLE GGWALH")
(44888 . "HANGUL SYLLABLE GGWAM")
(44889 . "HANGUL SYLLABLE GGWAB")
(44890 . "HANGUL SYLLABLE GGWABS")
(44891 . "HANGUL SYLLABLE GGWAS")
(44892 . "HANGUL SYLLABLE GGWASS")
(44893 . "HANGUL SYLLABLE GGWANG")
(44894 . "HANGUL SYLLABLE GGWAJ")
(44895 . "HANGUL SYLLABLE GGWAC")
(44896 . "HANGUL SYLLABLE GGWAK")
(44897 . "HANGUL SYLLABLE GGWAT")
(44898 . "HANGUL SYLLABLE GGWAP")
(44899 . "HANGUL SYLLABLE GGWAH")
(44900 . "HANGUL SYLLABLE GGWAE")
(44901 . "HANGUL SYLLABLE GGWAEG")
(44902 . "HANGUL SYLLABLE GGWAEGG")
(44903 . "HANGUL SYLLABLE GGWAEGS")
(44904 . "HANGUL SYLLABLE GGWAEN")
(44905 . "HANGUL SYLLABLE GGWAENJ")
(44906 . "HANGUL SYLLABLE GGWAENH")
(44907 . "HANGUL SYLLABLE GGWAED")
(44908 . "HANGUL SYLLABLE GGWAEL")
(44909 . "HANGUL SYLLABLE GGWAELG")
(44910 . "HANGUL SYLLABLE GGWAELM")
(44911 . "HANGUL SYLLABLE GGWAELB")
(44912 . "HANGUL SYLLABLE GGWAELS")
(44913 . "HANGUL SYLLABLE GGWAELT")
(44914 . "HANGUL SYLLABLE GGWAELP")
(44915 . "HANGUL SYLLABLE GGWAELH")
(44916 . "HANGUL SYLLABLE GGWAEM")
(44917 . "HANGUL SYLLABLE GGWAEB")
(44918 . "HANGUL SYLLABLE GGWAEBS")
(44919 . "HANGUL SYLLABLE GGWAES")
(44920 . "HANGUL SYLLABLE GGWAESS")
(44921 . "HANGUL SYLLABLE GGWAENG")
(44922 . "HANGUL SYLLABLE GGWAEJ")
(44923 . "HANGUL SYLLABLE GGWAEC")
(44924 . "HANGUL SYLLABLE GGWAEK")
(44925 . "HANGUL SYLLABLE GGWAET")
(44926 . "HANGUL SYLLABLE GGWAEP")
(44927 . "HANGUL SYLLABLE GGWAEH")
(44928 . "HANGUL SYLLABLE GGOE")
(44929 . "HANGUL SYLLABLE GGOEG")
(44930 . "HANGUL SYLLABLE GGOEGG")
(44931 . "HANGUL SYLLABLE GGOEGS")
(44932 . "HANGUL SYLLABLE GGOEN")
(44933 . "HANGUL SYLLABLE GGOENJ")
(44934 . "HANGUL SYLLABLE GGOENH")
(44935 . "HANGUL SYLLABLE GGOED")
(44936 . "HANGUL SYLLABLE GGOEL")
(44937 . "HANGUL SYLLABLE GGOELG")
(44938 . "HANGUL SYLLABLE GGOELM")
(44939 . "HANGUL SYLLABLE GGOELB")
(44940 . "HANGUL SYLLABLE GGOELS")
(44941 . "HANGUL SYLLABLE GGOELT")
(44942 . "HANGUL SYLLABLE GGOELP")
(44943 . "HANGUL SYLLABLE GGOELH")
(44944 . "HANGUL SYLLABLE GGOEM")
(44945 . "HANGUL SYLLABLE GGOEB")
(44946 . "HANGUL SYLLABLE GGOEBS")
(44947 . "HANGUL SYLLABLE GGOES")
(44948 . "HANGUL SYLLABLE GGOESS")
(44949 . "HANGUL SYLLABLE GGOENG")
(44950 . "HANGUL SYLLABLE GGOEJ")
(44951 . "HANGUL SYLLABLE GGOEC")
(44952 . "HANGUL SYLLABLE GGOEK")
(44953 . "HANGUL SYLLABLE GGOET")
(44954 . "HANGUL SYLLABLE GGOEP")
(44955 . "HANGUL SYLLABLE GGOEH")
(44956 . "HANGUL SYLLABLE GGYO")
(44957 . "HANGUL SYLLABLE GGYOG")
(44958 . "HANGUL SYLLABLE GGYOGG")
(44959 . "HANGUL SYLLABLE GGYOGS")
(44960 . "HANGUL SYLLABLE GGYON")
(44961 . "HANGUL SYLLABLE GGYONJ")
(44962 . "HANGUL SYLLABLE GGYONH")
(44963 . "HANGUL SYLLABLE GGYOD")
(44964 . "HANGUL SYLLABLE GGYOL")
(44965 . "HANGUL SYLLABLE GGYOLG")
(44966 . "HANGUL SYLLABLE GGYOLM")
(44967 . "HANGUL SYLLABLE GGYOLB")
(44968 . "HANGUL SYLLABLE GGYOLS")
(44969 . "HANGUL SYLLABLE GGYOLT")
(44970 . "HANGUL SYLLABLE GGYOLP")
(44971 . "HANGUL SYLLABLE GGYOLH")
(44972 . "HANGUL SYLLABLE GGYOM")
(44973 . "HANGUL SYLLABLE GGYOB")
(44974 . "HANGUL SYLLABLE GGYOBS")
(44975 . "HANGUL SYLLABLE GGYOS")
(44976 . "HANGUL SYLLABLE GGYOSS")
(44977 . "HANGUL SYLLABLE GGYONG")
(44978 . "HANGUL SYLLABLE GGYOJ")
(44979 . "HANGUL SYLLABLE GGYOC")
(44980 . "HANGUL SYLLABLE GGYOK")
(44981 . "HANGUL SYLLABLE GGYOT")
(44982 . "HANGUL SYLLABLE GGYOP")
(44983 . "HANGUL SYLLABLE GGYOH")
(44984 . "HANGUL SYLLABLE GGU")
(44985 . "HANGUL SYLLABLE GGUG")
(44986 . "HANGUL SYLLABLE GGUGG")
(44987 . "HANGUL SYLLABLE GGUGS")
(44988 . "HANGUL SYLLABLE GGUN")
(44989 . "HANGUL SYLLABLE GGUNJ")
(44990 . "HANGUL SYLLABLE GGUNH")
(44991 . "HANGUL SYLLABLE GGUD")
(44992 . "HANGUL SYLLABLE GGUL")
(44993 . "HANGUL SYLLABLE GGULG")
(44994 . "HANGUL SYLLABLE GGULM")
(44995 . "HANGUL SYLLABLE GGULB")
(44996 . "HANGUL SYLLABLE GGULS")
(44997 . "HANGUL SYLLABLE GGULT")
(44998 . "HANGUL SYLLABLE GGULP")
(44999 . "HANGUL SYLLABLE GGULH")
(45000 . "HANGUL SYLLABLE GGUM")
(45001 . "HANGUL SYLLABLE GGUB")
(45002 . "HANGUL SYLLABLE GGUBS")
(45003 . "HANGUL SYLLABLE GGUS")
(45004 . "HANGUL SYLLABLE GGUSS")
(45005 . "HANGUL SYLLABLE GGUNG")
(45006 . "HANGUL SYLLABLE GGUJ")
(45007 . "HANGUL SYLLABLE GGUC")
(45008 . "HANGUL SYLLABLE GGUK")
(45009 . "HANGUL SYLLABLE GGUT")
(45010 . "HANGUL SYLLABLE GGUP")
(45011 . "HANGUL SYLLABLE GGUH")
(45012 . "HANGUL SYLLABLE GGWEO")
(45013 . "HANGUL SYLLABLE GGWEOG")
(45014 . "HANGUL SYLLABLE GGWEOGG")
(45015 . "HANGUL SYLLABLE GGWEOGS")
(45016 . "HANGUL SYLLABLE GGWEON")
(45017 . "HANGUL SYLLABLE GGWEONJ")
(45018 . "HANGUL SYLLABLE GGWEONH")
(45019 . "HANGUL SYLLABLE GGWEOD")
(45020 . "HANGUL SYLLABLE GGWEOL")
(45021 . "HANGUL SYLLABLE GGWEOLG")
(45022 . "HANGUL SYLLABLE GGWEOLM")
(45023 . "HANGUL SYLLABLE GGWEOLB")
(45024 . "HANGUL SYLLABLE GGWEOLS")
(45025 . "HANGUL SYLLABLE GGWEOLT")
(45026 . "HANGUL SYLLABLE GGWEOLP")
(45027 . "HANGUL SYLLABLE GGWEOLH")
(45028 . "HANGUL SYLLABLE GGWEOM")
(45029 . "HANGUL SYLLABLE GGWEOB")
(45030 . "HANGUL SYLLABLE GGWEOBS")
(45031 . "HANGUL SYLLABLE GGWEOS")
(45032 . "HANGUL SYLLABLE GGWEOSS")
(45033 . "HANGUL SYLLABLE GGWEONG")
(45034 . "HANGUL SYLLABLE GGWEOJ")
(45035 . "HANGUL SYLLABLE GGWEOC")
(45036 . "HANGUL SYLLABLE GGWEOK")
(45037 . "HANGUL SYLLABLE GGWEOT")
(45038 . "HANGUL SYLLABLE GGWEOP")
(45039 . "HANGUL SYLLABLE GGWEOH")
(45040 . "HANGUL SYLLABLE GGWE")
(45041 . "HANGUL SYLLABLE GGWEG")
(45042 . "HANGUL SYLLABLE GGWEGG")
(45043 . "HANGUL SYLLABLE GGWEGS")
(45044 . "HANGUL SYLLABLE GGWEN")
(45045 . "HANGUL SYLLABLE GGWENJ")
(45046 . "HANGUL SYLLABLE GGWENH")
(45047 . "HANGUL SYLLABLE GGWED")
(45048 . "HANGUL SYLLABLE GGWEL")
(45049 . "HANGUL SYLLABLE GGWELG")
(45050 . "HANGUL SYLLABLE GGWELM")
(45051 . "HANGUL SYLLABLE GGWELB")
(45052 . "HANGUL SYLLABLE GGWELS")
(45053 . "HANGUL SYLLABLE GGWELT")
(45054 . "HANGUL SYLLABLE GGWELP")
(45055 . "HANGUL SYLLABLE GGWELH")
(45056 . "HANGUL SYLLABLE GGWEM")
(45057 . "HANGUL SYLLABLE GGWEB")
(45058 . "HANGUL SYLLABLE GGWEBS")
(45059 . "HANGUL SYLLABLE GGWES")
(45060 . "HANGUL SYLLABLE GGWESS")
(45061 . "HANGUL SYLLABLE GGWENG")
(45062 . "HANGUL SYLLABLE GGWEJ")
(45063 . "HANGUL SYLLABLE GGWEC")
(45064 . "HANGUL SYLLABLE GGWEK")
(45065 . "HANGUL SYLLABLE GGWET")
(45066 . "HANGUL SYLLABLE GGWEP")
(45067 . "HANGUL SYLLABLE GGWEH")
(45068 . "HANGUL SYLLABLE GGWI")
(45069 . "HANGUL SYLLABLE GGWIG")
(45070 . "HANGUL SYLLABLE GGWIGG")
(45071 . "HANGUL SYLLABLE GGWIGS")
(45072 . "HANGUL SYLLABLE GGWIN")
(45073 . "HANGUL SYLLABLE GGWINJ")
(45074 . "HANGUL SYLLABLE GGWINH")
(45075 . "HANGUL SYLLABLE GGWID")
(45076 . "HANGUL SYLLABLE GGWIL")
(45077 . "HANGUL SYLLABLE GGWILG")
(45078 . "HANGUL SYLLABLE GGWILM")
(45079 . "HANGUL SYLLABLE GGWILB")
(45080 . "HANGUL SYLLABLE GGWILS")
(45081 . "HANGUL SYLLABLE GGWILT")
(45082 . "HANGUL SYLLABLE GGWILP")
(45083 . "HANGUL SYLLABLE GGWILH")
(45084 . "HANGUL SYLLABLE GGWIM")
(45085 . "HANGUL SYLLABLE GGWIB")
(45086 . "HANGUL SYLLABLE GGWIBS")
(45087 . "HANGUL SYLLABLE GGWIS")
(45088 . "HANGUL SYLLABLE GGWISS")
(45089 . "HANGUL SYLLABLE GGWING")
(45090 . "HANGUL SYLLABLE GGWIJ")
(45091 . "HANGUL SYLLABLE GGWIC")
(45092 . "HANGUL SYLLABLE GGWIK")
(45093 . "HANGUL SYLLABLE GGWIT")
(45094 . "HANGUL SYLLABLE GGWIP")
(45095 . "HANGUL SYLLABLE GGWIH")
(45096 . "HANGUL SYLLABLE GGYU")
(45097 . "HANGUL SYLLABLE GGYUG")
(45098 . "HANGUL SYLLABLE GGYUGG")
(45099 . "HANGUL SYLLABLE GGYUGS")
(45100 . "HANGUL SYLLABLE GGYUN")
(45101 . "HANGUL SYLLABLE GGYUNJ")
(45102 . "HANGUL SYLLABLE GGYUNH")
(45103 . "HANGUL SYLLABLE GGYUD")
(45104 . "HANGUL SYLLABLE GGYUL")
(45105 . "HANGUL SYLLABLE GGYULG")
(45106 . "HANGUL SYLLABLE GGYULM")
(45107 . "HANGUL SYLLABLE GGYULB")
(45108 . "HANGUL SYLLABLE GGYULS")
(45109 . "HANGUL SYLLABLE GGYULT")
(45110 . "HANGUL SYLLABLE GGYULP")
(45111 . "HANGUL SYLLABLE GGYULH")
(45112 . "HANGUL SYLLABLE GGYUM")
(45113 . "HANGUL SYLLABLE GGYUB")
(45114 . "HANGUL SYLLABLE GGYUBS")
(45115 . "HANGUL SYLLABLE GGYUS")
(45116 . "HANGUL SYLLABLE GGYUSS")
(45117 . "HANGUL SYLLABLE GGYUNG")
(45118 . "HANGUL SYLLABLE GGYUJ")
(45119 . "HANGUL SYLLABLE GGYUC")
(45120 . "HANGUL SYLLABLE GGYUK")
(45121 . "HANGUL SYLLABLE GGYUT")
(45122 . "HANGUL SYLLABLE GGYUP")
(45123 . "HANGUL SYLLABLE GGYUH")
(45124 . "HANGUL SYLLABLE GGEU")
(45125 . "HANGUL SYLLABLE GGEUG")
(45126 . "HANGUL SYLLABLE GGEUGG")
(45127 . "HANGUL SYLLABLE GGEUGS")
(45128 . "HANGUL SYLLABLE GGEUN")
(45129 . "HANGUL SYLLABLE GGEUNJ")
(45130 . "HANGUL SYLLABLE GGEUNH")
(45131 . "HANGUL SYLLABLE GGEUD")
(45132 . "HANGUL SYLLABLE GGEUL")
(45133 . "HANGUL SYLLABLE GGEULG")
(45134 . "HANGUL SYLLABLE GGEULM")
(45135 . "HANGUL SYLLABLE GGEULB")
(45136 . "HANGUL SYLLABLE GGEULS")
(45137 . "HANGUL SYLLABLE GGEULT")
(45138 . "HANGUL SYLLABLE GGEULP")
(45139 . "HANGUL SYLLABLE GGEULH")
(45140 . "HANGUL SYLLABLE GGEUM")
(45141 . "HANGUL SYLLABLE GGEUB")
(45142 . "HANGUL SYLLABLE GGEUBS")
(45143 . "HANGUL SYLLABLE GGEUS")
(45144 . "HANGUL SYLLABLE GGEUSS")
(45145 . "HANGUL SYLLABLE GGEUNG")
(45146 . "HANGUL SYLLABLE GGEUJ")
(45147 . "HANGUL SYLLABLE GGEUC")
(45148 . "HANGUL SYLLABLE GGEUK")
(45149 . "HANGUL SYLLABLE GGEUT")
(45150 . "HANGUL SYLLABLE GGEUP")
(45151 . "HANGUL SYLLABLE GGEUH")
(45152 . "HANGUL SYLLABLE GGYI")
(45153 . "HANGUL SYLLABLE GGYIG")
(45154 . "HANGUL SYLLABLE GGYIGG")
(45155 . "HANGUL SYLLABLE GGYIGS")
(45156 . "HANGUL SYLLABLE GGYIN")
(45157 . "HANGUL SYLLABLE GGYINJ")
(45158 . "HANGUL SYLLABLE GGYINH")
(45159 . "HANGUL SYLLABLE GGYID")
(45160 . "HANGUL SYLLABLE GGYIL")
(45161 . "HANGUL SYLLABLE GGYILG")
(45162 . "HANGUL SYLLABLE GGYILM")
(45163 . "HANGUL SYLLABLE GGYILB")
(45164 . "HANGUL SYLLABLE GGYILS")
(45165 . "HANGUL SYLLABLE GGYILT")
(45166 . "HANGUL SYLLABLE GGYILP")
(45167 . "HANGUL SYLLABLE GGYILH")
(45168 . "HANGUL SYLLABLE GGYIM")
(45169 . "HANGUL SYLLABLE GGYIB")
(45170 . "HANGUL SYLLABLE GGYIBS")
(45171 . "HANGUL SYLLABLE GGYIS")
(45172 . "HANGUL SYLLABLE GGYISS")
(45173 . "HANGUL SYLLABLE GGYING")
(45174 . "HANGUL SYLLABLE GGYIJ")
(45175 . "HANGUL SYLLABLE GGYIC")
(45176 . "HANGUL SYLLABLE GGYIK")
(45177 . "HANGUL SYLLABLE GGYIT")
(45178 . "HANGUL SYLLABLE GGYIP")
(45179 . "HANGUL SYLLABLE GGYIH")
(45180 . "HANGUL SYLLABLE GGI")
(45181 . "HANGUL SYLLABLE GGIG")
(45182 . "HANGUL SYLLABLE GGIGG")
(45183 . "HANGUL SYLLABLE GGIGS")
(45184 . "HANGUL SYLLABLE GGIN")
(45185 . "HANGUL SYLLABLE GGINJ")
(45186 . "HANGUL SYLLABLE GGINH")
(45187 . "HANGUL SYLLABLE GGID")
(45188 . "HANGUL SYLLABLE GGIL")
(45189 . "HANGUL SYLLABLE GGILG")
(45190 . "HANGUL SYLLABLE GGILM")
(45191 . "HANGUL SYLLABLE GGILB")
(45192 . "HANGUL SYLLABLE GGILS")
(45193 . "HANGUL SYLLABLE GGILT")
(45194 . "HANGUL SYLLABLE GGILP")
(45195 . "HANGUL SYLLABLE GGILH")
(45196 . "HANGUL SYLLABLE GGIM")
(45197 . "HANGUL SYLLABLE GGIB")
(45198 . "HANGUL SYLLABLE GGIBS")
(45199 . "HANGUL SYLLABLE GGIS")
(45200 . "HANGUL SYLLABLE GGISS")
(45201 . "HANGUL SYLLABLE GGING")
(45202 . "HANGUL SYLLABLE GGIJ")
(45203 . "HANGUL SYLLABLE GGIC")
(45204 . "HANGUL SYLLABLE GGIK")
(45205 . "HANGUL SYLLABLE GGIT")
(45206 . "HANGUL SYLLABLE GGIP")
(45207 . "HANGUL SYLLABLE GGIH")
(45208 . "HANGUL SYLLABLE NA")
(45209 . "HANGUL SYLLABLE NAG")
(45210 . "HANGUL SYLLABLE NAGG")
(45211 . "HANGUL SYLLABLE NAGS")
(45212 . "HANGUL SYLLABLE NAN")
(45213 . "HANGUL SYLLABLE NANJ")
(45214 . "HANGUL SYLLABLE NANH")
(45215 . "HANGUL SYLLABLE NAD")
(45216 . "HANGUL SYLLABLE NAL")
(45217 . "HANGUL SYLLABLE NALG")
(45218 . "HANGUL SYLLABLE NALM")
(45219 . "HANGUL SYLLABLE NALB")
(45220 . "HANGUL SYLLABLE NALS")
(45221 . "HANGUL SYLLABLE NALT")
(45222 . "HANGUL SYLLABLE NALP")
(45223 . "HANGUL SYLLABLE NALH")
(45224 . "HANGUL SYLLABLE NAM")
(45225 . "HANGUL SYLLABLE NAB")
(45226 . "HANGUL SYLLABLE NABS")
(45227 . "HANGUL SYLLABLE NAS")
(45228 . "HANGUL SYLLABLE NASS")
(45229 . "HANGUL SYLLABLE NANG")
(45230 . "HANGUL SYLLABLE NAJ")
(45231 . "HANGUL SYLLABLE NAC")
(45232 . "HANGUL SYLLABLE NAK")
(45233 . "HANGUL SYLLABLE NAT")
(45234 . "HANGUL SYLLABLE NAP")
(45235 . "HANGUL SYLLABLE NAH")
(45236 . "HANGUL SYLLABLE NAE")
(45237 . "HANGUL SYLLABLE NAEG")
(45238 . "HANGUL SYLLABLE NAEGG")
(45239 . "HANGUL SYLLABLE NAEGS")
(45240 . "HANGUL SYLLABLE NAEN")
(45241 . "HANGUL SYLLABLE NAENJ")
(45242 . "HANGUL SYLLABLE NAENH")
(45243 . "HANGUL SYLLABLE NAED")
(45244 . "HANGUL SYLLABLE NAEL")
(45245 . "HANGUL SYLLABLE NAELG")
(45246 . "HANGUL SYLLABLE NAELM")
(45247 . "HANGUL SYLLABLE NAELB")
(45248 . "HANGUL SYLLABLE NAELS")
(45249 . "HANGUL SYLLABLE NAELT")
(45250 . "HANGUL SYLLABLE NAELP")
(45251 . "HANGUL SYLLABLE NAELH")
(45252 . "HANGUL SYLLABLE NAEM")
(45253 . "HANGUL SYLLABLE NAEB")
(45254 . "HANGUL SYLLABLE NAEBS")
(45255 . "HANGUL SYLLABLE NAES")
(45256 . "HANGUL SYLLABLE NAESS")
(45257 . "HANGUL SYLLABLE NAENG")
(45258 . "HANGUL SYLLABLE NAEJ")
(45259 . "HANGUL SYLLABLE NAEC")
(45260 . "HANGUL SYLLABLE NAEK")
(45261 . "HANGUL SYLLABLE NAET")
(45262 . "HANGUL SYLLABLE NAEP")
(45263 . "HANGUL SYLLABLE NAEH")
(45264 . "HANGUL SYLLABLE NYA")
(45265 . "HANGUL SYLLABLE NYAG")
(45266 . "HANGUL SYLLABLE NYAGG")
(45267 . "HANGUL SYLLABLE NYAGS")
(45268 . "HANGUL SYLLABLE NYAN")
(45269 . "HANGUL SYLLABLE NYANJ")
(45270 . "HANGUL SYLLABLE NYANH")
(45271 . "HANGUL SYLLABLE NYAD")
(45272 . "HANGUL SYLLABLE NYAL")
(45273 . "HANGUL SYLLABLE NYALG")
(45274 . "HANGUL SYLLABLE NYALM")
(45275 . "HANGUL SYLLABLE NYALB")
(45276 . "HANGUL SYLLABLE NYALS")
(45277 . "HANGUL SYLLABLE NYALT")
(45278 . "HANGUL SYLLABLE NYALP")
(45279 . "HANGUL SYLLABLE NYALH")
(45280 . "HANGUL SYLLABLE NYAM")
(45281 . "HANGUL SYLLABLE NYAB")
(45282 . "HANGUL SYLLABLE NYABS")
(45283 . "HANGUL SYLLABLE NYAS")
(45284 . "HANGUL SYLLABLE NYASS")
(45285 . "HANGUL SYLLABLE NYANG")
(45286 . "HANGUL SYLLABLE NYAJ")
(45287 . "HANGUL SYLLABLE NYAC")
(45288 . "HANGUL SYLLABLE NYAK")
(45289 . "HANGUL SYLLABLE NYAT")
(45290 . "HANGUL SYLLABLE NYAP")
(45291 . "HANGUL SYLLABLE NYAH")
(45292 . "HANGUL SYLLABLE NYAE")
(45293 . "HANGUL SYLLABLE NYAEG")
(45294 . "HANGUL SYLLABLE NYAEGG")
(45295 . "HANGUL SYLLABLE NYAEGS")
(45296 . "HANGUL SYLLABLE NYAEN")
(45297 . "HANGUL SYLLABLE NYAENJ")
(45298 . "HANGUL SYLLABLE NYAENH")
(45299 . "HANGUL SYLLABLE NYAED")
(45300 . "HANGUL SYLLABLE NYAEL")
(45301 . "HANGUL SYLLABLE NYAELG")
(45302 . "HANGUL SYLLABLE NYAELM")
(45303 . "HANGUL SYLLABLE NYAELB")
(45304 . "HANGUL SYLLABLE NYAELS")
(45305 . "HANGUL SYLLABLE NYAELT")
(45306 . "HANGUL SYLLABLE NYAELP")
(45307 . "HANGUL SYLLABLE NYAELH")
(45308 . "HANGUL SYLLABLE NYAEM")
(45309 . "HANGUL SYLLABLE NYAEB")
(45310 . "HANGUL SYLLABLE NYAEBS")
(45311 . "HANGUL SYLLABLE NYAES")
(45312 . "HANGUL SYLLABLE NYAESS")
(45313 . "HANGUL SYLLABLE NYAENG")
(45314 . "HANGUL SYLLABLE NYAEJ")
(45315 . "HANGUL SYLLABLE NYAEC")
(45316 . "HANGUL SYLLABLE NYAEK")
(45317 . "HANGUL SYLLABLE NYAET")
(45318 . "HANGUL SYLLABLE NYAEP")
(45319 . "HANGUL SYLLABLE NYAEH")
(45320 . "HANGUL SYLLABLE NEO")
(45321 . "HANGUL SYLLABLE NEOG")
(45322 . "HANGUL SYLLABLE NEOGG")
(45323 . "HANGUL SYLLABLE NEOGS")
(45324 . "HANGUL SYLLABLE NEON")
(45325 . "HANGUL SYLLABLE NEONJ")
(45326 . "HANGUL SYLLABLE NEONH")
(45327 . "HANGUL SYLLABLE NEOD")
(45328 . "HANGUL SYLLABLE NEOL")
(45329 . "HANGUL SYLLABLE NEOLG")
(45330 . "HANGUL SYLLABLE NEOLM")
(45331 . "HANGUL SYLLABLE NEOLB")
(45332 . "HANGUL SYLLABLE NEOLS")
(45333 . "HANGUL SYLLABLE NEOLT")
(45334 . "HANGUL SYLLABLE NEOLP")
(45335 . "HANGUL SYLLABLE NEOLH")
(45336 . "HANGUL SYLLABLE NEOM")
(45337 . "HANGUL SYLLABLE NEOB")
(45338 . "HANGUL SYLLABLE NEOBS")
(45339 . "HANGUL SYLLABLE NEOS")
(45340 . "HANGUL SYLLABLE NEOSS")
(45341 . "HANGUL SYLLABLE NEONG")
(45342 . "HANGUL SYLLABLE NEOJ")
(45343 . "HANGUL SYLLABLE NEOC")
(45344 . "HANGUL SYLLABLE NEOK")
(45345 . "HANGUL SYLLABLE NEOT")
(45346 . "HANGUL SYLLABLE NEOP")
(45347 . "HANGUL SYLLABLE NEOH")
(45348 . "HANGUL SYLLABLE NE")
(45349 . "HANGUL SYLLABLE NEG")
(45350 . "HANGUL SYLLABLE NEGG")
(45351 . "HANGUL SYLLABLE NEGS")
(45352 . "HANGUL SYLLABLE NEN")
(45353 . "HANGUL SYLLABLE NENJ")
(45354 . "HANGUL SYLLABLE NENH")
(45355 . "HANGUL SYLLABLE NED")
(45356 . "HANGUL SYLLABLE NEL")
(45357 . "HANGUL SYLLABLE NELG")
(45358 . "HANGUL SYLLABLE NELM")
(45359 . "HANGUL SYLLABLE NELB")
(45360 . "HANGUL SYLLABLE NELS")
(45361 . "HANGUL SYLLABLE NELT")
(45362 . "HANGUL SYLLABLE NELP")
(45363 . "HANGUL SYLLABLE NELH")
(45364 . "HANGUL SYLLABLE NEM")
(45365 . "HANGUL SYLLABLE NEB")
(45366 . "HANGUL SYLLABLE NEBS")
(45367 . "HANGUL SYLLABLE NES")
(45368 . "HANGUL SYLLABLE NESS")
(45369 . "HANGUL SYLLABLE NENG")
(45370 . "HANGUL SYLLABLE NEJ")
(45371 . "HANGUL SYLLABLE NEC")
(45372 . "HANGUL SYLLABLE NEK")
(45373 . "HANGUL SYLLABLE NET")
(45374 . "HANGUL SYLLABLE NEP")
(45375 . "HANGUL SYLLABLE NEH")
(45376 . "HANGUL SYLLABLE NYEO")
(45377 . "HANGUL SYLLABLE NYEOG")
(45378 . "HANGUL SYLLABLE NYEOGG")
(45379 . "HANGUL SYLLABLE NYEOGS")
(45380 . "HANGUL SYLLABLE NYEON")
(45381 . "HANGUL SYLLABLE NYEONJ")
(45382 . "HANGUL SYLLABLE NYEONH")
(45383 . "HANGUL SYLLABLE NYEOD")
(45384 . "HANGUL SYLLABLE NYEOL")
(45385 . "HANGUL SYLLABLE NYEOLG")
(45386 . "HANGUL SYLLABLE NYEOLM")
(45387 . "HANGUL SYLLABLE NYEOLB")
(45388 . "HANGUL SYLLABLE NYEOLS")
(45389 . "HANGUL SYLLABLE NYEOLT")
(45390 . "HANGUL SYLLABLE NYEOLP")
(45391 . "HANGUL SYLLABLE NYEOLH")
(45392 . "HANGUL SYLLABLE NYEOM")
(45393 . "HANGUL SYLLABLE NYEOB")
(45394 . "HANGUL SYLLABLE NYEOBS")
(45395 . "HANGUL SYLLABLE NYEOS")
(45396 . "HANGUL SYLLABLE NYEOSS")
(45397 . "HANGUL SYLLABLE NYEONG")
(45398 . "HANGUL SYLLABLE NYEOJ")
(45399 . "HANGUL SYLLABLE NYEOC")
(45400 . "HANGUL SYLLABLE NYEOK")
(45401 . "HANGUL SYLLABLE NYEOT")
(45402 . "HANGUL SYLLABLE NYEOP")
(45403 . "HANGUL SYLLABLE NYEOH")
(45404 . "HANGUL SYLLABLE NYE")
(45405 . "HANGUL SYLLABLE NYEG")
(45406 . "HANGUL SYLLABLE NYEGG")
(45407 . "HANGUL SYLLABLE NYEGS")
(45408 . "HANGUL SYLLABLE NYEN")
(45409 . "HANGUL SYLLABLE NYENJ")
(45410 . "HANGUL SYLLABLE NYENH")
(45411 . "HANGUL SYLLABLE NYED")
(45412 . "HANGUL SYLLABLE NYEL")
(45413 . "HANGUL SYLLABLE NYELG")
(45414 . "HANGUL SYLLABLE NYELM")
(45415 . "HANGUL SYLLABLE NYELB")
(45416 . "HANGUL SYLLABLE NYELS")
(45417 . "HANGUL SYLLABLE NYELT")
(45418 . "HANGUL SYLLABLE NYELP")
(45419 . "HANGUL SYLLABLE NYELH")
(45420 . "HANGUL SYLLABLE NYEM")
(45421 . "HANGUL SYLLABLE NYEB")
(45422 . "HANGUL SYLLABLE NYEBS")
(45423 . "HANGUL SYLLABLE NYES")
(45424 . "HANGUL SYLLABLE NYESS")
(45425 . "HANGUL SYLLABLE NYENG")
(45426 . "HANGUL SYLLABLE NYEJ")
(45427 . "HANGUL SYLLABLE NYEC")
(45428 . "HANGUL SYLLABLE NYEK")
(45429 . "HANGUL SYLLABLE NYET")
(45430 . "HANGUL SYLLABLE NYEP")
(45431 . "HANGUL SYLLABLE NYEH")
(45432 . "HANGUL SYLLABLE NO")
(45433 . "HANGUL SYLLABLE NOG")
(45434 . "HANGUL SYLLABLE NOGG")
(45435 . "HANGUL SYLLABLE NOGS")
(45436 . "HANGUL SYLLABLE NON")
(45437 . "HANGUL SYLLABLE NONJ")
(45438 . "HANGUL SYLLABLE NONH")
(45439 . "HANGUL SYLLABLE NOD")
(45440 . "HANGUL SYLLABLE NOL")
(45441 . "HANGUL SYLLABLE NOLG")
(45442 . "HANGUL SYLLABLE NOLM")
(45443 . "HANGUL SYLLABLE NOLB")
(45444 . "HANGUL SYLLABLE NOLS")
(45445 . "HANGUL SYLLABLE NOLT")
(45446 . "HANGUL SYLLABLE NOLP")
(45447 . "HANGUL SYLLABLE NOLH")
(45448 . "HANGUL SYLLABLE NOM")
(45449 . "HANGUL SYLLABLE NOB")
(45450 . "HANGUL SYLLABLE NOBS")
(45451 . "HANGUL SYLLABLE NOS")
(45452 . "HANGUL SYLLABLE NOSS")
(45453 . "HANGUL SYLLABLE NONG")
(45454 . "HANGUL SYLLABLE NOJ")
(45455 . "HANGUL SYLLABLE NOC")
(45456 . "HANGUL SYLLABLE NOK")
(45457 . "HANGUL SYLLABLE NOT")
(45458 . "HANGUL SYLLABLE NOP")
(45459 . "HANGUL SYLLABLE NOH")
(45460 . "HANGUL SYLLABLE NWA")
(45461 . "HANGUL SYLLABLE NWAG")
(45462 . "HANGUL SYLLABLE NWAGG")
(45463 . "HANGUL SYLLABLE NWAGS")
(45464 . "HANGUL SYLLABLE NWAN")
(45465 . "HANGUL SYLLABLE NWANJ")
(45466 . "HANGUL SYLLABLE NWANH")
(45467 . "HANGUL SYLLABLE NWAD")
(45468 . "HANGUL SYLLABLE NWAL")
(45469 . "HANGUL SYLLABLE NWALG")
(45470 . "HANGUL SYLLABLE NWALM")
(45471 . "HANGUL SYLLABLE NWALB")
(45472 . "HANGUL SYLLABLE NWALS")
(45473 . "HANGUL SYLLABLE NWALT")
(45474 . "HANGUL SYLLABLE NWALP")
(45475 . "HANGUL SYLLABLE NWALH")
(45476 . "HANGUL SYLLABLE NWAM")
(45477 . "HANGUL SYLLABLE NWAB")
(45478 . "HANGUL SYLLABLE NWABS")
(45479 . "HANGUL SYLLABLE NWAS")
(45480 . "HANGUL SYLLABLE NWASS")
(45481 . "HANGUL SYLLABLE NWANG")
(45482 . "HANGUL SYLLABLE NWAJ")
(45483 . "HANGUL SYLLABLE NWAC")
(45484 . "HANGUL SYLLABLE NWAK")
(45485 . "HANGUL SYLLABLE NWAT")
(45486 . "HANGUL SYLLABLE NWAP")
(45487 . "HANGUL SYLLABLE NWAH")
(45488 . "HANGUL SYLLABLE NWAE")
(45489 . "HANGUL SYLLABLE NWAEG")
(45490 . "HANGUL SYLLABLE NWAEGG")
(45491 . "HANGUL SYLLABLE NWAEGS")
(45492 . "HANGUL SYLLABLE NWAEN")
(45493 . "HANGUL SYLLABLE NWAENJ")
(45494 . "HANGUL SYLLABLE NWAENH")
(45495 . "HANGUL SYLLABLE NWAED")
(45496 . "HANGUL SYLLABLE NWAEL")
(45497 . "HANGUL SYLLABLE NWAELG")
(45498 . "HANGUL SYLLABLE NWAELM")
(45499 . "HANGUL SYLLABLE NWAELB")
(45500 . "HANGUL SYLLABLE NWAELS")
(45501 . "HANGUL SYLLABLE NWAELT")
(45502 . "HANGUL SYLLABLE NWAELP")
(45503 . "HANGUL SYLLABLE NWAELH")
(45504 . "HANGUL SYLLABLE NWAEM")
(45505 . "HANGUL SYLLABLE NWAEB")
(45506 . "HANGUL SYLLABLE NWAEBS")
(45507 . "HANGUL SYLLABLE NWAES")
(45508 . "HANGUL SYLLABLE NWAESS")
(45509 . "HANGUL SYLLABLE NWAENG")
(45510 . "HANGUL SYLLABLE NWAEJ")
(45511 . "HANGUL SYLLABLE NWAEC")
(45512 . "HANGUL SYLLABLE NWAEK")
(45513 . "HANGUL SYLLABLE NWAET")
(45514 . "HANGUL SYLLABLE NWAEP")
(45515 . "HANGUL SYLLABLE NWAEH")
(45516 . "HANGUL SYLLABLE NOE")
(45517 . "HANGUL SYLLABLE NOEG")
(45518 . "HANGUL SYLLABLE NOEGG")
(45519 . "HANGUL SYLLABLE NOEGS")
(45520 . "HANGUL SYLLABLE NOEN")
(45521 . "HANGUL SYLLABLE NOENJ")
(45522 . "HANGUL SYLLABLE NOENH")
(45523 . "HANGUL SYLLABLE NOED")
(45524 . "HANGUL SYLLABLE NOEL")
(45525 . "HANGUL SYLLABLE NOELG")
(45526 . "HANGUL SYLLABLE NOELM")
(45527 . "HANGUL SYLLABLE NOELB")
(45528 . "HANGUL SYLLABLE NOELS")
(45529 . "HANGUL SYLLABLE NOELT")
(45530 . "HANGUL SYLLABLE NOELP")
(45531 . "HANGUL SYLLABLE NOELH")
(45532 . "HANGUL SYLLABLE NOEM")
(45533 . "HANGUL SYLLABLE NOEB")
(45534 . "HANGUL SYLLABLE NOEBS")
(45535 . "HANGUL SYLLABLE NOES")
(45536 . "HANGUL SYLLABLE NOESS")
(45537 . "HANGUL SYLLABLE NOENG")
(45538 . "HANGUL SYLLABLE NOEJ")
(45539 . "HANGUL SYLLABLE NOEC")
(45540 . "HANGUL SYLLABLE NOEK")
(45541 . "HANGUL SYLLABLE NOET")
(45542 . "HANGUL SYLLABLE NOEP")
(45543 . "HANGUL SYLLABLE NOEH")
(45544 . "HANGUL SYLLABLE NYO")
(45545 . "HANGUL SYLLABLE NYOG")
(45546 . "HANGUL SYLLABLE NYOGG")
(45547 . "HANGUL SYLLABLE NYOGS")
(45548 . "HANGUL SYLLABLE NYON")
(45549 . "HANGUL SYLLABLE NYONJ")
(45550 . "HANGUL SYLLABLE NYONH")
(45551 . "HANGUL SYLLABLE NYOD")
(45552 . "HANGUL SYLLABLE NYOL")
(45553 . "HANGUL SYLLABLE NYOLG")
(45554 . "HANGUL SYLLABLE NYOLM")
(45555 . "HANGUL SYLLABLE NYOLB")
(45556 . "HANGUL SYLLABLE NYOLS")
(45557 . "HANGUL SYLLABLE NYOLT")
(45558 . "HANGUL SYLLABLE NYOLP")
(45559 . "HANGUL SYLLABLE NYOLH")
(45560 . "HANGUL SYLLABLE NYOM")
(45561 . "HANGUL SYLLABLE NYOB")
(45562 . "HANGUL SYLLABLE NYOBS")
(45563 . "HANGUL SYLLABLE NYOS")
(45564 . "HANGUL SYLLABLE NYOSS")
(45565 . "HANGUL SYLLABLE NYONG")
(45566 . "HANGUL SYLLABLE NYOJ")
(45567 . "HANGUL SYLLABLE NYOC")
(45568 . "HANGUL SYLLABLE NYOK")
(45569 . "HANGUL SYLLABLE NYOT")
(45570 . "HANGUL SYLLABLE NYOP")
(45571 . "HANGUL SYLLABLE NYOH")
(45572 . "HANGUL SYLLABLE NU")
(45573 . "HANGUL SYLLABLE NUG")
(45574 . "HANGUL SYLLABLE NUGG")
(45575 . "HANGUL SYLLABLE NUGS")
(45576 . "HANGUL SYLLABLE NUN")
(45577 . "HANGUL SYLLABLE NUNJ")
(45578 . "HANGUL SYLLABLE NUNH")
(45579 . "HANGUL SYLLABLE NUD")
(45580 . "HANGUL SYLLABLE NUL")
(45581 . "HANGUL SYLLABLE NULG")
(45582 . "HANGUL SYLLABLE NULM")
(45583 . "HANGUL SYLLABLE NULB")
(45584 . "HANGUL SYLLABLE NULS")
(45585 . "HANGUL SYLLABLE NULT")
(45586 . "HANGUL SYLLABLE NULP")
(45587 . "HANGUL SYLLABLE NULH")
(45588 . "HANGUL SYLLABLE NUM")
(45589 . "HANGUL SYLLABLE NUB")
(45590 . "HANGUL SYLLABLE NUBS")
(45591 . "HANGUL SYLLABLE NUS")
(45592 . "HANGUL SYLLABLE NUSS")
(45593 . "HANGUL SYLLABLE NUNG")
(45594 . "HANGUL SYLLABLE NUJ")
(45595 . "HANGUL SYLLABLE NUC")
(45596 . "HANGUL SYLLABLE NUK")
(45597 . "HANGUL SYLLABLE NUT")
(45598 . "HANGUL SYLLABLE NUP")
(45599 . "HANGUL SYLLABLE NUH")
(45600 . "HANGUL SYLLABLE NWEO")
(45601 . "HANGUL SYLLABLE NWEOG")
(45602 . "HANGUL SYLLABLE NWEOGG")
(45603 . "HANGUL SYLLABLE NWEOGS")
(45604 . "HANGUL SYLLABLE NWEON")
(45605 . "HANGUL SYLLABLE NWEONJ")
(45606 . "HANGUL SYLLABLE NWEONH")
(45607 . "HANGUL SYLLABLE NWEOD")
(45608 . "HANGUL SYLLABLE NWEOL")
(45609 . "HANGUL SYLLABLE NWEOLG")
(45610 . "HANGUL SYLLABLE NWEOLM")
(45611 . "HANGUL SYLLABLE NWEOLB")
(45612 . "HANGUL SYLLABLE NWEOLS")
(45613 . "HANGUL SYLLABLE NWEOLT")
(45614 . "HANGUL SYLLABLE NWEOLP")
(45615 . "HANGUL SYLLABLE NWEOLH")
(45616 . "HANGUL SYLLABLE NWEOM")
(45617 . "HANGUL SYLLABLE NWEOB")
(45618 . "HANGUL SYLLABLE NWEOBS")
(45619 . "HANGUL SYLLABLE NWEOS")
(45620 . "HANGUL SYLLABLE NWEOSS")
(45621 . "HANGUL SYLLABLE NWEONG")
(45622 . "HANGUL SYLLABLE NWEOJ")
(45623 . "HANGUL SYLLABLE NWEOC")
(45624 . "HANGUL SYLLABLE NWEOK")
(45625 . "HANGUL SYLLABLE NWEOT")
(45626 . "HANGUL SYLLABLE NWEOP")
(45627 . "HANGUL SYLLABLE NWEOH")
(45628 . "HANGUL SYLLABLE NWE")
(45629 . "HANGUL SYLLABLE NWEG")
(45630 . "HANGUL SYLLABLE NWEGG")
(45631 . "HANGUL SYLLABLE NWEGS")
(45632 . "HANGUL SYLLABLE NWEN")
(45633 . "HANGUL SYLLABLE NWENJ")
(45634 . "HANGUL SYLLABLE NWENH")
(45635 . "HANGUL SYLLABLE NWED")
(45636 . "HANGUL SYLLABLE NWEL")
(45637 . "HANGUL SYLLABLE NWELG")
(45638 . "HANGUL SYLLABLE NWELM")
(45639 . "HANGUL SYLLABLE NWELB")
(45640 . "HANGUL SYLLABLE NWELS")
(45641 . "HANGUL SYLLABLE NWELT")
(45642 . "HANGUL SYLLABLE NWELP")
(45643 . "HANGUL SYLLABLE NWELH")
(45644 . "HANGUL SYLLABLE NWEM")
(45645 . "HANGUL SYLLABLE NWEB")
(45646 . "HANGUL SYLLABLE NWEBS")
(45647 . "HANGUL SYLLABLE NWES")
(45648 . "HANGUL SYLLABLE NWESS")
(45649 . "HANGUL SYLLABLE NWENG")
(45650 . "HANGUL SYLLABLE NWEJ")
(45651 . "HANGUL SYLLABLE NWEC")
(45652 . "HANGUL SYLLABLE NWEK")
(45653 . "HANGUL SYLLABLE NWET")
(45654 . "HANGUL SYLLABLE NWEP")
(45655 . "HANGUL SYLLABLE NWEH")
(45656 . "HANGUL SYLLABLE NWI")
(45657 . "HANGUL SYLLABLE NWIG")
(45658 . "HANGUL SYLLABLE NWIGG")
(45659 . "HANGUL SYLLABLE NWIGS")
(45660 . "HANGUL SYLLABLE NWIN")
(45661 . "HANGUL SYLLABLE NWINJ")
(45662 . "HANGUL SYLLABLE NWINH")
(45663 . "HANGUL SYLLABLE NWID")
(45664 . "HANGUL SYLLABLE NWIL")
(45665 . "HANGUL SYLLABLE NWILG")
(45666 . "HANGUL SYLLABLE NWILM")
(45667 . "HANGUL SYLLABLE NWILB")
(45668 . "HANGUL SYLLABLE NWILS")
(45669 . "HANGUL SYLLABLE NWILT")
(45670 . "HANGUL SYLLABLE NWILP")
(45671 . "HANGUL SYLLABLE NWILH")
(45672 . "HANGUL SYLLABLE NWIM")
(45673 . "HANGUL SYLLABLE NWIB")
(45674 . "HANGUL SYLLABLE NWIBS")
(45675 . "HANGUL SYLLABLE NWIS")
(45676 . "HANGUL SYLLABLE NWISS")
(45677 . "HANGUL SYLLABLE NWING")
(45678 . "HANGUL SYLLABLE NWIJ")
(45679 . "HANGUL SYLLABLE NWIC")
(45680 . "HANGUL SYLLABLE NWIK")
(45681 . "HANGUL SYLLABLE NWIT")
(45682 . "HANGUL SYLLABLE NWIP")
(45683 . "HANGUL SYLLABLE NWIH")
(45684 . "HANGUL SYLLABLE NYU")
(45685 . "HANGUL SYLLABLE NYUG")
(45686 . "HANGUL SYLLABLE NYUGG")
(45687 . "HANGUL SYLLABLE NYUGS")
(45688 . "HANGUL SYLLABLE NYUN")
(45689 . "HANGUL SYLLABLE NYUNJ")
(45690 . "HANGUL SYLLABLE NYUNH")
(45691 . "HANGUL SYLLABLE NYUD")
(45692 . "HANGUL SYLLABLE NYUL")
(45693 . "HANGUL SYLLABLE NYULG")
(45694 . "HANGUL SYLLABLE NYULM")
(45695 . "HANGUL SYLLABLE NYULB")
(45696 . "HANGUL SYLLABLE NYULS")
(45697 . "HANGUL SYLLABLE NYULT")
(45698 . "HANGUL SYLLABLE NYULP")
(45699 . "HANGUL SYLLABLE NYULH")
(45700 . "HANGUL SYLLABLE NYUM")
(45701 . "HANGUL SYLLABLE NYUB")
(45702 . "HANGUL SYLLABLE NYUBS")
(45703 . "HANGUL SYLLABLE NYUS")
(45704 . "HANGUL SYLLABLE NYUSS")
(45705 . "HANGUL SYLLABLE NYUNG")
(45706 . "HANGUL SYLLABLE NYUJ")
(45707 . "HANGUL SYLLABLE NYUC")
(45708 . "HANGUL SYLLABLE NYUK")
(45709 . "HANGUL SYLLABLE NYUT")
(45710 . "HANGUL SYLLABLE NYUP")
(45711 . "HANGUL SYLLABLE NYUH")
(45712 . "HANGUL SYLLABLE NEU")
(45713 . "HANGUL SYLLABLE NEUG")
(45714 . "HANGUL SYLLABLE NEUGG")
(45715 . "HANGUL SYLLABLE NEUGS")
(45716 . "HANGUL SYLLABLE NEUN")
(45717 . "HANGUL SYLLABLE NEUNJ")
(45718 . "HANGUL SYLLABLE NEUNH")
(45719 . "HANGUL SYLLABLE NEUD")
(45720 . "HANGUL SYLLABLE NEUL")
(45721 . "HANGUL SYLLABLE NEULG")
(45722 . "HANGUL SYLLABLE NEULM")
(45723 . "HANGUL SYLLABLE NEULB")
(45724 . "HANGUL SYLLABLE NEULS")
(45725 . "HANGUL SYLLABLE NEULT")
(45726 . "HANGUL SYLLABLE NEULP")
(45727 . "HANGUL SYLLABLE NEULH")
(45728 . "HANGUL SYLLABLE NEUM")
(45729 . "HANGUL SYLLABLE NEUB")
(45730 . "HANGUL SYLLABLE NEUBS")
(45731 . "HANGUL SYLLABLE NEUS")
(45732 . "HANGUL SYLLABLE NEUSS")
(45733 . "HANGUL SYLLABLE NEUNG")
(45734 . "HANGUL SYLLABLE NEUJ")
(45735 . "HANGUL SYLLABLE NEUC")
(45736 . "HANGUL SYLLABLE NEUK")
(45737 . "HANGUL SYLLABLE NEUT")
(45738 . "HANGUL SYLLABLE NEUP")
(45739 . "HANGUL SYLLABLE NEUH")
(45740 . "HANGUL SYLLABLE NYI")
(45741 . "HANGUL SYLLABLE NYIG")
(45742 . "HANGUL SYLLABLE NYIGG")
(45743 . "HANGUL SYLLABLE NYIGS")
(45744 . "HANGUL SYLLABLE NYIN")
(45745 . "HANGUL SYLLABLE NYINJ")
(45746 . "HANGUL SYLLABLE NYINH")
(45747 . "HANGUL SYLLABLE NYID")
(45748 . "HANGUL SYLLABLE NYIL")
(45749 . "HANGUL SYLLABLE NYILG")
(45750 . "HANGUL SYLLABLE NYILM")
(45751 . "HANGUL SYLLABLE NYILB")
(45752 . "HANGUL SYLLABLE NYILS")
(45753 . "HANGUL SYLLABLE NYILT")
(45754 . "HANGUL SYLLABLE NYILP")
(45755 . "HANGUL SYLLABLE NYILH")
(45756 . "HANGUL SYLLABLE NYIM")
(45757 . "HANGUL SYLLABLE NYIB")
(45758 . "HANGUL SYLLABLE NYIBS")
(45759 . "HANGUL SYLLABLE NYIS")
(45760 . "HANGUL SYLLABLE NYISS")
(45761 . "HANGUL SYLLABLE NYING")
(45762 . "HANGUL SYLLABLE NYIJ")
(45763 . "HANGUL SYLLABLE NYIC")
(45764 . "HANGUL SYLLABLE NYIK")
(45765 . "HANGUL SYLLABLE NYIT")
(45766 . "HANGUL SYLLABLE NYIP")
(45767 . "HANGUL SYLLABLE NYIH")
(45768 . "HANGUL SYLLABLE NI")
(45769 . "HANGUL SYLLABLE NIG")
(45770 . "HANGUL SYLLABLE NIGG")
(45771 . "HANGUL SYLLABLE NIGS")
(45772 . "HANGUL SYLLABLE NIN")
(45773 . "HANGUL SYLLABLE NINJ")
(45774 . "HANGUL SYLLABLE NINH")
(45775 . "HANGUL SYLLABLE NID")
(45776 . "HANGUL SYLLABLE NIL")
(45777 . "HANGUL SYLLABLE NILG")
(45778 . "HANGUL SYLLABLE NILM")
(45779 . "HANGUL SYLLABLE NILB")
(45780 . "HANGUL SYLLABLE NILS")
(45781 . "HANGUL SYLLABLE NILT")
(45782 . "HANGUL SYLLABLE NILP")
(45783 . "HANGUL SYLLABLE NILH")
(45784 . "HANGUL SYLLABLE NIM")
(45785 . "HANGUL SYLLABLE NIB")
(45786 . "HANGUL SYLLABLE NIBS")
(45787 . "HANGUL SYLLABLE NIS")
(45788 . "HANGUL SYLLABLE NISS")
(45789 . "HANGUL SYLLABLE NING")
(45790 . "HANGUL SYLLABLE NIJ")
(45791 . "HANGUL SYLLABLE NIC")
(45792 . "HANGUL SYLLABLE NIK")
(45793 . "HANGUL SYLLABLE NIT")
(45794 . "HANGUL SYLLABLE NIP")
(45795 . "HANGUL SYLLABLE NIH")
(45796 . "HANGUL SYLLABLE DA")
(45797 . "HANGUL SYLLABLE DAG")
(45798 . "HANGUL SYLLABLE DAGG")
(45799 . "HANGUL SYLLABLE DAGS")
(45800 . "HANGUL SYLLABLE DAN")
(45801 . "HANGUL SYLLABLE DANJ")
(45802 . "HANGUL SYLLABLE DANH")
(45803 . "HANGUL SYLLABLE DAD")
(45804 . "HANGUL SYLLABLE DAL")
(45805 . "HANGUL SYLLABLE DALG")
(45806 . "HANGUL SYLLABLE DALM")
(45807 . "HANGUL SYLLABLE DALB")
(45808 . "HANGUL SYLLABLE DALS")
(45809 . "HANGUL SYLLABLE DALT")
(45810 . "HANGUL SYLLABLE DALP")
(45811 . "HANGUL SYLLABLE DALH")
(45812 . "HANGUL SYLLABLE DAM")
(45813 . "HANGUL SYLLABLE DAB")
(45814 . "HANGUL SYLLABLE DABS")
(45815 . "HANGUL SYLLABLE DAS")
(45816 . "HANGUL SYLLABLE DASS")
(45817 . "HANGUL SYLLABLE DANG")
(45818 . "HANGUL SYLLABLE DAJ")
(45819 . "HANGUL SYLLABLE DAC")
(45820 . "HANGUL SYLLABLE DAK")
(45821 . "HANGUL SYLLABLE DAT")
(45822 . "HANGUL SYLLABLE DAP")
(45823 . "HANGUL SYLLABLE DAH")
(45824 . "HANGUL SYLLABLE DAE")
(45825 . "HANGUL SYLLABLE DAEG")
(45826 . "HANGUL SYLLABLE DAEGG")
(45827 . "HANGUL SYLLABLE DAEGS")
(45828 . "HANGUL SYLLABLE DAEN")
(45829 . "HANGUL SYLLABLE DAENJ")
(45830 . "HANGUL SYLLABLE DAENH")
(45831 . "HANGUL SYLLABLE DAED")
(45832 . "HANGUL SYLLABLE DAEL")
(45833 . "HANGUL SYLLABLE DAELG")
(45834 . "HANGUL SYLLABLE DAELM")
(45835 . "HANGUL SYLLABLE DAELB")
(45836 . "HANGUL SYLLABLE DAELS")
(45837 . "HANGUL SYLLABLE DAELT")
(45838 . "HANGUL SYLLABLE DAELP")
(45839 . "HANGUL SYLLABLE DAELH")
(45840 . "HANGUL SYLLABLE DAEM")
(45841 . "HANGUL SYLLABLE DAEB")
(45842 . "HANGUL SYLLABLE DAEBS")
(45843 . "HANGUL SYLLABLE DAES")
(45844 . "HANGUL SYLLABLE DAESS")
(45845 . "HANGUL SYLLABLE DAENG")
(45846 . "HANGUL SYLLABLE DAEJ")
(45847 . "HANGUL SYLLABLE DAEC")
(45848 . "HANGUL SYLLABLE DAEK")
(45849 . "HANGUL SYLLABLE DAET")
(45850 . "HANGUL SYLLABLE DAEP")
(45851 . "HANGUL SYLLABLE DAEH")
(45852 . "HANGUL SYLLABLE DYA")
(45853 . "HANGUL SYLLABLE DYAG")
(45854 . "HANGUL SYLLABLE DYAGG")
(45855 . "HANGUL SYLLABLE DYAGS")
(45856 . "HANGUL SYLLABLE DYAN")
(45857 . "HANGUL SYLLABLE DYANJ")
(45858 . "HANGUL SYLLABLE DYANH")
(45859 . "HANGUL SYLLABLE DYAD")
(45860 . "HANGUL SYLLABLE DYAL")
(45861 . "HANGUL SYLLABLE DYALG")
(45862 . "HANGUL SYLLABLE DYALM")
(45863 . "HANGUL SYLLABLE DYALB")
(45864 . "HANGUL SYLLABLE DYALS")
(45865 . "HANGUL SYLLABLE DYALT")
(45866 . "HANGUL SYLLABLE DYALP")
(45867 . "HANGUL SYLLABLE DYALH")
(45868 . "HANGUL SYLLABLE DYAM")
(45869 . "HANGUL SYLLABLE DYAB")
(45870 . "HANGUL SYLLABLE DYABS")
(45871 . "HANGUL SYLLABLE DYAS")
(45872 . "HANGUL SYLLABLE DYASS")
(45873 . "HANGUL SYLLABLE DYANG")
(45874 . "HANGUL SYLLABLE DYAJ")
(45875 . "HANGUL SYLLABLE DYAC")
(45876 . "HANGUL SYLLABLE DYAK")
(45877 . "HANGUL SYLLABLE DYAT")
(45878 . "HANGUL SYLLABLE DYAP")
(45879 . "HANGUL SYLLABLE DYAH")
(45880 . "HANGUL SYLLABLE DYAE")
(45881 . "HANGUL SYLLABLE DYAEG")
(45882 . "HANGUL SYLLABLE DYAEGG")
(45883 . "HANGUL SYLLABLE DYAEGS")
(45884 . "HANGUL SYLLABLE DYAEN")
(45885 . "HANGUL SYLLABLE DYAENJ")
(45886 . "HANGUL SYLLABLE DYAENH")
(45887 . "HANGUL SYLLABLE DYAED")
(45888 . "HANGUL SYLLABLE DYAEL")
(45889 . "HANGUL SYLLABLE DYAELG")
(45890 . "HANGUL SYLLABLE DYAELM")
(45891 . "HANGUL SYLLABLE DYAELB")
(45892 . "HANGUL SYLLABLE DYAELS")
(45893 . "HANGUL SYLLABLE DYAELT")
(45894 . "HANGUL SYLLABLE DYAELP")
(45895 . "HANGUL SYLLABLE DYAELH")
(45896 . "HANGUL SYLLABLE DYAEM")
(45897 . "HANGUL SYLLABLE DYAEB")
(45898 . "HANGUL SYLLABLE DYAEBS")
(45899 . "HANGUL SYLLABLE DYAES")
(45900 . "HANGUL SYLLABLE DYAESS")
(45901 . "HANGUL SYLLABLE DYAENG")
(45902 . "HANGUL SYLLABLE DYAEJ")
(45903 . "HANGUL SYLLABLE DYAEC")
(45904 . "HANGUL SYLLABLE DYAEK")
(45905 . "HANGUL SYLLABLE DYAET")
(45906 . "HANGUL SYLLABLE DYAEP")
(45907 . "HANGUL SYLLABLE DYAEH")
(45908 . "HANGUL SYLLABLE DEO")
(45909 . "HANGUL SYLLABLE DEOG")
(45910 . "HANGUL SYLLABLE DEOGG")
(45911 . "HANGUL SYLLABLE DEOGS")
(45912 . "HANGUL SYLLABLE DEON")
(45913 . "HANGUL SYLLABLE DEONJ")
(45914 . "HANGUL SYLLABLE DEONH")
(45915 . "HANGUL SYLLABLE DEOD")
(45916 . "HANGUL SYLLABLE DEOL")
(45917 . "HANGUL SYLLABLE DEOLG")
(45918 . "HANGUL SYLLABLE DEOLM")
(45919 . "HANGUL SYLLABLE DEOLB")
(45920 . "HANGUL SYLLABLE DEOLS")
(45921 . "HANGUL SYLLABLE DEOLT")
(45922 . "HANGUL SYLLABLE DEOLP")
(45923 . "HANGUL SYLLABLE DEOLH")
(45924 . "HANGUL SYLLABLE DEOM")
(45925 . "HANGUL SYLLABLE DEOB")
(45926 . "HANGUL SYLLABLE DEOBS")
(45927 . "HANGUL SYLLABLE DEOS")
(45928 . "HANGUL SYLLABLE DEOSS")
(45929 . "HANGUL SYLLABLE DEONG")
(45930 . "HANGUL SYLLABLE DEOJ")
(45931 . "HANGUL SYLLABLE DEOC")
(45932 . "HANGUL SYLLABLE DEOK")
(45933 . "HANGUL SYLLABLE DEOT")
(45934 . "HANGUL SYLLABLE DEOP")
(45935 . "HANGUL SYLLABLE DEOH")
(45936 . "HANGUL SYLLABLE DE")
(45937 . "HANGUL SYLLABLE DEG")
(45938 . "HANGUL SYLLABLE DEGG")
(45939 . "HANGUL SYLLABLE DEGS")
(45940 . "HANGUL SYLLABLE DEN")
(45941 . "HANGUL SYLLABLE DENJ")
(45942 . "HANGUL SYLLABLE DENH")
(45943 . "HANGUL SYLLABLE DED")
(45944 . "HANGUL SYLLABLE DEL")
(45945 . "HANGUL SYLLABLE DELG")
(45946 . "HANGUL SYLLABLE DELM")
(45947 . "HANGUL SYLLABLE DELB")
(45948 . "HANGUL SYLLABLE DELS")
(45949 . "HANGUL SYLLABLE DELT")
(45950 . "HANGUL SYLLABLE DELP")
(45951 . "HANGUL SYLLABLE DELH")
(45952 . "HANGUL SYLLABLE DEM")
(45953 . "HANGUL SYLLABLE DEB")
(45954 . "HANGUL SYLLABLE DEBS")
(45955 . "HANGUL SYLLABLE DES")
(45956 . "HANGUL SYLLABLE DESS")
(45957 . "HANGUL SYLLABLE DENG")
(45958 . "HANGUL SYLLABLE DEJ")
(45959 . "HANGUL SYLLABLE DEC")
(45960 . "HANGUL SYLLABLE DEK")
(45961 . "HANGUL SYLLABLE DET")
(45962 . "HANGUL SYLLABLE DEP")
(45963 . "HANGUL SYLLABLE DEH")
(45964 . "HANGUL SYLLABLE DYEO")
(45965 . "HANGUL SYLLABLE DYEOG")
(45966 . "HANGUL SYLLABLE DYEOGG")
(45967 . "HANGUL SYLLABLE DYEOGS")
(45968 . "HANGUL SYLLABLE DYEON")
(45969 . "HANGUL SYLLABLE DYEONJ")
(45970 . "HANGUL SYLLABLE DYEONH")
(45971 . "HANGUL SYLLABLE DYEOD")
(45972 . "HANGUL SYLLABLE DYEOL")
(45973 . "HANGUL SYLLABLE DYEOLG")
(45974 . "HANGUL SYLLABLE DYEOLM")
(45975 . "HANGUL SYLLABLE DYEOLB")
(45976 . "HANGUL SYLLABLE DYEOLS")
(45977 . "HANGUL SYLLABLE DYEOLT")
(45978 . "HANGUL SYLLABLE DYEOLP")
(45979 . "HANGUL SYLLABLE DYEOLH")
(45980 . "HANGUL SYLLABLE DYEOM")
(45981 . "HANGUL SYLLABLE DYEOB")
(45982 . "HANGUL SYLLABLE DYEOBS")
(45983 . "HANGUL SYLLABLE DYEOS")
(45984 . "HANGUL SYLLABLE DYEOSS")
(45985 . "HANGUL SYLLABLE DYEONG")
(45986 . "HANGUL SYLLABLE DYEOJ")
(45987 . "HANGUL SYLLABLE DYEOC")
(45988 . "HANGUL SYLLABLE DYEOK")
(45989 . "HANGUL SYLLABLE DYEOT")
(45990 . "HANGUL SYLLABLE DYEOP")
(45991 . "HANGUL SYLLABLE DYEOH")
(45992 . "HANGUL SYLLABLE DYE")
(45993 . "HANGUL SYLLABLE DYEG")
(45994 . "HANGUL SYLLABLE DYEGG")
(45995 . "HANGUL SYLLABLE DYEGS")
(45996 . "HANGUL SYLLABLE DYEN")
(45997 . "HANGUL SYLLABLE DYENJ")
(45998 . "HANGUL SYLLABLE DYENH")
(45999 . "HANGUL SYLLABLE DYED")
(46000 . "HANGUL SYLLABLE DYEL")
(46001 . "HANGUL SYLLABLE DYELG")
(46002 . "HANGUL SYLLABLE DYELM")
(46003 . "HANGUL SYLLABLE DYELB")
(46004 . "HANGUL SYLLABLE DYELS")
(46005 . "HANGUL SYLLABLE DYELT")
(46006 . "HANGUL SYLLABLE DYELP")
(46007 . "HANGUL SYLLABLE DYELH")
(46008 . "HANGUL SYLLABLE DYEM")
(46009 . "HANGUL SYLLABLE DYEB")
(46010 . "HANGUL SYLLABLE DYEBS")
(46011 . "HANGUL SYLLABLE DYES")
(46012 . "HANGUL SYLLABLE DYESS")
(46013 . "HANGUL SYLLABLE DYENG")
(46014 . "HANGUL SYLLABLE DYEJ")
(46015 . "HANGUL SYLLABLE DYEC")
(46016 . "HANGUL SYLLABLE DYEK")
(46017 . "HANGUL SYLLABLE DYET")
(46018 . "HANGUL SYLLABLE DYEP")
(46019 . "HANGUL SYLLABLE DYEH")
(46020 . "HANGUL SYLLABLE DO")
(46021 . "HANGUL SYLLABLE DOG")
(46022 . "HANGUL SYLLABLE DOGG")
(46023 . "HANGUL SYLLABLE DOGS")
(46024 . "HANGUL SYLLABLE DON")
(46025 . "HANGUL SYLLABLE DONJ")
(46026 . "HANGUL SYLLABLE DONH")
(46027 . "HANGUL SYLLABLE DOD")
(46028 . "HANGUL SYLLABLE DOL")
(46029 . "HANGUL SYLLABLE DOLG")
(46030 . "HANGUL SYLLABLE DOLM")
(46031 . "HANGUL SYLLABLE DOLB")
(46032 . "HANGUL SYLLABLE DOLS")
(46033 . "HANGUL SYLLABLE DOLT")
(46034 . "HANGUL SYLLABLE DOLP")
(46035 . "HANGUL SYLLABLE DOLH")
(46036 . "HANGUL SYLLABLE DOM")
(46037 . "HANGUL SYLLABLE DOB")
(46038 . "HANGUL SYLLABLE DOBS")
(46039 . "HANGUL SYLLABLE DOS")
(46040 . "HANGUL SYLLABLE DOSS")
(46041 . "HANGUL SYLLABLE DONG")
(46042 . "HANGUL SYLLABLE DOJ")
(46043 . "HANGUL SYLLABLE DOC")
(46044 . "HANGUL SYLLABLE DOK")
(46045 . "HANGUL SYLLABLE DOT")
(46046 . "HANGUL SYLLABLE DOP")
(46047 . "HANGUL SYLLABLE DOH")
(46048 . "HANGUL SYLLABLE DWA")
(46049 . "HANGUL SYLLABLE DWAG")
(46050 . "HANGUL SYLLABLE DWAGG")
(46051 . "HANGUL SYLLABLE DWAGS")
(46052 . "HANGUL SYLLABLE DWAN")
(46053 . "HANGUL SYLLABLE DWANJ")
(46054 . "HANGUL SYLLABLE DWANH")
(46055 . "HANGUL SYLLABLE DWAD")
(46056 . "HANGUL SYLLABLE DWAL")
(46057 . "HANGUL SYLLABLE DWALG")
(46058 . "HANGUL SYLLABLE DWALM")
(46059 . "HANGUL SYLLABLE DWALB")
(46060 . "HANGUL SYLLABLE DWALS")
(46061 . "HANGUL SYLLABLE DWALT")
(46062 . "HANGUL SYLLABLE DWALP")
(46063 . "HANGUL SYLLABLE DWALH")
(46064 . "HANGUL SYLLABLE DWAM")
(46065 . "HANGUL SYLLABLE DWAB")
(46066 . "HANGUL SYLLABLE DWABS")
(46067 . "HANGUL SYLLABLE DWAS")
(46068 . "HANGUL SYLLABLE DWASS")
(46069 . "HANGUL SYLLABLE DWANG")
(46070 . "HANGUL SYLLABLE DWAJ")
(46071 . "HANGUL SYLLABLE DWAC")
(46072 . "HANGUL SYLLABLE DWAK")
(46073 . "HANGUL SYLLABLE DWAT")
(46074 . "HANGUL SYLLABLE DWAP")
(46075 . "HANGUL SYLLABLE DWAH")
(46076 . "HANGUL SYLLABLE DWAE")
(46077 . "HANGUL SYLLABLE DWAEG")
(46078 . "HANGUL SYLLABLE DWAEGG")
(46079 . "HANGUL SYLLABLE DWAEGS")
(46080 . "HANGUL SYLLABLE DWAEN")
(46081 . "HANGUL SYLLABLE DWAENJ")
(46082 . "HANGUL SYLLABLE DWAENH")
(46083 . "HANGUL SYLLABLE DWAED")
(46084 . "HANGUL SYLLABLE DWAEL")
(46085 . "HANGUL SYLLABLE DWAELG")
(46086 . "HANGUL SYLLABLE DWAELM")
(46087 . "HANGUL SYLLABLE DWAELB")
(46088 . "HANGUL SYLLABLE DWAELS")
(46089 . "HANGUL SYLLABLE DWAELT")
(46090 . "HANGUL SYLLABLE DWAELP")
(46091 . "HANGUL SYLLABLE DWAELH")
(46092 . "HANGUL SYLLABLE DWAEM")
(46093 . "HANGUL SYLLABLE DWAEB")
(46094 . "HANGUL SYLLABLE DWAEBS")
(46095 . "HANGUL SYLLABLE DWAES")
(46096 . "HANGUL SYLLABLE DWAESS")
(46097 . "HANGUL SYLLABLE DWAENG")
(46098 . "HANGUL SYLLABLE DWAEJ")
(46099 . "HANGUL SYLLABLE DWAEC")
(46100 . "HANGUL SYLLABLE DWAEK")
(46101 . "HANGUL SYLLABLE DWAET")
(46102 . "HANGUL SYLLABLE DWAEP")
(46103 . "HANGUL SYLLABLE DWAEH")
(46104 . "HANGUL SYLLABLE DOE")
(46105 . "HANGUL SYLLABLE DOEG")
(46106 . "HANGUL SYLLABLE DOEGG")
(46107 . "HANGUL SYLLABLE DOEGS")
(46108 . "HANGUL SYLLABLE DOEN")
(46109 . "HANGUL SYLLABLE DOENJ")
(46110 . "HANGUL SYLLABLE DOENH")
(46111 . "HANGUL SYLLABLE DOED")
(46112 . "HANGUL SYLLABLE DOEL")
(46113 . "HANGUL SYLLABLE DOELG")
(46114 . "HANGUL SYLLABLE DOELM")
(46115 . "HANGUL SYLLABLE DOELB")
(46116 . "HANGUL SYLLABLE DOELS")
(46117 . "HANGUL SYLLABLE DOELT")
(46118 . "HANGUL SYLLABLE DOELP")
(46119 . "HANGUL SYLLABLE DOELH")
(46120 . "HANGUL SYLLABLE DOEM")
(46121 . "HANGUL SYLLABLE DOEB")
(46122 . "HANGUL SYLLABLE DOEBS")
(46123 . "HANGUL SYLLABLE DOES")
(46124 . "HANGUL SYLLABLE DOESS")
(46125 . "HANGUL SYLLABLE DOENG")
(46126 . "HANGUL SYLLABLE DOEJ")
(46127 . "HANGUL SYLLABLE DOEC")
(46128 . "HANGUL SYLLABLE DOEK")
(46129 . "HANGUL SYLLABLE DOET")
(46130 . "HANGUL SYLLABLE DOEP")
(46131 . "HANGUL SYLLABLE DOEH")
(46132 . "HANGUL SYLLABLE DYO")
(46133 . "HANGUL SYLLABLE DYOG")
(46134 . "HANGUL SYLLABLE DYOGG")
(46135 . "HANGUL SYLLABLE DYOGS")
(46136 . "HANGUL SYLLABLE DYON")
(46137 . "HANGUL SYLLABLE DYONJ")
(46138 . "HANGUL SYLLABLE DYONH")
(46139 . "HANGUL SYLLABLE DYOD")
(46140 . "HANGUL SYLLABLE DYOL")
(46141 . "HANGUL SYLLABLE DYOLG")
(46142 . "HANGUL SYLLABLE DYOLM")
(46143 . "HANGUL SYLLABLE DYOLB")
(46144 . "HANGUL SYLLABLE DYOLS")
(46145 . "HANGUL SYLLABLE DYOLT")
(46146 . "HANGUL SYLLABLE DYOLP")
(46147 . "HANGUL SYLLABLE DYOLH")
(46148 . "HANGUL SYLLABLE DYOM")
(46149 . "HANGUL SYLLABLE DYOB")
(46150 . "HANGUL SYLLABLE DYOBS")
(46151 . "HANGUL SYLLABLE DYOS")
(46152 . "HANGUL SYLLABLE DYOSS")
(46153 . "HANGUL SYLLABLE DYONG")
(46154 . "HANGUL SYLLABLE DYOJ")
(46155 . "HANGUL SYLLABLE DYOC")
(46156 . "HANGUL SYLLABLE DYOK")
(46157 . "HANGUL SYLLABLE DYOT")
(46158 . "HANGUL SYLLABLE DYOP")
(46159 . "HANGUL SYLLABLE DYOH")
(46160 . "HANGUL SYLLABLE DU")
(46161 . "HANGUL SYLLABLE DUG")
(46162 . "HANGUL SYLLABLE DUGG")
(46163 . "HANGUL SYLLABLE DUGS")
(46164 . "HANGUL SYLLABLE DUN")
(46165 . "HANGUL SYLLABLE DUNJ")
(46166 . "HANGUL SYLLABLE DUNH")
(46167 . "HANGUL SYLLABLE DUD")
(46168 . "HANGUL SYLLABLE DUL")
(46169 . "HANGUL SYLLABLE DULG")
(46170 . "HANGUL SYLLABLE DULM")
(46171 . "HANGUL SYLLABLE DULB")
(46172 . "HANGUL SYLLABLE DULS")
(46173 . "HANGUL SYLLABLE DULT")
(46174 . "HANGUL SYLLABLE DULP")
(46175 . "HANGUL SYLLABLE DULH")
(46176 . "HANGUL SYLLABLE DUM")
(46177 . "HANGUL SYLLABLE DUB")
(46178 . "HANGUL SYLLABLE DUBS")
(46179 . "HANGUL SYLLABLE DUS")
(46180 . "HANGUL SYLLABLE DUSS")
(46181 . "HANGUL SYLLABLE DUNG")
(46182 . "HANGUL SYLLABLE DUJ")
(46183 . "HANGUL SYLLABLE DUC")
(46184 . "HANGUL SYLLABLE DUK")
(46185 . "HANGUL SYLLABLE DUT")
(46186 . "HANGUL SYLLABLE DUP")
(46187 . "HANGUL SYLLABLE DUH")
(46188 . "HANGUL SYLLABLE DWEO")
(46189 . "HANGUL SYLLABLE DWEOG")
(46190 . "HANGUL SYLLABLE DWEOGG")
(46191 . "HANGUL SYLLABLE DWEOGS")
(46192 . "HANGUL SYLLABLE DWEON")
(46193 . "HANGUL SYLLABLE DWEONJ")
(46194 . "HANGUL SYLLABLE DWEONH")
(46195 . "HANGUL SYLLABLE DWEOD")
(46196 . "HANGUL SYLLABLE DWEOL")
(46197 . "HANGUL SYLLABLE DWEOLG")
(46198 . "HANGUL SYLLABLE DWEOLM")
(46199 . "HANGUL SYLLABLE DWEOLB")
(46200 . "HANGUL SYLLABLE DWEOLS")
(46201 . "HANGUL SYLLABLE DWEOLT")
(46202 . "HANGUL SYLLABLE DWEOLP")
(46203 . "HANGUL SYLLABLE DWEOLH")
(46204 . "HANGUL SYLLABLE DWEOM")
(46205 . "HANGUL SYLLABLE DWEOB")
(46206 . "HANGUL SYLLABLE DWEOBS")
(46207 . "HANGUL SYLLABLE DWEOS")
(46208 . "HANGUL SYLLABLE DWEOSS")
(46209 . "HANGUL SYLLABLE DWEONG")
(46210 . "HANGUL SYLLABLE DWEOJ")
(46211 . "HANGUL SYLLABLE DWEOC")
(46212 . "HANGUL SYLLABLE DWEOK")
(46213 . "HANGUL SYLLABLE DWEOT")
(46214 . "HANGUL SYLLABLE DWEOP")
(46215 . "HANGUL SYLLABLE DWEOH")
(46216 . "HANGUL SYLLABLE DWE")
(46217 . "HANGUL SYLLABLE DWEG")
(46218 . "HANGUL SYLLABLE DWEGG")
(46219 . "HANGUL SYLLABLE DWEGS")
(46220 . "HANGUL SYLLABLE DWEN")
(46221 . "HANGUL SYLLABLE DWENJ")
(46222 . "HANGUL SYLLABLE DWENH")
(46223 . "HANGUL SYLLABLE DWED")
(46224 . "HANGUL SYLLABLE DWEL")
(46225 . "HANGUL SYLLABLE DWELG")
(46226 . "HANGUL SYLLABLE DWELM")
(46227 . "HANGUL SYLLABLE DWELB")
(46228 . "HANGUL SYLLABLE DWELS")
(46229 . "HANGUL SYLLABLE DWELT")
(46230 . "HANGUL SYLLABLE DWELP")
(46231 . "HANGUL SYLLABLE DWELH")
(46232 . "HANGUL SYLLABLE DWEM")
(46233 . "HANGUL SYLLABLE DWEB")
(46234 . "HANGUL SYLLABLE DWEBS")
(46235 . "HANGUL SYLLABLE DWES")
(46236 . "HANGUL SYLLABLE DWESS")
(46237 . "HANGUL SYLLABLE DWENG")
(46238 . "HANGUL SYLLABLE DWEJ")
(46239 . "HANGUL SYLLABLE DWEC")
(46240 . "HANGUL SYLLABLE DWEK")
(46241 . "HANGUL SYLLABLE DWET")
(46242 . "HANGUL SYLLABLE DWEP")
(46243 . "HANGUL SYLLABLE DWEH")
(46244 . "HANGUL SYLLABLE DWI")
(46245 . "HANGUL SYLLABLE DWIG")
(46246 . "HANGUL SYLLABLE DWIGG")
(46247 . "HANGUL SYLLABLE DWIGS")
(46248 . "HANGUL SYLLABLE DWIN")
(46249 . "HANGUL SYLLABLE DWINJ")
(46250 . "HANGUL SYLLABLE DWINH")
(46251 . "HANGUL SYLLABLE DWID")
(46252 . "HANGUL SYLLABLE DWIL")
(46253 . "HANGUL SYLLABLE DWILG")
(46254 . "HANGUL SYLLABLE DWILM")
(46255 . "HANGUL SYLLABLE DWILB")
(46256 . "HANGUL SYLLABLE DWILS")
(46257 . "HANGUL SYLLABLE DWILT")
(46258 . "HANGUL SYLLABLE DWILP")
(46259 . "HANGUL SYLLABLE DWILH")
(46260 . "HANGUL SYLLABLE DWIM")
(46261 . "HANGUL SYLLABLE DWIB")
(46262 . "HANGUL SYLLABLE DWIBS")
(46263 . "HANGUL SYLLABLE DWIS")
(46264 . "HANGUL SYLLABLE DWISS")
(46265 . "HANGUL SYLLABLE DWING")
(46266 . "HANGUL SYLLABLE DWIJ")
(46267 . "HANGUL SYLLABLE DWIC")
(46268 . "HANGUL SYLLABLE DWIK")
(46269 . "HANGUL SYLLABLE DWIT")
(46270 . "HANGUL SYLLABLE DWIP")
(46271 . "HANGUL SYLLABLE DWIH")
(46272 . "HANGUL SYLLABLE DYU")
(46273 . "HANGUL SYLLABLE DYUG")
(46274 . "HANGUL SYLLABLE DYUGG")
(46275 . "HANGUL SYLLABLE DYUGS")
(46276 . "HANGUL SYLLABLE DYUN")
(46277 . "HANGUL SYLLABLE DYUNJ")
(46278 . "HANGUL SYLLABLE DYUNH")
(46279 . "HANGUL SYLLABLE DYUD")
(46280 . "HANGUL SYLLABLE DYUL")
(46281 . "HANGUL SYLLABLE DYULG")
(46282 . "HANGUL SYLLABLE DYULM")
(46283 . "HANGUL SYLLABLE DYULB")
(46284 . "HANGUL SYLLABLE DYULS")
(46285 . "HANGUL SYLLABLE DYULT")
(46286 . "HANGUL SYLLABLE DYULP")
(46287 . "HANGUL SYLLABLE DYULH")
(46288 . "HANGUL SYLLABLE DYUM")
(46289 . "HANGUL SYLLABLE DYUB")
(46290 . "HANGUL SYLLABLE DYUBS")
(46291 . "HANGUL SYLLABLE DYUS")
(46292 . "HANGUL SYLLABLE DYUSS")
(46293 . "HANGUL SYLLABLE DYUNG")
(46294 . "HANGUL SYLLABLE DYUJ")
(46295 . "HANGUL SYLLABLE DYUC")
(46296 . "HANGUL SYLLABLE DYUK")
(46297 . "HANGUL SYLLABLE DYUT")
(46298 . "HANGUL SYLLABLE DYUP")
(46299 . "HANGUL SYLLABLE DYUH")
(46300 . "HANGUL SYLLABLE DEU")
(46301 . "HANGUL SYLLABLE DEUG")
(46302 . "HANGUL SYLLABLE DEUGG")
(46303 . "HANGUL SYLLABLE DEUGS")
(46304 . "HANGUL SYLLABLE DEUN")
(46305 . "HANGUL SYLLABLE DEUNJ")
(46306 . "HANGUL SYLLABLE DEUNH")
(46307 . "HANGUL SYLLABLE DEUD")
(46308 . "HANGUL SYLLABLE DEUL")
(46309 . "HANGUL SYLLABLE DEULG")
(46310 . "HANGUL SYLLABLE DEULM")
(46311 . "HANGUL SYLLABLE DEULB")
(46312 . "HANGUL SYLLABLE DEULS")
(46313 . "HANGUL SYLLABLE DEULT")
(46314 . "HANGUL SYLLABLE DEULP")
(46315 . "HANGUL SYLLABLE DEULH")
(46316 . "HANGUL SYLLABLE DEUM")
(46317 . "HANGUL SYLLABLE DEUB")
(46318 . "HANGUL SYLLABLE DEUBS")
(46319 . "HANGUL SYLLABLE DEUS")
(46320 . "HANGUL SYLLABLE DEUSS")
(46321 . "HANGUL SYLLABLE DEUNG")
(46322 . "HANGUL SYLLABLE DEUJ")
(46323 . "HANGUL SYLLABLE DEUC")
(46324 . "HANGUL SYLLABLE DEUK")
(46325 . "HANGUL SYLLABLE DEUT")
(46326 . "HANGUL SYLLABLE DEUP")
(46327 . "HANGUL SYLLABLE DEUH")
(46328 . "HANGUL SYLLABLE DYI")
(46329 . "HANGUL SYLLABLE DYIG")
(46330 . "HANGUL SYLLABLE DYIGG")
(46331 . "HANGUL SYLLABLE DYIGS")
(46332 . "HANGUL SYLLABLE DYIN")
(46333 . "HANGUL SYLLABLE DYINJ")
(46334 . "HANGUL SYLLABLE DYINH")
(46335 . "HANGUL SYLLABLE DYID")
(46336 . "HANGUL SYLLABLE DYIL")
(46337 . "HANGUL SYLLABLE DYILG")
(46338 . "HANGUL SYLLABLE DYILM")
(46339 . "HANGUL SYLLABLE DYILB")
(46340 . "HANGUL SYLLABLE DYILS")
(46341 . "HANGUL SYLLABLE DYILT")
(46342 . "HANGUL SYLLABLE DYILP")
(46343 . "HANGUL SYLLABLE DYILH")
(46344 . "HANGUL SYLLABLE DYIM")
(46345 . "HANGUL SYLLABLE DYIB")
(46346 . "HANGUL SYLLABLE DYIBS")
(46347 . "HANGUL SYLLABLE DYIS")
(46348 . "HANGUL SYLLABLE DYISS")
(46349 . "HANGUL SYLLABLE DYING")
(46350 . "HANGUL SYLLABLE DYIJ")
(46351 . "HANGUL SYLLABLE DYIC")
(46352 . "HANGUL SYLLABLE DYIK")
(46353 . "HANGUL SYLLABLE DYIT")
(46354 . "HANGUL SYLLABLE DYIP")
(46355 . "HANGUL SYLLABLE DYIH")
(46356 . "HANGUL SYLLABLE DI")
(46357 . "HANGUL SYLLABLE DIG")
(46358 . "HANGUL SYLLABLE DIGG")
(46359 . "HANGUL SYLLABLE DIGS")
(46360 . "HANGUL SYLLABLE DIN")
(46361 . "HANGUL SYLLABLE DINJ")
(46362 . "HANGUL SYLLABLE DINH")
(46363 . "HANGUL SYLLABLE DID")
(46364 . "HANGUL SYLLABLE DIL")
(46365 . "HANGUL SYLLABLE DILG")
(46366 . "HANGUL SYLLABLE DILM")
(46367 . "HANGUL SYLLABLE DILB")
(46368 . "HANGUL SYLLABLE DILS")
(46369 . "HANGUL SYLLABLE DILT")
(46370 . "HANGUL SYLLABLE DILP")
(46371 . "HANGUL SYLLABLE DILH")
(46372 . "HANGUL SYLLABLE DIM")
(46373 . "HANGUL SYLLABLE DIB")
(46374 . "HANGUL SYLLABLE DIBS")
(46375 . "HANGUL SYLLABLE DIS")
(46376 . "HANGUL SYLLABLE DISS")
(46377 . "HANGUL SYLLABLE DING")
(46378 . "HANGUL SYLLABLE DIJ")
(46379 . "HANGUL SYLLABLE DIC")
(46380 . "HANGUL SYLLABLE DIK")
(46381 . "HANGUL SYLLABLE DIT")
(46382 . "HANGUL SYLLABLE DIP")
(46383 . "HANGUL SYLLABLE DIH")
(46384 . "HANGUL SYLLABLE DDA")
(46385 . "HANGUL SYLLABLE DDAG")
(46386 . "HANGUL SYLLABLE DDAGG")
(46387 . "HANGUL SYLLABLE DDAGS")
(46388 . "HANGUL SYLLABLE DDAN")
(46389 . "HANGUL SYLLABLE DDANJ")
(46390 . "HANGUL SYLLABLE DDANH")
(46391 . "HANGUL SYLLABLE DDAD")
(46392 . "HANGUL SYLLABLE DDAL")
(46393 . "HANGUL SYLLABLE DDALG")
(46394 . "HANGUL SYLLABLE DDALM")
(46395 . "HANGUL SYLLABLE DDALB")
(46396 . "HANGUL SYLLABLE DDALS")
(46397 . "HANGUL SYLLABLE DDALT")
(46398 . "HANGUL SYLLABLE DDALP")
(46399 . "HANGUL SYLLABLE DDALH")
(46400 . "HANGUL SYLLABLE DDAM")
(46401 . "HANGUL SYLLABLE DDAB")
(46402 . "HANGUL SYLLABLE DDABS")
(46403 . "HANGUL SYLLABLE DDAS")
(46404 . "HANGUL SYLLABLE DDASS")
(46405 . "HANGUL SYLLABLE DDANG")
(46406 . "HANGUL SYLLABLE DDAJ")
(46407 . "HANGUL SYLLABLE DDAC")
(46408 . "HANGUL SYLLABLE DDAK")
(46409 . "HANGUL SYLLABLE DDAT")
(46410 . "HANGUL SYLLABLE DDAP")
(46411 . "HANGUL SYLLABLE DDAH")
(46412 . "HANGUL SYLLABLE DDAE")
(46413 . "HANGUL SYLLABLE DDAEG")
(46414 . "HANGUL SYLLABLE DDAEGG")
(46415 . "HANGUL SYLLABLE DDAEGS")
(46416 . "HANGUL SYLLABLE DDAEN")
(46417 . "HANGUL SYLLABLE DDAENJ")
(46418 . "HANGUL SYLLABLE DDAENH")
(46419 . "HANGUL SYLLABLE DDAED")
(46420 . "HANGUL SYLLABLE DDAEL")
(46421 . "HANGUL SYLLABLE DDAELG")
(46422 . "HANGUL SYLLABLE DDAELM")
(46423 . "HANGUL SYLLABLE DDAELB")
(46424 . "HANGUL SYLLABLE DDAELS")
(46425 . "HANGUL SYLLABLE DDAELT")
(46426 . "HANGUL SYLLABLE DDAELP")
(46427 . "HANGUL SYLLABLE DDAELH")
(46428 . "HANGUL SYLLABLE DDAEM")
(46429 . "HANGUL SYLLABLE DDAEB")
(46430 . "HANGUL SYLLABLE DDAEBS")
(46431 . "HANGUL SYLLABLE DDAES")
(46432 . "HANGUL SYLLABLE DDAESS")
(46433 . "HANGUL SYLLABLE DDAENG")
(46434 . "HANGUL SYLLABLE DDAEJ")
(46435 . "HANGUL SYLLABLE DDAEC")
(46436 . "HANGUL SYLLABLE DDAEK")
(46437 . "HANGUL SYLLABLE DDAET")
(46438 . "HANGUL SYLLABLE DDAEP")
(46439 . "HANGUL SYLLABLE DDAEH")
(46440 . "HANGUL SYLLABLE DDYA")
(46441 . "HANGUL SYLLABLE DDYAG")
(46442 . "HANGUL SYLLABLE DDYAGG")
(46443 . "HANGUL SYLLABLE DDYAGS")
(46444 . "HANGUL SYLLABLE DDYAN")
(46445 . "HANGUL SYLLABLE DDYANJ")
(46446 . "HANGUL SYLLABLE DDYANH")
(46447 . "HANGUL SYLLABLE DDYAD")
(46448 . "HANGUL SYLLABLE DDYAL")
(46449 . "HANGUL SYLLABLE DDYALG")
(46450 . "HANGUL SYLLABLE DDYALM")
(46451 . "HANGUL SYLLABLE DDYALB")
(46452 . "HANGUL SYLLABLE DDYALS")
(46453 . "HANGUL SYLLABLE DDYALT")
(46454 . "HANGUL SYLLABLE DDYALP")
(46455 . "HANGUL SYLLABLE DDYALH")
(46456 . "HANGUL SYLLABLE DDYAM")
(46457 . "HANGUL SYLLABLE DDYAB")
(46458 . "HANGUL SYLLABLE DDYABS")
(46459 . "HANGUL SYLLABLE DDYAS")
(46460 . "HANGUL SYLLABLE DDYASS")
(46461 . "HANGUL SYLLABLE DDYANG")
(46462 . "HANGUL SYLLABLE DDYAJ")
(46463 . "HANGUL SYLLABLE DDYAC")
(46464 . "HANGUL SYLLABLE DDYAK")
(46465 . "HANGUL SYLLABLE DDYAT")
(46466 . "HANGUL SYLLABLE DDYAP")
(46467 . "HANGUL SYLLABLE DDYAH")
(46468 . "HANGUL SYLLABLE DDYAE")
(46469 . "HANGUL SYLLABLE DDYAEG")
(46470 . "HANGUL SYLLABLE DDYAEGG")
(46471 . "HANGUL SYLLABLE DDYAEGS")
(46472 . "HANGUL SYLLABLE DDYAEN")
(46473 . "HANGUL SYLLABLE DDYAENJ")
(46474 . "HANGUL SYLLABLE DDYAENH")
(46475 . "HANGUL SYLLABLE DDYAED")
(46476 . "HANGUL SYLLABLE DDYAEL")
(46477 . "HANGUL SYLLABLE DDYAELG")
(46478 . "HANGUL SYLLABLE DDYAELM")
(46479 . "HANGUL SYLLABLE DDYAELB")
(46480 . "HANGUL SYLLABLE DDYAELS")
(46481 . "HANGUL SYLLABLE DDYAELT")
(46482 . "HANGUL SYLLABLE DDYAELP")
(46483 . "HANGUL SYLLABLE DDYAELH")
(46484 . "HANGUL SYLLABLE DDYAEM")
(46485 . "HANGUL SYLLABLE DDYAEB")
(46486 . "HANGUL SYLLABLE DDYAEBS")
(46487 . "HANGUL SYLLABLE DDYAES")
(46488 . "HANGUL SYLLABLE DDYAESS")
(46489 . "HANGUL SYLLABLE DDYAENG")
(46490 . "HANGUL SYLLABLE DDYAEJ")
(46491 . "HANGUL SYLLABLE DDYAEC")
(46492 . "HANGUL SYLLABLE DDYAEK")
(46493 . "HANGUL SYLLABLE DDYAET")
(46494 . "HANGUL SYLLABLE DDYAEP")
(46495 . "HANGUL SYLLABLE DDYAEH")
(46496 . "HANGUL SYLLABLE DDEO")
(46497 . "HANGUL SYLLABLE DDEOG")
(46498 . "HANGUL SYLLABLE DDEOGG")
(46499 . "HANGUL SYLLABLE DDEOGS")
(46500 . "HANGUL SYLLABLE DDEON")
(46501 . "HANGUL SYLLABLE DDEONJ")
(46502 . "HANGUL SYLLABLE DDEONH")
(46503 . "HANGUL SYLLABLE DDEOD")
(46504 . "HANGUL SYLLABLE DDEOL")
(46505 . "HANGUL SYLLABLE DDEOLG")
(46506 . "HANGUL SYLLABLE DDEOLM")
(46507 . "HANGUL SYLLABLE DDEOLB")
(46508 . "HANGUL SYLLABLE DDEOLS")
(46509 . "HANGUL SYLLABLE DDEOLT")
(46510 . "HANGUL SYLLABLE DDEOLP")
(46511 . "HANGUL SYLLABLE DDEOLH")
(46512 . "HANGUL SYLLABLE DDEOM")
(46513 . "HANGUL SYLLABLE DDEOB")
(46514 . "HANGUL SYLLABLE DDEOBS")
(46515 . "HANGUL SYLLABLE DDEOS")
(46516 . "HANGUL SYLLABLE DDEOSS")
(46517 . "HANGUL SYLLABLE DDEONG")
(46518 . "HANGUL SYLLABLE DDEOJ")
(46519 . "HANGUL SYLLABLE DDEOC")
(46520 . "HANGUL SYLLABLE DDEOK")
(46521 . "HANGUL SYLLABLE DDEOT")
(46522 . "HANGUL SYLLABLE DDEOP")
(46523 . "HANGUL SYLLABLE DDEOH")
(46524 . "HANGUL SYLLABLE DDE")
(46525 . "HANGUL SYLLABLE DDEG")
(46526 . "HANGUL SYLLABLE DDEGG")
(46527 . "HANGUL SYLLABLE DDEGS")
(46528 . "HANGUL SYLLABLE DDEN")
(46529 . "HANGUL SYLLABLE DDENJ")
(46530 . "HANGUL SYLLABLE DDENH")
(46531 . "HANGUL SYLLABLE DDED")
(46532 . "HANGUL SYLLABLE DDEL")
(46533 . "HANGUL SYLLABLE DDELG")
(46534 . "HANGUL SYLLABLE DDELM")
(46535 . "HANGUL SYLLABLE DDELB")
(46536 . "HANGUL SYLLABLE DDELS")
(46537 . "HANGUL SYLLABLE DDELT")
(46538 . "HANGUL SYLLABLE DDELP")
(46539 . "HANGUL SYLLABLE DDELH")
(46540 . "HANGUL SYLLABLE DDEM")
(46541 . "HANGUL SYLLABLE DDEB")
(46542 . "HANGUL SYLLABLE DDEBS")
(46543 . "HANGUL SYLLABLE DDES")
(46544 . "HANGUL SYLLABLE DDESS")
(46545 . "HANGUL SYLLABLE DDENG")
(46546 . "HANGUL SYLLABLE DDEJ")
(46547 . "HANGUL SYLLABLE DDEC")
(46548 . "HANGUL SYLLABLE DDEK")
(46549 . "HANGUL SYLLABLE DDET")
(46550 . "HANGUL SYLLABLE DDEP")
(46551 . "HANGUL SYLLABLE DDEH")
(46552 . "HANGUL SYLLABLE DDYEO")
(46553 . "HANGUL SYLLABLE DDYEOG")
(46554 . "HANGUL SYLLABLE DDYEOGG")
(46555 . "HANGUL SYLLABLE DDYEOGS")
(46556 . "HANGUL SYLLABLE DDYEON")
(46557 . "HANGUL SYLLABLE DDYEONJ")
(46558 . "HANGUL SYLLABLE DDYEONH")
(46559 . "HANGUL SYLLABLE DDYEOD")
(46560 . "HANGUL SYLLABLE DDYEOL")
(46561 . "HANGUL SYLLABLE DDYEOLG")
(46562 . "HANGUL SYLLABLE DDYEOLM")
(46563 . "HANGUL SYLLABLE DDYEOLB")
(46564 . "HANGUL SYLLABLE DDYEOLS")
(46565 . "HANGUL SYLLABLE DDYEOLT")
(46566 . "HANGUL SYLLABLE DDYEOLP")
(46567 . "HANGUL SYLLABLE DDYEOLH")
(46568 . "HANGUL SYLLABLE DDYEOM")
(46569 . "HANGUL SYLLABLE DDYEOB")
(46570 . "HANGUL SYLLABLE DDYEOBS")
(46571 . "HANGUL SYLLABLE DDYEOS")
(46572 . "HANGUL SYLLABLE DDYEOSS")
(46573 . "HANGUL SYLLABLE DDYEONG")
(46574 . "HANGUL SYLLABLE DDYEOJ")
(46575 . "HANGUL SYLLABLE DDYEOC")
(46576 . "HANGUL SYLLABLE DDYEOK")
(46577 . "HANGUL SYLLABLE DDYEOT")
(46578 . "HANGUL SYLLABLE DDYEOP")
(46579 . "HANGUL SYLLABLE DDYEOH")
(46580 . "HANGUL SYLLABLE DDYE")
(46581 . "HANGUL SYLLABLE DDYEG")
(46582 . "HANGUL SYLLABLE DDYEGG")
(46583 . "HANGUL SYLLABLE DDYEGS")
(46584 . "HANGUL SYLLABLE DDYEN")
(46585 . "HANGUL SYLLABLE DDYENJ")
(46586 . "HANGUL SYLLABLE DDYENH")
(46587 . "HANGUL SYLLABLE DDYED")
(46588 . "HANGUL SYLLABLE DDYEL")
(46589 . "HANGUL SYLLABLE DDYELG")
(46590 . "HANGUL SYLLABLE DDYELM")
(46591 . "HANGUL SYLLABLE DDYELB")
(46592 . "HANGUL SYLLABLE DDYELS")
(46593 . "HANGUL SYLLABLE DDYELT")
(46594 . "HANGUL SYLLABLE DDYELP")
(46595 . "HANGUL SYLLABLE DDYELH")
(46596 . "HANGUL SYLLABLE DDYEM")
(46597 . "HANGUL SYLLABLE DDYEB")
(46598 . "HANGUL SYLLABLE DDYEBS")
(46599 . "HANGUL SYLLABLE DDYES")
(46600 . "HANGUL SYLLABLE DDYESS")
(46601 . "HANGUL SYLLABLE DDYENG")
(46602 . "HANGUL SYLLABLE DDYEJ")
(46603 . "HANGUL SYLLABLE DDYEC")
(46604 . "HANGUL SYLLABLE DDYEK")
(46605 . "HANGUL SYLLABLE DDYET")
(46606 . "HANGUL SYLLABLE DDYEP")
(46607 . "HANGUL SYLLABLE DDYEH")
(46608 . "HANGUL SYLLABLE DDO")
(46609 . "HANGUL SYLLABLE DDOG")
(46610 . "HANGUL SYLLABLE DDOGG")
(46611 . "HANGUL SYLLABLE DDOGS")
(46612 . "HANGUL SYLLABLE DDON")
(46613 . "HANGUL SYLLABLE DDONJ")
(46614 . "HANGUL SYLLABLE DDONH")
(46615 . "HANGUL SYLLABLE DDOD")
(46616 . "HANGUL SYLLABLE DDOL")
(46617 . "HANGUL SYLLABLE DDOLG")
(46618 . "HANGUL SYLLABLE DDOLM")
(46619 . "HANGUL SYLLABLE DDOLB")
(46620 . "HANGUL SYLLABLE DDOLS")
(46621 . "HANGUL SYLLABLE DDOLT")
(46622 . "HANGUL SYLLABLE DDOLP")
(46623 . "HANGUL SYLLABLE DDOLH")
(46624 . "HANGUL SYLLABLE DDOM")
(46625 . "HANGUL SYLLABLE DDOB")
(46626 . "HANGUL SYLLABLE DDOBS")
(46627 . "HANGUL SYLLABLE DDOS")
(46628 . "HANGUL SYLLABLE DDOSS")
(46629 . "HANGUL SYLLABLE DDONG")
(46630 . "HANGUL SYLLABLE DDOJ")
(46631 . "HANGUL SYLLABLE DDOC")
(46632 . "HANGUL SYLLABLE DDOK")
(46633 . "HANGUL SYLLABLE DDOT")
(46634 . "HANGUL SYLLABLE DDOP")
(46635 . "HANGUL SYLLABLE DDOH")
(46636 . "HANGUL SYLLABLE DDWA")
(46637 . "HANGUL SYLLABLE DDWAG")
(46638 . "HANGUL SYLLABLE DDWAGG")
(46639 . "HANGUL SYLLABLE DDWAGS")
(46640 . "HANGUL SYLLABLE DDWAN")
(46641 . "HANGUL SYLLABLE DDWANJ")
(46642 . "HANGUL SYLLABLE DDWANH")
(46643 . "HANGUL SYLLABLE DDWAD")
(46644 . "HANGUL SYLLABLE DDWAL")
(46645 . "HANGUL SYLLABLE DDWALG")
(46646 . "HANGUL SYLLABLE DDWALM")
(46647 . "HANGUL SYLLABLE DDWALB")
(46648 . "HANGUL SYLLABLE DDWALS")
(46649 . "HANGUL SYLLABLE DDWALT")
(46650 . "HANGUL SYLLABLE DDWALP")
(46651 . "HANGUL SYLLABLE DDWALH")
(46652 . "HANGUL SYLLABLE DDWAM")
(46653 . "HANGUL SYLLABLE DDWAB")
(46654 . "HANGUL SYLLABLE DDWABS")
(46655 . "HANGUL SYLLABLE DDWAS")
(46656 . "HANGUL SYLLABLE DDWASS")
(46657 . "HANGUL SYLLABLE DDWANG")
(46658 . "HANGUL SYLLABLE DDWAJ")
(46659 . "HANGUL SYLLABLE DDWAC")
(46660 . "HANGUL SYLLABLE DDWAK")
(46661 . "HANGUL SYLLABLE DDWAT")
(46662 . "HANGUL SYLLABLE DDWAP")
(46663 . "HANGUL SYLLABLE DDWAH")
(46664 . "HANGUL SYLLABLE DDWAE")
(46665 . "HANGUL SYLLABLE DDWAEG")
(46666 . "HANGUL SYLLABLE DDWAEGG")
(46667 . "HANGUL SYLLABLE DDWAEGS")
(46668 . "HANGUL SYLLABLE DDWAEN")
(46669 . "HANGUL SYLLABLE DDWAENJ")
(46670 . "HANGUL SYLLABLE DDWAENH")
(46671 . "HANGUL SYLLABLE DDWAED")
(46672 . "HANGUL SYLLABLE DDWAEL")
(46673 . "HANGUL SYLLABLE DDWAELG")
(46674 . "HANGUL SYLLABLE DDWAELM")
(46675 . "HANGUL SYLLABLE DDWAELB")
(46676 . "HANGUL SYLLABLE DDWAELS")
(46677 . "HANGUL SYLLABLE DDWAELT")
(46678 . "HANGUL SYLLABLE DDWAELP")
(46679 . "HANGUL SYLLABLE DDWAELH")
(46680 . "HANGUL SYLLABLE DDWAEM")
(46681 . "HANGUL SYLLABLE DDWAEB")
(46682 . "HANGUL SYLLABLE DDWAEBS")
(46683 . "HANGUL SYLLABLE DDWAES")
(46684 . "HANGUL SYLLABLE DDWAESS")
(46685 . "HANGUL SYLLABLE DDWAENG")
(46686 . "HANGUL SYLLABLE DDWAEJ")
(46687 . "HANGUL SYLLABLE DDWAEC")
(46688 . "HANGUL SYLLABLE DDWAEK")
(46689 . "HANGUL SYLLABLE DDWAET")
(46690 . "HANGUL SYLLABLE DDWAEP")
(46691 . "HANGUL SYLLABLE DDWAEH")
(46692 . "HANGUL SYLLABLE DDOE")
(46693 . "HANGUL SYLLABLE DDOEG")
(46694 . "HANGUL SYLLABLE DDOEGG")
(46695 . "HANGUL SYLLABLE DDOEGS")
(46696 . "HANGUL SYLLABLE DDOEN")
(46697 . "HANGUL SYLLABLE DDOENJ")
(46698 . "HANGUL SYLLABLE DDOENH")
(46699 . "HANGUL SYLLABLE DDOED")
(46700 . "HANGUL SYLLABLE DDOEL")
(46701 . "HANGUL SYLLABLE DDOELG")
(46702 . "HANGUL SYLLABLE DDOELM")
(46703 . "HANGUL SYLLABLE DDOELB")
(46704 . "HANGUL SYLLABLE DDOELS")
(46705 . "HANGUL SYLLABLE DDOELT")
(46706 . "HANGUL SYLLABLE DDOELP")
(46707 . "HANGUL SYLLABLE DDOELH")
(46708 . "HANGUL SYLLABLE DDOEM")
(46709 . "HANGUL SYLLABLE DDOEB")
(46710 . "HANGUL SYLLABLE DDOEBS")
(46711 . "HANGUL SYLLABLE DDOES")
(46712 . "HANGUL SYLLABLE DDOESS")
(46713 . "HANGUL SYLLABLE DDOENG")
(46714 . "HANGUL SYLLABLE DDOEJ")
(46715 . "HANGUL SYLLABLE DDOEC")
(46716 . "HANGUL SYLLABLE DDOEK")
(46717 . "HANGUL SYLLABLE DDOET")
(46718 . "HANGUL SYLLABLE DDOEP")
(46719 . "HANGUL SYLLABLE DDOEH")
(46720 . "HANGUL SYLLABLE DDYO")
(46721 . "HANGUL SYLLABLE DDYOG")
(46722 . "HANGUL SYLLABLE DDYOGG")
(46723 . "HANGUL SYLLABLE DDYOGS")
(46724 . "HANGUL SYLLABLE DDYON")
(46725 . "HANGUL SYLLABLE DDYONJ")
(46726 . "HANGUL SYLLABLE DDYONH")
(46727 . "HANGUL SYLLABLE DDYOD")
(46728 . "HANGUL SYLLABLE DDYOL")
(46729 . "HANGUL SYLLABLE DDYOLG")
(46730 . "HANGUL SYLLABLE DDYOLM")
(46731 . "HANGUL SYLLABLE DDYOLB")
(46732 . "HANGUL SYLLABLE DDYOLS")
(46733 . "HANGUL SYLLABLE DDYOLT")
(46734 . "HANGUL SYLLABLE DDYOLP")
(46735 . "HANGUL SYLLABLE DDYOLH")
(46736 . "HANGUL SYLLABLE DDYOM")
(46737 . "HANGUL SYLLABLE DDYOB")
(46738 . "HANGUL SYLLABLE DDYOBS")
(46739 . "HANGUL SYLLABLE DDYOS")
(46740 . "HANGUL SYLLABLE DDYOSS")
(46741 . "HANGUL SYLLABLE DDYONG")
(46742 . "HANGUL SYLLABLE DDYOJ")
(46743 . "HANGUL SYLLABLE DDYOC")
(46744 . "HANGUL SYLLABLE DDYOK")
(46745 . "HANGUL SYLLABLE DDYOT")
(46746 . "HANGUL SYLLABLE DDYOP")
(46747 . "HANGUL SYLLABLE DDYOH")
(46748 . "HANGUL SYLLABLE DDU")
(46749 . "HANGUL SYLLABLE DDUG")
(46750 . "HANGUL SYLLABLE DDUGG")
(46751 . "HANGUL SYLLABLE DDUGS")
(46752 . "HANGUL SYLLABLE DDUN")
(46753 . "HANGUL SYLLABLE DDUNJ")
(46754 . "HANGUL SYLLABLE DDUNH")
(46755 . "HANGUL SYLLABLE DDUD")
(46756 . "HANGUL SYLLABLE DDUL")
(46757 . "HANGUL SYLLABLE DDULG")
(46758 . "HANGUL SYLLABLE DDULM")
(46759 . "HANGUL SYLLABLE DDULB")
(46760 . "HANGUL SYLLABLE DDULS")
(46761 . "HANGUL SYLLABLE DDULT")
(46762 . "HANGUL SYLLABLE DDULP")
(46763 . "HANGUL SYLLABLE DDULH")
(46764 . "HANGUL SYLLABLE DDUM")
(46765 . "HANGUL SYLLABLE DDUB")
(46766 . "HANGUL SYLLABLE DDUBS")
(46767 . "HANGUL SYLLABLE DDUS")
(46768 . "HANGUL SYLLABLE DDUSS")
(46769 . "HANGUL SYLLABLE DDUNG")
(46770 . "HANGUL SYLLABLE DDUJ")
(46771 . "HANGUL SYLLABLE DDUC")
(46772 . "HANGUL SYLLABLE DDUK")
(46773 . "HANGUL SYLLABLE DDUT")
(46774 . "HANGUL SYLLABLE DDUP")
(46775 . "HANGUL SYLLABLE DDUH")
(46776 . "HANGUL SYLLABLE DDWEO")
(46777 . "HANGUL SYLLABLE DDWEOG")
(46778 . "HANGUL SYLLABLE DDWEOGG")
(46779 . "HANGUL SYLLABLE DDWEOGS")
(46780 . "HANGUL SYLLABLE DDWEON")
(46781 . "HANGUL SYLLABLE DDWEONJ")
(46782 . "HANGUL SYLLABLE DDWEONH")
(46783 . "HANGUL SYLLABLE DDWEOD")
(46784 . "HANGUL SYLLABLE DDWEOL")
(46785 . "HANGUL SYLLABLE DDWEOLG")
(46786 . "HANGUL SYLLABLE DDWEOLM")
(46787 . "HANGUL SYLLABLE DDWEOLB")
(46788 . "HANGUL SYLLABLE DDWEOLS")
(46789 . "HANGUL SYLLABLE DDWEOLT")
(46790 . "HANGUL SYLLABLE DDWEOLP")
(46791 . "HANGUL SYLLABLE DDWEOLH")
(46792 . "HANGUL SYLLABLE DDWEOM")
(46793 . "HANGUL SYLLABLE DDWEOB")
(46794 . "HANGUL SYLLABLE DDWEOBS")
(46795 . "HANGUL SYLLABLE DDWEOS")
(46796 . "HANGUL SYLLABLE DDWEOSS")
(46797 . "HANGUL SYLLABLE DDWEONG")
(46798 . "HANGUL SYLLABLE DDWEOJ")
(46799 . "HANGUL SYLLABLE DDWEOC")
(46800 . "HANGUL SYLLABLE DDWEOK")
(46801 . "HANGUL SYLLABLE DDWEOT")
(46802 . "HANGUL SYLLABLE DDWEOP")
(46803 . "HANGUL SYLLABLE DDWEOH")
(46804 . "HANGUL SYLLABLE DDWE")
(46805 . "HANGUL SYLLABLE DDWEG")
(46806 . "HANGUL SYLLABLE DDWEGG")
(46807 . "HANGUL SYLLABLE DDWEGS")
(46808 . "HANGUL SYLLABLE DDWEN")
(46809 . "HANGUL SYLLABLE DDWENJ")
(46810 . "HANGUL SYLLABLE DDWENH")
(46811 . "HANGUL SYLLABLE DDWED")
(46812 . "HANGUL SYLLABLE DDWEL")
(46813 . "HANGUL SYLLABLE DDWELG")
(46814 . "HANGUL SYLLABLE DDWELM")
(46815 . "HANGUL SYLLABLE DDWELB")
(46816 . "HANGUL SYLLABLE DDWELS")
(46817 . "HANGUL SYLLABLE DDWELT")
(46818 . "HANGUL SYLLABLE DDWELP")
(46819 . "HANGUL SYLLABLE DDWELH")
(46820 . "HANGUL SYLLABLE DDWEM")
(46821 . "HANGUL SYLLABLE DDWEB")
(46822 . "HANGUL SYLLABLE DDWEBS")
(46823 . "HANGUL SYLLABLE DDWES")
(46824 . "HANGUL SYLLABLE DDWESS")
(46825 . "HANGUL SYLLABLE DDWENG")
(46826 . "HANGUL SYLLABLE DDWEJ")
(46827 . "HANGUL SYLLABLE DDWEC")
(46828 . "HANGUL SYLLABLE DDWEK")
(46829 . "HANGUL SYLLABLE DDWET")
(46830 . "HANGUL SYLLABLE DDWEP")
(46831 . "HANGUL SYLLABLE DDWEH")
(46832 . "HANGUL SYLLABLE DDWI")
(46833 . "HANGUL SYLLABLE DDWIG")
(46834 . "HANGUL SYLLABLE DDWIGG")
(46835 . "HANGUL SYLLABLE DDWIGS")
(46836 . "HANGUL SYLLABLE DDWIN")
(46837 . "HANGUL SYLLABLE DDWINJ")
(46838 . "HANGUL SYLLABLE DDWINH")
(46839 . "HANGUL SYLLABLE DDWID")
(46840 . "HANGUL SYLLABLE DDWIL")
(46841 . "HANGUL SYLLABLE DDWILG")
(46842 . "HANGUL SYLLABLE DDWILM")
(46843 . "HANGUL SYLLABLE DDWILB")
(46844 . "HANGUL SYLLABLE DDWILS")
(46845 . "HANGUL SYLLABLE DDWILT")
(46846 . "HANGUL SYLLABLE DDWILP")
(46847 . "HANGUL SYLLABLE DDWILH")
(46848 . "HANGUL SYLLABLE DDWIM")
(46849 . "HANGUL SYLLABLE DDWIB")
(46850 . "HANGUL SYLLABLE DDWIBS")
(46851 . "HANGUL SYLLABLE DDWIS")
(46852 . "HANGUL SYLLABLE DDWISS")
(46853 . "HANGUL SYLLABLE DDWING")
(46854 . "HANGUL SYLLABLE DDWIJ")
(46855 . "HANGUL SYLLABLE DDWIC")
(46856 . "HANGUL SYLLABLE DDWIK")
(46857 . "HANGUL SYLLABLE DDWIT")
(46858 . "HANGUL SYLLABLE DDWIP")
(46859 . "HANGUL SYLLABLE DDWIH")
(46860 . "HANGUL SYLLABLE DDYU")
(46861 . "HANGUL SYLLABLE DDYUG")
(46862 . "HANGUL SYLLABLE DDYUGG")
(46863 . "HANGUL SYLLABLE DDYUGS")
(46864 . "HANGUL SYLLABLE DDYUN")
(46865 . "HANGUL SYLLABLE DDYUNJ")
(46866 . "HANGUL SYLLABLE DDYUNH")
(46867 . "HANGUL SYLLABLE DDYUD")
(46868 . "HANGUL SYLLABLE DDYUL")
(46869 . "HANGUL SYLLABLE DDYULG")
(46870 . "HANGUL SYLLABLE DDYULM")
(46871 . "HANGUL SYLLABLE DDYULB")
(46872 . "HANGUL SYLLABLE DDYULS")
(46873 . "HANGUL SYLLABLE DDYULT")
(46874 . "HANGUL SYLLABLE DDYULP")
(46875 . "HANGUL SYLLABLE DDYULH")
(46876 . "HANGUL SYLLABLE DDYUM")
(46877 . "HANGUL SYLLABLE DDYUB")
(46878 . "HANGUL SYLLABLE DDYUBS")
(46879 . "HANGUL SYLLABLE DDYUS")
(46880 . "HANGUL SYLLABLE DDYUSS")
(46881 . "HANGUL SYLLABLE DDYUNG")
(46882 . "HANGUL SYLLABLE DDYUJ")
(46883 . "HANGUL SYLLABLE DDYUC")
(46884 . "HANGUL SYLLABLE DDYUK")
(46885 . "HANGUL SYLLABLE DDYUT")
(46886 . "HANGUL SYLLABLE DDYUP")
(46887 . "HANGUL SYLLABLE DDYUH")
(46888 . "HANGUL SYLLABLE DDEU")
(46889 . "HANGUL SYLLABLE DDEUG")
(46890 . "HANGUL SYLLABLE DDEUGG")
(46891 . "HANGUL SYLLABLE DDEUGS")
(46892 . "HANGUL SYLLABLE DDEUN")
(46893 . "HANGUL SYLLABLE DDEUNJ")
(46894 . "HANGUL SYLLABLE DDEUNH")
(46895 . "HANGUL SYLLABLE DDEUD")
(46896 . "HANGUL SYLLABLE DDEUL")
(46897 . "HANGUL SYLLABLE DDEULG")
(46898 . "HANGUL SYLLABLE DDEULM")
(46899 . "HANGUL SYLLABLE DDEULB")
(46900 . "HANGUL SYLLABLE DDEULS")
(46901 . "HANGUL SYLLABLE DDEULT")
(46902 . "HANGUL SYLLABLE DDEULP")
(46903 . "HANGUL SYLLABLE DDEULH")
(46904 . "HANGUL SYLLABLE DDEUM")
(46905 . "HANGUL SYLLABLE DDEUB")
(46906 . "HANGUL SYLLABLE DDEUBS")
(46907 . "HANGUL SYLLABLE DDEUS")
(46908 . "HANGUL SYLLABLE DDEUSS")
(46909 . "HANGUL SYLLABLE DDEUNG")
(46910 . "HANGUL SYLLABLE DDEUJ")
(46911 . "HANGUL SYLLABLE DDEUC")
(46912 . "HANGUL SYLLABLE DDEUK")
(46913 . "HANGUL SYLLABLE DDEUT")
(46914 . "HANGUL SYLLABLE DDEUP")
(46915 . "HANGUL SYLLABLE DDEUH")
(46916 . "HANGUL SYLLABLE DDYI")
(46917 . "HANGUL SYLLABLE DDYIG")
(46918 . "HANGUL SYLLABLE DDYIGG")
(46919 . "HANGUL SYLLABLE DDYIGS")
(46920 . "HANGUL SYLLABLE DDYIN")
(46921 . "HANGUL SYLLABLE DDYINJ")
(46922 . "HANGUL SYLLABLE DDYINH")
(46923 . "HANGUL SYLLABLE DDYID")
(46924 . "HANGUL SYLLABLE DDYIL")
(46925 . "HANGUL SYLLABLE DDYILG")
(46926 . "HANGUL SYLLABLE DDYILM")
(46927 . "HANGUL SYLLABLE DDYILB")
(46928 . "HANGUL SYLLABLE DDYILS")
(46929 . "HANGUL SYLLABLE DDYILT")
(46930 . "HANGUL SYLLABLE DDYILP")
(46931 . "HANGUL SYLLABLE DDYILH")
(46932 . "HANGUL SYLLABLE DDYIM")
(46933 . "HANGUL SYLLABLE DDYIB")
(46934 . "HANGUL SYLLABLE DDYIBS")
(46935 . "HANGUL SYLLABLE DDYIS")
(46936 . "HANGUL SYLLABLE DDYISS")
(46937 . "HANGUL SYLLABLE DDYING")
(46938 . "HANGUL SYLLABLE DDYIJ")
(46939 . "HANGUL SYLLABLE DDYIC")
(46940 . "HANGUL SYLLABLE DDYIK")
(46941 . "HANGUL SYLLABLE DDYIT")
(46942 . "HANGUL SYLLABLE DDYIP")
(46943 . "HANGUL SYLLABLE DDYIH")
(46944 . "HANGUL SYLLABLE DDI")
(46945 . "HANGUL SYLLABLE DDIG")
(46946 . "HANGUL SYLLABLE DDIGG")
(46947 . "HANGUL SYLLABLE DDIGS")
(46948 . "HANGUL SYLLABLE DDIN")
(46949 . "HANGUL SYLLABLE DDINJ")
(46950 . "HANGUL SYLLABLE DDINH")
(46951 . "HANGUL SYLLABLE DDID")
(46952 . "HANGUL SYLLABLE DDIL")
(46953 . "HANGUL SYLLABLE DDILG")
(46954 . "HANGUL SYLLABLE DDILM")
(46955 . "HANGUL SYLLABLE DDILB")
(46956 . "HANGUL SYLLABLE DDILS")
(46957 . "HANGUL SYLLABLE DDILT")
(46958 . "HANGUL SYLLABLE DDILP")
(46959 . "HANGUL SYLLABLE DDILH")
(46960 . "HANGUL SYLLABLE DDIM")
(46961 . "HANGUL SYLLABLE DDIB")
(46962 . "HANGUL SYLLABLE DDIBS")
(46963 . "HANGUL SYLLABLE DDIS")
(46964 . "HANGUL SYLLABLE DDISS")
(46965 . "HANGUL SYLLABLE DDING")
(46966 . "HANGUL SYLLABLE DDIJ")
(46967 . "HANGUL SYLLABLE DDIC")
(46968 . "HANGUL SYLLABLE DDIK")
(46969 . "HANGUL SYLLABLE DDIT")
(46970 . "HANGUL SYLLABLE DDIP")
(46971 . "HANGUL SYLLABLE DDIH")
(46972 . "HANGUL SYLLABLE RA")
(46973 . "HANGUL SYLLABLE RAG")
(46974 . "HANGUL SYLLABLE RAGG")
(46975 . "HANGUL SYLLABLE RAGS")
(46976 . "HANGUL SYLLABLE RAN")
(46977 . "HANGUL SYLLABLE RANJ")
(46978 . "HANGUL SYLLABLE RANH")
(46979 . "HANGUL SYLLABLE RAD")
(46980 . "HANGUL SYLLABLE RAL")
(46981 . "HANGUL SYLLABLE RALG")
(46982 . "HANGUL SYLLABLE RALM")
(46983 . "HANGUL SYLLABLE RALB")
(46984 . "HANGUL SYLLABLE RALS")
(46985 . "HANGUL SYLLABLE RALT")
(46986 . "HANGUL SYLLABLE RALP")
(46987 . "HANGUL SYLLABLE RALH")
(46988 . "HANGUL SYLLABLE RAM")
(46989 . "HANGUL SYLLABLE RAB")
(46990 . "HANGUL SYLLABLE RABS")
(46991 . "HANGUL SYLLABLE RAS")
(46992 . "HANGUL SYLLABLE RASS")
(46993 . "HANGUL SYLLABLE RANG")
(46994 . "HANGUL SYLLABLE RAJ")
(46995 . "HANGUL SYLLABLE RAC")
(46996 . "HANGUL SYLLABLE RAK")
(46997 . "HANGUL SYLLABLE RAT")
(46998 . "HANGUL SYLLABLE RAP")
(46999 . "HANGUL SYLLABLE RAH")
(47000 . "HANGUL SYLLABLE RAE")
(47001 . "HANGUL SYLLABLE RAEG")
(47002 . "HANGUL SYLLABLE RAEGG")
(47003 . "HANGUL SYLLABLE RAEGS")
(47004 . "HANGUL SYLLABLE RAEN")
(47005 . "HANGUL SYLLABLE RAENJ")
(47006 . "HANGUL SYLLABLE RAENH")
(47007 . "HANGUL SYLLABLE RAED")
(47008 . "HANGUL SYLLABLE RAEL")
(47009 . "HANGUL SYLLABLE RAELG")
(47010 . "HANGUL SYLLABLE RAELM")
(47011 . "HANGUL SYLLABLE RAELB")
(47012 . "HANGUL SYLLABLE RAELS")
(47013 . "HANGUL SYLLABLE RAELT")
(47014 . "HANGUL SYLLABLE RAELP")
(47015 . "HANGUL SYLLABLE RAELH")
(47016 . "HANGUL SYLLABLE RAEM")
(47017 . "HANGUL SYLLABLE RAEB")
(47018 . "HANGUL SYLLABLE RAEBS")
(47019 . "HANGUL SYLLABLE RAES")
(47020 . "HANGUL SYLLABLE RAESS")
(47021 . "HANGUL SYLLABLE RAENG")
(47022 . "HANGUL SYLLABLE RAEJ")
(47023 . "HANGUL SYLLABLE RAEC")
(47024 . "HANGUL SYLLABLE RAEK")
(47025 . "HANGUL SYLLABLE RAET")
(47026 . "HANGUL SYLLABLE RAEP")
(47027 . "HANGUL SYLLABLE RAEH")
(47028 . "HANGUL SYLLABLE RYA")
(47029 . "HANGUL SYLLABLE RYAG")
(47030 . "HANGUL SYLLABLE RYAGG")
(47031 . "HANGUL SYLLABLE RYAGS")
(47032 . "HANGUL SYLLABLE RYAN")
(47033 . "HANGUL SYLLABLE RYANJ")
(47034 . "HANGUL SYLLABLE RYANH")
(47035 . "HANGUL SYLLABLE RYAD")
(47036 . "HANGUL SYLLABLE RYAL")
(47037 . "HANGUL SYLLABLE RYALG")
(47038 . "HANGUL SYLLABLE RYALM")
(47039 . "HANGUL SYLLABLE RYALB")
(47040 . "HANGUL SYLLABLE RYALS")
(47041 . "HANGUL SYLLABLE RYALT")
(47042 . "HANGUL SYLLABLE RYALP")
(47043 . "HANGUL SYLLABLE RYALH")
(47044 . "HANGUL SYLLABLE RYAM")
(47045 . "HANGUL SYLLABLE RYAB")
(47046 . "HANGUL SYLLABLE RYABS")
(47047 . "HANGUL SYLLABLE RYAS")
(47048 . "HANGUL SYLLABLE RYASS")
(47049 . "HANGUL SYLLABLE RYANG")
(47050 . "HANGUL SYLLABLE RYAJ")
(47051 . "HANGUL SYLLABLE RYAC")
(47052 . "HANGUL SYLLABLE RYAK")
(47053 . "HANGUL SYLLABLE RYAT")
(47054 . "HANGUL SYLLABLE RYAP")
(47055 . "HANGUL SYLLABLE RYAH")
(47056 . "HANGUL SYLLABLE RYAE")
(47057 . "HANGUL SYLLABLE RYAEG")
(47058 . "HANGUL SYLLABLE RYAEGG")
(47059 . "HANGUL SYLLABLE RYAEGS")
(47060 . "HANGUL SYLLABLE RYAEN")
(47061 . "HANGUL SYLLABLE RYAENJ")
(47062 . "HANGUL SYLLABLE RYAENH")
(47063 . "HANGUL SYLLABLE RYAED")
(47064 . "HANGUL SYLLABLE RYAEL")
(47065 . "HANGUL SYLLABLE RYAELG")
(47066 . "HANGUL SYLLABLE RYAELM")
(47067 . "HANGUL SYLLABLE RYAELB")
(47068 . "HANGUL SYLLABLE RYAELS")
(47069 . "HANGUL SYLLABLE RYAELT")
(47070 . "HANGUL SYLLABLE RYAELP")
(47071 . "HANGUL SYLLABLE RYAELH")
(47072 . "HANGUL SYLLABLE RYAEM")
(47073 . "HANGUL SYLLABLE RYAEB")
(47074 . "HANGUL SYLLABLE RYAEBS")
(47075 . "HANGUL SYLLABLE RYAES")
(47076 . "HANGUL SYLLABLE RYAESS")
(47077 . "HANGUL SYLLABLE RYAENG")
(47078 . "HANGUL SYLLABLE RYAEJ")
(47079 . "HANGUL SYLLABLE RYAEC")
(47080 . "HANGUL SYLLABLE RYAEK")
(47081 . "HANGUL SYLLABLE RYAET")
(47082 . "HANGUL SYLLABLE RYAEP")
(47083 . "HANGUL SYLLABLE RYAEH")
(47084 . "HANGUL SYLLABLE REO")
(47085 . "HANGUL SYLLABLE REOG")
(47086 . "HANGUL SYLLABLE REOGG")
(47087 . "HANGUL SYLLABLE REOGS")
(47088 . "HANGUL SYLLABLE REON")
(47089 . "HANGUL SYLLABLE REONJ")
(47090 . "HANGUL SYLLABLE REONH")
(47091 . "HANGUL SYLLABLE REOD")
(47092 . "HANGUL SYLLABLE REOL")
(47093 . "HANGUL SYLLABLE REOLG")
(47094 . "HANGUL SYLLABLE REOLM")
(47095 . "HANGUL SYLLABLE REOLB")
(47096 . "HANGUL SYLLABLE REOLS")
(47097 . "HANGUL SYLLABLE REOLT")
(47098 . "HANGUL SYLLABLE REOLP")
(47099 . "HANGUL SYLLABLE REOLH")
(47100 . "HANGUL SYLLABLE REOM")
(47101 . "HANGUL SYLLABLE REOB")
(47102 . "HANGUL SYLLABLE REOBS")
(47103 . "HANGUL SYLLABLE REOS")
(47104 . "HANGUL SYLLABLE REOSS")
(47105 . "HANGUL SYLLABLE REONG")
(47106 . "HANGUL SYLLABLE REOJ")
(47107 . "HANGUL SYLLABLE REOC")
(47108 . "HANGUL SYLLABLE REOK")
(47109 . "HANGUL SYLLABLE REOT")
(47110 . "HANGUL SYLLABLE REOP")
(47111 . "HANGUL SYLLABLE REOH")
(47112 . "HANGUL SYLLABLE RE")
(47113 . "HANGUL SYLLABLE REG")
(47114 . "HANGUL SYLLABLE REGG")
(47115 . "HANGUL SYLLABLE REGS")
(47116 . "HANGUL SYLLABLE REN")
(47117 . "HANGUL SYLLABLE RENJ")
(47118 . "HANGUL SYLLABLE RENH")
(47119 . "HANGUL SYLLABLE RED")
(47120 . "HANGUL SYLLABLE REL")
(47121 . "HANGUL SYLLABLE RELG")
(47122 . "HANGUL SYLLABLE RELM")
(47123 . "HANGUL SYLLABLE RELB")
(47124 . "HANGUL SYLLABLE RELS")
(47125 . "HANGUL SYLLABLE RELT")
(47126 . "HANGUL SYLLABLE RELP")
(47127 . "HANGUL SYLLABLE RELH")
(47128 . "HANGUL SYLLABLE REM")
(47129 . "HANGUL SYLLABLE REB")
(47130 . "HANGUL SYLLABLE REBS")
(47131 . "HANGUL SYLLABLE RES")
(47132 . "HANGUL SYLLABLE RESS")
(47133 . "HANGUL SYLLABLE RENG")
(47134 . "HANGUL SYLLABLE REJ")
(47135 . "HANGUL SYLLABLE REC")
(47136 . "HANGUL SYLLABLE REK")
(47137 . "HANGUL SYLLABLE RET")
(47138 . "HANGUL SYLLABLE REP")
(47139 . "HANGUL SYLLABLE REH")
(47140 . "HANGUL SYLLABLE RYEO")
(47141 . "HANGUL SYLLABLE RYEOG")
(47142 . "HANGUL SYLLABLE RYEOGG")
(47143 . "HANGUL SYLLABLE RYEOGS")
(47144 . "HANGUL SYLLABLE RYEON")
(47145 . "HANGUL SYLLABLE RYEONJ")
(47146 . "HANGUL SYLLABLE RYEONH")
(47147 . "HANGUL SYLLABLE RYEOD")
(47148 . "HANGUL SYLLABLE RYEOL")
(47149 . "HANGUL SYLLABLE RYEOLG")
(47150 . "HANGUL SYLLABLE RYEOLM")
(47151 . "HANGUL SYLLABLE RYEOLB")
(47152 . "HANGUL SYLLABLE RYEOLS")
(47153 . "HANGUL SYLLABLE RYEOLT")
(47154 . "HANGUL SYLLABLE RYEOLP")
(47155 . "HANGUL SYLLABLE RYEOLH")
(47156 . "HANGUL SYLLABLE RYEOM")
(47157 . "HANGUL SYLLABLE RYEOB")
(47158 . "HANGUL SYLLABLE RYEOBS")
(47159 . "HANGUL SYLLABLE RYEOS")
(47160 . "HANGUL SYLLABLE RYEOSS")
(47161 . "HANGUL SYLLABLE RYEONG")
(47162 . "HANGUL SYLLABLE RYEOJ")
(47163 . "HANGUL SYLLABLE RYEOC")
(47164 . "HANGUL SYLLABLE RYEOK")
(47165 . "HANGUL SYLLABLE RYEOT")
(47166 . "HANGUL SYLLABLE RYEOP")
(47167 . "HANGUL SYLLABLE RYEOH")
(47168 . "HANGUL SYLLABLE RYE")
(47169 . "HANGUL SYLLABLE RYEG")
(47170 . "HANGUL SYLLABLE RYEGG")
(47171 . "HANGUL SYLLABLE RYEGS")
(47172 . "HANGUL SYLLABLE RYEN")
(47173 . "HANGUL SYLLABLE RYENJ")
(47174 . "HANGUL SYLLABLE RYENH")
(47175 . "HANGUL SYLLABLE RYED")
(47176 . "HANGUL SYLLABLE RYEL")
(47177 . "HANGUL SYLLABLE RYELG")
(47178 . "HANGUL SYLLABLE RYELM")
(47179 . "HANGUL SYLLABLE RYELB")
(47180 . "HANGUL SYLLABLE RYELS")
(47181 . "HANGUL SYLLABLE RYELT")
(47182 . "HANGUL SYLLABLE RYELP")
(47183 . "HANGUL SYLLABLE RYELH")
(47184 . "HANGUL SYLLABLE RYEM")
(47185 . "HANGUL SYLLABLE RYEB")
(47186 . "HANGUL SYLLABLE RYEBS")
(47187 . "HANGUL SYLLABLE RYES")
(47188 . "HANGUL SYLLABLE RYESS")
(47189 . "HANGUL SYLLABLE RYENG")
(47190 . "HANGUL SYLLABLE RYEJ")
(47191 . "HANGUL SYLLABLE RYEC")
(47192 . "HANGUL SYLLABLE RYEK")
(47193 . "HANGUL SYLLABLE RYET")
(47194 . "HANGUL SYLLABLE RYEP")
(47195 . "HANGUL SYLLABLE RYEH")
(47196 . "HANGUL SYLLABLE RO")
(47197 . "HANGUL SYLLABLE ROG")
(47198 . "HANGUL SYLLABLE ROGG")
(47199 . "HANGUL SYLLABLE ROGS")
(47200 . "HANGUL SYLLABLE RON")
(47201 . "HANGUL SYLLABLE RONJ")
(47202 . "HANGUL SYLLABLE RONH")
(47203 . "HANGUL SYLLABLE ROD")
(47204 . "HANGUL SYLLABLE ROL")
(47205 . "HANGUL SYLLABLE ROLG")
(47206 . "HANGUL SYLLABLE ROLM")
(47207 . "HANGUL SYLLABLE ROLB")
(47208 . "HANGUL SYLLABLE ROLS")
(47209 . "HANGUL SYLLABLE ROLT")
(47210 . "HANGUL SYLLABLE ROLP")
(47211 . "HANGUL SYLLABLE ROLH")
(47212 . "HANGUL SYLLABLE ROM")
(47213 . "HANGUL SYLLABLE ROB")
(47214 . "HANGUL SYLLABLE ROBS")
(47215 . "HANGUL SYLLABLE ROS")
(47216 . "HANGUL SYLLABLE ROSS")
(47217 . "HANGUL SYLLABLE RONG")
(47218 . "HANGUL SYLLABLE ROJ")
(47219 . "HANGUL SYLLABLE ROC")
(47220 . "HANGUL SYLLABLE ROK")
(47221 . "HANGUL SYLLABLE ROT")
(47222 . "HANGUL SYLLABLE ROP")
(47223 . "HANGUL SYLLABLE ROH")
(47224 . "HANGUL SYLLABLE RWA")
(47225 . "HANGUL SYLLABLE RWAG")
(47226 . "HANGUL SYLLABLE RWAGG")
(47227 . "HANGUL SYLLABLE RWAGS")
(47228 . "HANGUL SYLLABLE RWAN")
(47229 . "HANGUL SYLLABLE RWANJ")
(47230 . "HANGUL SYLLABLE RWANH")
(47231 . "HANGUL SYLLABLE RWAD")
(47232 . "HANGUL SYLLABLE RWAL")
(47233 . "HANGUL SYLLABLE RWALG")
(47234 . "HANGUL SYLLABLE RWALM")
(47235 . "HANGUL SYLLABLE RWALB")
(47236 . "HANGUL SYLLABLE RWALS")
(47237 . "HANGUL SYLLABLE RWALT")
(47238 . "HANGUL SYLLABLE RWALP")
(47239 . "HANGUL SYLLABLE RWALH")
(47240 . "HANGUL SYLLABLE RWAM")
(47241 . "HANGUL SYLLABLE RWAB")
(47242 . "HANGUL SYLLABLE RWABS")
(47243 . "HANGUL SYLLABLE RWAS")
(47244 . "HANGUL SYLLABLE RWASS")
(47245 . "HANGUL SYLLABLE RWANG")
(47246 . "HANGUL SYLLABLE RWAJ")
(47247 . "HANGUL SYLLABLE RWAC")
(47248 . "HANGUL SYLLABLE RWAK")
(47249 . "HANGUL SYLLABLE RWAT")
(47250 . "HANGUL SYLLABLE RWAP")
(47251 . "HANGUL SYLLABLE RWAH")
(47252 . "HANGUL SYLLABLE RWAE")
(47253 . "HANGUL SYLLABLE RWAEG")
(47254 . "HANGUL SYLLABLE RWAEGG")
(47255 . "HANGUL SYLLABLE RWAEGS")
(47256 . "HANGUL SYLLABLE RWAEN")
(47257 . "HANGUL SYLLABLE RWAENJ")
(47258 . "HANGUL SYLLABLE RWAENH")
(47259 . "HANGUL SYLLABLE RWAED")
(47260 . "HANGUL SYLLABLE RWAEL")
(47261 . "HANGUL SYLLABLE RWAELG")
(47262 . "HANGUL SYLLABLE RWAELM")
(47263 . "HANGUL SYLLABLE RWAELB")
(47264 . "HANGUL SYLLABLE RWAELS")
(47265 . "HANGUL SYLLABLE RWAELT")
(47266 . "HANGUL SYLLABLE RWAELP")
(47267 . "HANGUL SYLLABLE RWAELH")
(47268 . "HANGUL SYLLABLE RWAEM")
(47269 . "HANGUL SYLLABLE RWAEB")
(47270 . "HANGUL SYLLABLE RWAEBS")
(47271 . "HANGUL SYLLABLE RWAES")
(47272 . "HANGUL SYLLABLE RWAESS")
(47273 . "HANGUL SYLLABLE RWAENG")
(47274 . "HANGUL SYLLABLE RWAEJ")
(47275 . "HANGUL SYLLABLE RWAEC")
(47276 . "HANGUL SYLLABLE RWAEK")
(47277 . "HANGUL SYLLABLE RWAET")
(47278 . "HANGUL SYLLABLE RWAEP")
(47279 . "HANGUL SYLLABLE RWAEH")
(47280 . "HANGUL SYLLABLE ROE")
(47281 . "HANGUL SYLLABLE ROEG")
(47282 . "HANGUL SYLLABLE ROEGG")
(47283 . "HANGUL SYLLABLE ROEGS")
(47284 . "HANGUL SYLLABLE ROEN")
(47285 . "HANGUL SYLLABLE ROENJ")
(47286 . "HANGUL SYLLABLE ROENH")
(47287 . "HANGUL SYLLABLE ROED")
(47288 . "HANGUL SYLLABLE ROEL")
(47289 . "HANGUL SYLLABLE ROELG")
(47290 . "HANGUL SYLLABLE ROELM")
(47291 . "HANGUL SYLLABLE ROELB")
(47292 . "HANGUL SYLLABLE ROELS")
(47293 . "HANGUL SYLLABLE ROELT")
(47294 . "HANGUL SYLLABLE ROELP")
(47295 . "HANGUL SYLLABLE ROELH")
(47296 . "HANGUL SYLLABLE ROEM")
(47297 . "HANGUL SYLLABLE ROEB")
(47298 . "HANGUL SYLLABLE ROEBS")
(47299 . "HANGUL SYLLABLE ROES")
(47300 . "HANGUL SYLLABLE ROESS")
(47301 . "HANGUL SYLLABLE ROENG")
(47302 . "HANGUL SYLLABLE ROEJ")
(47303 . "HANGUL SYLLABLE ROEC")
(47304 . "HANGUL SYLLABLE ROEK")
(47305 . "HANGUL SYLLABLE ROET")
(47306 . "HANGUL SYLLABLE ROEP")
(47307 . "HANGUL SYLLABLE ROEH")
(47308 . "HANGUL SYLLABLE RYO")
(47309 . "HANGUL SYLLABLE RYOG")
(47310 . "HANGUL SYLLABLE RYOGG")
(47311 . "HANGUL SYLLABLE RYOGS")
(47312 . "HANGUL SYLLABLE RYON")
(47313 . "HANGUL SYLLABLE RYONJ")
(47314 . "HANGUL SYLLABLE RYONH")
(47315 . "HANGUL SYLLABLE RYOD")
(47316 . "HANGUL SYLLABLE RYOL")
(47317 . "HANGUL SYLLABLE RYOLG")
(47318 . "HANGUL SYLLABLE RYOLM")
(47319 . "HANGUL SYLLABLE RYOLB")
(47320 . "HANGUL SYLLABLE RYOLS")
(47321 . "HANGUL SYLLABLE RYOLT")
(47322 . "HANGUL SYLLABLE RYOLP")
(47323 . "HANGUL SYLLABLE RYOLH")
(47324 . "HANGUL SYLLABLE RYOM")
(47325 . "HANGUL SYLLABLE RYOB")
(47326 . "HANGUL SYLLABLE RYOBS")
(47327 . "HANGUL SYLLABLE RYOS")
(47328 . "HANGUL SYLLABLE RYOSS")
(47329 . "HANGUL SYLLABLE RYONG")
(47330 . "HANGUL SYLLABLE RYOJ")
(47331 . "HANGUL SYLLABLE RYOC")
(47332 . "HANGUL SYLLABLE RYOK")
(47333 . "HANGUL SYLLABLE RYOT")
(47334 . "HANGUL SYLLABLE RYOP")
(47335 . "HANGUL SYLLABLE RYOH")
(47336 . "HANGUL SYLLABLE RU")
(47337 . "HANGUL SYLLABLE RUG")
(47338 . "HANGUL SYLLABLE RUGG")
(47339 . "HANGUL SYLLABLE RUGS")
(47340 . "HANGUL SYLLABLE RUN")
(47341 . "HANGUL SYLLABLE RUNJ")
(47342 . "HANGUL SYLLABLE RUNH")
(47343 . "HANGUL SYLLABLE RUD")
(47344 . "HANGUL SYLLABLE RUL")
(47345 . "HANGUL SYLLABLE RULG")
(47346 . "HANGUL SYLLABLE RULM")
(47347 . "HANGUL SYLLABLE RULB")
(47348 . "HANGUL SYLLABLE RULS")
(47349 . "HANGUL SYLLABLE RULT")
(47350 . "HANGUL SYLLABLE RULP")
(47351 . "HANGUL SYLLABLE RULH")
(47352 . "HANGUL SYLLABLE RUM")
(47353 . "HANGUL SYLLABLE RUB")
(47354 . "HANGUL SYLLABLE RUBS")
(47355 . "HANGUL SYLLABLE RUS")
(47356 . "HANGUL SYLLABLE RUSS")
(47357 . "HANGUL SYLLABLE RUNG")
(47358 . "HANGUL SYLLABLE RUJ")
(47359 . "HANGUL SYLLABLE RUC")
(47360 . "HANGUL SYLLABLE RUK")
(47361 . "HANGUL SYLLABLE RUT")
(47362 . "HANGUL SYLLABLE RUP")
(47363 . "HANGUL SYLLABLE RUH")
(47364 . "HANGUL SYLLABLE RWEO")
(47365 . "HANGUL SYLLABLE RWEOG")
(47366 . "HANGUL SYLLABLE RWEOGG")
(47367 . "HANGUL SYLLABLE RWEOGS")
(47368 . "HANGUL SYLLABLE RWEON")
(47369 . "HANGUL SYLLABLE RWEONJ")
(47370 . "HANGUL SYLLABLE RWEONH")
(47371 . "HANGUL SYLLABLE RWEOD")
(47372 . "HANGUL SYLLABLE RWEOL")
(47373 . "HANGUL SYLLABLE RWEOLG")
(47374 . "HANGUL SYLLABLE RWEOLM")
(47375 . "HANGUL SYLLABLE RWEOLB")
(47376 . "HANGUL SYLLABLE RWEOLS")
(47377 . "HANGUL SYLLABLE RWEOLT")
(47378 . "HANGUL SYLLABLE RWEOLP")
(47379 . "HANGUL SYLLABLE RWEOLH")
(47380 . "HANGUL SYLLABLE RWEOM")
(47381 . "HANGUL SYLLABLE RWEOB")
(47382 . "HANGUL SYLLABLE RWEOBS")
(47383 . "HANGUL SYLLABLE RWEOS")
(47384 . "HANGUL SYLLABLE RWEOSS")
(47385 . "HANGUL SYLLABLE RWEONG")
(47386 . "HANGUL SYLLABLE RWEOJ")
(47387 . "HANGUL SYLLABLE RWEOC")
(47388 . "HANGUL SYLLABLE RWEOK")
(47389 . "HANGUL SYLLABLE RWEOT")
(47390 . "HANGUL SYLLABLE RWEOP")
(47391 . "HANGUL SYLLABLE RWEOH")
(47392 . "HANGUL SYLLABLE RWE")
(47393 . "HANGUL SYLLABLE RWEG")
(47394 . "HANGUL SYLLABLE RWEGG")
(47395 . "HANGUL SYLLABLE RWEGS")
(47396 . "HANGUL SYLLABLE RWEN")
(47397 . "HANGUL SYLLABLE RWENJ")
(47398 . "HANGUL SYLLABLE RWENH")
(47399 . "HANGUL SYLLABLE RWED")
(47400 . "HANGUL SYLLABLE RWEL")
(47401 . "HANGUL SYLLABLE RWELG")
(47402 . "HANGUL SYLLABLE RWELM")
(47403 . "HANGUL SYLLABLE RWELB")
(47404 . "HANGUL SYLLABLE RWELS")
(47405 . "HANGUL SYLLABLE RWELT")
(47406 . "HANGUL SYLLABLE RWELP")
(47407 . "HANGUL SYLLABLE RWELH")
(47408 . "HANGUL SYLLABLE RWEM")
(47409 . "HANGUL SYLLABLE RWEB")
(47410 . "HANGUL SYLLABLE RWEBS")
(47411 . "HANGUL SYLLABLE RWES")
(47412 . "HANGUL SYLLABLE RWESS")
(47413 . "HANGUL SYLLABLE RWENG")
(47414 . "HANGUL SYLLABLE RWEJ")
(47415 . "HANGUL SYLLABLE RWEC")
(47416 . "HANGUL SYLLABLE RWEK")
(47417 . "HANGUL SYLLABLE RWET")
(47418 . "HANGUL SYLLABLE RWEP")
(47419 . "HANGUL SYLLABLE RWEH")
(47420 . "HANGUL SYLLABLE RWI")
(47421 . "HANGUL SYLLABLE RWIG")
(47422 . "HANGUL SYLLABLE RWIGG")
(47423 . "HANGUL SYLLABLE RWIGS")
(47424 . "HANGUL SYLLABLE RWIN")
(47425 . "HANGUL SYLLABLE RWINJ")
(47426 . "HANGUL SYLLABLE RWINH")
(47427 . "HANGUL SYLLABLE RWID")
(47428 . "HANGUL SYLLABLE RWIL")
(47429 . "HANGUL SYLLABLE RWILG")
(47430 . "HANGUL SYLLABLE RWILM")
(47431 . "HANGUL SYLLABLE RWILB")
(47432 . "HANGUL SYLLABLE RWILS")
(47433 . "HANGUL SYLLABLE RWILT")
(47434 . "HANGUL SYLLABLE RWILP")
(47435 . "HANGUL SYLLABLE RWILH")
(47436 . "HANGUL SYLLABLE RWIM")
(47437 . "HANGUL SYLLABLE RWIB")
(47438 . "HANGUL SYLLABLE RWIBS")
(47439 . "HANGUL SYLLABLE RWIS")
(47440 . "HANGUL SYLLABLE RWISS")
(47441 . "HANGUL SYLLABLE RWING")
(47442 . "HANGUL SYLLABLE RWIJ")
(47443 . "HANGUL SYLLABLE RWIC")
(47444 . "HANGUL SYLLABLE RWIK")
(47445 . "HANGUL SYLLABLE RWIT")
(47446 . "HANGUL SYLLABLE RWIP")
(47447 . "HANGUL SYLLABLE RWIH")
(47448 . "HANGUL SYLLABLE RYU")
(47449 . "HANGUL SYLLABLE RYUG")
(47450 . "HANGUL SYLLABLE RYUGG")
(47451 . "HANGUL SYLLABLE RYUGS")
(47452 . "HANGUL SYLLABLE RYUN")
(47453 . "HANGUL SYLLABLE RYUNJ")
(47454 . "HANGUL SYLLABLE RYUNH")
(47455 . "HANGUL SYLLABLE RYUD")
(47456 . "HANGUL SYLLABLE RYUL")
(47457 . "HANGUL SYLLABLE RYULG")
(47458 . "HANGUL SYLLABLE RYULM")
(47459 . "HANGUL SYLLABLE RYULB")
(47460 . "HANGUL SYLLABLE RYULS")
(47461 . "HANGUL SYLLABLE RYULT")
(47462 . "HANGUL SYLLABLE RYULP")
(47463 . "HANGUL SYLLABLE RYULH")
(47464 . "HANGUL SYLLABLE RYUM")
(47465 . "HANGUL SYLLABLE RYUB")
(47466 . "HANGUL SYLLABLE RYUBS")
(47467 . "HANGUL SYLLABLE RYUS")
(47468 . "HANGUL SYLLABLE RYUSS")
(47469 . "HANGUL SYLLABLE RYUNG")
(47470 . "HANGUL SYLLABLE RYUJ")
(47471 . "HANGUL SYLLABLE RYUC")
(47472 . "HANGUL SYLLABLE RYUK")
(47473 . "HANGUL SYLLABLE RYUT")
(47474 . "HANGUL SYLLABLE RYUP")
(47475 . "HANGUL SYLLABLE RYUH")
(47476 . "HANGUL SYLLABLE REU")
(47477 . "HANGUL SYLLABLE REUG")
(47478 . "HANGUL SYLLABLE REUGG")
(47479 . "HANGUL SYLLABLE REUGS")
(47480 . "HANGUL SYLLABLE REUN")
(47481 . "HANGUL SYLLABLE REUNJ")
(47482 . "HANGUL SYLLABLE REUNH")
(47483 . "HANGUL SYLLABLE REUD")
(47484 . "HANGUL SYLLABLE REUL")
(47485 . "HANGUL SYLLABLE REULG")
(47486 . "HANGUL SYLLABLE REULM")
(47487 . "HANGUL SYLLABLE REULB")
(47488 . "HANGUL SYLLABLE REULS")
(47489 . "HANGUL SYLLABLE REULT")
(47490 . "HANGUL SYLLABLE REULP")
(47491 . "HANGUL SYLLABLE REULH")
(47492 . "HANGUL SYLLABLE REUM")
(47493 . "HANGUL SYLLABLE REUB")
(47494 . "HANGUL SYLLABLE REUBS")
(47495 . "HANGUL SYLLABLE REUS")
(47496 . "HANGUL SYLLABLE REUSS")
(47497 . "HANGUL SYLLABLE REUNG")
(47498 . "HANGUL SYLLABLE REUJ")
(47499 . "HANGUL SYLLABLE REUC")
(47500 . "HANGUL SYLLABLE REUK")
(47501 . "HANGUL SYLLABLE REUT")
(47502 . "HANGUL SYLLABLE REUP")
(47503 . "HANGUL SYLLABLE REUH")
(47504 . "HANGUL SYLLABLE RYI")
(47505 . "HANGUL SYLLABLE RYIG")
(47506 . "HANGUL SYLLABLE RYIGG")
(47507 . "HANGUL SYLLABLE RYIGS")
(47508 . "HANGUL SYLLABLE RYIN")
(47509 . "HANGUL SYLLABLE RYINJ")
(47510 . "HANGUL SYLLABLE RYINH")
(47511 . "HANGUL SYLLABLE RYID")
(47512 . "HANGUL SYLLABLE RYIL")
(47513 . "HANGUL SYLLABLE RYILG")
(47514 . "HANGUL SYLLABLE RYILM")
(47515 . "HANGUL SYLLABLE RYILB")
(47516 . "HANGUL SYLLABLE RYILS")
(47517 . "HANGUL SYLLABLE RYILT")
(47518 . "HANGUL SYLLABLE RYILP")
(47519 . "HANGUL SYLLABLE RYILH")
(47520 . "HANGUL SYLLABLE RYIM")
(47521 . "HANGUL SYLLABLE RYIB")
(47522 . "HANGUL SYLLABLE RYIBS")
(47523 . "HANGUL SYLLABLE RYIS")
(47524 . "HANGUL SYLLABLE RYISS")
(47525 . "HANGUL SYLLABLE RYING")
(47526 . "HANGUL SYLLABLE RYIJ")
(47527 . "HANGUL SYLLABLE RYIC")
(47528 . "HANGUL SYLLABLE RYIK")
(47529 . "HANGUL SYLLABLE RYIT")
(47530 . "HANGUL SYLLABLE RYIP")
(47531 . "HANGUL SYLLABLE RYIH")
(47532 . "HANGUL SYLLABLE RI")
(47533 . "HANGUL SYLLABLE RIG")
(47534 . "HANGUL SYLLABLE RIGG")
(47535 . "HANGUL SYLLABLE RIGS")
(47536 . "HANGUL SYLLABLE RIN")
(47537 . "HANGUL SYLLABLE RINJ")
(47538 . "HANGUL SYLLABLE RINH")
(47539 . "HANGUL SYLLABLE RID")
(47540 . "HANGUL SYLLABLE RIL")
(47541 . "HANGUL SYLLABLE RILG")
(47542 . "HANGUL SYLLABLE RILM")
(47543 . "HANGUL SYLLABLE RILB")
(47544 . "HANGUL SYLLABLE RILS")
(47545 . "HANGUL SYLLABLE RILT")
(47546 . "HANGUL SYLLABLE RILP")
(47547 . "HANGUL SYLLABLE RILH")
(47548 . "HANGUL SYLLABLE RIM")
(47549 . "HANGUL SYLLABLE RIB")
(47550 . "HANGUL SYLLABLE RIBS")
(47551 . "HANGUL SYLLABLE RIS")
(47552 . "HANGUL SYLLABLE RISS")
(47553 . "HANGUL SYLLABLE RING")
(47554 . "HANGUL SYLLABLE RIJ")
(47555 . "HANGUL SYLLABLE RIC")
(47556 . "HANGUL SYLLABLE RIK")
(47557 . "HANGUL SYLLABLE RIT")
(47558 . "HANGUL SYLLABLE RIP")
(47559 . "HANGUL SYLLABLE RIH")
(47560 . "HANGUL SYLLABLE MA")
(47561 . "HANGUL SYLLABLE MAG")
(47562 . "HANGUL SYLLABLE MAGG")
(47563 . "HANGUL SYLLABLE MAGS")
(47564 . "HANGUL SYLLABLE MAN")
(47565 . "HANGUL SYLLABLE MANJ")
(47566 . "HANGUL SYLLABLE MANH")
(47567 . "HANGUL SYLLABLE MAD")
(47568 . "HANGUL SYLLABLE MAL")
(47569 . "HANGUL SYLLABLE MALG")
(47570 . "HANGUL SYLLABLE MALM")
(47571 . "HANGUL SYLLABLE MALB")
(47572 . "HANGUL SYLLABLE MALS")
(47573 . "HANGUL SYLLABLE MALT")
(47574 . "HANGUL SYLLABLE MALP")
(47575 . "HANGUL SYLLABLE MALH")
(47576 . "HANGUL SYLLABLE MAM")
(47577 . "HANGUL SYLLABLE MAB")
(47578 . "HANGUL SYLLABLE MABS")
(47579 . "HANGUL SYLLABLE MAS")
(47580 . "HANGUL SYLLABLE MASS")
(47581 . "HANGUL SYLLABLE MANG")
(47582 . "HANGUL SYLLABLE MAJ")
(47583 . "HANGUL SYLLABLE MAC")
(47584 . "HANGUL SYLLABLE MAK")
(47585 . "HANGUL SYLLABLE MAT")
(47586 . "HANGUL SYLLABLE MAP")
(47587 . "HANGUL SYLLABLE MAH")
(47588 . "HANGUL SYLLABLE MAE")
(47589 . "HANGUL SYLLABLE MAEG")
(47590 . "HANGUL SYLLABLE MAEGG")
(47591 . "HANGUL SYLLABLE MAEGS")
(47592 . "HANGUL SYLLABLE MAEN")
(47593 . "HANGUL SYLLABLE MAENJ")
(47594 . "HANGUL SYLLABLE MAENH")
(47595 . "HANGUL SYLLABLE MAED")
(47596 . "HANGUL SYLLABLE MAEL")
(47597 . "HANGUL SYLLABLE MAELG")
(47598 . "HANGUL SYLLABLE MAELM")
(47599 . "HANGUL SYLLABLE MAELB")
(47600 . "HANGUL SYLLABLE MAELS")
(47601 . "HANGUL SYLLABLE MAELT")
(47602 . "HANGUL SYLLABLE MAELP")
(47603 . "HANGUL SYLLABLE MAELH")
(47604 . "HANGUL SYLLABLE MAEM")
(47605 . "HANGUL SYLLABLE MAEB")
(47606 . "HANGUL SYLLABLE MAEBS")
(47607 . "HANGUL SYLLABLE MAES")
(47608 . "HANGUL SYLLABLE MAESS")
(47609 . "HANGUL SYLLABLE MAENG")
(47610 . "HANGUL SYLLABLE MAEJ")
(47611 . "HANGUL SYLLABLE MAEC")
(47612 . "HANGUL SYLLABLE MAEK")
(47613 . "HANGUL SYLLABLE MAET")
(47614 . "HANGUL SYLLABLE MAEP")
(47615 . "HANGUL SYLLABLE MAEH")
(47616 . "HANGUL SYLLABLE MYA")
(47617 . "HANGUL SYLLABLE MYAG")
(47618 . "HANGUL SYLLABLE MYAGG")
(47619 . "HANGUL SYLLABLE MYAGS")
(47620 . "HANGUL SYLLABLE MYAN")
(47621 . "HANGUL SYLLABLE MYANJ")
(47622 . "HANGUL SYLLABLE MYANH")
(47623 . "HANGUL SYLLABLE MYAD")
(47624 . "HANGUL SYLLABLE MYAL")
(47625 . "HANGUL SYLLABLE MYALG")
(47626 . "HANGUL SYLLABLE MYALM")
(47627 . "HANGUL SYLLABLE MYALB")
(47628 . "HANGUL SYLLABLE MYALS")
(47629 . "HANGUL SYLLABLE MYALT")
(47630 . "HANGUL SYLLABLE MYALP")
(47631 . "HANGUL SYLLABLE MYALH")
(47632 . "HANGUL SYLLABLE MYAM")
(47633 . "HANGUL SYLLABLE MYAB")
(47634 . "HANGUL SYLLABLE MYABS")
(47635 . "HANGUL SYLLABLE MYAS")
(47636 . "HANGUL SYLLABLE MYASS")
(47637 . "HANGUL SYLLABLE MYANG")
(47638 . "HANGUL SYLLABLE MYAJ")
(47639 . "HANGUL SYLLABLE MYAC")
(47640 . "HANGUL SYLLABLE MYAK")
(47641 . "HANGUL SYLLABLE MYAT")
(47642 . "HANGUL SYLLABLE MYAP")
(47643 . "HANGUL SYLLABLE MYAH")
(47644 . "HANGUL SYLLABLE MYAE")
(47645 . "HANGUL SYLLABLE MYAEG")
(47646 . "HANGUL SYLLABLE MYAEGG")
(47647 . "HANGUL SYLLABLE MYAEGS")
(47648 . "HANGUL SYLLABLE MYAEN")
(47649 . "HANGUL SYLLABLE MYAENJ")
(47650 . "HANGUL SYLLABLE MYAENH")
(47651 . "HANGUL SYLLABLE MYAED")
(47652 . "HANGUL SYLLABLE MYAEL")
(47653 . "HANGUL SYLLABLE MYAELG")
(47654 . "HANGUL SYLLABLE MYAELM")
(47655 . "HANGUL SYLLABLE MYAELB")
(47656 . "HANGUL SYLLABLE MYAELS")
(47657 . "HANGUL SYLLABLE MYAELT")
(47658 . "HANGUL SYLLABLE MYAELP")
(47659 . "HANGUL SYLLABLE MYAELH")
(47660 . "HANGUL SYLLABLE MYAEM")
(47661 . "HANGUL SYLLABLE MYAEB")
(47662 . "HANGUL SYLLABLE MYAEBS")
(47663 . "HANGUL SYLLABLE MYAES")
(47664 . "HANGUL SYLLABLE MYAESS")
(47665 . "HANGUL SYLLABLE MYAENG")
(47666 . "HANGUL SYLLABLE MYAEJ")
(47667 . "HANGUL SYLLABLE MYAEC")
(47668 . "HANGUL SYLLABLE MYAEK")
(47669 . "HANGUL SYLLABLE MYAET")
(47670 . "HANGUL SYLLABLE MYAEP")
(47671 . "HANGUL SYLLABLE MYAEH")
(47672 . "HANGUL SYLLABLE MEO")
(47673 . "HANGUL SYLLABLE MEOG")
(47674 . "HANGUL SYLLABLE MEOGG")
(47675 . "HANGUL SYLLABLE MEOGS")
(47676 . "HANGUL SYLLABLE MEON")
(47677 . "HANGUL SYLLABLE MEONJ")
(47678 . "HANGUL SYLLABLE MEONH")
(47679 . "HANGUL SYLLABLE MEOD")
(47680 . "HANGUL SYLLABLE MEOL")
(47681 . "HANGUL SYLLABLE MEOLG")
(47682 . "HANGUL SYLLABLE MEOLM")
(47683 . "HANGUL SYLLABLE MEOLB")
(47684 . "HANGUL SYLLABLE MEOLS")
(47685 . "HANGUL SYLLABLE MEOLT")
(47686 . "HANGUL SYLLABLE MEOLP")
(47687 . "HANGUL SYLLABLE MEOLH")
(47688 . "HANGUL SYLLABLE MEOM")
(47689 . "HANGUL SYLLABLE MEOB")
(47690 . "HANGUL SYLLABLE MEOBS")
(47691 . "HANGUL SYLLABLE MEOS")
(47692 . "HANGUL SYLLABLE MEOSS")
(47693 . "HANGUL SYLLABLE MEONG")
(47694 . "HANGUL SYLLABLE MEOJ")
(47695 . "HANGUL SYLLABLE MEOC")
(47696 . "HANGUL SYLLABLE MEOK")
(47697 . "HANGUL SYLLABLE MEOT")
(47698 . "HANGUL SYLLABLE MEOP")
(47699 . "HANGUL SYLLABLE MEOH")
(47700 . "HANGUL SYLLABLE ME")
(47701 . "HANGUL SYLLABLE MEG")
(47702 . "HANGUL SYLLABLE MEGG")
(47703 . "HANGUL SYLLABLE MEGS")
(47704 . "HANGUL SYLLABLE MEN")
(47705 . "HANGUL SYLLABLE MENJ")
(47706 . "HANGUL SYLLABLE MENH")
(47707 . "HANGUL SYLLABLE MED")
(47708 . "HANGUL SYLLABLE MEL")
(47709 . "HANGUL SYLLABLE MELG")
(47710 . "HANGUL SYLLABLE MELM")
(47711 . "HANGUL SYLLABLE MELB")
(47712 . "HANGUL SYLLABLE MELS")
(47713 . "HANGUL SYLLABLE MELT")
(47714 . "HANGUL SYLLABLE MELP")
(47715 . "HANGUL SYLLABLE MELH")
(47716 . "HANGUL SYLLABLE MEM")
(47717 . "HANGUL SYLLABLE MEB")
(47718 . "HANGUL SYLLABLE MEBS")
(47719 . "HANGUL SYLLABLE MES")
(47720 . "HANGUL SYLLABLE MESS")
(47721 . "HANGUL SYLLABLE MENG")
(47722 . "HANGUL SYLLABLE MEJ")
(47723 . "HANGUL SYLLABLE MEC")
(47724 . "HANGUL SYLLABLE MEK")
(47725 . "HANGUL SYLLABLE MET")
(47726 . "HANGUL SYLLABLE MEP")
(47727 . "HANGUL SYLLABLE MEH")
(47728 . "HANGUL SYLLABLE MYEO")
(47729 . "HANGUL SYLLABLE MYEOG")
(47730 . "HANGUL SYLLABLE MYEOGG")
(47731 . "HANGUL SYLLABLE MYEOGS")
(47732 . "HANGUL SYLLABLE MYEON")
(47733 . "HANGUL SYLLABLE MYEONJ")
(47734 . "HANGUL SYLLABLE MYEONH")
(47735 . "HANGUL SYLLABLE MYEOD")
(47736 . "HANGUL SYLLABLE MYEOL")
(47737 . "HANGUL SYLLABLE MYEOLG")
(47738 . "HANGUL SYLLABLE MYEOLM")
(47739 . "HANGUL SYLLABLE MYEOLB")
(47740 . "HANGUL SYLLABLE MYEOLS")
(47741 . "HANGUL SYLLABLE MYEOLT")
(47742 . "HANGUL SYLLABLE MYEOLP")
(47743 . "HANGUL SYLLABLE MYEOLH")
(47744 . "HANGUL SYLLABLE MYEOM")
(47745 . "HANGUL SYLLABLE MYEOB")
(47746 . "HANGUL SYLLABLE MYEOBS")
(47747 . "HANGUL SYLLABLE MYEOS")
(47748 . "HANGUL SYLLABLE MYEOSS")
(47749 . "HANGUL SYLLABLE MYEONG")
(47750 . "HANGUL SYLLABLE MYEOJ")
(47751 . "HANGUL SYLLABLE MYEOC")
(47752 . "HANGUL SYLLABLE MYEOK")
(47753 . "HANGUL SYLLABLE MYEOT")
(47754 . "HANGUL SYLLABLE MYEOP")
(47755 . "HANGUL SYLLABLE MYEOH")
(47756 . "HANGUL SYLLABLE MYE")
(47757 . "HANGUL SYLLABLE MYEG")
(47758 . "HANGUL SYLLABLE MYEGG")
(47759 . "HANGUL SYLLABLE MYEGS")
(47760 . "HANGUL SYLLABLE MYEN")
(47761 . "HANGUL SYLLABLE MYENJ")
(47762 . "HANGUL SYLLABLE MYENH")
(47763 . "HANGUL SYLLABLE MYED")
(47764 . "HANGUL SYLLABLE MYEL")
(47765 . "HANGUL SYLLABLE MYELG")
(47766 . "HANGUL SYLLABLE MYELM")
(47767 . "HANGUL SYLLABLE MYELB")
(47768 . "HANGUL SYLLABLE MYELS")
(47769 . "HANGUL SYLLABLE MYELT")
(47770 . "HANGUL SYLLABLE MYELP")
(47771 . "HANGUL SYLLABLE MYELH")
(47772 . "HANGUL SYLLABLE MYEM")
(47773 . "HANGUL SYLLABLE MYEB")
(47774 . "HANGUL SYLLABLE MYEBS")
(47775 . "HANGUL SYLLABLE MYES")
(47776 . "HANGUL SYLLABLE MYESS")
(47777 . "HANGUL SYLLABLE MYENG")
(47778 . "HANGUL SYLLABLE MYEJ")
(47779 . "HANGUL SYLLABLE MYEC")
(47780 . "HANGUL SYLLABLE MYEK")
(47781 . "HANGUL SYLLABLE MYET")
(47782 . "HANGUL SYLLABLE MYEP")
(47783 . "HANGUL SYLLABLE MYEH")
(47784 . "HANGUL SYLLABLE MO")
(47785 . "HANGUL SYLLABLE MOG")
(47786 . "HANGUL SYLLABLE MOGG")
(47787 . "HANGUL SYLLABLE MOGS")
(47788 . "HANGUL SYLLABLE MON")
(47789 . "HANGUL SYLLABLE MONJ")
(47790 . "HANGUL SYLLABLE MONH")
(47791 . "HANGUL SYLLABLE MOD")
(47792 . "HANGUL SYLLABLE MOL")
(47793 . "HANGUL SYLLABLE MOLG")
(47794 . "HANGUL SYLLABLE MOLM")
(47795 . "HANGUL SYLLABLE MOLB")
(47796 . "HANGUL SYLLABLE MOLS")
(47797 . "HANGUL SYLLABLE MOLT")
(47798 . "HANGUL SYLLABLE MOLP")
(47799 . "HANGUL SYLLABLE MOLH")
(47800 . "HANGUL SYLLABLE MOM")
(47801 . "HANGUL SYLLABLE MOB")
(47802 . "HANGUL SYLLABLE MOBS")
(47803 . "HANGUL SYLLABLE MOS")
(47804 . "HANGUL SYLLABLE MOSS")
(47805 . "HANGUL SYLLABLE MONG")
(47806 . "HANGUL SYLLABLE MOJ")
(47807 . "HANGUL SYLLABLE MOC")
(47808 . "HANGUL SYLLABLE MOK")
(47809 . "HANGUL SYLLABLE MOT")
(47810 . "HANGUL SYLLABLE MOP")
(47811 . "HANGUL SYLLABLE MOH")
(47812 . "HANGUL SYLLABLE MWA")
(47813 . "HANGUL SYLLABLE MWAG")
(47814 . "HANGUL SYLLABLE MWAGG")
(47815 . "HANGUL SYLLABLE MWAGS")
(47816 . "HANGUL SYLLABLE MWAN")
(47817 . "HANGUL SYLLABLE MWANJ")
(47818 . "HANGUL SYLLABLE MWANH")
(47819 . "HANGUL SYLLABLE MWAD")
(47820 . "HANGUL SYLLABLE MWAL")
(47821 . "HANGUL SYLLABLE MWALG")
(47822 . "HANGUL SYLLABLE MWALM")
(47823 . "HANGUL SYLLABLE MWALB")
(47824 . "HANGUL SYLLABLE MWALS")
(47825 . "HANGUL SYLLABLE MWALT")
(47826 . "HANGUL SYLLABLE MWALP")
(47827 . "HANGUL SYLLABLE MWALH")
(47828 . "HANGUL SYLLABLE MWAM")
(47829 . "HANGUL SYLLABLE MWAB")
(47830 . "HANGUL SYLLABLE MWABS")
(47831 . "HANGUL SYLLABLE MWAS")
(47832 . "HANGUL SYLLABLE MWASS")
(47833 . "HANGUL SYLLABLE MWANG")
(47834 . "HANGUL SYLLABLE MWAJ")
(47835 . "HANGUL SYLLABLE MWAC")
(47836 . "HANGUL SYLLABLE MWAK")
(47837 . "HANGUL SYLLABLE MWAT")
(47838 . "HANGUL SYLLABLE MWAP")
(47839 . "HANGUL SYLLABLE MWAH")
(47840 . "HANGUL SYLLABLE MWAE")
(47841 . "HANGUL SYLLABLE MWAEG")
(47842 . "HANGUL SYLLABLE MWAEGG")
(47843 . "HANGUL SYLLABLE MWAEGS")
(47844 . "HANGUL SYLLABLE MWAEN")
(47845 . "HANGUL SYLLABLE MWAENJ")
(47846 . "HANGUL SYLLABLE MWAENH")
(47847 . "HANGUL SYLLABLE MWAED")
(47848 . "HANGUL SYLLABLE MWAEL")
(47849 . "HANGUL SYLLABLE MWAELG")
(47850 . "HANGUL SYLLABLE MWAELM")
(47851 . "HANGUL SYLLABLE MWAELB")
(47852 . "HANGUL SYLLABLE MWAELS")
(47853 . "HANGUL SYLLABLE MWAELT")
(47854 . "HANGUL SYLLABLE MWAELP")
(47855 . "HANGUL SYLLABLE MWAELH")
(47856 . "HANGUL SYLLABLE MWAEM")
(47857 . "HANGUL SYLLABLE MWAEB")
(47858 . "HANGUL SYLLABLE MWAEBS")
(47859 . "HANGUL SYLLABLE MWAES")
(47860 . "HANGUL SYLLABLE MWAESS")
(47861 . "HANGUL SYLLABLE MWAENG")
(47862 . "HANGUL SYLLABLE MWAEJ")
(47863 . "HANGUL SYLLABLE MWAEC")
(47864 . "HANGUL SYLLABLE MWAEK")
(47865 . "HANGUL SYLLABLE MWAET")
(47866 . "HANGUL SYLLABLE MWAEP")
(47867 . "HANGUL SYLLABLE MWAEH")
(47868 . "HANGUL SYLLABLE MOE")
(47869 . "HANGUL SYLLABLE MOEG")
(47870 . "HANGUL SYLLABLE MOEGG")
(47871 . "HANGUL SYLLABLE MOEGS")
(47872 . "HANGUL SYLLABLE MOEN")
(47873 . "HANGUL SYLLABLE MOENJ")
(47874 . "HANGUL SYLLABLE MOENH")
(47875 . "HANGUL SYLLABLE MOED")
(47876 . "HANGUL SYLLABLE MOEL")
(47877 . "HANGUL SYLLABLE MOELG")
(47878 . "HANGUL SYLLABLE MOELM")
(47879 . "HANGUL SYLLABLE MOELB")
(47880 . "HANGUL SYLLABLE MOELS")
(47881 . "HANGUL SYLLABLE MOELT")
(47882 . "HANGUL SYLLABLE MOELP")
(47883 . "HANGUL SYLLABLE MOELH")
(47884 . "HANGUL SYLLABLE MOEM")
(47885 . "HANGUL SYLLABLE MOEB")
(47886 . "HANGUL SYLLABLE MOEBS")
(47887 . "HANGUL SYLLABLE MOES")
(47888 . "HANGUL SYLLABLE MOESS")
(47889 . "HANGUL SYLLABLE MOENG")
(47890 . "HANGUL SYLLABLE MOEJ")
(47891 . "HANGUL SYLLABLE MOEC")
(47892 . "HANGUL SYLLABLE MOEK")
(47893 . "HANGUL SYLLABLE MOET")
(47894 . "HANGUL SYLLABLE MOEP")
(47895 . "HANGUL SYLLABLE MOEH")
(47896 . "HANGUL SYLLABLE MYO")
(47897 . "HANGUL SYLLABLE MYOG")
(47898 . "HANGUL SYLLABLE MYOGG")
(47899 . "HANGUL SYLLABLE MYOGS")
(47900 . "HANGUL SYLLABLE MYON")
(47901 . "HANGUL SYLLABLE MYONJ")
(47902 . "HANGUL SYLLABLE MYONH")
(47903 . "HANGUL SYLLABLE MYOD")
(47904 . "HANGUL SYLLABLE MYOL")
(47905 . "HANGUL SYLLABLE MYOLG")
(47906 . "HANGUL SYLLABLE MYOLM")
(47907 . "HANGUL SYLLABLE MYOLB")
(47908 . "HANGUL SYLLABLE MYOLS")
(47909 . "HANGUL SYLLABLE MYOLT")
(47910 . "HANGUL SYLLABLE MYOLP")
(47911 . "HANGUL SYLLABLE MYOLH")
(47912 . "HANGUL SYLLABLE MYOM")
(47913 . "HANGUL SYLLABLE MYOB")
(47914 . "HANGUL SYLLABLE MYOBS")
(47915 . "HANGUL SYLLABLE MYOS")
(47916 . "HANGUL SYLLABLE MYOSS")
(47917 . "HANGUL SYLLABLE MYONG")
(47918 . "HANGUL SYLLABLE MYOJ")
(47919 . "HANGUL SYLLABLE MYOC")
(47920 . "HANGUL SYLLABLE MYOK")
(47921 . "HANGUL SYLLABLE MYOT")
(47922 . "HANGUL SYLLABLE MYOP")
(47923 . "HANGUL SYLLABLE MYOH")
(47924 . "HANGUL SYLLABLE MU")
(47925 . "HANGUL SYLLABLE MUG")
(47926 . "HANGUL SYLLABLE MUGG")
(47927 . "HANGUL SYLLABLE MUGS")
(47928 . "HANGUL SYLLABLE MUN")
(47929 . "HANGUL SYLLABLE MUNJ")
(47930 . "HANGUL SYLLABLE MUNH")
(47931 . "HANGUL SYLLABLE MUD")
(47932 . "HANGUL SYLLABLE MUL")
(47933 . "HANGUL SYLLABLE MULG")
(47934 . "HANGUL SYLLABLE MULM")
(47935 . "HANGUL SYLLABLE MULB")
(47936 . "HANGUL SYLLABLE MULS")
(47937 . "HANGUL SYLLABLE MULT")
(47938 . "HANGUL SYLLABLE MULP")
(47939 . "HANGUL SYLLABLE MULH")
(47940 . "HANGUL SYLLABLE MUM")
(47941 . "HANGUL SYLLABLE MUB")
(47942 . "HANGUL SYLLABLE MUBS")
(47943 . "HANGUL SYLLABLE MUS")
(47944 . "HANGUL SYLLABLE MUSS")
(47945 . "HANGUL SYLLABLE MUNG")
(47946 . "HANGUL SYLLABLE MUJ")
(47947 . "HANGUL SYLLABLE MUC")
(47948 . "HANGUL SYLLABLE MUK")
(47949 . "HANGUL SYLLABLE MUT")
(47950 . "HANGUL SYLLABLE MUP")
(47951 . "HANGUL SYLLABLE MUH")
(47952 . "HANGUL SYLLABLE MWEO")
(47953 . "HANGUL SYLLABLE MWEOG")
(47954 . "HANGUL SYLLABLE MWEOGG")
(47955 . "HANGUL SYLLABLE MWEOGS")
(47956 . "HANGUL SYLLABLE MWEON")
(47957 . "HANGUL SYLLABLE MWEONJ")
(47958 . "HANGUL SYLLABLE MWEONH")
(47959 . "HANGUL SYLLABLE MWEOD")
(47960 . "HANGUL SYLLABLE MWEOL")
(47961 . "HANGUL SYLLABLE MWEOLG")
(47962 . "HANGUL SYLLABLE MWEOLM")
(47963 . "HANGUL SYLLABLE MWEOLB")
(47964 . "HANGUL SYLLABLE MWEOLS")
(47965 . "HANGUL SYLLABLE MWEOLT")
(47966 . "HANGUL SYLLABLE MWEOLP")
(47967 . "HANGUL SYLLABLE MWEOLH")
(47968 . "HANGUL SYLLABLE MWEOM")
(47969 . "HANGUL SYLLABLE MWEOB")
(47970 . "HANGUL SYLLABLE MWEOBS")
(47971 . "HANGUL SYLLABLE MWEOS")
(47972 . "HANGUL SYLLABLE MWEOSS")
(47973 . "HANGUL SYLLABLE MWEONG")
(47974 . "HANGUL SYLLABLE MWEOJ")
(47975 . "HANGUL SYLLABLE MWEOC")
(47976 . "HANGUL SYLLABLE MWEOK")
(47977 . "HANGUL SYLLABLE MWEOT")
(47978 . "HANGUL SYLLABLE MWEOP")
(47979 . "HANGUL SYLLABLE MWEOH")
(47980 . "HANGUL SYLLABLE MWE")
(47981 . "HANGUL SYLLABLE MWEG")
(47982 . "HANGUL SYLLABLE MWEGG")
(47983 . "HANGUL SYLLABLE MWEGS")
(47984 . "HANGUL SYLLABLE MWEN")
(47985 . "HANGUL SYLLABLE MWENJ")
(47986 . "HANGUL SYLLABLE MWENH")
(47987 . "HANGUL SYLLABLE MWED")
(47988 . "HANGUL SYLLABLE MWEL")
(47989 . "HANGUL SYLLABLE MWELG")
(47990 . "HANGUL SYLLABLE MWELM")
(47991 . "HANGUL SYLLABLE MWELB")
(47992 . "HANGUL SYLLABLE MWELS")
(47993 . "HANGUL SYLLABLE MWELT")
(47994 . "HANGUL SYLLABLE MWELP")
(47995 . "HANGUL SYLLABLE MWELH")
(47996 . "HANGUL SYLLABLE MWEM")
(47997 . "HANGUL SYLLABLE MWEB")
(47998 . "HANGUL SYLLABLE MWEBS")
(47999 . "HANGUL SYLLABLE MWES")
(48000 . "HANGUL SYLLABLE MWESS")
(48001 . "HANGUL SYLLABLE MWENG")
(48002 . "HANGUL SYLLABLE MWEJ")
(48003 . "HANGUL SYLLABLE MWEC")
(48004 . "HANGUL SYLLABLE MWEK")
(48005 . "HANGUL SYLLABLE MWET")
(48006 . "HANGUL SYLLABLE MWEP")
(48007 . "HANGUL SYLLABLE MWEH")
(48008 . "HANGUL SYLLABLE MWI")
(48009 . "HANGUL SYLLABLE MWIG")
(48010 . "HANGUL SYLLABLE MWIGG")
(48011 . "HANGUL SYLLABLE MWIGS")
(48012 . "HANGUL SYLLABLE MWIN")
(48013 . "HANGUL SYLLABLE MWINJ")
(48014 . "HANGUL SYLLABLE MWINH")
(48015 . "HANGUL SYLLABLE MWID")
(48016 . "HANGUL SYLLABLE MWIL")
(48017 . "HANGUL SYLLABLE MWILG")
(48018 . "HANGUL SYLLABLE MWILM")
(48019 . "HANGUL SYLLABLE MWILB")
(48020 . "HANGUL SYLLABLE MWILS")
(48021 . "HANGUL SYLLABLE MWILT")
(48022 . "HANGUL SYLLABLE MWILP")
(48023 . "HANGUL SYLLABLE MWILH")
(48024 . "HANGUL SYLLABLE MWIM")
(48025 . "HANGUL SYLLABLE MWIB")
(48026 . "HANGUL SYLLABLE MWIBS")
(48027 . "HANGUL SYLLABLE MWIS")
(48028 . "HANGUL SYLLABLE MWISS")
(48029 . "HANGUL SYLLABLE MWING")
(48030 . "HANGUL SYLLABLE MWIJ")
(48031 . "HANGUL SYLLABLE MWIC")
(48032 . "HANGUL SYLLABLE MWIK")
(48033 . "HANGUL SYLLABLE MWIT")
(48034 . "HANGUL SYLLABLE MWIP")
(48035 . "HANGUL SYLLABLE MWIH")
(48036 . "HANGUL SYLLABLE MYU")
(48037 . "HANGUL SYLLABLE MYUG")
(48038 . "HANGUL SYLLABLE MYUGG")
(48039 . "HANGUL SYLLABLE MYUGS")
(48040 . "HANGUL SYLLABLE MYUN")
(48041 . "HANGUL SYLLABLE MYUNJ")
(48042 . "HANGUL SYLLABLE MYUNH")
(48043 . "HANGUL SYLLABLE MYUD")
(48044 . "HANGUL SYLLABLE MYUL")
(48045 . "HANGUL SYLLABLE MYULG")
(48046 . "HANGUL SYLLABLE MYULM")
(48047 . "HANGUL SYLLABLE MYULB")
(48048 . "HANGUL SYLLABLE MYULS")
(48049 . "HANGUL SYLLABLE MYULT")
(48050 . "HANGUL SYLLABLE MYULP")
(48051 . "HANGUL SYLLABLE MYULH")
(48052 . "HANGUL SYLLABLE MYUM")
(48053 . "HANGUL SYLLABLE MYUB")
(48054 . "HANGUL SYLLABLE MYUBS")
(48055 . "HANGUL SYLLABLE MYUS")
(48056 . "HANGUL SYLLABLE MYUSS")
(48057 . "HANGUL SYLLABLE MYUNG")
(48058 . "HANGUL SYLLABLE MYUJ")
(48059 . "HANGUL SYLLABLE MYUC")
(48060 . "HANGUL SYLLABLE MYUK")
(48061 . "HANGUL SYLLABLE MYUT")
(48062 . "HANGUL SYLLABLE MYUP")
(48063 . "HANGUL SYLLABLE MYUH")
(48064 . "HANGUL SYLLABLE MEU")
(48065 . "HANGUL SYLLABLE MEUG")
(48066 . "HANGUL SYLLABLE MEUGG")
(48067 . "HANGUL SYLLABLE MEUGS")
(48068 . "HANGUL SYLLABLE MEUN")
(48069 . "HANGUL SYLLABLE MEUNJ")
(48070 . "HANGUL SYLLABLE MEUNH")
(48071 . "HANGUL SYLLABLE MEUD")
(48072 . "HANGUL SYLLABLE MEUL")
(48073 . "HANGUL SYLLABLE MEULG")
(48074 . "HANGUL SYLLABLE MEULM")
(48075 . "HANGUL SYLLABLE MEULB")
(48076 . "HANGUL SYLLABLE MEULS")
(48077 . "HANGUL SYLLABLE MEULT")
(48078 . "HANGUL SYLLABLE MEULP")
(48079 . "HANGUL SYLLABLE MEULH")
(48080 . "HANGUL SYLLABLE MEUM")
(48081 . "HANGUL SYLLABLE MEUB")
(48082 . "HANGUL SYLLABLE MEUBS")
(48083 . "HANGUL SYLLABLE MEUS")
(48084 . "HANGUL SYLLABLE MEUSS")
(48085 . "HANGUL SYLLABLE MEUNG")
(48086 . "HANGUL SYLLABLE MEUJ")
(48087 . "HANGUL SYLLABLE MEUC")
(48088 . "HANGUL SYLLABLE MEUK")
(48089 . "HANGUL SYLLABLE MEUT")
(48090 . "HANGUL SYLLABLE MEUP")
(48091 . "HANGUL SYLLABLE MEUH")
(48092 . "HANGUL SYLLABLE MYI")
(48093 . "HANGUL SYLLABLE MYIG")
(48094 . "HANGUL SYLLABLE MYIGG")
(48095 . "HANGUL SYLLABLE MYIGS")
(48096 . "HANGUL SYLLABLE MYIN")
(48097 . "HANGUL SYLLABLE MYINJ")
(48098 . "HANGUL SYLLABLE MYINH")
(48099 . "HANGUL SYLLABLE MYID")
(48100 . "HANGUL SYLLABLE MYIL")
(48101 . "HANGUL SYLLABLE MYILG")
(48102 . "HANGUL SYLLABLE MYILM")
(48103 . "HANGUL SYLLABLE MYILB")
(48104 . "HANGUL SYLLABLE MYILS")
(48105 . "HANGUL SYLLABLE MYILT")
(48106 . "HANGUL SYLLABLE MYILP")
(48107 . "HANGUL SYLLABLE MYILH")
(48108 . "HANGUL SYLLABLE MYIM")
(48109 . "HANGUL SYLLABLE MYIB")
(48110 . "HANGUL SYLLABLE MYIBS")
(48111 . "HANGUL SYLLABLE MYIS")
(48112 . "HANGUL SYLLABLE MYISS")
(48113 . "HANGUL SYLLABLE MYING")
(48114 . "HANGUL SYLLABLE MYIJ")
(48115 . "HANGUL SYLLABLE MYIC")
(48116 . "HANGUL SYLLABLE MYIK")
(48117 . "HANGUL SYLLABLE MYIT")
(48118 . "HANGUL SYLLABLE MYIP")
(48119 . "HANGUL SYLLABLE MYIH")
(48120 . "HANGUL SYLLABLE MI")
(48121 . "HANGUL SYLLABLE MIG")
(48122 . "HANGUL SYLLABLE MIGG")
(48123 . "HANGUL SYLLABLE MIGS")
(48124 . "HANGUL SYLLABLE MIN")
(48125 . "HANGUL SYLLABLE MINJ")
(48126 . "HANGUL SYLLABLE MINH")
(48127 . "HANGUL SYLLABLE MID")
(48128 . "HANGUL SYLLABLE MIL")
(48129 . "HANGUL SYLLABLE MILG")
(48130 . "HANGUL SYLLABLE MILM")
(48131 . "HANGUL SYLLABLE MILB")
(48132 . "HANGUL SYLLABLE MILS")
(48133 . "HANGUL SYLLABLE MILT")
(48134 . "HANGUL SYLLABLE MILP")
(48135 . "HANGUL SYLLABLE MILH")
(48136 . "HANGUL SYLLABLE MIM")
(48137 . "HANGUL SYLLABLE MIB")
(48138 . "HANGUL SYLLABLE MIBS")
(48139 . "HANGUL SYLLABLE MIS")
(48140 . "HANGUL SYLLABLE MISS")
(48141 . "HANGUL SYLLABLE MING")
(48142 . "HANGUL SYLLABLE MIJ")
(48143 . "HANGUL SYLLABLE MIC")
(48144 . "HANGUL SYLLABLE MIK")
(48145 . "HANGUL SYLLABLE MIT")
(48146 . "HANGUL SYLLABLE MIP")
(48147 . "HANGUL SYLLABLE MIH")
(48148 . "HANGUL SYLLABLE BA")
(48149 . "HANGUL SYLLABLE BAG")
(48150 . "HANGUL SYLLABLE BAGG")
(48151 . "HANGUL SYLLABLE BAGS")
(48152 . "HANGUL SYLLABLE BAN")
(48153 . "HANGUL SYLLABLE BANJ")
(48154 . "HANGUL SYLLABLE BANH")
(48155 . "HANGUL SYLLABLE BAD")
(48156 . "HANGUL SYLLABLE BAL")
(48157 . "HANGUL SYLLABLE BALG")
(48158 . "HANGUL SYLLABLE BALM")
(48159 . "HANGUL SYLLABLE BALB")
(48160 . "HANGUL SYLLABLE BALS")
(48161 . "HANGUL SYLLABLE BALT")
(48162 . "HANGUL SYLLABLE BALP")
(48163 . "HANGUL SYLLABLE BALH")
(48164 . "HANGUL SYLLABLE BAM")
(48165 . "HANGUL SYLLABLE BAB")
(48166 . "HANGUL SYLLABLE BABS")
(48167 . "HANGUL SYLLABLE BAS")
(48168 . "HANGUL SYLLABLE BASS")
(48169 . "HANGUL SYLLABLE BANG")
(48170 . "HANGUL SYLLABLE BAJ")
(48171 . "HANGUL SYLLABLE BAC")
(48172 . "HANGUL SYLLABLE BAK")
(48173 . "HANGUL SYLLABLE BAT")
(48174 . "HANGUL SYLLABLE BAP")
(48175 . "HANGUL SYLLABLE BAH")
(48176 . "HANGUL SYLLABLE BAE")
(48177 . "HANGUL SYLLABLE BAEG")
(48178 . "HANGUL SYLLABLE BAEGG")
(48179 . "HANGUL SYLLABLE BAEGS")
(48180 . "HANGUL SYLLABLE BAEN")
(48181 . "HANGUL SYLLABLE BAENJ")
(48182 . "HANGUL SYLLABLE BAENH")
(48183 . "HANGUL SYLLABLE BAED")
(48184 . "HANGUL SYLLABLE BAEL")
(48185 . "HANGUL SYLLABLE BAELG")
(48186 . "HANGUL SYLLABLE BAELM")
(48187 . "HANGUL SYLLABLE BAELB")
(48188 . "HANGUL SYLLABLE BAELS")
(48189 . "HANGUL SYLLABLE BAELT")
(48190 . "HANGUL SYLLABLE BAELP")
(48191 . "HANGUL SYLLABLE BAELH")
(48192 . "HANGUL SYLLABLE BAEM")
(48193 . "HANGUL SYLLABLE BAEB")
(48194 . "HANGUL SYLLABLE BAEBS")
(48195 . "HANGUL SYLLABLE BAES")
(48196 . "HANGUL SYLLABLE BAESS")
(48197 . "HANGUL SYLLABLE BAENG")
(48198 . "HANGUL SYLLABLE BAEJ")
(48199 . "HANGUL SYLLABLE BAEC")
(48200 . "HANGUL SYLLABLE BAEK")
(48201 . "HANGUL SYLLABLE BAET")
(48202 . "HANGUL SYLLABLE BAEP")
(48203 . "HANGUL SYLLABLE BAEH")
(48204 . "HANGUL SYLLABLE BYA")
(48205 . "HANGUL SYLLABLE BYAG")
(48206 . "HANGUL SYLLABLE BYAGG")
(48207 . "HANGUL SYLLABLE BYAGS")
(48208 . "HANGUL SYLLABLE BYAN")
(48209 . "HANGUL SYLLABLE BYANJ")
(48210 . "HANGUL SYLLABLE BYANH")
(48211 . "HANGUL SYLLABLE BYAD")
(48212 . "HANGUL SYLLABLE BYAL")
(48213 . "HANGUL SYLLABLE BYALG")
(48214 . "HANGUL SYLLABLE BYALM")
(48215 . "HANGUL SYLLABLE BYALB")
(48216 . "HANGUL SYLLABLE BYALS")
(48217 . "HANGUL SYLLABLE BYALT")
(48218 . "HANGUL SYLLABLE BYALP")
(48219 . "HANGUL SYLLABLE BYALH")
(48220 . "HANGUL SYLLABLE BYAM")
(48221 . "HANGUL SYLLABLE BYAB")
(48222 . "HANGUL SYLLABLE BYABS")
(48223 . "HANGUL SYLLABLE BYAS")
(48224 . "HANGUL SYLLABLE BYASS")
(48225 . "HANGUL SYLLABLE BYANG")
(48226 . "HANGUL SYLLABLE BYAJ")
(48227 . "HANGUL SYLLABLE BYAC")
(48228 . "HANGUL SYLLABLE BYAK")
(48229 . "HANGUL SYLLABLE BYAT")
(48230 . "HANGUL SYLLABLE BYAP")
(48231 . "HANGUL SYLLABLE BYAH")
(48232 . "HANGUL SYLLABLE BYAE")
(48233 . "HANGUL SYLLABLE BYAEG")
(48234 . "HANGUL SYLLABLE BYAEGG")
(48235 . "HANGUL SYLLABLE BYAEGS")
(48236 . "HANGUL SYLLABLE BYAEN")
(48237 . "HANGUL SYLLABLE BYAENJ")
(48238 . "HANGUL SYLLABLE BYAENH")
(48239 . "HANGUL SYLLABLE BYAED")
(48240 . "HANGUL SYLLABLE BYAEL")
(48241 . "HANGUL SYLLABLE BYAELG")
(48242 . "HANGUL SYLLABLE BYAELM")
(48243 . "HANGUL SYLLABLE BYAELB")
(48244 . "HANGUL SYLLABLE BYAELS")
(48245 . "HANGUL SYLLABLE BYAELT")
(48246 . "HANGUL SYLLABLE BYAELP")
(48247 . "HANGUL SYLLABLE BYAELH")
(48248 . "HANGUL SYLLABLE BYAEM")
(48249 . "HANGUL SYLLABLE BYAEB")
(48250 . "HANGUL SYLLABLE BYAEBS")
(48251 . "HANGUL SYLLABLE BYAES")
(48252 . "HANGUL SYLLABLE BYAESS")
(48253 . "HANGUL SYLLABLE BYAENG")
(48254 . "HANGUL SYLLABLE BYAEJ")
(48255 . "HANGUL SYLLABLE BYAEC")
(48256 . "HANGUL SYLLABLE BYAEK")
(48257 . "HANGUL SYLLABLE BYAET")
(48258 . "HANGUL SYLLABLE BYAEP")
(48259 . "HANGUL SYLLABLE BYAEH")
(48260 . "HANGUL SYLLABLE BEO")
(48261 . "HANGUL SYLLABLE BEOG")
(48262 . "HANGUL SYLLABLE BEOGG")
(48263 . "HANGUL SYLLABLE BEOGS")
(48264 . "HANGUL SYLLABLE BEON")
(48265 . "HANGUL SYLLABLE BEONJ")
(48266 . "HANGUL SYLLABLE BEONH")
(48267 . "HANGUL SYLLABLE BEOD")
(48268 . "HANGUL SYLLABLE BEOL")
(48269 . "HANGUL SYLLABLE BEOLG")
(48270 . "HANGUL SYLLABLE BEOLM")
(48271 . "HANGUL SYLLABLE BEOLB")
(48272 . "HANGUL SYLLABLE BEOLS")
(48273 . "HANGUL SYLLABLE BEOLT")
(48274 . "HANGUL SYLLABLE BEOLP")
(48275 . "HANGUL SYLLABLE BEOLH")
(48276 . "HANGUL SYLLABLE BEOM")
(48277 . "HANGUL SYLLABLE BEOB")
(48278 . "HANGUL SYLLABLE BEOBS")
(48279 . "HANGUL SYLLABLE BEOS")
(48280 . "HANGUL SYLLABLE BEOSS")
(48281 . "HANGUL SYLLABLE BEONG")
(48282 . "HANGUL SYLLABLE BEOJ")
(48283 . "HANGUL SYLLABLE BEOC")
(48284 . "HANGUL SYLLABLE BEOK")
(48285 . "HANGUL SYLLABLE BEOT")
(48286 . "HANGUL SYLLABLE BEOP")
(48287 . "HANGUL SYLLABLE BEOH")
(48288 . "HANGUL SYLLABLE BE")
(48289 . "HANGUL SYLLABLE BEG")
(48290 . "HANGUL SYLLABLE BEGG")
(48291 . "HANGUL SYLLABLE BEGS")
(48292 . "HANGUL SYLLABLE BEN")
(48293 . "HANGUL SYLLABLE BENJ")
(48294 . "HANGUL SYLLABLE BENH")
(48295 . "HANGUL SYLLABLE BED")
(48296 . "HANGUL SYLLABLE BEL")
(48297 . "HANGUL SYLLABLE BELG")
(48298 . "HANGUL SYLLABLE BELM")
(48299 . "HANGUL SYLLABLE BELB")
(48300 . "HANGUL SYLLABLE BELS")
(48301 . "HANGUL SYLLABLE BELT")
(48302 . "HANGUL SYLLABLE BELP")
(48303 . "HANGUL SYLLABLE BELH")
(48304 . "HANGUL SYLLABLE BEM")
(48305 . "HANGUL SYLLABLE BEB")
(48306 . "HANGUL SYLLABLE BEBS")
(48307 . "HANGUL SYLLABLE BES")
(48308 . "HANGUL SYLLABLE BESS")
(48309 . "HANGUL SYLLABLE BENG")
(48310 . "HANGUL SYLLABLE BEJ")
(48311 . "HANGUL SYLLABLE BEC")
(48312 . "HANGUL SYLLABLE BEK")
(48313 . "HANGUL SYLLABLE BET")
(48314 . "HANGUL SYLLABLE BEP")
(48315 . "HANGUL SYLLABLE BEH")
(48316 . "HANGUL SYLLABLE BYEO")
(48317 . "HANGUL SYLLABLE BYEOG")
(48318 . "HANGUL SYLLABLE BYEOGG")
(48319 . "HANGUL SYLLABLE BYEOGS")
(48320 . "HANGUL SYLLABLE BYEON")
(48321 . "HANGUL SYLLABLE BYEONJ")
(48322 . "HANGUL SYLLABLE BYEONH")
(48323 . "HANGUL SYLLABLE BYEOD")
(48324 . "HANGUL SYLLABLE BYEOL")
(48325 . "HANGUL SYLLABLE BYEOLG")
(48326 . "HANGUL SYLLABLE BYEOLM")
(48327 . "HANGUL SYLLABLE BYEOLB")
(48328 . "HANGUL SYLLABLE BYEOLS")
(48329 . "HANGUL SYLLABLE BYEOLT")
(48330 . "HANGUL SYLLABLE BYEOLP")
(48331 . "HANGUL SYLLABLE BYEOLH")
(48332 . "HANGUL SYLLABLE BYEOM")
(48333 . "HANGUL SYLLABLE BYEOB")
(48334 . "HANGUL SYLLABLE BYEOBS")
(48335 . "HANGUL SYLLABLE BYEOS")
(48336 . "HANGUL SYLLABLE BYEOSS")
(48337 . "HANGUL SYLLABLE BYEONG")
(48338 . "HANGUL SYLLABLE BYEOJ")
(48339 . "HANGUL SYLLABLE BYEOC")
(48340 . "HANGUL SYLLABLE BYEOK")
(48341 . "HANGUL SYLLABLE BYEOT")
(48342 . "HANGUL SYLLABLE BYEOP")
(48343 . "HANGUL SYLLABLE BYEOH")
(48344 . "HANGUL SYLLABLE BYE")
(48345 . "HANGUL SYLLABLE BYEG")
(48346 . "HANGUL SYLLABLE BYEGG")
(48347 . "HANGUL SYLLABLE BYEGS")
(48348 . "HANGUL SYLLABLE BYEN")
(48349 . "HANGUL SYLLABLE BYENJ")
(48350 . "HANGUL SYLLABLE BYENH")
(48351 . "HANGUL SYLLABLE BYED")
(48352 . "HANGUL SYLLABLE BYEL")
(48353 . "HANGUL SYLLABLE BYELG")
(48354 . "HANGUL SYLLABLE BYELM")
(48355 . "HANGUL SYLLABLE BYELB")
(48356 . "HANGUL SYLLABLE BYELS")
(48357 . "HANGUL SYLLABLE BYELT")
(48358 . "HANGUL SYLLABLE BYELP")
(48359 . "HANGUL SYLLABLE BYELH")
(48360 . "HANGUL SYLLABLE BYEM")
(48361 . "HANGUL SYLLABLE BYEB")
(48362 . "HANGUL SYLLABLE BYEBS")
(48363 . "HANGUL SYLLABLE BYES")
(48364 . "HANGUL SYLLABLE BYESS")
(48365 . "HANGUL SYLLABLE BYENG")
(48366 . "HANGUL SYLLABLE BYEJ")
(48367 . "HANGUL SYLLABLE BYEC")
(48368 . "HANGUL SYLLABLE BYEK")
(48369 . "HANGUL SYLLABLE BYET")
(48370 . "HANGUL SYLLABLE BYEP")
(48371 . "HANGUL SYLLABLE BYEH")
(48372 . "HANGUL SYLLABLE BO")
(48373 . "HANGUL SYLLABLE BOG")
(48374 . "HANGUL SYLLABLE BOGG")
(48375 . "HANGUL SYLLABLE BOGS")
(48376 . "HANGUL SYLLABLE BON")
(48377 . "HANGUL SYLLABLE BONJ")
(48378 . "HANGUL SYLLABLE BONH")
(48379 . "HANGUL SYLLABLE BOD")
(48380 . "HANGUL SYLLABLE BOL")
(48381 . "HANGUL SYLLABLE BOLG")
(48382 . "HANGUL SYLLABLE BOLM")
(48383 . "HANGUL SYLLABLE BOLB")
(48384 . "HANGUL SYLLABLE BOLS")
(48385 . "HANGUL SYLLABLE BOLT")
(48386 . "HANGUL SYLLABLE BOLP")
(48387 . "HANGUL SYLLABLE BOLH")
(48388 . "HANGUL SYLLABLE BOM")
(48389 . "HANGUL SYLLABLE BOB")
(48390 . "HANGUL SYLLABLE BOBS")
(48391 . "HANGUL SYLLABLE BOS")
(48392 . "HANGUL SYLLABLE BOSS")
(48393 . "HANGUL SYLLABLE BONG")
(48394 . "HANGUL SYLLABLE BOJ")
(48395 . "HANGUL SYLLABLE BOC")
(48396 . "HANGUL SYLLABLE BOK")
(48397 . "HANGUL SYLLABLE BOT")
(48398 . "HANGUL SYLLABLE BOP")
(48399 . "HANGUL SYLLABLE BOH")
(48400 . "HANGUL SYLLABLE BWA")
(48401 . "HANGUL SYLLABLE BWAG")
(48402 . "HANGUL SYLLABLE BWAGG")
(48403 . "HANGUL SYLLABLE BWAGS")
(48404 . "HANGUL SYLLABLE BWAN")
(48405 . "HANGUL SYLLABLE BWANJ")
(48406 . "HANGUL SYLLABLE BWANH")
(48407 . "HANGUL SYLLABLE BWAD")
(48408 . "HANGUL SYLLABLE BWAL")
(48409 . "HANGUL SYLLABLE BWALG")
(48410 . "HANGUL SYLLABLE BWALM")
(48411 . "HANGUL SYLLABLE BWALB")
(48412 . "HANGUL SYLLABLE BWALS")
(48413 . "HANGUL SYLLABLE BWALT")
(48414 . "HANGUL SYLLABLE BWALP")
(48415 . "HANGUL SYLLABLE BWALH")
(48416 . "HANGUL SYLLABLE BWAM")
(48417 . "HANGUL SYLLABLE BWAB")
(48418 . "HANGUL SYLLABLE BWABS")
(48419 . "HANGUL SYLLABLE BWAS")
(48420 . "HANGUL SYLLABLE BWASS")
(48421 . "HANGUL SYLLABLE BWANG")
(48422 . "HANGUL SYLLABLE BWAJ")
(48423 . "HANGUL SYLLABLE BWAC")
(48424 . "HANGUL SYLLABLE BWAK")
(48425 . "HANGUL SYLLABLE BWAT")
(48426 . "HANGUL SYLLABLE BWAP")
(48427 . "HANGUL SYLLABLE BWAH")
(48428 . "HANGUL SYLLABLE BWAE")
(48429 . "HANGUL SYLLABLE BWAEG")
(48430 . "HANGUL SYLLABLE BWAEGG")
(48431 . "HANGUL SYLLABLE BWAEGS")
(48432 . "HANGUL SYLLABLE BWAEN")
(48433 . "HANGUL SYLLABLE BWAENJ")
(48434 . "HANGUL SYLLABLE BWAENH")
(48435 . "HANGUL SYLLABLE BWAED")
(48436 . "HANGUL SYLLABLE BWAEL")
(48437 . "HANGUL SYLLABLE BWAELG")
(48438 . "HANGUL SYLLABLE BWAELM")
(48439 . "HANGUL SYLLABLE BWAELB")
(48440 . "HANGUL SYLLABLE BWAELS")
(48441 . "HANGUL SYLLABLE BWAELT")
(48442 . "HANGUL SYLLABLE BWAELP")
(48443 . "HANGUL SYLLABLE BWAELH")
(48444 . "HANGUL SYLLABLE BWAEM")
(48445 . "HANGUL SYLLABLE BWAEB")
(48446 . "HANGUL SYLLABLE BWAEBS")
(48447 . "HANGUL SYLLABLE BWAES")
(48448 . "HANGUL SYLLABLE BWAESS")
(48449 . "HANGUL SYLLABLE BWAENG")
(48450 . "HANGUL SYLLABLE BWAEJ")
(48451 . "HANGUL SYLLABLE BWAEC")
(48452 . "HANGUL SYLLABLE BWAEK")
(48453 . "HANGUL SYLLABLE BWAET")
(48454 . "HANGUL SYLLABLE BWAEP")
(48455 . "HANGUL SYLLABLE BWAEH")
(48456 . "HANGUL SYLLABLE BOE")
(48457 . "HANGUL SYLLABLE BOEG")
(48458 . "HANGUL SYLLABLE BOEGG")
(48459 . "HANGUL SYLLABLE BOEGS")
(48460 . "HANGUL SYLLABLE BOEN")
(48461 . "HANGUL SYLLABLE BOENJ")
(48462 . "HANGUL SYLLABLE BOENH")
(48463 . "HANGUL SYLLABLE BOED")
(48464 . "HANGUL SYLLABLE BOEL")
(48465 . "HANGUL SYLLABLE BOELG")
(48466 . "HANGUL SYLLABLE BOELM")
(48467 . "HANGUL SYLLABLE BOELB")
(48468 . "HANGUL SYLLABLE BOELS")
(48469 . "HANGUL SYLLABLE BOELT")
(48470 . "HANGUL SYLLABLE BOELP")
(48471 . "HANGUL SYLLABLE BOELH")
(48472 . "HANGUL SYLLABLE BOEM")
(48473 . "HANGUL SYLLABLE BOEB")
(48474 . "HANGUL SYLLABLE BOEBS")
(48475 . "HANGUL SYLLABLE BOES")
(48476 . "HANGUL SYLLABLE BOESS")
(48477 . "HANGUL SYLLABLE BOENG")
(48478 . "HANGUL SYLLABLE BOEJ")
(48479 . "HANGUL SYLLABLE BOEC")
(48480 . "HANGUL SYLLABLE BOEK")
(48481 . "HANGUL SYLLABLE BOET")
(48482 . "HANGUL SYLLABLE BOEP")
(48483 . "HANGUL SYLLABLE BOEH")
(48484 . "HANGUL SYLLABLE BYO")
(48485 . "HANGUL SYLLABLE BYOG")
(48486 . "HANGUL SYLLABLE BYOGG")
(48487 . "HANGUL SYLLABLE BYOGS")
(48488 . "HANGUL SYLLABLE BYON")
(48489 . "HANGUL SYLLABLE BYONJ")
(48490 . "HANGUL SYLLABLE BYONH")
(48491 . "HANGUL SYLLABLE BYOD")
(48492 . "HANGUL SYLLABLE BYOL")
(48493 . "HANGUL SYLLABLE BYOLG")
(48494 . "HANGUL SYLLABLE BYOLM")
(48495 . "HANGUL SYLLABLE BYOLB")
(48496 . "HANGUL SYLLABLE BYOLS")
(48497 . "HANGUL SYLLABLE BYOLT")
(48498 . "HANGUL SYLLABLE BYOLP")
(48499 . "HANGUL SYLLABLE BYOLH")
(48500 . "HANGUL SYLLABLE BYOM")
(48501 . "HANGUL SYLLABLE BYOB")
(48502 . "HANGUL SYLLABLE BYOBS")
(48503 . "HANGUL SYLLABLE BYOS")
(48504 . "HANGUL SYLLABLE BYOSS")
(48505 . "HANGUL SYLLABLE BYONG")
(48506 . "HANGUL SYLLABLE BYOJ")
(48507 . "HANGUL SYLLABLE BYOC")
(48508 . "HANGUL SYLLABLE BYOK")
(48509 . "HANGUL SYLLABLE BYOT")
(48510 . "HANGUL SYLLABLE BYOP")
(48511 . "HANGUL SYLLABLE BYOH")
(48512 . "HANGUL SYLLABLE BU")
(48513 . "HANGUL SYLLABLE BUG")
(48514 . "HANGUL SYLLABLE BUGG")
(48515 . "HANGUL SYLLABLE BUGS")
(48516 . "HANGUL SYLLABLE BUN")
(48517 . "HANGUL SYLLABLE BUNJ")
(48518 . "HANGUL SYLLABLE BUNH")
(48519 . "HANGUL SYLLABLE BUD")
(48520 . "HANGUL SYLLABLE BUL")
(48521 . "HANGUL SYLLABLE BULG")
(48522 . "HANGUL SYLLABLE BULM")
(48523 . "HANGUL SYLLABLE BULB")
(48524 . "HANGUL SYLLABLE BULS")
(48525 . "HANGUL SYLLABLE BULT")
(48526 . "HANGUL SYLLABLE BULP")
(48527 . "HANGUL SYLLABLE BULH")
(48528 . "HANGUL SYLLABLE BUM")
(48529 . "HANGUL SYLLABLE BUB")
(48530 . "HANGUL SYLLABLE BUBS")
(48531 . "HANGUL SYLLABLE BUS")
(48532 . "HANGUL SYLLABLE BUSS")
(48533 . "HANGUL SYLLABLE BUNG")
(48534 . "HANGUL SYLLABLE BUJ")
(48535 . "HANGUL SYLLABLE BUC")
(48536 . "HANGUL SYLLABLE BUK")
(48537 . "HANGUL SYLLABLE BUT")
(48538 . "HANGUL SYLLABLE BUP")
(48539 . "HANGUL SYLLABLE BUH")
(48540 . "HANGUL SYLLABLE BWEO")
(48541 . "HANGUL SYLLABLE BWEOG")
(48542 . "HANGUL SYLLABLE BWEOGG")
(48543 . "HANGUL SYLLABLE BWEOGS")
(48544 . "HANGUL SYLLABLE BWEON")
(48545 . "HANGUL SYLLABLE BWEONJ")
(48546 . "HANGUL SYLLABLE BWEONH")
(48547 . "HANGUL SYLLABLE BWEOD")
(48548 . "HANGUL SYLLABLE BWEOL")
(48549 . "HANGUL SYLLABLE BWEOLG")
(48550 . "HANGUL SYLLABLE BWEOLM")
(48551 . "HANGUL SYLLABLE BWEOLB")
(48552 . "HANGUL SYLLABLE BWEOLS")
(48553 . "HANGUL SYLLABLE BWEOLT")
(48554 . "HANGUL SYLLABLE BWEOLP")
(48555 . "HANGUL SYLLABLE BWEOLH")
(48556 . "HANGUL SYLLABLE BWEOM")
(48557 . "HANGUL SYLLABLE BWEOB")
(48558 . "HANGUL SYLLABLE BWEOBS")
(48559 . "HANGUL SYLLABLE BWEOS")
(48560 . "HANGUL SYLLABLE BWEOSS")
(48561 . "HANGUL SYLLABLE BWEONG")
(48562 . "HANGUL SYLLABLE BWEOJ")
(48563 . "HANGUL SYLLABLE BWEOC")
(48564 . "HANGUL SYLLABLE BWEOK")
(48565 . "HANGUL SYLLABLE BWEOT")
(48566 . "HANGUL SYLLABLE BWEOP")
(48567 . "HANGUL SYLLABLE BWEOH")
(48568 . "HANGUL SYLLABLE BWE")
(48569 . "HANGUL SYLLABLE BWEG")
(48570 . "HANGUL SYLLABLE BWEGG")
(48571 . "HANGUL SYLLABLE BWEGS")
(48572 . "HANGUL SYLLABLE BWEN")
(48573 . "HANGUL SYLLABLE BWENJ")
(48574 . "HANGUL SYLLABLE BWENH")
(48575 . "HANGUL SYLLABLE BWED")
(48576 . "HANGUL SYLLABLE BWEL")
(48577 . "HANGUL SYLLABLE BWELG")
(48578 . "HANGUL SYLLABLE BWELM")
(48579 . "HANGUL SYLLABLE BWELB")
(48580 . "HANGUL SYLLABLE BWELS")
(48581 . "HANGUL SYLLABLE BWELT")
(48582 . "HANGUL SYLLABLE BWELP")
(48583 . "HANGUL SYLLABLE BWELH")
(48584 . "HANGUL SYLLABLE BWEM")
(48585 . "HANGUL SYLLABLE BWEB")
(48586 . "HANGUL SYLLABLE BWEBS")
(48587 . "HANGUL SYLLABLE BWES")
(48588 . "HANGUL SYLLABLE BWESS")
(48589 . "HANGUL SYLLABLE BWENG")
(48590 . "HANGUL SYLLABLE BWEJ")
(48591 . "HANGUL SYLLABLE BWEC")
(48592 . "HANGUL SYLLABLE BWEK")
(48593 . "HANGUL SYLLABLE BWET")
(48594 . "HANGUL SYLLABLE BWEP")
(48595 . "HANGUL SYLLABLE BWEH")
(48596 . "HANGUL SYLLABLE BWI")
(48597 . "HANGUL SYLLABLE BWIG")
(48598 . "HANGUL SYLLABLE BWIGG")
(48599 . "HANGUL SYLLABLE BWIGS")
(48600 . "HANGUL SYLLABLE BWIN")
(48601 . "HANGUL SYLLABLE BWINJ")
(48602 . "HANGUL SYLLABLE BWINH")
(48603 . "HANGUL SYLLABLE BWID")
(48604 . "HANGUL SYLLABLE BWIL")
(48605 . "HANGUL SYLLABLE BWILG")
(48606 . "HANGUL SYLLABLE BWILM")
(48607 . "HANGUL SYLLABLE BWILB")
(48608 . "HANGUL SYLLABLE BWILS")
(48609 . "HANGUL SYLLABLE BWILT")
(48610 . "HANGUL SYLLABLE BWILP")
(48611 . "HANGUL SYLLABLE BWILH")
(48612 . "HANGUL SYLLABLE BWIM")
(48613 . "HANGUL SYLLABLE BWIB")
(48614 . "HANGUL SYLLABLE BWIBS")
(48615 . "HANGUL SYLLABLE BWIS")
(48616 . "HANGUL SYLLABLE BWISS")
(48617 . "HANGUL SYLLABLE BWING")
(48618 . "HANGUL SYLLABLE BWIJ")
(48619 . "HANGUL SYLLABLE BWIC")
(48620 . "HANGUL SYLLABLE BWIK")
(48621 . "HANGUL SYLLABLE BWIT")
(48622 . "HANGUL SYLLABLE BWIP")
(48623 . "HANGUL SYLLABLE BWIH")
(48624 . "HANGUL SYLLABLE BYU")
(48625 . "HANGUL SYLLABLE BYUG")
(48626 . "HANGUL SYLLABLE BYUGG")
(48627 . "HANGUL SYLLABLE BYUGS")
(48628 . "HANGUL SYLLABLE BYUN")
(48629 . "HANGUL SYLLABLE BYUNJ")
(48630 . "HANGUL SYLLABLE BYUNH")
(48631 . "HANGUL SYLLABLE BYUD")
(48632 . "HANGUL SYLLABLE BYUL")
(48633 . "HANGUL SYLLABLE BYULG")
(48634 . "HANGUL SYLLABLE BYULM")
(48635 . "HANGUL SYLLABLE BYULB")
(48636 . "HANGUL SYLLABLE BYULS")
(48637 . "HANGUL SYLLABLE BYULT")
(48638 . "HANGUL SYLLABLE BYULP")
(48639 . "HANGUL SYLLABLE BYULH")
(48640 . "HANGUL SYLLABLE BYUM")
(48641 . "HANGUL SYLLABLE BYUB")
(48642 . "HANGUL SYLLABLE BYUBS")
(48643 . "HANGUL SYLLABLE BYUS")
(48644 . "HANGUL SYLLABLE BYUSS")
(48645 . "HANGUL SYLLABLE BYUNG")
(48646 . "HANGUL SYLLABLE BYUJ")
(48647 . "HANGUL SYLLABLE BYUC")
(48648 . "HANGUL SYLLABLE BYUK")
(48649 . "HANGUL SYLLABLE BYUT")
(48650 . "HANGUL SYLLABLE BYUP")
(48651 . "HANGUL SYLLABLE BYUH")
(48652 . "HANGUL SYLLABLE BEU")
(48653 . "HANGUL SYLLABLE BEUG")
(48654 . "HANGUL SYLLABLE BEUGG")
(48655 . "HANGUL SYLLABLE BEUGS")
(48656 . "HANGUL SYLLABLE BEUN")
(48657 . "HANGUL SYLLABLE BEUNJ")
(48658 . "HANGUL SYLLABLE BEUNH")
(48659 . "HANGUL SYLLABLE BEUD")
(48660 . "HANGUL SYLLABLE BEUL")
(48661 . "HANGUL SYLLABLE BEULG")
(48662 . "HANGUL SYLLABLE BEULM")
(48663 . "HANGUL SYLLABLE BEULB")
(48664 . "HANGUL SYLLABLE BEULS")
(48665 . "HANGUL SYLLABLE BEULT")
(48666 . "HANGUL SYLLABLE BEULP")
(48667 . "HANGUL SYLLABLE BEULH")
(48668 . "HANGUL SYLLABLE BEUM")
(48669 . "HANGUL SYLLABLE BEUB")
(48670 . "HANGUL SYLLABLE BEUBS")
(48671 . "HANGUL SYLLABLE BEUS")
(48672 . "HANGUL SYLLABLE BEUSS")
(48673 . "HANGUL SYLLABLE BEUNG")
(48674 . "HANGUL SYLLABLE BEUJ")
(48675 . "HANGUL SYLLABLE BEUC")
(48676 . "HANGUL SYLLABLE BEUK")
(48677 . "HANGUL SYLLABLE BEUT")
(48678 . "HANGUL SYLLABLE BEUP")
(48679 . "HANGUL SYLLABLE BEUH")
(48680 . "HANGUL SYLLABLE BYI")
(48681 . "HANGUL SYLLABLE BYIG")
(48682 . "HANGUL SYLLABLE BYIGG")
(48683 . "HANGUL SYLLABLE BYIGS")
(48684 . "HANGUL SYLLABLE BYIN")
(48685 . "HANGUL SYLLABLE BYINJ")
(48686 . "HANGUL SYLLABLE BYINH")
(48687 . "HANGUL SYLLABLE BYID")
(48688 . "HANGUL SYLLABLE BYIL")
(48689 . "HANGUL SYLLABLE BYILG")
(48690 . "HANGUL SYLLABLE BYILM")
(48691 . "HANGUL SYLLABLE BYILB")
(48692 . "HANGUL SYLLABLE BYILS")
(48693 . "HANGUL SYLLABLE BYILT")
(48694 . "HANGUL SYLLABLE BYILP")
(48695 . "HANGUL SYLLABLE BYILH")
(48696 . "HANGUL SYLLABLE BYIM")
(48697 . "HANGUL SYLLABLE BYIB")
(48698 . "HANGUL SYLLABLE BYIBS")
(48699 . "HANGUL SYLLABLE BYIS")
(48700 . "HANGUL SYLLABLE BYISS")
(48701 . "HANGUL SYLLABLE BYING")
(48702 . "HANGUL SYLLABLE BYIJ")
(48703 . "HANGUL SYLLABLE BYIC")
(48704 . "HANGUL SYLLABLE BYIK")
(48705 . "HANGUL SYLLABLE BYIT")
(48706 . "HANGUL SYLLABLE BYIP")
(48707 . "HANGUL SYLLABLE BYIH")
(48708 . "HANGUL SYLLABLE BI")
(48709 . "HANGUL SYLLABLE BIG")
(48710 . "HANGUL SYLLABLE BIGG")
(48711 . "HANGUL SYLLABLE BIGS")
(48712 . "HANGUL SYLLABLE BIN")
(48713 . "HANGUL SYLLABLE BINJ")
(48714 . "HANGUL SYLLABLE BINH")
(48715 . "HANGUL SYLLABLE BID")
(48716 . "HANGUL SYLLABLE BIL")
(48717 . "HANGUL SYLLABLE BILG")
(48718 . "HANGUL SYLLABLE BILM")
(48719 . "HANGUL SYLLABLE BILB")
(48720 . "HANGUL SYLLABLE BILS")
(48721 . "HANGUL SYLLABLE BILT")
(48722 . "HANGUL SYLLABLE BILP")
(48723 . "HANGUL SYLLABLE BILH")
(48724 . "HANGUL SYLLABLE BIM")
(48725 . "HANGUL SYLLABLE BIB")
(48726 . "HANGUL SYLLABLE BIBS")
(48727 . "HANGUL SYLLABLE BIS")
(48728 . "HANGUL SYLLABLE BISS")
(48729 . "HANGUL SYLLABLE BING")
(48730 . "HANGUL SYLLABLE BIJ")
(48731 . "HANGUL SYLLABLE BIC")
(48732 . "HANGUL SYLLABLE BIK")
(48733 . "HANGUL SYLLABLE BIT")
(48734 . "HANGUL SYLLABLE BIP")
(48735 . "HANGUL SYLLABLE BIH")
(48736 . "HANGUL SYLLABLE BBA")
(48737 . "HANGUL SYLLABLE BBAG")
(48738 . "HANGUL SYLLABLE BBAGG")
(48739 . "HANGUL SYLLABLE BBAGS")
(48740 . "HANGUL SYLLABLE BBAN")
(48741 . "HANGUL SYLLABLE BBANJ")
(48742 . "HANGUL SYLLABLE BBANH")
(48743 . "HANGUL SYLLABLE BBAD")
(48744 . "HANGUL SYLLABLE BBAL")
(48745 . "HANGUL SYLLABLE BBALG")
(48746 . "HANGUL SYLLABLE BBALM")
(48747 . "HANGUL SYLLABLE BBALB")
(48748 . "HANGUL SYLLABLE BBALS")
(48749 . "HANGUL SYLLABLE BBALT")
(48750 . "HANGUL SYLLABLE BBALP")
(48751 . "HANGUL SYLLABLE BBALH")
(48752 . "HANGUL SYLLABLE BBAM")
(48753 . "HANGUL SYLLABLE BBAB")
(48754 . "HANGUL SYLLABLE BBABS")
(48755 . "HANGUL SYLLABLE BBAS")
(48756 . "HANGUL SYLLABLE BBASS")
(48757 . "HANGUL SYLLABLE BBANG")
(48758 . "HANGUL SYLLABLE BBAJ")
(48759 . "HANGUL SYLLABLE BBAC")
(48760 . "HANGUL SYLLABLE BBAK")
(48761 . "HANGUL SYLLABLE BBAT")
(48762 . "HANGUL SYLLABLE BBAP")
(48763 . "HANGUL SYLLABLE BBAH")
(48764 . "HANGUL SYLLABLE BBAE")
(48765 . "HANGUL SYLLABLE BBAEG")
(48766 . "HANGUL SYLLABLE BBAEGG")
(48767 . "HANGUL SYLLABLE BBAEGS")
(48768 . "HANGUL SYLLABLE BBAEN")
(48769 . "HANGUL SYLLABLE BBAENJ")
(48770 . "HANGUL SYLLABLE BBAENH")
(48771 . "HANGUL SYLLABLE BBAED")
(48772 . "HANGUL SYLLABLE BBAEL")
(48773 . "HANGUL SYLLABLE BBAELG")
(48774 . "HANGUL SYLLABLE BBAELM")
(48775 . "HANGUL SYLLABLE BBAELB")
(48776 . "HANGUL SYLLABLE BBAELS")
(48777 . "HANGUL SYLLABLE BBAELT")
(48778 . "HANGUL SYLLABLE BBAELP")
(48779 . "HANGUL SYLLABLE BBAELH")
(48780 . "HANGUL SYLLABLE BBAEM")
(48781 . "HANGUL SYLLABLE BBAEB")
(48782 . "HANGUL SYLLABLE BBAEBS")
(48783 . "HANGUL SYLLABLE BBAES")
(48784 . "HANGUL SYLLABLE BBAESS")
(48785 . "HANGUL SYLLABLE BBAENG")
(48786 . "HANGUL SYLLABLE BBAEJ")
(48787 . "HANGUL SYLLABLE BBAEC")
(48788 . "HANGUL SYLLABLE BBAEK")
(48789 . "HANGUL SYLLABLE BBAET")
(48790 . "HANGUL SYLLABLE BBAEP")
(48791 . "HANGUL SYLLABLE BBAEH")
(48792 . "HANGUL SYLLABLE BBYA")
(48793 . "HANGUL SYLLABLE BBYAG")
(48794 . "HANGUL SYLLABLE BBYAGG")
(48795 . "HANGUL SYLLABLE BBYAGS")
(48796 . "HANGUL SYLLABLE BBYAN")
(48797 . "HANGUL SYLLABLE BBYANJ")
(48798 . "HANGUL SYLLABLE BBYANH")
(48799 . "HANGUL SYLLABLE BBYAD")
(48800 . "HANGUL SYLLABLE BBYAL")
(48801 . "HANGUL SYLLABLE BBYALG")
(48802 . "HANGUL SYLLABLE BBYALM")
(48803 . "HANGUL SYLLABLE BBYALB")
(48804 . "HANGUL SYLLABLE BBYALS")
(48805 . "HANGUL SYLLABLE BBYALT")
(48806 . "HANGUL SYLLABLE BBYALP")
(48807 . "HANGUL SYLLABLE BBYALH")
(48808 . "HANGUL SYLLABLE BBYAM")
(48809 . "HANGUL SYLLABLE BBYAB")
(48810 . "HANGUL SYLLABLE BBYABS")
(48811 . "HANGUL SYLLABLE BBYAS")
(48812 . "HANGUL SYLLABLE BBYASS")
(48813 . "HANGUL SYLLABLE BBYANG")
(48814 . "HANGUL SYLLABLE BBYAJ")
(48815 . "HANGUL SYLLABLE BBYAC")
(48816 . "HANGUL SYLLABLE BBYAK")
(48817 . "HANGUL SYLLABLE BBYAT")
(48818 . "HANGUL SYLLABLE BBYAP")
(48819 . "HANGUL SYLLABLE BBYAH")
(48820 . "HANGUL SYLLABLE BBYAE")
(48821 . "HANGUL SYLLABLE BBYAEG")
(48822 . "HANGUL SYLLABLE BBYAEGG")
(48823 . "HANGUL SYLLABLE BBYAEGS")
(48824 . "HANGUL SYLLABLE BBYAEN")
(48825 . "HANGUL SYLLABLE BBYAENJ")
(48826 . "HANGUL SYLLABLE BBYAENH")
(48827 . "HANGUL SYLLABLE BBYAED")
(48828 . "HANGUL SYLLABLE BBYAEL")
(48829 . "HANGUL SYLLABLE BBYAELG")
(48830 . "HANGUL SYLLABLE BBYAELM")
(48831 . "HANGUL SYLLABLE BBYAELB")
(48832 . "HANGUL SYLLABLE BBYAELS")
(48833 . "HANGUL SYLLABLE BBYAELT")
(48834 . "HANGUL SYLLABLE BBYAELP")
(48835 . "HANGUL SYLLABLE BBYAELH")
(48836 . "HANGUL SYLLABLE BBYAEM")
(48837 . "HANGUL SYLLABLE BBYAEB")
(48838 . "HANGUL SYLLABLE BBYAEBS")
(48839 . "HANGUL SYLLABLE BBYAES")
(48840 . "HANGUL SYLLABLE BBYAESS")
(48841 . "HANGUL SYLLABLE BBYAENG")
(48842 . "HANGUL SYLLABLE BBYAEJ")
(48843 . "HANGUL SYLLABLE BBYAEC")
(48844 . "HANGUL SYLLABLE BBYAEK")
(48845 . "HANGUL SYLLABLE BBYAET")
(48846 . "HANGUL SYLLABLE BBYAEP")
(48847 . "HANGUL SYLLABLE BBYAEH")
(48848 . "HANGUL SYLLABLE BBEO")
(48849 . "HANGUL SYLLABLE BBEOG")
(48850 . "HANGUL SYLLABLE BBEOGG")
(48851 . "HANGUL SYLLABLE BBEOGS")
(48852 . "HANGUL SYLLABLE BBEON")
(48853 . "HANGUL SYLLABLE BBEONJ")
(48854 . "HANGUL SYLLABLE BBEONH")
(48855 . "HANGUL SYLLABLE BBEOD")
(48856 . "HANGUL SYLLABLE BBEOL")
(48857 . "HANGUL SYLLABLE BBEOLG")
(48858 . "HANGUL SYLLABLE BBEOLM")
(48859 . "HANGUL SYLLABLE BBEOLB")
(48860 . "HANGUL SYLLABLE BBEOLS")
(48861 . "HANGUL SYLLABLE BBEOLT")
(48862 . "HANGUL SYLLABLE BBEOLP")
(48863 . "HANGUL SYLLABLE BBEOLH")
(48864 . "HANGUL SYLLABLE BBEOM")
(48865 . "HANGUL SYLLABLE BBEOB")
(48866 . "HANGUL SYLLABLE BBEOBS")
(48867 . "HANGUL SYLLABLE BBEOS")
(48868 . "HANGUL SYLLABLE BBEOSS")
(48869 . "HANGUL SYLLABLE BBEONG")
(48870 . "HANGUL SYLLABLE BBEOJ")
(48871 . "HANGUL SYLLABLE BBEOC")
(48872 . "HANGUL SYLLABLE BBEOK")
(48873 . "HANGUL SYLLABLE BBEOT")
(48874 . "HANGUL SYLLABLE BBEOP")
(48875 . "HANGUL SYLLABLE BBEOH")
(48876 . "HANGUL SYLLABLE BBE")
(48877 . "HANGUL SYLLABLE BBEG")
(48878 . "HANGUL SYLLABLE BBEGG")
(48879 . "HANGUL SYLLABLE BBEGS")
(48880 . "HANGUL SYLLABLE BBEN")
(48881 . "HANGUL SYLLABLE BBENJ")
(48882 . "HANGUL SYLLABLE BBENH")
(48883 . "HANGUL SYLLABLE BBED")
(48884 . "HANGUL SYLLABLE BBEL")
(48885 . "HANGUL SYLLABLE BBELG")
(48886 . "HANGUL SYLLABLE BBELM")
(48887 . "HANGUL SYLLABLE BBELB")
(48888 . "HANGUL SYLLABLE BBELS")
(48889 . "HANGUL SYLLABLE BBELT")
(48890 . "HANGUL SYLLABLE BBELP")
(48891 . "HANGUL SYLLABLE BBELH")
(48892 . "HANGUL SYLLABLE BBEM")
(48893 . "HANGUL SYLLABLE BBEB")
(48894 . "HANGUL SYLLABLE BBEBS")
(48895 . "HANGUL SYLLABLE BBES")
(48896 . "HANGUL SYLLABLE BBESS")
(48897 . "HANGUL SYLLABLE BBENG")
(48898 . "HANGUL SYLLABLE BBEJ")
(48899 . "HANGUL SYLLABLE BBEC")
(48900 . "HANGUL SYLLABLE BBEK")
(48901 . "HANGUL SYLLABLE BBET")
(48902 . "HANGUL SYLLABLE BBEP")
(48903 . "HANGUL SYLLABLE BBEH")
(48904 . "HANGUL SYLLABLE BBYEO")
(48905 . "HANGUL SYLLABLE BBYEOG")
(48906 . "HANGUL SYLLABLE BBYEOGG")
(48907 . "HANGUL SYLLABLE BBYEOGS")
(48908 . "HANGUL SYLLABLE BBYEON")
(48909 . "HANGUL SYLLABLE BBYEONJ")
(48910 . "HANGUL SYLLABLE BBYEONH")
(48911 . "HANGUL SYLLABLE BBYEOD")
(48912 . "HANGUL SYLLABLE BBYEOL")
(48913 . "HANGUL SYLLABLE BBYEOLG")
(48914 . "HANGUL SYLLABLE BBYEOLM")
(48915 . "HANGUL SYLLABLE BBYEOLB")
(48916 . "HANGUL SYLLABLE BBYEOLS")
(48917 . "HANGUL SYLLABLE BBYEOLT")
(48918 . "HANGUL SYLLABLE BBYEOLP")
(48919 . "HANGUL SYLLABLE BBYEOLH")
(48920 . "HANGUL SYLLABLE BBYEOM")
(48921 . "HANGUL SYLLABLE BBYEOB")
(48922 . "HANGUL SYLLABLE BBYEOBS")
(48923 . "HANGUL SYLLABLE BBYEOS")
(48924 . "HANGUL SYLLABLE BBYEOSS")
(48925 . "HANGUL SYLLABLE BBYEONG")
(48926 . "HANGUL SYLLABLE BBYEOJ")
(48927 . "HANGUL SYLLABLE BBYEOC")
(48928 . "HANGUL SYLLABLE BBYEOK")
(48929 . "HANGUL SYLLABLE BBYEOT")
(48930 . "HANGUL SYLLABLE BBYEOP")
(48931 . "HANGUL SYLLABLE BBYEOH")
(48932 . "HANGUL SYLLABLE BBYE")
(48933 . "HANGUL SYLLABLE BBYEG")
(48934 . "HANGUL SYLLABLE BBYEGG")
(48935 . "HANGUL SYLLABLE BBYEGS")
(48936 . "HANGUL SYLLABLE BBYEN")
(48937 . "HANGUL SYLLABLE BBYENJ")
(48938 . "HANGUL SYLLABLE BBYENH")
(48939 . "HANGUL SYLLABLE BBYED")
(48940 . "HANGUL SYLLABLE BBYEL")
(48941 . "HANGUL SYLLABLE BBYELG")
(48942 . "HANGUL SYLLABLE BBYELM")
(48943 . "HANGUL SYLLABLE BBYELB")
(48944 . "HANGUL SYLLABLE BBYELS")
(48945 . "HANGUL SYLLABLE BBYELT")
(48946 . "HANGUL SYLLABLE BBYELP")
(48947 . "HANGUL SYLLABLE BBYELH")
(48948 . "HANGUL SYLLABLE BBYEM")
(48949 . "HANGUL SYLLABLE BBYEB")
(48950 . "HANGUL SYLLABLE BBYEBS")
(48951 . "HANGUL SYLLABLE BBYES")
(48952 . "HANGUL SYLLABLE BBYESS")
(48953 . "HANGUL SYLLABLE BBYENG")
(48954 . "HANGUL SYLLABLE BBYEJ")
(48955 . "HANGUL SYLLABLE BBYEC")
(48956 . "HANGUL SYLLABLE BBYEK")
(48957 . "HANGUL SYLLABLE BBYET")
(48958 . "HANGUL SYLLABLE BBYEP")
(48959 . "HANGUL SYLLABLE BBYEH")
(48960 . "HANGUL SYLLABLE BBO")
(48961 . "HANGUL SYLLABLE BBOG")
(48962 . "HANGUL SYLLABLE BBOGG")
(48963 . "HANGUL SYLLABLE BBOGS")
(48964 . "HANGUL SYLLABLE BBON")
(48965 . "HANGUL SYLLABLE BBONJ")
(48966 . "HANGUL SYLLABLE BBONH")
(48967 . "HANGUL SYLLABLE BBOD")
(48968 . "HANGUL SYLLABLE BBOL")
(48969 . "HANGUL SYLLABLE BBOLG")
(48970 . "HANGUL SYLLABLE BBOLM")
(48971 . "HANGUL SYLLABLE BBOLB")
(48972 . "HANGUL SYLLABLE BBOLS")
(48973 . "HANGUL SYLLABLE BBOLT")
(48974 . "HANGUL SYLLABLE BBOLP")
(48975 . "HANGUL SYLLABLE BBOLH")
(48976 . "HANGUL SYLLABLE BBOM")
(48977 . "HANGUL SYLLABLE BBOB")
(48978 . "HANGUL SYLLABLE BBOBS")
(48979 . "HANGUL SYLLABLE BBOS")
(48980 . "HANGUL SYLLABLE BBOSS")
(48981 . "HANGUL SYLLABLE BBONG")
(48982 . "HANGUL SYLLABLE BBOJ")
(48983 . "HANGUL SYLLABLE BBOC")
(48984 . "HANGUL SYLLABLE BBOK")
(48985 . "HANGUL SYLLABLE BBOT")
(48986 . "HANGUL SYLLABLE BBOP")
(48987 . "HANGUL SYLLABLE BBOH")
(48988 . "HANGUL SYLLABLE BBWA")
(48989 . "HANGUL SYLLABLE BBWAG")
(48990 . "HANGUL SYLLABLE BBWAGG")
(48991 . "HANGUL SYLLABLE BBWAGS")
(48992 . "HANGUL SYLLABLE BBWAN")
(48993 . "HANGUL SYLLABLE BBWANJ")
(48994 . "HANGUL SYLLABLE BBWANH")
(48995 . "HANGUL SYLLABLE BBWAD")
(48996 . "HANGUL SYLLABLE BBWAL")
(48997 . "HANGUL SYLLABLE BBWALG")
(48998 . "HANGUL SYLLABLE BBWALM")
(48999 . "HANGUL SYLLABLE BBWALB")
(49000 . "HANGUL SYLLABLE BBWALS")
(49001 . "HANGUL SYLLABLE BBWALT")
(49002 . "HANGUL SYLLABLE BBWALP")
(49003 . "HANGUL SYLLABLE BBWALH")
(49004 . "HANGUL SYLLABLE BBWAM")
(49005 . "HANGUL SYLLABLE BBWAB")
(49006 . "HANGUL SYLLABLE BBWABS")
(49007 . "HANGUL SYLLABLE BBWAS")
(49008 . "HANGUL SYLLABLE BBWASS")
(49009 . "HANGUL SYLLABLE BBWANG")
(49010 . "HANGUL SYLLABLE BBWAJ")
(49011 . "HANGUL SYLLABLE BBWAC")
(49012 . "HANGUL SYLLABLE BBWAK")
(49013 . "HANGUL SYLLABLE BBWAT")
(49014 . "HANGUL SYLLABLE BBWAP")
(49015 . "HANGUL SYLLABLE BBWAH")
(49016 . "HANGUL SYLLABLE BBWAE")
(49017 . "HANGUL SYLLABLE BBWAEG")
(49018 . "HANGUL SYLLABLE BBWAEGG")
(49019 . "HANGUL SYLLABLE BBWAEGS")
(49020 . "HANGUL SYLLABLE BBWAEN")
(49021 . "HANGUL SYLLABLE BBWAENJ")
(49022 . "HANGUL SYLLABLE BBWAENH")
(49023 . "HANGUL SYLLABLE BBWAED")
(49024 . "HANGUL SYLLABLE BBWAEL")
(49025 . "HANGUL SYLLABLE BBWAELG")
(49026 . "HANGUL SYLLABLE BBWAELM")
(49027 . "HANGUL SYLLABLE BBWAELB")
(49028 . "HANGUL SYLLABLE BBWAELS")
(49029 . "HANGUL SYLLABLE BBWAELT")
(49030 . "HANGUL SYLLABLE BBWAELP")
(49031 . "HANGUL SYLLABLE BBWAELH")
(49032 . "HANGUL SYLLABLE BBWAEM")
(49033 . "HANGUL SYLLABLE BBWAEB")
(49034 . "HANGUL SYLLABLE BBWAEBS")
(49035 . "HANGUL SYLLABLE BBWAES")
(49036 . "HANGUL SYLLABLE BBWAESS")
(49037 . "HANGUL SYLLABLE BBWAENG")
(49038 . "HANGUL SYLLABLE BBWAEJ")
(49039 . "HANGUL SYLLABLE BBWAEC")
(49040 . "HANGUL SYLLABLE BBWAEK")
(49041 . "HANGUL SYLLABLE BBWAET")
(49042 . "HANGUL SYLLABLE BBWAEP")
(49043 . "HANGUL SYLLABLE BBWAEH")
(49044 . "HANGUL SYLLABLE BBOE")
(49045 . "HANGUL SYLLABLE BBOEG")
(49046 . "HANGUL SYLLABLE BBOEGG")
(49047 . "HANGUL SYLLABLE BBOEGS")
(49048 . "HANGUL SYLLABLE BBOEN")
(49049 . "HANGUL SYLLABLE BBOENJ")
(49050 . "HANGUL SYLLABLE BBOENH")
(49051 . "HANGUL SYLLABLE BBOED")
(49052 . "HANGUL SYLLABLE BBOEL")
(49053 . "HANGUL SYLLABLE BBOELG")
(49054 . "HANGUL SYLLABLE BBOELM")
(49055 . "HANGUL SYLLABLE BBOELB")
(49056 . "HANGUL SYLLABLE BBOELS")
(49057 . "HANGUL SYLLABLE BBOELT")
(49058 . "HANGUL SYLLABLE BBOELP")
(49059 . "HANGUL SYLLABLE BBOELH")
(49060 . "HANGUL SYLLABLE BBOEM")
(49061 . "HANGUL SYLLABLE BBOEB")
(49062 . "HANGUL SYLLABLE BBOEBS")
(49063 . "HANGUL SYLLABLE BBOES")
(49064 . "HANGUL SYLLABLE BBOESS")
(49065 . "HANGUL SYLLABLE BBOENG")
(49066 . "HANGUL SYLLABLE BBOEJ")
(49067 . "HANGUL SYLLABLE BBOEC")
(49068 . "HANGUL SYLLABLE BBOEK")
(49069 . "HANGUL SYLLABLE BBOET")
(49070 . "HANGUL SYLLABLE BBOEP")
(49071 . "HANGUL SYLLABLE BBOEH")
(49072 . "HANGUL SYLLABLE BBYO")
(49073 . "HANGUL SYLLABLE BBYOG")
(49074 . "HANGUL SYLLABLE BBYOGG")
(49075 . "HANGUL SYLLABLE BBYOGS")
(49076 . "HANGUL SYLLABLE BBYON")
(49077 . "HANGUL SYLLABLE BBYONJ")
(49078 . "HANGUL SYLLABLE BBYONH")
(49079 . "HANGUL SYLLABLE BBYOD")
(49080 . "HANGUL SYLLABLE BBYOL")
(49081 . "HANGUL SYLLABLE BBYOLG")
(49082 . "HANGUL SYLLABLE BBYOLM")
(49083 . "HANGUL SYLLABLE BBYOLB")
(49084 . "HANGUL SYLLABLE BBYOLS")
(49085 . "HANGUL SYLLABLE BBYOLT")
(49086 . "HANGUL SYLLABLE BBYOLP")
(49087 . "HANGUL SYLLABLE BBYOLH")
(49088 . "HANGUL SYLLABLE BBYOM")
(49089 . "HANGUL SYLLABLE BBYOB")
(49090 . "HANGUL SYLLABLE BBYOBS")
(49091 . "HANGUL SYLLABLE BBYOS")
(49092 . "HANGUL SYLLABLE BBYOSS")
(49093 . "HANGUL SYLLABLE BBYONG")
(49094 . "HANGUL SYLLABLE BBYOJ")
(49095 . "HANGUL SYLLABLE BBYOC")
(49096 . "HANGUL SYLLABLE BBYOK")
(49097 . "HANGUL SYLLABLE BBYOT")
(49098 . "HANGUL SYLLABLE BBYOP")
(49099 . "HANGUL SYLLABLE BBYOH")
(49100 . "HANGUL SYLLABLE BBU")
(49101 . "HANGUL SYLLABLE BBUG")
(49102 . "HANGUL SYLLABLE BBUGG")
(49103 . "HANGUL SYLLABLE BBUGS")
(49104 . "HANGUL SYLLABLE BBUN")
(49105 . "HANGUL SYLLABLE BBUNJ")
(49106 . "HANGUL SYLLABLE BBUNH")
(49107 . "HANGUL SYLLABLE BBUD")
(49108 . "HANGUL SYLLABLE BBUL")
(49109 . "HANGUL SYLLABLE BBULG")
(49110 . "HANGUL SYLLABLE BBULM")
(49111 . "HANGUL SYLLABLE BBULB")
(49112 . "HANGUL SYLLABLE BBULS")
(49113 . "HANGUL SYLLABLE BBULT")
(49114 . "HANGUL SYLLABLE BBULP")
(49115 . "HANGUL SYLLABLE BBULH")
(49116 . "HANGUL SYLLABLE BBUM")
(49117 . "HANGUL SYLLABLE BBUB")
(49118 . "HANGUL SYLLABLE BBUBS")
(49119 . "HANGUL SYLLABLE BBUS")
(49120 . "HANGUL SYLLABLE BBUSS")
(49121 . "HANGUL SYLLABLE BBUNG")
(49122 . "HANGUL SYLLABLE BBUJ")
(49123 . "HANGUL SYLLABLE BBUC")
(49124 . "HANGUL SYLLABLE BBUK")
(49125 . "HANGUL SYLLABLE BBUT")
(49126 . "HANGUL SYLLABLE BBUP")
(49127 . "HANGUL SYLLABLE BBUH")
(49128 . "HANGUL SYLLABLE BBWEO")
(49129 . "HANGUL SYLLABLE BBWEOG")
(49130 . "HANGUL SYLLABLE BBWEOGG")
(49131 . "HANGUL SYLLABLE BBWEOGS")
(49132 . "HANGUL SYLLABLE BBWEON")
(49133 . "HANGUL SYLLABLE BBWEONJ")
(49134 . "HANGUL SYLLABLE BBWEONH")
(49135 . "HANGUL SYLLABLE BBWEOD")
(49136 . "HANGUL SYLLABLE BBWEOL")
(49137 . "HANGUL SYLLABLE BBWEOLG")
(49138 . "HANGUL SYLLABLE BBWEOLM")
(49139 . "HANGUL SYLLABLE BBWEOLB")
(49140 . "HANGUL SYLLABLE BBWEOLS")
(49141 . "HANGUL SYLLABLE BBWEOLT")
(49142 . "HANGUL SYLLABLE BBWEOLP")
(49143 . "HANGUL SYLLABLE BBWEOLH")
(49144 . "HANGUL SYLLABLE BBWEOM")
(49145 . "HANGUL SYLLABLE BBWEOB")
(49146 . "HANGUL SYLLABLE BBWEOBS")
(49147 . "HANGUL SYLLABLE BBWEOS")
(49148 . "HANGUL SYLLABLE BBWEOSS")
(49149 . "HANGUL SYLLABLE BBWEONG")
(49150 . "HANGUL SYLLABLE BBWEOJ")
(49151 . "HANGUL SYLLABLE BBWEOC")
(49152 . "HANGUL SYLLABLE BBWEOK")
(49153 . "HANGUL SYLLABLE BBWEOT")
(49154 . "HANGUL SYLLABLE BBWEOP")
(49155 . "HANGUL SYLLABLE BBWEOH")
(49156 . "HANGUL SYLLABLE BBWE")
(49157 . "HANGUL SYLLABLE BBWEG")
(49158 . "HANGUL SYLLABLE BBWEGG")
(49159 . "HANGUL SYLLABLE BBWEGS")
(49160 . "HANGUL SYLLABLE BBWEN")
(49161 . "HANGUL SYLLABLE BBWENJ")
(49162 . "HANGUL SYLLABLE BBWENH")
(49163 . "HANGUL SYLLABLE BBWED")
(49164 . "HANGUL SYLLABLE BBWEL")
(49165 . "HANGUL SYLLABLE BBWELG")
(49166 . "HANGUL SYLLABLE BBWELM")
(49167 . "HANGUL SYLLABLE BBWELB")
(49168 . "HANGUL SYLLABLE BBWELS")
(49169 . "HANGUL SYLLABLE BBWELT")
(49170 . "HANGUL SYLLABLE BBWELP")
(49171 . "HANGUL SYLLABLE BBWELH")
(49172 . "HANGUL SYLLABLE BBWEM")
(49173 . "HANGUL SYLLABLE BBWEB")
(49174 . "HANGUL SYLLABLE BBWEBS")
(49175 . "HANGUL SYLLABLE BBWES")
(49176 . "HANGUL SYLLABLE BBWESS")
(49177 . "HANGUL SYLLABLE BBWENG")
(49178 . "HANGUL SYLLABLE BBWEJ")
(49179 . "HANGUL SYLLABLE BBWEC")
(49180 . "HANGUL SYLLABLE BBWEK")
(49181 . "HANGUL SYLLABLE BBWET")
(49182 . "HANGUL SYLLABLE BBWEP")
(49183 . "HANGUL SYLLABLE BBWEH")
(49184 . "HANGUL SYLLABLE BBWI")
(49185 . "HANGUL SYLLABLE BBWIG")
(49186 . "HANGUL SYLLABLE BBWIGG")
(49187 . "HANGUL SYLLABLE BBWIGS")
(49188 . "HANGUL SYLLABLE BBWIN")
(49189 . "HANGUL SYLLABLE BBWINJ")
(49190 . "HANGUL SYLLABLE BBWINH")
(49191 . "HANGUL SYLLABLE BBWID")
(49192 . "HANGUL SYLLABLE BBWIL")
(49193 . "HANGUL SYLLABLE BBWILG")
(49194 . "HANGUL SYLLABLE BBWILM")
(49195 . "HANGUL SYLLABLE BBWILB")
(49196 . "HANGUL SYLLABLE BBWILS")
(49197 . "HANGUL SYLLABLE BBWILT")
(49198 . "HANGUL SYLLABLE BBWILP")
(49199 . "HANGUL SYLLABLE BBWILH")
(49200 . "HANGUL SYLLABLE BBWIM")
(49201 . "HANGUL SYLLABLE BBWIB")
(49202 . "HANGUL SYLLABLE BBWIBS")
(49203 . "HANGUL SYLLABLE BBWIS")
(49204 . "HANGUL SYLLABLE BBWISS")
(49205 . "HANGUL SYLLABLE BBWING")
(49206 . "HANGUL SYLLABLE BBWIJ")
(49207 . "HANGUL SYLLABLE BBWIC")
(49208 . "HANGUL SYLLABLE BBWIK")
(49209 . "HANGUL SYLLABLE BBWIT")
(49210 . "HANGUL SYLLABLE BBWIP")
(49211 . "HANGUL SYLLABLE BBWIH")
(49212 . "HANGUL SYLLABLE BBYU")
(49213 . "HANGUL SYLLABLE BBYUG")
(49214 . "HANGUL SYLLABLE BBYUGG")
(49215 . "HANGUL SYLLABLE BBYUGS")
(49216 . "HANGUL SYLLABLE BBYUN")
(49217 . "HANGUL SYLLABLE BBYUNJ")
(49218 . "HANGUL SYLLABLE BBYUNH")
(49219 . "HANGUL SYLLABLE BBYUD")
(49220 . "HANGUL SYLLABLE BBYUL")
(49221 . "HANGUL SYLLABLE BBYULG")
(49222 . "HANGUL SYLLABLE BBYULM")
(49223 . "HANGUL SYLLABLE BBYULB")
(49224 . "HANGUL SYLLABLE BBYULS")
(49225 . "HANGUL SYLLABLE BBYULT")
(49226 . "HANGUL SYLLABLE BBYULP")
(49227 . "HANGUL SYLLABLE BBYULH")
(49228 . "HANGUL SYLLABLE BBYUM")
(49229 . "HANGUL SYLLABLE BBYUB")
(49230 . "HANGUL SYLLABLE BBYUBS")
(49231 . "HANGUL SYLLABLE BBYUS")
(49232 . "HANGUL SYLLABLE BBYUSS")
(49233 . "HANGUL SYLLABLE BBYUNG")
(49234 . "HANGUL SYLLABLE BBYUJ")
(49235 . "HANGUL SYLLABLE BBYUC")
(49236 . "HANGUL SYLLABLE BBYUK")
(49237 . "HANGUL SYLLABLE BBYUT")
(49238 . "HANGUL SYLLABLE BBYUP")
(49239 . "HANGUL SYLLABLE BBYUH")
(49240 . "HANGUL SYLLABLE BBEU")
(49241 . "HANGUL SYLLABLE BBEUG")
(49242 . "HANGUL SYLLABLE BBEUGG")
(49243 . "HANGUL SYLLABLE BBEUGS")
(49244 . "HANGUL SYLLABLE BBEUN")
(49245 . "HANGUL SYLLABLE BBEUNJ")
(49246 . "HANGUL SYLLABLE BBEUNH")
(49247 . "HANGUL SYLLABLE BBEUD")
(49248 . "HANGUL SYLLABLE BBEUL")
(49249 . "HANGUL SYLLABLE BBEULG")
(49250 . "HANGUL SYLLABLE BBEULM")
(49251 . "HANGUL SYLLABLE BBEULB")
(49252 . "HANGUL SYLLABLE BBEULS")
(49253 . "HANGUL SYLLABLE BBEULT")
(49254 . "HANGUL SYLLABLE BBEULP")
(49255 . "HANGUL SYLLABLE BBEULH")
(49256 . "HANGUL SYLLABLE BBEUM")
(49257 . "HANGUL SYLLABLE BBEUB")
(49258 . "HANGUL SYLLABLE BBEUBS")
(49259 . "HANGUL SYLLABLE BBEUS")
(49260 . "HANGUL SYLLABLE BBEUSS")
(49261 . "HANGUL SYLLABLE BBEUNG")
(49262 . "HANGUL SYLLABLE BBEUJ")
(49263 . "HANGUL SYLLABLE BBEUC")
(49264 . "HANGUL SYLLABLE BBEUK")
(49265 . "HANGUL SYLLABLE BBEUT")
(49266 . "HANGUL SYLLABLE BBEUP")
(49267 . "HANGUL SYLLABLE BBEUH")
(49268 . "HANGUL SYLLABLE BBYI")
(49269 . "HANGUL SYLLABLE BBYIG")
(49270 . "HANGUL SYLLABLE BBYIGG")
(49271 . "HANGUL SYLLABLE BBYIGS")
(49272 . "HANGUL SYLLABLE BBYIN")
(49273 . "HANGUL SYLLABLE BBYINJ")
(49274 . "HANGUL SYLLABLE BBYINH")
(49275 . "HANGUL SYLLABLE BBYID")
(49276 . "HANGUL SYLLABLE BBYIL")
(49277 . "HANGUL SYLLABLE BBYILG")
(49278 . "HANGUL SYLLABLE BBYILM")
(49279 . "HANGUL SYLLABLE BBYILB")
(49280 . "HANGUL SYLLABLE BBYILS")
(49281 . "HANGUL SYLLABLE BBYILT")
(49282 . "HANGUL SYLLABLE BBYILP")
(49283 . "HANGUL SYLLABLE BBYILH")
(49284 . "HANGUL SYLLABLE BBYIM")
(49285 . "HANGUL SYLLABLE BBYIB")
(49286 . "HANGUL SYLLABLE BBYIBS")
(49287 . "HANGUL SYLLABLE BBYIS")
(49288 . "HANGUL SYLLABLE BBYISS")
(49289 . "HANGUL SYLLABLE BBYING")
(49290 . "HANGUL SYLLABLE BBYIJ")
(49291 . "HANGUL SYLLABLE BBYIC")
(49292 . "HANGUL SYLLABLE BBYIK")
(49293 . "HANGUL SYLLABLE BBYIT")
(49294 . "HANGUL SYLLABLE BBYIP")
(49295 . "HANGUL SYLLABLE BBYIH")
(49296 . "HANGUL SYLLABLE BBI")
(49297 . "HANGUL SYLLABLE BBIG")
(49298 . "HANGUL SYLLABLE BBIGG")
(49299 . "HANGUL SYLLABLE BBIGS")
(49300 . "HANGUL SYLLABLE BBIN")
(49301 . "HANGUL SYLLABLE BBINJ")
(49302 . "HANGUL SYLLABLE BBINH")
(49303 . "HANGUL SYLLABLE BBID")
(49304 . "HANGUL SYLLABLE BBIL")
(49305 . "HANGUL SYLLABLE BBILG")
(49306 . "HANGUL SYLLABLE BBILM")
(49307 . "HANGUL SYLLABLE BBILB")
(49308 . "HANGUL SYLLABLE BBILS")
(49309 . "HANGUL SYLLABLE BBILT")
(49310 . "HANGUL SYLLABLE BBILP")
(49311 . "HANGUL SYLLABLE BBILH")
(49312 . "HANGUL SYLLABLE BBIM")
(49313 . "HANGUL SYLLABLE BBIB")
(49314 . "HANGUL SYLLABLE BBIBS")
(49315 . "HANGUL SYLLABLE BBIS")
(49316 . "HANGUL SYLLABLE BBISS")
(49317 . "HANGUL SYLLABLE BBING")
(49318 . "HANGUL SYLLABLE BBIJ")
(49319 . "HANGUL SYLLABLE BBIC")
(49320 . "HANGUL SYLLABLE BBIK")
(49321 . "HANGUL SYLLABLE BBIT")
(49322 . "HANGUL SYLLABLE BBIP")
(49323 . "HANGUL SYLLABLE BBIH")
(49324 . "HANGUL SYLLABLE SA")
(49325 . "HANGUL SYLLABLE SAG")
(49326 . "HANGUL SYLLABLE SAGG")
(49327 . "HANGUL SYLLABLE SAGS")
(49328 . "HANGUL SYLLABLE SAN")
(49329 . "HANGUL SYLLABLE SANJ")
(49330 . "HANGUL SYLLABLE SANH")
(49331 . "HANGUL SYLLABLE SAD")
(49332 . "HANGUL SYLLABLE SAL")
(49333 . "HANGUL SYLLABLE SALG")
(49334 . "HANGUL SYLLABLE SALM")
(49335 . "HANGUL SYLLABLE SALB")
(49336 . "HANGUL SYLLABLE SALS")
(49337 . "HANGUL SYLLABLE SALT")
(49338 . "HANGUL SYLLABLE SALP")
(49339 . "HANGUL SYLLABLE SALH")
(49340 . "HANGUL SYLLABLE SAM")
(49341 . "HANGUL SYLLABLE SAB")
(49342 . "HANGUL SYLLABLE SABS")
(49343 . "HANGUL SYLLABLE SAS")
(49344 . "HANGUL SYLLABLE SASS")
(49345 . "HANGUL SYLLABLE SANG")
(49346 . "HANGUL SYLLABLE SAJ")
(49347 . "HANGUL SYLLABLE SAC")
(49348 . "HANGUL SYLLABLE SAK")
(49349 . "HANGUL SYLLABLE SAT")
(49350 . "HANGUL SYLLABLE SAP")
(49351 . "HANGUL SYLLABLE SAH")
(49352 . "HANGUL SYLLABLE SAE")
(49353 . "HANGUL SYLLABLE SAEG")
(49354 . "HANGUL SYLLABLE SAEGG")
(49355 . "HANGUL SYLLABLE SAEGS")
(49356 . "HANGUL SYLLABLE SAEN")
(49357 . "HANGUL SYLLABLE SAENJ")
(49358 . "HANGUL SYLLABLE SAENH")
(49359 . "HANGUL SYLLABLE SAED")
(49360 . "HANGUL SYLLABLE SAEL")
(49361 . "HANGUL SYLLABLE SAELG")
(49362 . "HANGUL SYLLABLE SAELM")
(49363 . "HANGUL SYLLABLE SAELB")
(49364 . "HANGUL SYLLABLE SAELS")
(49365 . "HANGUL SYLLABLE SAELT")
(49366 . "HANGUL SYLLABLE SAELP")
(49367 . "HANGUL SYLLABLE SAELH")
(49368 . "HANGUL SYLLABLE SAEM")
(49369 . "HANGUL SYLLABLE SAEB")
(49370 . "HANGUL SYLLABLE SAEBS")
(49371 . "HANGUL SYLLABLE SAES")
(49372 . "HANGUL SYLLABLE SAESS")
(49373 . "HANGUL SYLLABLE SAENG")
(49374 . "HANGUL SYLLABLE SAEJ")
(49375 . "HANGUL SYLLABLE SAEC")
(49376 . "HANGUL SYLLABLE SAEK")
(49377 . "HANGUL SYLLABLE SAET")
(49378 . "HANGUL SYLLABLE SAEP")
(49379 . "HANGUL SYLLABLE SAEH")
(49380 . "HANGUL SYLLABLE SYA")
(49381 . "HANGUL SYLLABLE SYAG")
(49382 . "HANGUL SYLLABLE SYAGG")
(49383 . "HANGUL SYLLABLE SYAGS")
(49384 . "HANGUL SYLLABLE SYAN")
(49385 . "HANGUL SYLLABLE SYANJ")
(49386 . "HANGUL SYLLABLE SYANH")
(49387 . "HANGUL SYLLABLE SYAD")
(49388 . "HANGUL SYLLABLE SYAL")
(49389 . "HANGUL SYLLABLE SYALG")
(49390 . "HANGUL SYLLABLE SYALM")
(49391 . "HANGUL SYLLABLE SYALB")
(49392 . "HANGUL SYLLABLE SYALS")
(49393 . "HANGUL SYLLABLE SYALT")
(49394 . "HANGUL SYLLABLE SYALP")
(49395 . "HANGUL SYLLABLE SYALH")
(49396 . "HANGUL SYLLABLE SYAM")
(49397 . "HANGUL SYLLABLE SYAB")
(49398 . "HANGUL SYLLABLE SYABS")
(49399 . "HANGUL SYLLABLE SYAS")
(49400 . "HANGUL SYLLABLE SYASS")
(49401 . "HANGUL SYLLABLE SYANG")
(49402 . "HANGUL SYLLABLE SYAJ")
(49403 . "HANGUL SYLLABLE SYAC")
(49404 . "HANGUL SYLLABLE SYAK")
(49405 . "HANGUL SYLLABLE SYAT")
(49406 . "HANGUL SYLLABLE SYAP")
(49407 . "HANGUL SYLLABLE SYAH")
(49408 . "HANGUL SYLLABLE SYAE")
(49409 . "HANGUL SYLLABLE SYAEG")
(49410 . "HANGUL SYLLABLE SYAEGG")
(49411 . "HANGUL SYLLABLE SYAEGS")
(49412 . "HANGUL SYLLABLE SYAEN")
(49413 . "HANGUL SYLLABLE SYAENJ")
(49414 . "HANGUL SYLLABLE SYAENH")
(49415 . "HANGUL SYLLABLE SYAED")
(49416 . "HANGUL SYLLABLE SYAEL")
(49417 . "HANGUL SYLLABLE SYAELG")
(49418 . "HANGUL SYLLABLE SYAELM")
(49419 . "HANGUL SYLLABLE SYAELB")
(49420 . "HANGUL SYLLABLE SYAELS")
(49421 . "HANGUL SYLLABLE SYAELT")
(49422 . "HANGUL SYLLABLE SYAELP")
(49423 . "HANGUL SYLLABLE SYAELH")
(49424 . "HANGUL SYLLABLE SYAEM")
(49425 . "HANGUL SYLLABLE SYAEB")
(49426 . "HANGUL SYLLABLE SYAEBS")
(49427 . "HANGUL SYLLABLE SYAES")
(49428 . "HANGUL SYLLABLE SYAESS")
(49429 . "HANGUL SYLLABLE SYAENG")
(49430 . "HANGUL SYLLABLE SYAEJ")
(49431 . "HANGUL SYLLABLE SYAEC")
(49432 . "HANGUL SYLLABLE SYAEK")
(49433 . "HANGUL SYLLABLE SYAET")
(49434 . "HANGUL SYLLABLE SYAEP")
(49435 . "HANGUL SYLLABLE SYAEH")
(49436 . "HANGUL SYLLABLE SEO")
(49437 . "HANGUL SYLLABLE SEOG")
(49438 . "HANGUL SYLLABLE SEOGG")
(49439 . "HANGUL SYLLABLE SEOGS")
(49440 . "HANGUL SYLLABLE SEON")
(49441 . "HANGUL SYLLABLE SEONJ")
(49442 . "HANGUL SYLLABLE SEONH")
(49443 . "HANGUL SYLLABLE SEOD")
(49444 . "HANGUL SYLLABLE SEOL")
(49445 . "HANGUL SYLLABLE SEOLG")
(49446 . "HANGUL SYLLABLE SEOLM")
(49447 . "HANGUL SYLLABLE SEOLB")
(49448 . "HANGUL SYLLABLE SEOLS")
(49449 . "HANGUL SYLLABLE SEOLT")
(49450 . "HANGUL SYLLABLE SEOLP")
(49451 . "HANGUL SYLLABLE SEOLH")
(49452 . "HANGUL SYLLABLE SEOM")
(49453 . "HANGUL SYLLABLE SEOB")
(49454 . "HANGUL SYLLABLE SEOBS")
(49455 . "HANGUL SYLLABLE SEOS")
(49456 . "HANGUL SYLLABLE SEOSS")
(49457 . "HANGUL SYLLABLE SEONG")
(49458 . "HANGUL SYLLABLE SEOJ")
(49459 . "HANGUL SYLLABLE SEOC")
(49460 . "HANGUL SYLLABLE SEOK")
(49461 . "HANGUL SYLLABLE SEOT")
(49462 . "HANGUL SYLLABLE SEOP")
(49463 . "HANGUL SYLLABLE SEOH")
(49464 . "HANGUL SYLLABLE SE")
(49465 . "HANGUL SYLLABLE SEG")
(49466 . "HANGUL SYLLABLE SEGG")
(49467 . "HANGUL SYLLABLE SEGS")
(49468 . "HANGUL SYLLABLE SEN")
(49469 . "HANGUL SYLLABLE SENJ")
(49470 . "HANGUL SYLLABLE SENH")
(49471 . "HANGUL SYLLABLE SED")
(49472 . "HANGUL SYLLABLE SEL")
(49473 . "HANGUL SYLLABLE SELG")
(49474 . "HANGUL SYLLABLE SELM")
(49475 . "HANGUL SYLLABLE SELB")
(49476 . "HANGUL SYLLABLE SELS")
(49477 . "HANGUL SYLLABLE SELT")
(49478 . "HANGUL SYLLABLE SELP")
(49479 . "HANGUL SYLLABLE SELH")
(49480 . "HANGUL SYLLABLE SEM")
(49481 . "HANGUL SYLLABLE SEB")
(49482 . "HANGUL SYLLABLE SEBS")
(49483 . "HANGUL SYLLABLE SES")
(49484 . "HANGUL SYLLABLE SESS")
(49485 . "HANGUL SYLLABLE SENG")
(49486 . "HANGUL SYLLABLE SEJ")
(49487 . "HANGUL SYLLABLE SEC")
(49488 . "HANGUL SYLLABLE SEK")
(49489 . "HANGUL SYLLABLE SET")
(49490 . "HANGUL SYLLABLE SEP")
(49491 . "HANGUL SYLLABLE SEH")
(49492 . "HANGUL SYLLABLE SYEO")
(49493 . "HANGUL SYLLABLE SYEOG")
(49494 . "HANGUL SYLLABLE SYEOGG")
(49495 . "HANGUL SYLLABLE SYEOGS")
(49496 . "HANGUL SYLLABLE SYEON")
(49497 . "HANGUL SYLLABLE SYEONJ")
(49498 . "HANGUL SYLLABLE SYEONH")
(49499 . "HANGUL SYLLABLE SYEOD")
(49500 . "HANGUL SYLLABLE SYEOL")
(49501 . "HANGUL SYLLABLE SYEOLG")
(49502 . "HANGUL SYLLABLE SYEOLM")
(49503 . "HANGUL SYLLABLE SYEOLB")
(49504 . "HANGUL SYLLABLE SYEOLS")
(49505 . "HANGUL SYLLABLE SYEOLT")
(49506 . "HANGUL SYLLABLE SYEOLP")
(49507 . "HANGUL SYLLABLE SYEOLH")
(49508 . "HANGUL SYLLABLE SYEOM")
(49509 . "HANGUL SYLLABLE SYEOB")
(49510 . "HANGUL SYLLABLE SYEOBS")
(49511 . "HANGUL SYLLABLE SYEOS")
(49512 . "HANGUL SYLLABLE SYEOSS")
(49513 . "HANGUL SYLLABLE SYEONG")
(49514 . "HANGUL SYLLABLE SYEOJ")
(49515 . "HANGUL SYLLABLE SYEOC")
(49516 . "HANGUL SYLLABLE SYEOK")
(49517 . "HANGUL SYLLABLE SYEOT")
(49518 . "HANGUL SYLLABLE SYEOP")
(49519 . "HANGUL SYLLABLE SYEOH")
(49520 . "HANGUL SYLLABLE SYE")
(49521 . "HANGUL SYLLABLE SYEG")
(49522 . "HANGUL SYLLABLE SYEGG")
(49523 . "HANGUL SYLLABLE SYEGS")
(49524 . "HANGUL SYLLABLE SYEN")
(49525 . "HANGUL SYLLABLE SYENJ")
(49526 . "HANGUL SYLLABLE SYENH")
(49527 . "HANGUL SYLLABLE SYED")
(49528 . "HANGUL SYLLABLE SYEL")
(49529 . "HANGUL SYLLABLE SYELG")
(49530 . "HANGUL SYLLABLE SYELM")
(49531 . "HANGUL SYLLABLE SYELB")
(49532 . "HANGUL SYLLABLE SYELS")
(49533 . "HANGUL SYLLABLE SYELT")
(49534 . "HANGUL SYLLABLE SYELP")
(49535 . "HANGUL SYLLABLE SYELH")
(49536 . "HANGUL SYLLABLE SYEM")
(49537 . "HANGUL SYLLABLE SYEB")
(49538 . "HANGUL SYLLABLE SYEBS")
(49539 . "HANGUL SYLLABLE SYES")
(49540 . "HANGUL SYLLABLE SYESS")
(49541 . "HANGUL SYLLABLE SYENG")
(49542 . "HANGUL SYLLABLE SYEJ")
(49543 . "HANGUL SYLLABLE SYEC")
(49544 . "HANGUL SYLLABLE SYEK")
(49545 . "HANGUL SYLLABLE SYET")
(49546 . "HANGUL SYLLABLE SYEP")
(49547 . "HANGUL SYLLABLE SYEH")
(49548 . "HANGUL SYLLABLE SO")
(49549 . "HANGUL SYLLABLE SOG")
(49550 . "HANGUL SYLLABLE SOGG")
(49551 . "HANGUL SYLLABLE SOGS")
(49552 . "HANGUL SYLLABLE SON")
(49553 . "HANGUL SYLLABLE SONJ")
(49554 . "HANGUL SYLLABLE SONH")
(49555 . "HANGUL SYLLABLE SOD")
(49556 . "HANGUL SYLLABLE SOL")
(49557 . "HANGUL SYLLABLE SOLG")
(49558 . "HANGUL SYLLABLE SOLM")
(49559 . "HANGUL SYLLABLE SOLB")
(49560 . "HANGUL SYLLABLE SOLS")
(49561 . "HANGUL SYLLABLE SOLT")
(49562 . "HANGUL SYLLABLE SOLP")
(49563 . "HANGUL SYLLABLE SOLH")
(49564 . "HANGUL SYLLABLE SOM")
(49565 . "HANGUL SYLLABLE SOB")
(49566 . "HANGUL SYLLABLE SOBS")
(49567 . "HANGUL SYLLABLE SOS")
(49568 . "HANGUL SYLLABLE SOSS")
(49569 . "HANGUL SYLLABLE SONG")
(49570 . "HANGUL SYLLABLE SOJ")
(49571 . "HANGUL SYLLABLE SOC")
(49572 . "HANGUL SYLLABLE SOK")
(49573 . "HANGUL SYLLABLE SOT")
(49574 . "HANGUL SYLLABLE SOP")
(49575 . "HANGUL SYLLABLE SOH")
(49576 . "HANGUL SYLLABLE SWA")
(49577 . "HANGUL SYLLABLE SWAG")
(49578 . "HANGUL SYLLABLE SWAGG")
(49579 . "HANGUL SYLLABLE SWAGS")
(49580 . "HANGUL SYLLABLE SWAN")
(49581 . "HANGUL SYLLABLE SWANJ")
(49582 . "HANGUL SYLLABLE SWANH")
(49583 . "HANGUL SYLLABLE SWAD")
(49584 . "HANGUL SYLLABLE SWAL")
(49585 . "HANGUL SYLLABLE SWALG")
(49586 . "HANGUL SYLLABLE SWALM")
(49587 . "HANGUL SYLLABLE SWALB")
(49588 . "HANGUL SYLLABLE SWALS")
(49589 . "HANGUL SYLLABLE SWALT")
(49590 . "HANGUL SYLLABLE SWALP")
(49591 . "HANGUL SYLLABLE SWALH")
(49592 . "HANGUL SYLLABLE SWAM")
(49593 . "HANGUL SYLLABLE SWAB")
(49594 . "HANGUL SYLLABLE SWABS")
(49595 . "HANGUL SYLLABLE SWAS")
(49596 . "HANGUL SYLLABLE SWASS")
(49597 . "HANGUL SYLLABLE SWANG")
(49598 . "HANGUL SYLLABLE SWAJ")
(49599 . "HANGUL SYLLABLE SWAC")
(49600 . "HANGUL SYLLABLE SWAK")
(49601 . "HANGUL SYLLABLE SWAT")
(49602 . "HANGUL SYLLABLE SWAP")
(49603 . "HANGUL SYLLABLE SWAH")
(49604 . "HANGUL SYLLABLE SWAE")
(49605 . "HANGUL SYLLABLE SWAEG")
(49606 . "HANGUL SYLLABLE SWAEGG")
(49607 . "HANGUL SYLLABLE SWAEGS")
(49608 . "HANGUL SYLLABLE SWAEN")
(49609 . "HANGUL SYLLABLE SWAENJ")
(49610 . "HANGUL SYLLABLE SWAENH")
(49611 . "HANGUL SYLLABLE SWAED")
(49612 . "HANGUL SYLLABLE SWAEL")
(49613 . "HANGUL SYLLABLE SWAELG")
(49614 . "HANGUL SYLLABLE SWAELM")
(49615 . "HANGUL SYLLABLE SWAELB")
(49616 . "HANGUL SYLLABLE SWAELS")
(49617 . "HANGUL SYLLABLE SWAELT")
(49618 . "HANGUL SYLLABLE SWAELP")
(49619 . "HANGUL SYLLABLE SWAELH")
(49620 . "HANGUL SYLLABLE SWAEM")
(49621 . "HANGUL SYLLABLE SWAEB")
(49622 . "HANGUL SYLLABLE SWAEBS")
(49623 . "HANGUL SYLLABLE SWAES")
(49624 . "HANGUL SYLLABLE SWAESS")
(49625 . "HANGUL SYLLABLE SWAENG")
(49626 . "HANGUL SYLLABLE SWAEJ")
(49627 . "HANGUL SYLLABLE SWAEC")
(49628 . "HANGUL SYLLABLE SWAEK")
(49629 . "HANGUL SYLLABLE SWAET")
(49630 . "HANGUL SYLLABLE SWAEP")
(49631 . "HANGUL SYLLABLE SWAEH")
(49632 . "HANGUL SYLLABLE SOE")
(49633 . "HANGUL SYLLABLE SOEG")
(49634 . "HANGUL SYLLABLE SOEGG")
(49635 . "HANGUL SYLLABLE SOEGS")
(49636 . "HANGUL SYLLABLE SOEN")
(49637 . "HANGUL SYLLABLE SOENJ")
(49638 . "HANGUL SYLLABLE SOENH")
(49639 . "HANGUL SYLLABLE SOED")
(49640 . "HANGUL SYLLABLE SOEL")
(49641 . "HANGUL SYLLABLE SOELG")
(49642 . "HANGUL SYLLABLE SOELM")
(49643 . "HANGUL SYLLABLE SOELB")
(49644 . "HANGUL SYLLABLE SOELS")
(49645 . "HANGUL SYLLABLE SOELT")
(49646 . "HANGUL SYLLABLE SOELP")
(49647 . "HANGUL SYLLABLE SOELH")
(49648 . "HANGUL SYLLABLE SOEM")
(49649 . "HANGUL SYLLABLE SOEB")
(49650 . "HANGUL SYLLABLE SOEBS")
(49651 . "HANGUL SYLLABLE SOES")
(49652 . "HANGUL SYLLABLE SOESS")
(49653 . "HANGUL SYLLABLE SOENG")
(49654 . "HANGUL SYLLABLE SOEJ")
(49655 . "HANGUL SYLLABLE SOEC")
(49656 . "HANGUL SYLLABLE SOEK")
(49657 . "HANGUL SYLLABLE SOET")
(49658 . "HANGUL SYLLABLE SOEP")
(49659 . "HANGUL SYLLABLE SOEH")
(49660 . "HANGUL SYLLABLE SYO")
(49661 . "HANGUL SYLLABLE SYOG")
(49662 . "HANGUL SYLLABLE SYOGG")
(49663 . "HANGUL SYLLABLE SYOGS")
(49664 . "HANGUL SYLLABLE SYON")
(49665 . "HANGUL SYLLABLE SYONJ")
(49666 . "HANGUL SYLLABLE SYONH")
(49667 . "HANGUL SYLLABLE SYOD")
(49668 . "HANGUL SYLLABLE SYOL")
(49669 . "HANGUL SYLLABLE SYOLG")
(49670 . "HANGUL SYLLABLE SYOLM")
(49671 . "HANGUL SYLLABLE SYOLB")
(49672 . "HANGUL SYLLABLE SYOLS")
(49673 . "HANGUL SYLLABLE SYOLT")
(49674 . "HANGUL SYLLABLE SYOLP")
(49675 . "HANGUL SYLLABLE SYOLH")
(49676 . "HANGUL SYLLABLE SYOM")
(49677 . "HANGUL SYLLABLE SYOB")
(49678 . "HANGUL SYLLABLE SYOBS")
(49679 . "HANGUL SYLLABLE SYOS")
(49680 . "HANGUL SYLLABLE SYOSS")
(49681 . "HANGUL SYLLABLE SYONG")
(49682 . "HANGUL SYLLABLE SYOJ")
(49683 . "HANGUL SYLLABLE SYOC")
(49684 . "HANGUL SYLLABLE SYOK")
(49685 . "HANGUL SYLLABLE SYOT")
(49686 . "HANGUL SYLLABLE SYOP")
(49687 . "HANGUL SYLLABLE SYOH")
(49688 . "HANGUL SYLLABLE SU")
(49689 . "HANGUL SYLLABLE SUG")
(49690 . "HANGUL SYLLABLE SUGG")
(49691 . "HANGUL SYLLABLE SUGS")
(49692 . "HANGUL SYLLABLE SUN")
(49693 . "HANGUL SYLLABLE SUNJ")
(49694 . "HANGUL SYLLABLE SUNH")
(49695 . "HANGUL SYLLABLE SUD")
(49696 . "HANGUL SYLLABLE SUL")
(49697 . "HANGUL SYLLABLE SULG")
(49698 . "HANGUL SYLLABLE SULM")
(49699 . "HANGUL SYLLABLE SULB")
(49700 . "HANGUL SYLLABLE SULS")
(49701 . "HANGUL SYLLABLE SULT")
(49702 . "HANGUL SYLLABLE SULP")
(49703 . "HANGUL SYLLABLE SULH")
(49704 . "HANGUL SYLLABLE SUM")
(49705 . "HANGUL SYLLABLE SUB")
(49706 . "HANGUL SYLLABLE SUBS")
(49707 . "HANGUL SYLLABLE SUS")
(49708 . "HANGUL SYLLABLE SUSS")
(49709 . "HANGUL SYLLABLE SUNG")
(49710 . "HANGUL SYLLABLE SUJ")
(49711 . "HANGUL SYLLABLE SUC")
(49712 . "HANGUL SYLLABLE SUK")
(49713 . "HANGUL SYLLABLE SUT")
(49714 . "HANGUL SYLLABLE SUP")
(49715 . "HANGUL SYLLABLE SUH")
(49716 . "HANGUL SYLLABLE SWEO")
(49717 . "HANGUL SYLLABLE SWEOG")
(49718 . "HANGUL SYLLABLE SWEOGG")
(49719 . "HANGUL SYLLABLE SWEOGS")
(49720 . "HANGUL SYLLABLE SWEON")
(49721 . "HANGUL SYLLABLE SWEONJ")
(49722 . "HANGUL SYLLABLE SWEONH")
(49723 . "HANGUL SYLLABLE SWEOD")
(49724 . "HANGUL SYLLABLE SWEOL")
(49725 . "HANGUL SYLLABLE SWEOLG")
(49726 . "HANGUL SYLLABLE SWEOLM")
(49727 . "HANGUL SYLLABLE SWEOLB")
(49728 . "HANGUL SYLLABLE SWEOLS")
(49729 . "HANGUL SYLLABLE SWEOLT")
(49730 . "HANGUL SYLLABLE SWEOLP")
(49731 . "HANGUL SYLLABLE SWEOLH")
(49732 . "HANGUL SYLLABLE SWEOM")
(49733 . "HANGUL SYLLABLE SWEOB")
(49734 . "HANGUL SYLLABLE SWEOBS")
(49735 . "HANGUL SYLLABLE SWEOS")
(49736 . "HANGUL SYLLABLE SWEOSS")
(49737 . "HANGUL SYLLABLE SWEONG")
(49738 . "HANGUL SYLLABLE SWEOJ")
(49739 . "HANGUL SYLLABLE SWEOC")
(49740 . "HANGUL SYLLABLE SWEOK")
(49741 . "HANGUL SYLLABLE SWEOT")
(49742 . "HANGUL SYLLABLE SWEOP")
(49743 . "HANGUL SYLLABLE SWEOH")
(49744 . "HANGUL SYLLABLE SWE")
(49745 . "HANGUL SYLLABLE SWEG")
(49746 . "HANGUL SYLLABLE SWEGG")
(49747 . "HANGUL SYLLABLE SWEGS")
(49748 . "HANGUL SYLLABLE SWEN")
(49749 . "HANGUL SYLLABLE SWENJ")
(49750 . "HANGUL SYLLABLE SWENH")
(49751 . "HANGUL SYLLABLE SWED")
(49752 . "HANGUL SYLLABLE SWEL")
(49753 . "HANGUL SYLLABLE SWELG")
(49754 . "HANGUL SYLLABLE SWELM")
(49755 . "HANGUL SYLLABLE SWELB")
(49756 . "HANGUL SYLLABLE SWELS")
(49757 . "HANGUL SYLLABLE SWELT")
(49758 . "HANGUL SYLLABLE SWELP")
(49759 . "HANGUL SYLLABLE SWELH")
(49760 . "HANGUL SYLLABLE SWEM")
(49761 . "HANGUL SYLLABLE SWEB")
(49762 . "HANGUL SYLLABLE SWEBS")
(49763 . "HANGUL SYLLABLE SWES")
(49764 . "HANGUL SYLLABLE SWESS")
(49765 . "HANGUL SYLLABLE SWENG")
(49766 . "HANGUL SYLLABLE SWEJ")
(49767 . "HANGUL SYLLABLE SWEC")
(49768 . "HANGUL SYLLABLE SWEK")
(49769 . "HANGUL SYLLABLE SWET")
(49770 . "HANGUL SYLLABLE SWEP")
(49771 . "HANGUL SYLLABLE SWEH")
(49772 . "HANGUL SYLLABLE SWI")
(49773 . "HANGUL SYLLABLE SWIG")
(49774 . "HANGUL SYLLABLE SWIGG")
(49775 . "HANGUL SYLLABLE SWIGS")
(49776 . "HANGUL SYLLABLE SWIN")
(49777 . "HANGUL SYLLABLE SWINJ")
(49778 . "HANGUL SYLLABLE SWINH")
(49779 . "HANGUL SYLLABLE SWID")
(49780 . "HANGUL SYLLABLE SWIL")
(49781 . "HANGUL SYLLABLE SWILG")
(49782 . "HANGUL SYLLABLE SWILM")
(49783 . "HANGUL SYLLABLE SWILB")
(49784 . "HANGUL SYLLABLE SWILS")
(49785 . "HANGUL SYLLABLE SWILT")
(49786 . "HANGUL SYLLABLE SWILP")
(49787 . "HANGUL SYLLABLE SWILH")
(49788 . "HANGUL SYLLABLE SWIM")
(49789 . "HANGUL SYLLABLE SWIB")
(49790 . "HANGUL SYLLABLE SWIBS")
(49791 . "HANGUL SYLLABLE SWIS")
(49792 . "HANGUL SYLLABLE SWISS")
(49793 . "HANGUL SYLLABLE SWING")
(49794 . "HANGUL SYLLABLE SWIJ")
(49795 . "HANGUL SYLLABLE SWIC")
(49796 . "HANGUL SYLLABLE SWIK")
(49797 . "HANGUL SYLLABLE SWIT")
(49798 . "HANGUL SYLLABLE SWIP")
(49799 . "HANGUL SYLLABLE SWIH")
(49800 . "HANGUL SYLLABLE SYU")
(49801 . "HANGUL SYLLABLE SYUG")
(49802 . "HANGUL SYLLABLE SYUGG")
(49803 . "HANGUL SYLLABLE SYUGS")
(49804 . "HANGUL SYLLABLE SYUN")
(49805 . "HANGUL SYLLABLE SYUNJ")
(49806 . "HANGUL SYLLABLE SYUNH")
(49807 . "HANGUL SYLLABLE SYUD")
(49808 . "HANGUL SYLLABLE SYUL")
(49809 . "HANGUL SYLLABLE SYULG")
(49810 . "HANGUL SYLLABLE SYULM")
(49811 . "HANGUL SYLLABLE SYULB")
(49812 . "HANGUL SYLLABLE SYULS")
(49813 . "HANGUL SYLLABLE SYULT")
(49814 . "HANGUL SYLLABLE SYULP")
(49815 . "HANGUL SYLLABLE SYULH")
(49816 . "HANGUL SYLLABLE SYUM")
(49817 . "HANGUL SYLLABLE SYUB")
(49818 . "HANGUL SYLLABLE SYUBS")
(49819 . "HANGUL SYLLABLE SYUS")
(49820 . "HANGUL SYLLABLE SYUSS")
(49821 . "HANGUL SYLLABLE SYUNG")
(49822 . "HANGUL SYLLABLE SYUJ")
(49823 . "HANGUL SYLLABLE SYUC")
(49824 . "HANGUL SYLLABLE SYUK")
(49825 . "HANGUL SYLLABLE SYUT")
(49826 . "HANGUL SYLLABLE SYUP")
(49827 . "HANGUL SYLLABLE SYUH")
(49828 . "HANGUL SYLLABLE SEU")
(49829 . "HANGUL SYLLABLE SEUG")
(49830 . "HANGUL SYLLABLE SEUGG")
(49831 . "HANGUL SYLLABLE SEUGS")
(49832 . "HANGUL SYLLABLE SEUN")
(49833 . "HANGUL SYLLABLE SEUNJ")
(49834 . "HANGUL SYLLABLE SEUNH")
(49835 . "HANGUL SYLLABLE SEUD")
(49836 . "HANGUL SYLLABLE SEUL")
(49837 . "HANGUL SYLLABLE SEULG")
(49838 . "HANGUL SYLLABLE SEULM")
(49839 . "HANGUL SYLLABLE SEULB")
(49840 . "HANGUL SYLLABLE SEULS")
(49841 . "HANGUL SYLLABLE SEULT")
(49842 . "HANGUL SYLLABLE SEULP")
(49843 . "HANGUL SYLLABLE SEULH")
(49844 . "HANGUL SYLLABLE SEUM")
(49845 . "HANGUL SYLLABLE SEUB")
(49846 . "HANGUL SYLLABLE SEUBS")
(49847 . "HANGUL SYLLABLE SEUS")
(49848 . "HANGUL SYLLABLE SEUSS")
(49849 . "HANGUL SYLLABLE SEUNG")
(49850 . "HANGUL SYLLABLE SEUJ")
(49851 . "HANGUL SYLLABLE SEUC")
(49852 . "HANGUL SYLLABLE SEUK")
(49853 . "HANGUL SYLLABLE SEUT")
(49854 . "HANGUL SYLLABLE SEUP")
(49855 . "HANGUL SYLLABLE SEUH")
(49856 . "HANGUL SYLLABLE SYI")
(49857 . "HANGUL SYLLABLE SYIG")
(49858 . "HANGUL SYLLABLE SYIGG")
(49859 . "HANGUL SYLLABLE SYIGS")
(49860 . "HANGUL SYLLABLE SYIN")
(49861 . "HANGUL SYLLABLE SYINJ")
(49862 . "HANGUL SYLLABLE SYINH")
(49863 . "HANGUL SYLLABLE SYID")
(49864 . "HANGUL SYLLABLE SYIL")
(49865 . "HANGUL SYLLABLE SYILG")
(49866 . "HANGUL SYLLABLE SYILM")
(49867 . "HANGUL SYLLABLE SYILB")
(49868 . "HANGUL SYLLABLE SYILS")
(49869 . "HANGUL SYLLABLE SYILT")
(49870 . "HANGUL SYLLABLE SYILP")
(49871 . "HANGUL SYLLABLE SYILH")
(49872 . "HANGUL SYLLABLE SYIM")
(49873 . "HANGUL SYLLABLE SYIB")
(49874 . "HANGUL SYLLABLE SYIBS")
(49875 . "HANGUL SYLLABLE SYIS")
(49876 . "HANGUL SYLLABLE SYISS")
(49877 . "HANGUL SYLLABLE SYING")
(49878 . "HANGUL SYLLABLE SYIJ")
(49879 . "HANGUL SYLLABLE SYIC")
(49880 . "HANGUL SYLLABLE SYIK")
(49881 . "HANGUL SYLLABLE SYIT")
(49882 . "HANGUL SYLLABLE SYIP")
(49883 . "HANGUL SYLLABLE SYIH")
(49884 . "HANGUL SYLLABLE SI")
(49885 . "HANGUL SYLLABLE SIG")
(49886 . "HANGUL SYLLABLE SIGG")
(49887 . "HANGUL SYLLABLE SIGS")
(49888 . "HANGUL SYLLABLE SIN")
(49889 . "HANGUL SYLLABLE SINJ")
(49890 . "HANGUL SYLLABLE SINH")
(49891 . "HANGUL SYLLABLE SID")
(49892 . "HANGUL SYLLABLE SIL")
(49893 . "HANGUL SYLLABLE SILG")
(49894 . "HANGUL SYLLABLE SILM")
(49895 . "HANGUL SYLLABLE SILB")
(49896 . "HANGUL SYLLABLE SILS")
(49897 . "HANGUL SYLLABLE SILT")
(49898 . "HANGUL SYLLABLE SILP")
(49899 . "HANGUL SYLLABLE SILH")
(49900 . "HANGUL SYLLABLE SIM")
(49901 . "HANGUL SYLLABLE SIB")
(49902 . "HANGUL SYLLABLE SIBS")
(49903 . "HANGUL SYLLABLE SIS")
(49904 . "HANGUL SYLLABLE SISS")
(49905 . "HANGUL SYLLABLE SING")
(49906 . "HANGUL SYLLABLE SIJ")
(49907 . "HANGUL SYLLABLE SIC")
(49908 . "HANGUL SYLLABLE SIK")
(49909 . "HANGUL SYLLABLE SIT")
(49910 . "HANGUL SYLLABLE SIP")
(49911 . "HANGUL SYLLABLE SIH")
(49912 . "HANGUL SYLLABLE SSA")
(49913 . "HANGUL SYLLABLE SSAG")
(49914 . "HANGUL SYLLABLE SSAGG")
(49915 . "HANGUL SYLLABLE SSAGS")
(49916 . "HANGUL SYLLABLE SSAN")
(49917 . "HANGUL SYLLABLE SSANJ")
(49918 . "HANGUL SYLLABLE SSANH")
(49919 . "HANGUL SYLLABLE SSAD")
(49920 . "HANGUL SYLLABLE SSAL")
(49921 . "HANGUL SYLLABLE SSALG")
(49922 . "HANGUL SYLLABLE SSALM")
(49923 . "HANGUL SYLLABLE SSALB")
(49924 . "HANGUL SYLLABLE SSALS")
(49925 . "HANGUL SYLLABLE SSALT")
(49926 . "HANGUL SYLLABLE SSALP")
(49927 . "HANGUL SYLLABLE SSALH")
(49928 . "HANGUL SYLLABLE SSAM")
(49929 . "HANGUL SYLLABLE SSAB")
(49930 . "HANGUL SYLLABLE SSABS")
(49931 . "HANGUL SYLLABLE SSAS")
(49932 . "HANGUL SYLLABLE SSASS")
(49933 . "HANGUL SYLLABLE SSANG")
(49934 . "HANGUL SYLLABLE SSAJ")
(49935 . "HANGUL SYLLABLE SSAC")
(49936 . "HANGUL SYLLABLE SSAK")
(49937 . "HANGUL SYLLABLE SSAT")
(49938 . "HANGUL SYLLABLE SSAP")
(49939 . "HANGUL SYLLABLE SSAH")
(49940 . "HANGUL SYLLABLE SSAE")
(49941 . "HANGUL SYLLABLE SSAEG")
(49942 . "HANGUL SYLLABLE SSAEGG")
(49943 . "HANGUL SYLLABLE SSAEGS")
(49944 . "HANGUL SYLLABLE SSAEN")
(49945 . "HANGUL SYLLABLE SSAENJ")
(49946 . "HANGUL SYLLABLE SSAENH")
(49947 . "HANGUL SYLLABLE SSAED")
(49948 . "HANGUL SYLLABLE SSAEL")
(49949 . "HANGUL SYLLABLE SSAELG")
(49950 . "HANGUL SYLLABLE SSAELM")
(49951 . "HANGUL SYLLABLE SSAELB")
(49952 . "HANGUL SYLLABLE SSAELS")
(49953 . "HANGUL SYLLABLE SSAELT")
(49954 . "HANGUL SYLLABLE SSAELP")
(49955 . "HANGUL SYLLABLE SSAELH")
(49956 . "HANGUL SYLLABLE SSAEM")
(49957 . "HANGUL SYLLABLE SSAEB")
(49958 . "HANGUL SYLLABLE SSAEBS")
(49959 . "HANGUL SYLLABLE SSAES")
(49960 . "HANGUL SYLLABLE SSAESS")
(49961 . "HANGUL SYLLABLE SSAENG")
(49962 . "HANGUL SYLLABLE SSAEJ")
(49963 . "HANGUL SYLLABLE SSAEC")
(49964 . "HANGUL SYLLABLE SSAEK")
(49965 . "HANGUL SYLLABLE SSAET")
(49966 . "HANGUL SYLLABLE SSAEP")
(49967 . "HANGUL SYLLABLE SSAEH")
(49968 . "HANGUL SYLLABLE SSYA")
(49969 . "HANGUL SYLLABLE SSYAG")
(49970 . "HANGUL SYLLABLE SSYAGG")
(49971 . "HANGUL SYLLABLE SSYAGS")
(49972 . "HANGUL SYLLABLE SSYAN")
(49973 . "HANGUL SYLLABLE SSYANJ")
(49974 . "HANGUL SYLLABLE SSYANH")
(49975 . "HANGUL SYLLABLE SSYAD")
(49976 . "HANGUL SYLLABLE SSYAL")
(49977 . "HANGUL SYLLABLE SSYALG")
(49978 . "HANGUL SYLLABLE SSYALM")
(49979 . "HANGUL SYLLABLE SSYALB")
(49980 . "HANGUL SYLLABLE SSYALS")
(49981 . "HANGUL SYLLABLE SSYALT")
(49982 . "HANGUL SYLLABLE SSYALP")
(49983 . "HANGUL SYLLABLE SSYALH")
(49984 . "HANGUL SYLLABLE SSYAM")
(49985 . "HANGUL SYLLABLE SSYAB")
(49986 . "HANGUL SYLLABLE SSYABS")
(49987 . "HANGUL SYLLABLE SSYAS")
(49988 . "HANGUL SYLLABLE SSYASS")
(49989 . "HANGUL SYLLABLE SSYANG")
(49990 . "HANGUL SYLLABLE SSYAJ")
(49991 . "HANGUL SYLLABLE SSYAC")
(49992 . "HANGUL SYLLABLE SSYAK")
(49993 . "HANGUL SYLLABLE SSYAT")
(49994 . "HANGUL SYLLABLE SSYAP")
(49995 . "HANGUL SYLLABLE SSYAH")
(49996 . "HANGUL SYLLABLE SSYAE")
(49997 . "HANGUL SYLLABLE SSYAEG")
(49998 . "HANGUL SYLLABLE SSYAEGG")
(49999 . "HANGUL SYLLABLE SSYAEGS")
(50000 . "HANGUL SYLLABLE SSYAEN")
(50001 . "HANGUL SYLLABLE SSYAENJ")
(50002 . "HANGUL SYLLABLE SSYAENH")
(50003 . "HANGUL SYLLABLE SSYAED")
(50004 . "HANGUL SYLLABLE SSYAEL")
(50005 . "HANGUL SYLLABLE SSYAELG")
(50006 . "HANGUL SYLLABLE SSYAELM")
(50007 . "HANGUL SYLLABLE SSYAELB")
(50008 . "HANGUL SYLLABLE SSYAELS")
(50009 . "HANGUL SYLLABLE SSYAELT")
(50010 . "HANGUL SYLLABLE SSYAELP")
(50011 . "HANGUL SYLLABLE SSYAELH")
(50012 . "HANGUL SYLLABLE SSYAEM")
(50013 . "HANGUL SYLLABLE SSYAEB")
(50014 . "HANGUL SYLLABLE SSYAEBS")
(50015 . "HANGUL SYLLABLE SSYAES")
(50016 . "HANGUL SYLLABLE SSYAESS")
(50017 . "HANGUL SYLLABLE SSYAENG")
(50018 . "HANGUL SYLLABLE SSYAEJ")
(50019 . "HANGUL SYLLABLE SSYAEC")
(50020 . "HANGUL SYLLABLE SSYAEK")
(50021 . "HANGUL SYLLABLE SSYAET")
(50022 . "HANGUL SYLLABLE SSYAEP")
(50023 . "HANGUL SYLLABLE SSYAEH")
(50024 . "HANGUL SYLLABLE SSEO")
(50025 . "HANGUL SYLLABLE SSEOG")
(50026 . "HANGUL SYLLABLE SSEOGG")
(50027 . "HANGUL SYLLABLE SSEOGS")
(50028 . "HANGUL SYLLABLE SSEON")
(50029 . "HANGUL SYLLABLE SSEONJ")
(50030 . "HANGUL SYLLABLE SSEONH")
(50031 . "HANGUL SYLLABLE SSEOD")
(50032 . "HANGUL SYLLABLE SSEOL")
(50033 . "HANGUL SYLLABLE SSEOLG")
(50034 . "HANGUL SYLLABLE SSEOLM")
(50035 . "HANGUL SYLLABLE SSEOLB")
(50036 . "HANGUL SYLLABLE SSEOLS")
(50037 . "HANGUL SYLLABLE SSEOLT")
(50038 . "HANGUL SYLLABLE SSEOLP")
(50039 . "HANGUL SYLLABLE SSEOLH")
(50040 . "HANGUL SYLLABLE SSEOM")
(50041 . "HANGUL SYLLABLE SSEOB")
(50042 . "HANGUL SYLLABLE SSEOBS")
(50043 . "HANGUL SYLLABLE SSEOS")
(50044 . "HANGUL SYLLABLE SSEOSS")
(50045 . "HANGUL SYLLABLE SSEONG")
(50046 . "HANGUL SYLLABLE SSEOJ")
(50047 . "HANGUL SYLLABLE SSEOC")
(50048 . "HANGUL SYLLABLE SSEOK")
(50049 . "HANGUL SYLLABLE SSEOT")
(50050 . "HANGUL SYLLABLE SSEOP")
(50051 . "HANGUL SYLLABLE SSEOH")
(50052 . "HANGUL SYLLABLE SSE")
(50053 . "HANGUL SYLLABLE SSEG")
(50054 . "HANGUL SYLLABLE SSEGG")
(50055 . "HANGUL SYLLABLE SSEGS")
(50056 . "HANGUL SYLLABLE SSEN")
(50057 . "HANGUL SYLLABLE SSENJ")
(50058 . "HANGUL SYLLABLE SSENH")
(50059 . "HANGUL SYLLABLE SSED")
(50060 . "HANGUL SYLLABLE SSEL")
(50061 . "HANGUL SYLLABLE SSELG")
(50062 . "HANGUL SYLLABLE SSELM")
(50063 . "HANGUL SYLLABLE SSELB")
(50064 . "HANGUL SYLLABLE SSELS")
(50065 . "HANGUL SYLLABLE SSELT")
(50066 . "HANGUL SYLLABLE SSELP")
(50067 . "HANGUL SYLLABLE SSELH")
(50068 . "HANGUL SYLLABLE SSEM")
(50069 . "HANGUL SYLLABLE SSEB")
(50070 . "HANGUL SYLLABLE SSEBS")
(50071 . "HANGUL SYLLABLE SSES")
(50072 . "HANGUL SYLLABLE SSESS")
(50073 . "HANGUL SYLLABLE SSENG")
(50074 . "HANGUL SYLLABLE SSEJ")
(50075 . "HANGUL SYLLABLE SSEC")
(50076 . "HANGUL SYLLABLE SSEK")
(50077 . "HANGUL SYLLABLE SSET")
(50078 . "HANGUL SYLLABLE SSEP")
(50079 . "HANGUL SYLLABLE SSEH")
(50080 . "HANGUL SYLLABLE SSYEO")
(50081 . "HANGUL SYLLABLE SSYEOG")
(50082 . "HANGUL SYLLABLE SSYEOGG")
(50083 . "HANGUL SYLLABLE SSYEOGS")
(50084 . "HANGUL SYLLABLE SSYEON")
(50085 . "HANGUL SYLLABLE SSYEONJ")
(50086 . "HANGUL SYLLABLE SSYEONH")
(50087 . "HANGUL SYLLABLE SSYEOD")
(50088 . "HANGUL SYLLABLE SSYEOL")
(50089 . "HANGUL SYLLABLE SSYEOLG")
(50090 . "HANGUL SYLLABLE SSYEOLM")
(50091 . "HANGUL SYLLABLE SSYEOLB")
(50092 . "HANGUL SYLLABLE SSYEOLS")
(50093 . "HANGUL SYLLABLE SSYEOLT")
(50094 . "HANGUL SYLLABLE SSYEOLP")
(50095 . "HANGUL SYLLABLE SSYEOLH")
(50096 . "HANGUL SYLLABLE SSYEOM")
(50097 . "HANGUL SYLLABLE SSYEOB")
(50098 . "HANGUL SYLLABLE SSYEOBS")
(50099 . "HANGUL SYLLABLE SSYEOS")
(50100 . "HANGUL SYLLABLE SSYEOSS")
(50101 . "HANGUL SYLLABLE SSYEONG")
(50102 . "HANGUL SYLLABLE SSYEOJ")
(50103 . "HANGUL SYLLABLE SSYEOC")
(50104 . "HANGUL SYLLABLE SSYEOK")
(50105 . "HANGUL SYLLABLE SSYEOT")
(50106 . "HANGUL SYLLABLE SSYEOP")
(50107 . "HANGUL SYLLABLE SSYEOH")
(50108 . "HANGUL SYLLABLE SSYE")
(50109 . "HANGUL SYLLABLE SSYEG")
(50110 . "HANGUL SYLLABLE SSYEGG")
(50111 . "HANGUL SYLLABLE SSYEGS")
(50112 . "HANGUL SYLLABLE SSYEN")
(50113 . "HANGUL SYLLABLE SSYENJ")
(50114 . "HANGUL SYLLABLE SSYENH")
(50115 . "HANGUL SYLLABLE SSYED")
(50116 . "HANGUL SYLLABLE SSYEL")
(50117 . "HANGUL SYLLABLE SSYELG")
(50118 . "HANGUL SYLLABLE SSYELM")
(50119 . "HANGUL SYLLABLE SSYELB")
(50120 . "HANGUL SYLLABLE SSYELS")
(50121 . "HANGUL SYLLABLE SSYELT")
(50122 . "HANGUL SYLLABLE SSYELP")
(50123 . "HANGUL SYLLABLE SSYELH")
(50124 . "HANGUL SYLLABLE SSYEM")
(50125 . "HANGUL SYLLABLE SSYEB")
(50126 . "HANGUL SYLLABLE SSYEBS")
(50127 . "HANGUL SYLLABLE SSYES")
(50128 . "HANGUL SYLLABLE SSYESS")
(50129 . "HANGUL SYLLABLE SSYENG")
(50130 . "HANGUL SYLLABLE SSYEJ")
(50131 . "HANGUL SYLLABLE SSYEC")
(50132 . "HANGUL SYLLABLE SSYEK")
(50133 . "HANGUL SYLLABLE SSYET")
(50134 . "HANGUL SYLLABLE SSYEP")
(50135 . "HANGUL SYLLABLE SSYEH")
(50136 . "HANGUL SYLLABLE SSO")
(50137 . "HANGUL SYLLABLE SSOG")
(50138 . "HANGUL SYLLABLE SSOGG")
(50139 . "HANGUL SYLLABLE SSOGS")
(50140 . "HANGUL SYLLABLE SSON")
(50141 . "HANGUL SYLLABLE SSONJ")
(50142 . "HANGUL SYLLABLE SSONH")
(50143 . "HANGUL SYLLABLE SSOD")
(50144 . "HANGUL SYLLABLE SSOL")
(50145 . "HANGUL SYLLABLE SSOLG")
(50146 . "HANGUL SYLLABLE SSOLM")
(50147 . "HANGUL SYLLABLE SSOLB")
(50148 . "HANGUL SYLLABLE SSOLS")
(50149 . "HANGUL SYLLABLE SSOLT")
(50150 . "HANGUL SYLLABLE SSOLP")
(50151 . "HANGUL SYLLABLE SSOLH")
(50152 . "HANGUL SYLLABLE SSOM")
(50153 . "HANGUL SYLLABLE SSOB")
(50154 . "HANGUL SYLLABLE SSOBS")
(50155 . "HANGUL SYLLABLE SSOS")
(50156 . "HANGUL SYLLABLE SSOSS")
(50157 . "HANGUL SYLLABLE SSONG")
(50158 . "HANGUL SYLLABLE SSOJ")
(50159 . "HANGUL SYLLABLE SSOC")
(50160 . "HANGUL SYLLABLE SSOK")
(50161 . "HANGUL SYLLABLE SSOT")
(50162 . "HANGUL SYLLABLE SSOP")
(50163 . "HANGUL SYLLABLE SSOH")
(50164 . "HANGUL SYLLABLE SSWA")
(50165 . "HANGUL SYLLABLE SSWAG")
(50166 . "HANGUL SYLLABLE SSWAGG")
(50167 . "HANGUL SYLLABLE SSWAGS")
(50168 . "HANGUL SYLLABLE SSWAN")
(50169 . "HANGUL SYLLABLE SSWANJ")
(50170 . "HANGUL SYLLABLE SSWANH")
(50171 . "HANGUL SYLLABLE SSWAD")
(50172 . "HANGUL SYLLABLE SSWAL")
(50173 . "HANGUL SYLLABLE SSWALG")
(50174 . "HANGUL SYLLABLE SSWALM")
(50175 . "HANGUL SYLLABLE SSWALB")
(50176 . "HANGUL SYLLABLE SSWALS")
(50177 . "HANGUL SYLLABLE SSWALT")
(50178 . "HANGUL SYLLABLE SSWALP")
(50179 . "HANGUL SYLLABLE SSWALH")
(50180 . "HANGUL SYLLABLE SSWAM")
(50181 . "HANGUL SYLLABLE SSWAB")
(50182 . "HANGUL SYLLABLE SSWABS")
(50183 . "HANGUL SYLLABLE SSWAS")
(50184 . "HANGUL SYLLABLE SSWASS")
(50185 . "HANGUL SYLLABLE SSWANG")
(50186 . "HANGUL SYLLABLE SSWAJ")
(50187 . "HANGUL SYLLABLE SSWAC")
(50188 . "HANGUL SYLLABLE SSWAK")
(50189 . "HANGUL SYLLABLE SSWAT")
(50190 . "HANGUL SYLLABLE SSWAP")
(50191 . "HANGUL SYLLABLE SSWAH")
(50192 . "HANGUL SYLLABLE SSWAE")
(50193 . "HANGUL SYLLABLE SSWAEG")
(50194 . "HANGUL SYLLABLE SSWAEGG")
(50195 . "HANGUL SYLLABLE SSWAEGS")
(50196 . "HANGUL SYLLABLE SSWAEN")
(50197 . "HANGUL SYLLABLE SSWAENJ")
(50198 . "HANGUL SYLLABLE SSWAENH")
(50199 . "HANGUL SYLLABLE SSWAED")
(50200 . "HANGUL SYLLABLE SSWAEL")
(50201 . "HANGUL SYLLABLE SSWAELG")
(50202 . "HANGUL SYLLABLE SSWAELM")
(50203 . "HANGUL SYLLABLE SSWAELB")
(50204 . "HANGUL SYLLABLE SSWAELS")
(50205 . "HANGUL SYLLABLE SSWAELT")
(50206 . "HANGUL SYLLABLE SSWAELP")
(50207 . "HANGUL SYLLABLE SSWAELH")
(50208 . "HANGUL SYLLABLE SSWAEM")
(50209 . "HANGUL SYLLABLE SSWAEB")
(50210 . "HANGUL SYLLABLE SSWAEBS")
(50211 . "HANGUL SYLLABLE SSWAES")
(50212 . "HANGUL SYLLABLE SSWAESS")
(50213 . "HANGUL SYLLABLE SSWAENG")
(50214 . "HANGUL SYLLABLE SSWAEJ")
(50215 . "HANGUL SYLLABLE SSWAEC")
(50216 . "HANGUL SYLLABLE SSWAEK")
(50217 . "HANGUL SYLLABLE SSWAET")
(50218 . "HANGUL SYLLABLE SSWAEP")
(50219 . "HANGUL SYLLABLE SSWAEH")
(50220 . "HANGUL SYLLABLE SSOE")
(50221 . "HANGUL SYLLABLE SSOEG")
(50222 . "HANGUL SYLLABLE SSOEGG")
(50223 . "HANGUL SYLLABLE SSOEGS")
(50224 . "HANGUL SYLLABLE SSOEN")
(50225 . "HANGUL SYLLABLE SSOENJ")
(50226 . "HANGUL SYLLABLE SSOENH")
(50227 . "HANGUL SYLLABLE SSOED")
(50228 . "HANGUL SYLLABLE SSOEL")
(50229 . "HANGUL SYLLABLE SSOELG")
(50230 . "HANGUL SYLLABLE SSOELM")
(50231 . "HANGUL SYLLABLE SSOELB")
(50232 . "HANGUL SYLLABLE SSOELS")
(50233 . "HANGUL SYLLABLE SSOELT")
(50234 . "HANGUL SYLLABLE SSOELP")
(50235 . "HANGUL SYLLABLE SSOELH")
(50236 . "HANGUL SYLLABLE SSOEM")
(50237 . "HANGUL SYLLABLE SSOEB")
(50238 . "HANGUL SYLLABLE SSOEBS")
(50239 . "HANGUL SYLLABLE SSOES")
(50240 . "HANGUL SYLLABLE SSOESS")
(50241 . "HANGUL SYLLABLE SSOENG")
(50242 . "HANGUL SYLLABLE SSOEJ")
(50243 . "HANGUL SYLLABLE SSOEC")
(50244 . "HANGUL SYLLABLE SSOEK")
(50245 . "HANGUL SYLLABLE SSOET")
(50246 . "HANGUL SYLLABLE SSOEP")
(50247 . "HANGUL SYLLABLE SSOEH")
(50248 . "HANGUL SYLLABLE SSYO")
(50249 . "HANGUL SYLLABLE SSYOG")
(50250 . "HANGUL SYLLABLE SSYOGG")
(50251 . "HANGUL SYLLABLE SSYOGS")
(50252 . "HANGUL SYLLABLE SSYON")
(50253 . "HANGUL SYLLABLE SSYONJ")
(50254 . "HANGUL SYLLABLE SSYONH")
(50255 . "HANGUL SYLLABLE SSYOD")
(50256 . "HANGUL SYLLABLE SSYOL")
(50257 . "HANGUL SYLLABLE SSYOLG")
(50258 . "HANGUL SYLLABLE SSYOLM")
(50259 . "HANGUL SYLLABLE SSYOLB")
(50260 . "HANGUL SYLLABLE SSYOLS")
(50261 . "HANGUL SYLLABLE SSYOLT")
(50262 . "HANGUL SYLLABLE SSYOLP")
(50263 . "HANGUL SYLLABLE SSYOLH")
(50264 . "HANGUL SYLLABLE SSYOM")
(50265 . "HANGUL SYLLABLE SSYOB")
(50266 . "HANGUL SYLLABLE SSYOBS")
(50267 . "HANGUL SYLLABLE SSYOS")
(50268 . "HANGUL SYLLABLE SSYOSS")
(50269 . "HANGUL SYLLABLE SSYONG")
(50270 . "HANGUL SYLLABLE SSYOJ")
(50271 . "HANGUL SYLLABLE SSYOC")
(50272 . "HANGUL SYLLABLE SSYOK")
(50273 . "HANGUL SYLLABLE SSYOT")
(50274 . "HANGUL SYLLABLE SSYOP")
(50275 . "HANGUL SYLLABLE SSYOH")
(50276 . "HANGUL SYLLABLE SSU")
(50277 . "HANGUL SYLLABLE SSUG")
(50278 . "HANGUL SYLLABLE SSUGG")
(50279 . "HANGUL SYLLABLE SSUGS")
(50280 . "HANGUL SYLLABLE SSUN")
(50281 . "HANGUL SYLLABLE SSUNJ")
(50282 . "HANGUL SYLLABLE SSUNH")
(50283 . "HANGUL SYLLABLE SSUD")
(50284 . "HANGUL SYLLABLE SSUL")
(50285 . "HANGUL SYLLABLE SSULG")
(50286 . "HANGUL SYLLABLE SSULM")
(50287 . "HANGUL SYLLABLE SSULB")
(50288 . "HANGUL SYLLABLE SSULS")
(50289 . "HANGUL SYLLABLE SSULT")
(50290 . "HANGUL SYLLABLE SSULP")
(50291 . "HANGUL SYLLABLE SSULH")
(50292 . "HANGUL SYLLABLE SSUM")
(50293 . "HANGUL SYLLABLE SSUB")
(50294 . "HANGUL SYLLABLE SSUBS")
(50295 . "HANGUL SYLLABLE SSUS")
(50296 . "HANGUL SYLLABLE SSUSS")
(50297 . "HANGUL SYLLABLE SSUNG")
(50298 . "HANGUL SYLLABLE SSUJ")
(50299 . "HANGUL SYLLABLE SSUC")
(50300 . "HANGUL SYLLABLE SSUK")
(50301 . "HANGUL SYLLABLE SSUT")
(50302 . "HANGUL SYLLABLE SSUP")
(50303 . "HANGUL SYLLABLE SSUH")
(50304 . "HANGUL SYLLABLE SSWEO")
(50305 . "HANGUL SYLLABLE SSWEOG")
(50306 . "HANGUL SYLLABLE SSWEOGG")
(50307 . "HANGUL SYLLABLE SSWEOGS")
(50308 . "HANGUL SYLLABLE SSWEON")
(50309 . "HANGUL SYLLABLE SSWEONJ")
(50310 . "HANGUL SYLLABLE SSWEONH")
(50311 . "HANGUL SYLLABLE SSWEOD")
(50312 . "HANGUL SYLLABLE SSWEOL")
(50313 . "HANGUL SYLLABLE SSWEOLG")
(50314 . "HANGUL SYLLABLE SSWEOLM")
(50315 . "HANGUL SYLLABLE SSWEOLB")
(50316 . "HANGUL SYLLABLE SSWEOLS")
(50317 . "HANGUL SYLLABLE SSWEOLT")
(50318 . "HANGUL SYLLABLE SSWEOLP")
(50319 . "HANGUL SYLLABLE SSWEOLH")
(50320 . "HANGUL SYLLABLE SSWEOM")
(50321 . "HANGUL SYLLABLE SSWEOB")
(50322 . "HANGUL SYLLABLE SSWEOBS")
(50323 . "HANGUL SYLLABLE SSWEOS")
(50324 . "HANGUL SYLLABLE SSWEOSS")
(50325 . "HANGUL SYLLABLE SSWEONG")
(50326 . "HANGUL SYLLABLE SSWEOJ")
(50327 . "HANGUL SYLLABLE SSWEOC")
(50328 . "HANGUL SYLLABLE SSWEOK")
(50329 . "HANGUL SYLLABLE SSWEOT")
(50330 . "HANGUL SYLLABLE SSWEOP")
(50331 . "HANGUL SYLLABLE SSWEOH")
(50332 . "HANGUL SYLLABLE SSWE")
(50333 . "HANGUL SYLLABLE SSWEG")
(50334 . "HANGUL SYLLABLE SSWEGG")
(50335 . "HANGUL SYLLABLE SSWEGS")
(50336 . "HANGUL SYLLABLE SSWEN")
(50337 . "HANGUL SYLLABLE SSWENJ")
(50338 . "HANGUL SYLLABLE SSWENH")
(50339 . "HANGUL SYLLABLE SSWED")
(50340 . "HANGUL SYLLABLE SSWEL")
(50341 . "HANGUL SYLLABLE SSWELG")
(50342 . "HANGUL SYLLABLE SSWELM")
(50343 . "HANGUL SYLLABLE SSWELB")
(50344 . "HANGUL SYLLABLE SSWELS")
(50345 . "HANGUL SYLLABLE SSWELT")
(50346 . "HANGUL SYLLABLE SSWELP")
(50347 . "HANGUL SYLLABLE SSWELH")
(50348 . "HANGUL SYLLABLE SSWEM")
(50349 . "HANGUL SYLLABLE SSWEB")
(50350 . "HANGUL SYLLABLE SSWEBS")
(50351 . "HANGUL SYLLABLE SSWES")
(50352 . "HANGUL SYLLABLE SSWESS")
(50353 . "HANGUL SYLLABLE SSWENG")
(50354 . "HANGUL SYLLABLE SSWEJ")
(50355 . "HANGUL SYLLABLE SSWEC")
(50356 . "HANGUL SYLLABLE SSWEK")
(50357 . "HANGUL SYLLABLE SSWET")
(50358 . "HANGUL SYLLABLE SSWEP")
(50359 . "HANGUL SYLLABLE SSWEH")
(50360 . "HANGUL SYLLABLE SSWI")
(50361 . "HANGUL SYLLABLE SSWIG")
(50362 . "HANGUL SYLLABLE SSWIGG")
(50363 . "HANGUL SYLLABLE SSWIGS")
(50364 . "HANGUL SYLLABLE SSWIN")
(50365 . "HANGUL SYLLABLE SSWINJ")
(50366 . "HANGUL SYLLABLE SSWINH")
(50367 . "HANGUL SYLLABLE SSWID")
(50368 . "HANGUL SYLLABLE SSWIL")
(50369 . "HANGUL SYLLABLE SSWILG")
(50370 . "HANGUL SYLLABLE SSWILM")
(50371 . "HANGUL SYLLABLE SSWILB")
(50372 . "HANGUL SYLLABLE SSWILS")
(50373 . "HANGUL SYLLABLE SSWILT")
(50374 . "HANGUL SYLLABLE SSWILP")
(50375 . "HANGUL SYLLABLE SSWILH")
(50376 . "HANGUL SYLLABLE SSWIM")
(50377 . "HANGUL SYLLABLE SSWIB")
(50378 . "HANGUL SYLLABLE SSWIBS")
(50379 . "HANGUL SYLLABLE SSWIS")
(50380 . "HANGUL SYLLABLE SSWISS")
(50381 . "HANGUL SYLLABLE SSWING")
(50382 . "HANGUL SYLLABLE SSWIJ")
(50383 . "HANGUL SYLLABLE SSWIC")
(50384 . "HANGUL SYLLABLE SSWIK")
(50385 . "HANGUL SYLLABLE SSWIT")
(50386 . "HANGUL SYLLABLE SSWIP")
(50387 . "HANGUL SYLLABLE SSWIH")
(50388 . "HANGUL SYLLABLE SSYU")
(50389 . "HANGUL SYLLABLE SSYUG")
(50390 . "HANGUL SYLLABLE SSYUGG")
(50391 . "HANGUL SYLLABLE SSYUGS")
(50392 . "HANGUL SYLLABLE SSYUN")
(50393 . "HANGUL SYLLABLE SSYUNJ")
(50394 . "HANGUL SYLLABLE SSYUNH")
(50395 . "HANGUL SYLLABLE SSYUD")
(50396 . "HANGUL SYLLABLE SSYUL")
(50397 . "HANGUL SYLLABLE SSYULG")
(50398 . "HANGUL SYLLABLE SSYULM")
(50399 . "HANGUL SYLLABLE SSYULB")
(50400 . "HANGUL SYLLABLE SSYULS")
(50401 . "HANGUL SYLLABLE SSYULT")
(50402 . "HANGUL SYLLABLE SSYULP")
(50403 . "HANGUL SYLLABLE SSYULH")
(50404 . "HANGUL SYLLABLE SSYUM")
(50405 . "HANGUL SYLLABLE SSYUB")
(50406 . "HANGUL SYLLABLE SSYUBS")
(50407 . "HANGUL SYLLABLE SSYUS")
(50408 . "HANGUL SYLLABLE SSYUSS")
(50409 . "HANGUL SYLLABLE SSYUNG")
(50410 . "HANGUL SYLLABLE SSYUJ")
(50411 . "HANGUL SYLLABLE SSYUC")
(50412 . "HANGUL SYLLABLE SSYUK")
(50413 . "HANGUL SYLLABLE SSYUT")
(50414 . "HANGUL SYLLABLE SSYUP")
(50415 . "HANGUL SYLLABLE SSYUH")
(50416 . "HANGUL SYLLABLE SSEU")
(50417 . "HANGUL SYLLABLE SSEUG")
(50418 . "HANGUL SYLLABLE SSEUGG")
(50419 . "HANGUL SYLLABLE SSEUGS")
(50420 . "HANGUL SYLLABLE SSEUN")
(50421 . "HANGUL SYLLABLE SSEUNJ")
(50422 . "HANGUL SYLLABLE SSEUNH")
(50423 . "HANGUL SYLLABLE SSEUD")
(50424 . "HANGUL SYLLABLE SSEUL")
(50425 . "HANGUL SYLLABLE SSEULG")
(50426 . "HANGUL SYLLABLE SSEULM")
(50427 . "HANGUL SYLLABLE SSEULB")
(50428 . "HANGUL SYLLABLE SSEULS")
(50429 . "HANGUL SYLLABLE SSEULT")
(50430 . "HANGUL SYLLABLE SSEULP")
(50431 . "HANGUL SYLLABLE SSEULH")
(50432 . "HANGUL SYLLABLE SSEUM")
(50433 . "HANGUL SYLLABLE SSEUB")
(50434 . "HANGUL SYLLABLE SSEUBS")
(50435 . "HANGUL SYLLABLE SSEUS")
(50436 . "HANGUL SYLLABLE SSEUSS")
(50437 . "HANGUL SYLLABLE SSEUNG")
(50438 . "HANGUL SYLLABLE SSEUJ")
(50439 . "HANGUL SYLLABLE SSEUC")
(50440 . "HANGUL SYLLABLE SSEUK")
(50441 . "HANGUL SYLLABLE SSEUT")
(50442 . "HANGUL SYLLABLE SSEUP")
(50443 . "HANGUL SYLLABLE SSEUH")
(50444 . "HANGUL SYLLABLE SSYI")
(50445 . "HANGUL SYLLABLE SSYIG")
(50446 . "HANGUL SYLLABLE SSYIGG")
(50447 . "HANGUL SYLLABLE SSYIGS")
(50448 . "HANGUL SYLLABLE SSYIN")
(50449 . "HANGUL SYLLABLE SSYINJ")
(50450 . "HANGUL SYLLABLE SSYINH")
(50451 . "HANGUL SYLLABLE SSYID")
(50452 . "HANGUL SYLLABLE SSYIL")
(50453 . "HANGUL SYLLABLE SSYILG")
(50454 . "HANGUL SYLLABLE SSYILM")
(50455 . "HANGUL SYLLABLE SSYILB")
(50456 . "HANGUL SYLLABLE SSYILS")
(50457 . "HANGUL SYLLABLE SSYILT")
(50458 . "HANGUL SYLLABLE SSYILP")
(50459 . "HANGUL SYLLABLE SSYILH")
(50460 . "HANGUL SYLLABLE SSYIM")
(50461 . "HANGUL SYLLABLE SSYIB")
(50462 . "HANGUL SYLLABLE SSYIBS")
(50463 . "HANGUL SYLLABLE SSYIS")
(50464 . "HANGUL SYLLABLE SSYISS")
(50465 . "HANGUL SYLLABLE SSYING")
(50466 . "HANGUL SYLLABLE SSYIJ")
(50467 . "HANGUL SYLLABLE SSYIC")
(50468 . "HANGUL SYLLABLE SSYIK")
(50469 . "HANGUL SYLLABLE SSYIT")
(50470 . "HANGUL SYLLABLE SSYIP")
(50471 . "HANGUL SYLLABLE SSYIH")
(50472 . "HANGUL SYLLABLE SSI")
(50473 . "HANGUL SYLLABLE SSIG")
(50474 . "HANGUL SYLLABLE SSIGG")
(50475 . "HANGUL SYLLABLE SSIGS")
(50476 . "HANGUL SYLLABLE SSIN")
(50477 . "HANGUL SYLLABLE SSINJ")
(50478 . "HANGUL SYLLABLE SSINH")
(50479 . "HANGUL SYLLABLE SSID")
(50480 . "HANGUL SYLLABLE SSIL")
(50481 . "HANGUL SYLLABLE SSILG")
(50482 . "HANGUL SYLLABLE SSILM")
(50483 . "HANGUL SYLLABLE SSILB")
(50484 . "HANGUL SYLLABLE SSILS")
(50485 . "HANGUL SYLLABLE SSILT")
(50486 . "HANGUL SYLLABLE SSILP")
(50487 . "HANGUL SYLLABLE SSILH")
(50488 . "HANGUL SYLLABLE SSIM")
(50489 . "HANGUL SYLLABLE SSIB")
(50490 . "HANGUL SYLLABLE SSIBS")
(50491 . "HANGUL SYLLABLE SSIS")
(50492 . "HANGUL SYLLABLE SSISS")
(50493 . "HANGUL SYLLABLE SSING")
(50494 . "HANGUL SYLLABLE SSIJ")
(50495 . "HANGUL SYLLABLE SSIC")
(50496 . "HANGUL SYLLABLE SSIK")
(50497 . "HANGUL SYLLABLE SSIT")
(50498 . "HANGUL SYLLABLE SSIP")
(50499 . "HANGUL SYLLABLE SSIH")
(50500 . "HANGUL SYLLABLE A")
(50501 . "HANGUL SYLLABLE AG")
(50502 . "HANGUL SYLLABLE AGG")
(50503 . "HANGUL SYLLABLE AGS")
(50504 . "HANGUL SYLLABLE AN")
(50505 . "HANGUL SYLLABLE ANJ")
(50506 . "HANGUL SYLLABLE ANH")
(50507 . "HANGUL SYLLABLE AD")
(50508 . "HANGUL SYLLABLE AL")
(50509 . "HANGUL SYLLABLE ALG")
(50510 . "HANGUL SYLLABLE ALM")
(50511 . "HANGUL SYLLABLE ALB")
(50512 . "HANGUL SYLLABLE ALS")
(50513 . "HANGUL SYLLABLE ALT")
(50514 . "HANGUL SYLLABLE ALP")
(50515 . "HANGUL SYLLABLE ALH")
(50516 . "HANGUL SYLLABLE AM")
(50517 . "HANGUL SYLLABLE AB")
(50518 . "HANGUL SYLLABLE ABS")
(50519 . "HANGUL SYLLABLE AS")
(50520 . "HANGUL SYLLABLE ASS")
(50521 . "HANGUL SYLLABLE ANG")
(50522 . "HANGUL SYLLABLE AJ")
(50523 . "HANGUL SYLLABLE AC")
(50524 . "HANGUL SYLLABLE AK")
(50525 . "HANGUL SYLLABLE AT")
(50526 . "HANGUL SYLLABLE AP")
(50527 . "HANGUL SYLLABLE AH")
(50528 . "HANGUL SYLLABLE AE")
(50529 . "HANGUL SYLLABLE AEG")
(50530 . "HANGUL SYLLABLE AEGG")
(50531 . "HANGUL SYLLABLE AEGS")
(50532 . "HANGUL SYLLABLE AEN")
(50533 . "HANGUL SYLLABLE AENJ")
(50534 . "HANGUL SYLLABLE AENH")
(50535 . "HANGUL SYLLABLE AED")
(50536 . "HANGUL SYLLABLE AEL")
(50537 . "HANGUL SYLLABLE AELG")
(50538 . "HANGUL SYLLABLE AELM")
(50539 . "HANGUL SYLLABLE AELB")
(50540 . "HANGUL SYLLABLE AELS")
(50541 . "HANGUL SYLLABLE AELT")
(50542 . "HANGUL SYLLABLE AELP")
(50543 . "HANGUL SYLLABLE AELH")
(50544 . "HANGUL SYLLABLE AEM")
(50545 . "HANGUL SYLLABLE AEB")
(50546 . "HANGUL SYLLABLE AEBS")
(50547 . "HANGUL SYLLABLE AES")
(50548 . "HANGUL SYLLABLE AESS")
(50549 . "HANGUL SYLLABLE AENG")
(50550 . "HANGUL SYLLABLE AEJ")
(50551 . "HANGUL SYLLABLE AEC")
(50552 . "HANGUL SYLLABLE AEK")
(50553 . "HANGUL SYLLABLE AET")
(50554 . "HANGUL SYLLABLE AEP")
(50555 . "HANGUL SYLLABLE AEH")
(50556 . "HANGUL SYLLABLE YA")
(50557 . "HANGUL SYLLABLE YAG")
(50558 . "HANGUL SYLLABLE YAGG")
(50559 . "HANGUL SYLLABLE YAGS")
(50560 . "HANGUL SYLLABLE YAN")
(50561 . "HANGUL SYLLABLE YANJ")
(50562 . "HANGUL SYLLABLE YANH")
(50563 . "HANGUL SYLLABLE YAD")
(50564 . "HANGUL SYLLABLE YAL")
(50565 . "HANGUL SYLLABLE YALG")
(50566 . "HANGUL SYLLABLE YALM")
(50567 . "HANGUL SYLLABLE YALB")
(50568 . "HANGUL SYLLABLE YALS")
(50569 . "HANGUL SYLLABLE YALT")
(50570 . "HANGUL SYLLABLE YALP")
(50571 . "HANGUL SYLLABLE YALH")
(50572 . "HANGUL SYLLABLE YAM")
(50573 . "HANGUL SYLLABLE YAB")
(50574 . "HANGUL SYLLABLE YABS")
(50575 . "HANGUL SYLLABLE YAS")
(50576 . "HANGUL SYLLABLE YASS")
(50577 . "HANGUL SYLLABLE YANG")
(50578 . "HANGUL SYLLABLE YAJ")
(50579 . "HANGUL SYLLABLE YAC")
(50580 . "HANGUL SYLLABLE YAK")
(50581 . "HANGUL SYLLABLE YAT")
(50582 . "HANGUL SYLLABLE YAP")
(50583 . "HANGUL SYLLABLE YAH")
(50584 . "HANGUL SYLLABLE YAE")
(50585 . "HANGUL SYLLABLE YAEG")
(50586 . "HANGUL SYLLABLE YAEGG")
(50587 . "HANGUL SYLLABLE YAEGS")
(50588 . "HANGUL SYLLABLE YAEN")
(50589 . "HANGUL SYLLABLE YAENJ")
(50590 . "HANGUL SYLLABLE YAENH")
(50591 . "HANGUL SYLLABLE YAED")
(50592 . "HANGUL SYLLABLE YAEL")
(50593 . "HANGUL SYLLABLE YAELG")
(50594 . "HANGUL SYLLABLE YAELM")
(50595 . "HANGUL SYLLABLE YAELB")
(50596 . "HANGUL SYLLABLE YAELS")
(50597 . "HANGUL SYLLABLE YAELT")
(50598 . "HANGUL SYLLABLE YAELP")
(50599 . "HANGUL SYLLABLE YAELH")
(50600 . "HANGUL SYLLABLE YAEM")
(50601 . "HANGUL SYLLABLE YAEB")
(50602 . "HANGUL SYLLABLE YAEBS")
(50603 . "HANGUL SYLLABLE YAES")
(50604 . "HANGUL SYLLABLE YAESS")
(50605 . "HANGUL SYLLABLE YAENG")
(50606 . "HANGUL SYLLABLE YAEJ")
(50607 . "HANGUL SYLLABLE YAEC")
(50608 . "HANGUL SYLLABLE YAEK")
(50609 . "HANGUL SYLLABLE YAET")
(50610 . "HANGUL SYLLABLE YAEP")
(50611 . "HANGUL SYLLABLE YAEH")
(50612 . "HANGUL SYLLABLE EO")
(50613 . "HANGUL SYLLABLE EOG")
(50614 . "HANGUL SYLLABLE EOGG")
(50615 . "HANGUL SYLLABLE EOGS")
(50616 . "HANGUL SYLLABLE EON")
(50617 . "HANGUL SYLLABLE EONJ")
(50618 . "HANGUL SYLLABLE EONH")
(50619 . "HANGUL SYLLABLE EOD")
(50620 . "HANGUL SYLLABLE EOL")
(50621 . "HANGUL SYLLABLE EOLG")
(50622 . "HANGUL SYLLABLE EOLM")
(50623 . "HANGUL SYLLABLE EOLB")
(50624 . "HANGUL SYLLABLE EOLS")
(50625 . "HANGUL SYLLABLE EOLT")
(50626 . "HANGUL SYLLABLE EOLP")
(50627 . "HANGUL SYLLABLE EOLH")
(50628 . "HANGUL SYLLABLE EOM")
(50629 . "HANGUL SYLLABLE EOB")
(50630 . "HANGUL SYLLABLE EOBS")
(50631 . "HANGUL SYLLABLE EOS")
(50632 . "HANGUL SYLLABLE EOSS")
(50633 . "HANGUL SYLLABLE EONG")
(50634 . "HANGUL SYLLABLE EOJ")
(50635 . "HANGUL SYLLABLE EOC")
(50636 . "HANGUL SYLLABLE EOK")
(50637 . "HANGUL SYLLABLE EOT")
(50638 . "HANGUL SYLLABLE EOP")
(50639 . "HANGUL SYLLABLE EOH")
(50640 . "HANGUL SYLLABLE E")
(50641 . "HANGUL SYLLABLE EG")
(50642 . "HANGUL SYLLABLE EGG")
(50643 . "HANGUL SYLLABLE EGS")
(50644 . "HANGUL SYLLABLE EN")
(50645 . "HANGUL SYLLABLE ENJ")
(50646 . "HANGUL SYLLABLE ENH")
(50647 . "HANGUL SYLLABLE ED")
(50648 . "HANGUL SYLLABLE EL")
(50649 . "HANGUL SYLLABLE ELG")
(50650 . "HANGUL SYLLABLE ELM")
(50651 . "HANGUL SYLLABLE ELB")
(50652 . "HANGUL SYLLABLE ELS")
(50653 . "HANGUL SYLLABLE ELT")
(50654 . "HANGUL SYLLABLE ELP")
(50655 . "HANGUL SYLLABLE ELH")
(50656 . "HANGUL SYLLABLE EM")
(50657 . "HANGUL SYLLABLE EB")
(50658 . "HANGUL SYLLABLE EBS")
(50659 . "HANGUL SYLLABLE ES")
(50660 . "HANGUL SYLLABLE ESS")
(50661 . "HANGUL SYLLABLE ENG")
(50662 . "HANGUL SYLLABLE EJ")
(50663 . "HANGUL SYLLABLE EC")
(50664 . "HANGUL SYLLABLE EK")
(50665 . "HANGUL SYLLABLE ET")
(50666 . "HANGUL SYLLABLE EP")
(50667 . "HANGUL SYLLABLE EH")
(50668 . "HANGUL SYLLABLE YEO")
(50669 . "HANGUL SYLLABLE YEOG")
(50670 . "HANGUL SYLLABLE YEOGG")
(50671 . "HANGUL SYLLABLE YEOGS")
(50672 . "HANGUL SYLLABLE YEON")
(50673 . "HANGUL SYLLABLE YEONJ")
(50674 . "HANGUL SYLLABLE YEONH")
(50675 . "HANGUL SYLLABLE YEOD")
(50676 . "HANGUL SYLLABLE YEOL")
(50677 . "HANGUL SYLLABLE YEOLG")
(50678 . "HANGUL SYLLABLE YEOLM")
(50679 . "HANGUL SYLLABLE YEOLB")
(50680 . "HANGUL SYLLABLE YEOLS")
(50681 . "HANGUL SYLLABLE YEOLT")
(50682 . "HANGUL SYLLABLE YEOLP")
(50683 . "HANGUL SYLLABLE YEOLH")
(50684 . "HANGUL SYLLABLE YEOM")
(50685 . "HANGUL SYLLABLE YEOB")
(50686 . "HANGUL SYLLABLE YEOBS")
(50687 . "HANGUL SYLLABLE YEOS")
(50688 . "HANGUL SYLLABLE YEOSS")
(50689 . "HANGUL SYLLABLE YEONG")
(50690 . "HANGUL SYLLABLE YEOJ")
(50691 . "HANGUL SYLLABLE YEOC")
(50692 . "HANGUL SYLLABLE YEOK")
(50693 . "HANGUL SYLLABLE YEOT")
(50694 . "HANGUL SYLLABLE YEOP")
(50695 . "HANGUL SYLLABLE YEOH")
(50696 . "HANGUL SYLLABLE YE")
(50697 . "HANGUL SYLLABLE YEG")
(50698 . "HANGUL SYLLABLE YEGG")
(50699 . "HANGUL SYLLABLE YEGS")
(50700 . "HANGUL SYLLABLE YEN")
(50701 . "HANGUL SYLLABLE YENJ")
(50702 . "HANGUL SYLLABLE YENH")
(50703 . "HANGUL SYLLABLE YED")
(50704 . "HANGUL SYLLABLE YEL")
(50705 . "HANGUL SYLLABLE YELG")
(50706 . "HANGUL SYLLABLE YELM")
(50707 . "HANGUL SYLLABLE YELB")
(50708 . "HANGUL SYLLABLE YELS")
(50709 . "HANGUL SYLLABLE YELT")
(50710 . "HANGUL SYLLABLE YELP")
(50711 . "HANGUL SYLLABLE YELH")
(50712 . "HANGUL SYLLABLE YEM")
(50713 . "HANGUL SYLLABLE YEB")
(50714 . "HANGUL SYLLABLE YEBS")
(50715 . "HANGUL SYLLABLE YES")
(50716 . "HANGUL SYLLABLE YESS")
(50717 . "HANGUL SYLLABLE YENG")
(50718 . "HANGUL SYLLABLE YEJ")
(50719 . "HANGUL SYLLABLE YEC")
(50720 . "HANGUL SYLLABLE YEK")
(50721 . "HANGUL SYLLABLE YET")
(50722 . "HANGUL SYLLABLE YEP")
(50723 . "HANGUL SYLLABLE YEH")
(50724 . "HANGUL SYLLABLE O")
(50725 . "HANGUL SYLLABLE OG")
(50726 . "HANGUL SYLLABLE OGG")
(50727 . "HANGUL SYLLABLE OGS")
(50728 . "HANGUL SYLLABLE ON")
(50729 . "HANGUL SYLLABLE ONJ")
(50730 . "HANGUL SYLLABLE ONH")
(50731 . "HANGUL SYLLABLE OD")
(50732 . "HANGUL SYLLABLE OL")
(50733 . "HANGUL SYLLABLE OLG")
(50734 . "HANGUL SYLLABLE OLM")
(50735 . "HANGUL SYLLABLE OLB")
(50736 . "HANGUL SYLLABLE OLS")
(50737 . "HANGUL SYLLABLE OLT")
(50738 . "HANGUL SYLLABLE OLP")
(50739 . "HANGUL SYLLABLE OLH")
(50740 . "HANGUL SYLLABLE OM")
(50741 . "HANGUL SYLLABLE OB")
(50742 . "HANGUL SYLLABLE OBS")
(50743 . "HANGUL SYLLABLE OS")
(50744 . "HANGUL SYLLABLE OSS")
(50745 . "HANGUL SYLLABLE ONG")
(50746 . "HANGUL SYLLABLE OJ")
(50747 . "HANGUL SYLLABLE OC")
(50748 . "HANGUL SYLLABLE OK")
(50749 . "HANGUL SYLLABLE OT")
(50750 . "HANGUL SYLLABLE OP")
(50751 . "HANGUL SYLLABLE OH")
(50752 . "HANGUL SYLLABLE WA")
(50753 . "HANGUL SYLLABLE WAG")
(50754 . "HANGUL SYLLABLE WAGG")
(50755 . "HANGUL SYLLABLE WAGS")
(50756 . "HANGUL SYLLABLE WAN")
(50757 . "HANGUL SYLLABLE WANJ")
(50758 . "HANGUL SYLLABLE WANH")
(50759 . "HANGUL SYLLABLE WAD")
(50760 . "HANGUL SYLLABLE WAL")
(50761 . "HANGUL SYLLABLE WALG")
(50762 . "HANGUL SYLLABLE WALM")
(50763 . "HANGUL SYLLABLE WALB")
(50764 . "HANGUL SYLLABLE WALS")
(50765 . "HANGUL SYLLABLE WALT")
(50766 . "HANGUL SYLLABLE WALP")
(50767 . "HANGUL SYLLABLE WALH")
(50768 . "HANGUL SYLLABLE WAM")
(50769 . "HANGUL SYLLABLE WAB")
(50770 . "HANGUL SYLLABLE WABS")
(50771 . "HANGUL SYLLABLE WAS")
(50772 . "HANGUL SYLLABLE WASS")
(50773 . "HANGUL SYLLABLE WANG")
(50774 . "HANGUL SYLLABLE WAJ")
(50775 . "HANGUL SYLLABLE WAC")
(50776 . "HANGUL SYLLABLE WAK")
(50777 . "HANGUL SYLLABLE WAT")
(50778 . "HANGUL SYLLABLE WAP")
(50779 . "HANGUL SYLLABLE WAH")
(50780 . "HANGUL SYLLABLE WAE")
(50781 . "HANGUL SYLLABLE WAEG")
(50782 . "HANGUL SYLLABLE WAEGG")
(50783 . "HANGUL SYLLABLE WAEGS")
(50784 . "HANGUL SYLLABLE WAEN")
(50785 . "HANGUL SYLLABLE WAENJ")
(50786 . "HANGUL SYLLABLE WAENH")
(50787 . "HANGUL SYLLABLE WAED")
(50788 . "HANGUL SYLLABLE WAEL")
(50789 . "HANGUL SYLLABLE WAELG")
(50790 . "HANGUL SYLLABLE WAELM")
(50791 . "HANGUL SYLLABLE WAELB")
(50792 . "HANGUL SYLLABLE WAELS")
(50793 . "HANGUL SYLLABLE WAELT")
(50794 . "HANGUL SYLLABLE WAELP")
(50795 . "HANGUL SYLLABLE WAELH")
(50796 . "HANGUL SYLLABLE WAEM")
(50797 . "HANGUL SYLLABLE WAEB")
(50798 . "HANGUL SYLLABLE WAEBS")
(50799 . "HANGUL SYLLABLE WAES")
(50800 . "HANGUL SYLLABLE WAESS")
(50801 . "HANGUL SYLLABLE WAENG")
(50802 . "HANGUL SYLLABLE WAEJ")
(50803 . "HANGUL SYLLABLE WAEC")
(50804 . "HANGUL SYLLABLE WAEK")
(50805 . "HANGUL SYLLABLE WAET")
(50806 . "HANGUL SYLLABLE WAEP")
(50807 . "HANGUL SYLLABLE WAEH")
(50808 . "HANGUL SYLLABLE OE")
(50809 . "HANGUL SYLLABLE OEG")
(50810 . "HANGUL SYLLABLE OEGG")
(50811 . "HANGUL SYLLABLE OEGS")
(50812 . "HANGUL SYLLABLE OEN")
(50813 . "HANGUL SYLLABLE OENJ")
(50814 . "HANGUL SYLLABLE OENH")
(50815 . "HANGUL SYLLABLE OED")
(50816 . "HANGUL SYLLABLE OEL")
(50817 . "HANGUL SYLLABLE OELG")
(50818 . "HANGUL SYLLABLE OELM")
(50819 . "HANGUL SYLLABLE OELB")
(50820 . "HANGUL SYLLABLE OELS")
(50821 . "HANGUL SYLLABLE OELT")
(50822 . "HANGUL SYLLABLE OELP")
(50823 . "HANGUL SYLLABLE OELH")
(50824 . "HANGUL SYLLABLE OEM")
(50825 . "HANGUL SYLLABLE OEB")
(50826 . "HANGUL SYLLABLE OEBS")
(50827 . "HANGUL SYLLABLE OES")
(50828 . "HANGUL SYLLABLE OESS")
(50829 . "HANGUL SYLLABLE OENG")
(50830 . "HANGUL SYLLABLE OEJ")
(50831 . "HANGUL SYLLABLE OEC")
(50832 . "HANGUL SYLLABLE OEK")
(50833 . "HANGUL SYLLABLE OET")
(50834 . "HANGUL SYLLABLE OEP")
(50835 . "HANGUL SYLLABLE OEH")
(50836 . "HANGUL SYLLABLE YO")
(50837 . "HANGUL SYLLABLE YOG")
(50838 . "HANGUL SYLLABLE YOGG")
(50839 . "HANGUL SYLLABLE YOGS")
(50840 . "HANGUL SYLLABLE YON")
(50841 . "HANGUL SYLLABLE YONJ")
(50842 . "HANGUL SYLLABLE YONH")
(50843 . "HANGUL SYLLABLE YOD")
(50844 . "HANGUL SYLLABLE YOL")
(50845 . "HANGUL SYLLABLE YOLG")
(50846 . "HANGUL SYLLABLE YOLM")
(50847 . "HANGUL SYLLABLE YOLB")
(50848 . "HANGUL SYLLABLE YOLS")
(50849 . "HANGUL SYLLABLE YOLT")
(50850 . "HANGUL SYLLABLE YOLP")
(50851 . "HANGUL SYLLABLE YOLH")
(50852 . "HANGUL SYLLABLE YOM")
(50853 . "HANGUL SYLLABLE YOB")
(50854 . "HANGUL SYLLABLE YOBS")
(50855 . "HANGUL SYLLABLE YOS")
(50856 . "HANGUL SYLLABLE YOSS")
(50857 . "HANGUL SYLLABLE YONG")
(50858 . "HANGUL SYLLABLE YOJ")
(50859 . "HANGUL SYLLABLE YOC")
(50860 . "HANGUL SYLLABLE YOK")
(50861 . "HANGUL SYLLABLE YOT")
(50862 . "HANGUL SYLLABLE YOP")
(50863 . "HANGUL SYLLABLE YOH")
(50864 . "HANGUL SYLLABLE U")
(50865 . "HANGUL SYLLABLE UG")
(50866 . "HANGUL SYLLABLE UGG")
(50867 . "HANGUL SYLLABLE UGS")
(50868 . "HANGUL SYLLABLE UN")
(50869 . "HANGUL SYLLABLE UNJ")
(50870 . "HANGUL SYLLABLE UNH")
(50871 . "HANGUL SYLLABLE UD")
(50872 . "HANGUL SYLLABLE UL")
(50873 . "HANGUL SYLLABLE ULG")
(50874 . "HANGUL SYLLABLE ULM")
(50875 . "HANGUL SYLLABLE ULB")
(50876 . "HANGUL SYLLABLE ULS")
(50877 . "HANGUL SYLLABLE ULT")
(50878 . "HANGUL SYLLABLE ULP")
(50879 . "HANGUL SYLLABLE ULH")
(50880 . "HANGUL SYLLABLE UM")
(50881 . "HANGUL SYLLABLE UB")
(50882 . "HANGUL SYLLABLE UBS")
(50883 . "HANGUL SYLLABLE US")
(50884 . "HANGUL SYLLABLE USS")
(50885 . "HANGUL SYLLABLE UNG")
(50886 . "HANGUL SYLLABLE UJ")
(50887 . "HANGUL SYLLABLE UC")
(50888 . "HANGUL SYLLABLE UK")
(50889 . "HANGUL SYLLABLE UT")
(50890 . "HANGUL SYLLABLE UP")
(50891 . "HANGUL SYLLABLE UH")
(50892 . "HANGUL SYLLABLE WEO")
(50893 . "HANGUL SYLLABLE WEOG")
(50894 . "HANGUL SYLLABLE WEOGG")
(50895 . "HANGUL SYLLABLE WEOGS")
(50896 . "HANGUL SYLLABLE WEON")
(50897 . "HANGUL SYLLABLE WEONJ")
(50898 . "HANGUL SYLLABLE WEONH")
(50899 . "HANGUL SYLLABLE WEOD")
(50900 . "HANGUL SYLLABLE WEOL")
(50901 . "HANGUL SYLLABLE WEOLG")
(50902 . "HANGUL SYLLABLE WEOLM")
(50903 . "HANGUL SYLLABLE WEOLB")
(50904 . "HANGUL SYLLABLE WEOLS")
(50905 . "HANGUL SYLLABLE WEOLT")
(50906 . "HANGUL SYLLABLE WEOLP")
(50907 . "HANGUL SYLLABLE WEOLH")
(50908 . "HANGUL SYLLABLE WEOM")
(50909 . "HANGUL SYLLABLE WEOB")
(50910 . "HANGUL SYLLABLE WEOBS")
(50911 . "HANGUL SYLLABLE WEOS")
(50912 . "HANGUL SYLLABLE WEOSS")
(50913 . "HANGUL SYLLABLE WEONG")
(50914 . "HANGUL SYLLABLE WEOJ")
(50915 . "HANGUL SYLLABLE WEOC")
(50916 . "HANGUL SYLLABLE WEOK")
(50917 . "HANGUL SYLLABLE WEOT")
(50918 . "HANGUL SYLLABLE WEOP")
(50919 . "HANGUL SYLLABLE WEOH")
(50920 . "HANGUL SYLLABLE WE")
(50921 . "HANGUL SYLLABLE WEG")
(50922 . "HANGUL SYLLABLE WEGG")
(50923 . "HANGUL SYLLABLE WEGS")
(50924 . "HANGUL SYLLABLE WEN")
(50925 . "HANGUL SYLLABLE WENJ")
(50926 . "HANGUL SYLLABLE WENH")
(50927 . "HANGUL SYLLABLE WED")
(50928 . "HANGUL SYLLABLE WEL")
(50929 . "HANGUL SYLLABLE WELG")
(50930 . "HANGUL SYLLABLE WELM")
(50931 . "HANGUL SYLLABLE WELB")
(50932 . "HANGUL SYLLABLE WELS")
(50933 . "HANGUL SYLLABLE WELT")
(50934 . "HANGUL SYLLABLE WELP")
(50935 . "HANGUL SYLLABLE WELH")
(50936 . "HANGUL SYLLABLE WEM")
(50937 . "HANGUL SYLLABLE WEB")
(50938 . "HANGUL SYLLABLE WEBS")
(50939 . "HANGUL SYLLABLE WES")
(50940 . "HANGUL SYLLABLE WESS")
(50941 . "HANGUL SYLLABLE WENG")
(50942 . "HANGUL SYLLABLE WEJ")
(50943 . "HANGUL SYLLABLE WEC")
(50944 . "HANGUL SYLLABLE WEK")
(50945 . "HANGUL SYLLABLE WET")
(50946 . "HANGUL SYLLABLE WEP")
(50947 . "HANGUL SYLLABLE WEH")
(50948 . "HANGUL SYLLABLE WI")
(50949 . "HANGUL SYLLABLE WIG")
(50950 . "HANGUL SYLLABLE WIGG")
(50951 . "HANGUL SYLLABLE WIGS")
(50952 . "HANGUL SYLLABLE WIN")
(50953 . "HANGUL SYLLABLE WINJ")
(50954 . "HANGUL SYLLABLE WINH")
(50955 . "HANGUL SYLLABLE WID")
(50956 . "HANGUL SYLLABLE WIL")
(50957 . "HANGUL SYLLABLE WILG")
(50958 . "HANGUL SYLLABLE WILM")
(50959 . "HANGUL SYLLABLE WILB")
(50960 . "HANGUL SYLLABLE WILS")
(50961 . "HANGUL SYLLABLE WILT")
(50962 . "HANGUL SYLLABLE WILP")
(50963 . "HANGUL SYLLABLE WILH")
(50964 . "HANGUL SYLLABLE WIM")
(50965 . "HANGUL SYLLABLE WIB")
(50966 . "HANGUL SYLLABLE WIBS")
(50967 . "HANGUL SYLLABLE WIS")
(50968 . "HANGUL SYLLABLE WISS")
(50969 . "HANGUL SYLLABLE WING")
(50970 . "HANGUL SYLLABLE WIJ")
(50971 . "HANGUL SYLLABLE WIC")
(50972 . "HANGUL SYLLABLE WIK")
(50973 . "HANGUL SYLLABLE WIT")
(50974 . "HANGUL SYLLABLE WIP")
(50975 . "HANGUL SYLLABLE WIH")
(50976 . "HANGUL SYLLABLE YU")
(50977 . "HANGUL SYLLABLE YUG")
(50978 . "HANGUL SYLLABLE YUGG")
(50979 . "HANGUL SYLLABLE YUGS")
(50980 . "HANGUL SYLLABLE YUN")
(50981 . "HANGUL SYLLABLE YUNJ")
(50982 . "HANGUL SYLLABLE YUNH")
(50983 . "HANGUL SYLLABLE YUD")
(50984 . "HANGUL SYLLABLE YUL")
(50985 . "HANGUL SYLLABLE YULG")
(50986 . "HANGUL SYLLABLE YULM")
(50987 . "HANGUL SYLLABLE YULB")
(50988 . "HANGUL SYLLABLE YULS")
(50989 . "HANGUL SYLLABLE YULT")
(50990 . "HANGUL SYLLABLE YULP")
(50991 . "HANGUL SYLLABLE YULH")
(50992 . "HANGUL SYLLABLE YUM")
(50993 . "HANGUL SYLLABLE YUB")
(50994 . "HANGUL SYLLABLE YUBS")
(50995 . "HANGUL SYLLABLE YUS")
(50996 . "HANGUL SYLLABLE YUSS")
(50997 . "HANGUL SYLLABLE YUNG")
(50998 . "HANGUL SYLLABLE YUJ")
(50999 . "HANGUL SYLLABLE YUC")
(51000 . "HANGUL SYLLABLE YUK")
(51001 . "HANGUL SYLLABLE YUT")
(51002 . "HANGUL SYLLABLE YUP")
(51003 . "HANGUL SYLLABLE YUH")
(51004 . "HANGUL SYLLABLE EU")
(51005 . "HANGUL SYLLABLE EUG")
(51006 . "HANGUL SYLLABLE EUGG")
(51007 . "HANGUL SYLLABLE EUGS")
(51008 . "HANGUL SYLLABLE EUN")
(51009 . "HANGUL SYLLABLE EUNJ")
(51010 . "HANGUL SYLLABLE EUNH")
(51011 . "HANGUL SYLLABLE EUD")
(51012 . "HANGUL SYLLABLE EUL")
(51013 . "HANGUL SYLLABLE EULG")
(51014 . "HANGUL SYLLABLE EULM")
(51015 . "HANGUL SYLLABLE EULB")
(51016 . "HANGUL SYLLABLE EULS")
(51017 . "HANGUL SYLLABLE EULT")
(51018 . "HANGUL SYLLABLE EULP")
(51019 . "HANGUL SYLLABLE EULH")
(51020 . "HANGUL SYLLABLE EUM")
(51021 . "HANGUL SYLLABLE EUB")
(51022 . "HANGUL SYLLABLE EUBS")
(51023 . "HANGUL SYLLABLE EUS")
(51024 . "HANGUL SYLLABLE EUSS")
(51025 . "HANGUL SYLLABLE EUNG")
(51026 . "HANGUL SYLLABLE EUJ")
(51027 . "HANGUL SYLLABLE EUC")
(51028 . "HANGUL SYLLABLE EUK")
(51029 . "HANGUL SYLLABLE EUT")
(51030 . "HANGUL SYLLABLE EUP")
(51031 . "HANGUL SYLLABLE EUH")
(51032 . "HANGUL SYLLABLE YI")
(51033 . "HANGUL SYLLABLE YIG")
(51034 . "HANGUL SYLLABLE YIGG")
(51035 . "HANGUL SYLLABLE YIGS")
(51036 . "HANGUL SYLLABLE YIN")
(51037 . "HANGUL SYLLABLE YINJ")
(51038 . "HANGUL SYLLABLE YINH")
(51039 . "HANGUL SYLLABLE YID")
(51040 . "HANGUL SYLLABLE YIL")
(51041 . "HANGUL SYLLABLE YILG")
(51042 . "HANGUL SYLLABLE YILM")
(51043 . "HANGUL SYLLABLE YILB")
(51044 . "HANGUL SYLLABLE YILS")
(51045 . "HANGUL SYLLABLE YILT")
(51046 . "HANGUL SYLLABLE YILP")
(51047 . "HANGUL SYLLABLE YILH")
(51048 . "HANGUL SYLLABLE YIM")
(51049 . "HANGUL SYLLABLE YIB")
(51050 . "HANGUL SYLLABLE YIBS")
(51051 . "HANGUL SYLLABLE YIS")
(51052 . "HANGUL SYLLABLE YISS")
(51053 . "HANGUL SYLLABLE YING")
(51054 . "HANGUL SYLLABLE YIJ")
(51055 . "HANGUL SYLLABLE YIC")
(51056 . "HANGUL SYLLABLE YIK")
(51057 . "HANGUL SYLLABLE YIT")
(51058 . "HANGUL SYLLABLE YIP")
(51059 . "HANGUL SYLLABLE YIH")
(51060 . "HANGUL SYLLABLE I")
(51061 . "HANGUL SYLLABLE IG")
(51062 . "HANGUL SYLLABLE IGG")
(51063 . "HANGUL SYLLABLE IGS")
(51064 . "HANGUL SYLLABLE IN")
(51065 . "HANGUL SYLLABLE INJ")
(51066 . "HANGUL SYLLABLE INH")
(51067 . "HANGUL SYLLABLE ID")
(51068 . "HANGUL SYLLABLE IL")
(51069 . "HANGUL SYLLABLE ILG")
(51070 . "HANGUL SYLLABLE ILM")
(51071 . "HANGUL SYLLABLE ILB")
(51072 . "HANGUL SYLLABLE ILS")
(51073 . "HANGUL SYLLABLE ILT")
(51074 . "HANGUL SYLLABLE ILP")
(51075 . "HANGUL SYLLABLE ILH")
(51076 . "HANGUL SYLLABLE IM")
(51077 . "HANGUL SYLLABLE IB")
(51078 . "HANGUL SYLLABLE IBS")
(51079 . "HANGUL SYLLABLE IS")
(51080 . "HANGUL SYLLABLE ISS")
(51081 . "HANGUL SYLLABLE ING")
(51082 . "HANGUL SYLLABLE IJ")
(51083 . "HANGUL SYLLABLE IC")
(51084 . "HANGUL SYLLABLE IK")
(51085 . "HANGUL SYLLABLE IT")
(51086 . "HANGUL SYLLABLE IP")
(51087 . "HANGUL SYLLABLE IH")
(51088 . "HANGUL SYLLABLE JA")
(51089 . "HANGUL SYLLABLE JAG")
(51090 . "HANGUL SYLLABLE JAGG")
(51091 . "HANGUL SYLLABLE JAGS")
(51092 . "HANGUL SYLLABLE JAN")
(51093 . "HANGUL SYLLABLE JANJ")
(51094 . "HANGUL SYLLABLE JANH")
(51095 . "HANGUL SYLLABLE JAD")
(51096 . "HANGUL SYLLABLE JAL")
(51097 . "HANGUL SYLLABLE JALG")
(51098 . "HANGUL SYLLABLE JALM")
(51099 . "HANGUL SYLLABLE JALB")
(51100 . "HANGUL SYLLABLE JALS")
(51101 . "HANGUL SYLLABLE JALT")
(51102 . "HANGUL SYLLABLE JALP")
(51103 . "HANGUL SYLLABLE JALH")
(51104 . "HANGUL SYLLABLE JAM")
(51105 . "HANGUL SYLLABLE JAB")
(51106 . "HANGUL SYLLABLE JABS")
(51107 . "HANGUL SYLLABLE JAS")
(51108 . "HANGUL SYLLABLE JASS")
(51109 . "HANGUL SYLLABLE JANG")
(51110 . "HANGUL SYLLABLE JAJ")
(51111 . "HANGUL SYLLABLE JAC")
(51112 . "HANGUL SYLLABLE JAK")
(51113 . "HANGUL SYLLABLE JAT")
(51114 . "HANGUL SYLLABLE JAP")
(51115 . "HANGUL SYLLABLE JAH")
(51116 . "HANGUL SYLLABLE JAE")
(51117 . "HANGUL SYLLABLE JAEG")
(51118 . "HANGUL SYLLABLE JAEGG")
(51119 . "HANGUL SYLLABLE JAEGS")
(51120 . "HANGUL SYLLABLE JAEN")
(51121 . "HANGUL SYLLABLE JAENJ")
(51122 . "HANGUL SYLLABLE JAENH")
(51123 . "HANGUL SYLLABLE JAED")
(51124 . "HANGUL SYLLABLE JAEL")
(51125 . "HANGUL SYLLABLE JAELG")
(51126 . "HANGUL SYLLABLE JAELM")
(51127 . "HANGUL SYLLABLE JAELB")
(51128 . "HANGUL SYLLABLE JAELS")
(51129 . "HANGUL SYLLABLE JAELT")
(51130 . "HANGUL SYLLABLE JAELP")
(51131 . "HANGUL SYLLABLE JAELH")
(51132 . "HANGUL SYLLABLE JAEM")
(51133 . "HANGUL SYLLABLE JAEB")
(51134 . "HANGUL SYLLABLE JAEBS")
(51135 . "HANGUL SYLLABLE JAES")
(51136 . "HANGUL SYLLABLE JAESS")
(51137 . "HANGUL SYLLABLE JAENG")
(51138 . "HANGUL SYLLABLE JAEJ")
(51139 . "HANGUL SYLLABLE JAEC")
(51140 . "HANGUL SYLLABLE JAEK")
(51141 . "HANGUL SYLLABLE JAET")
(51142 . "HANGUL SYLLABLE JAEP")
(51143 . "HANGUL SYLLABLE JAEH")
(51144 . "HANGUL SYLLABLE JYA")
(51145 . "HANGUL SYLLABLE JYAG")
(51146 . "HANGUL SYLLABLE JYAGG")
(51147 . "HANGUL SYLLABLE JYAGS")
(51148 . "HANGUL SYLLABLE JYAN")
(51149 . "HANGUL SYLLABLE JYANJ")
(51150 . "HANGUL SYLLABLE JYANH")
(51151 . "HANGUL SYLLABLE JYAD")
(51152 . "HANGUL SYLLABLE JYAL")
(51153 . "HANGUL SYLLABLE JYALG")
(51154 . "HANGUL SYLLABLE JYALM")
(51155 . "HANGUL SYLLABLE JYALB")
(51156 . "HANGUL SYLLABLE JYALS")
(51157 . "HANGUL SYLLABLE JYALT")
(51158 . "HANGUL SYLLABLE JYALP")
(51159 . "HANGUL SYLLABLE JYALH")
(51160 . "HANGUL SYLLABLE JYAM")
(51161 . "HANGUL SYLLABLE JYAB")
(51162 . "HANGUL SYLLABLE JYABS")
(51163 . "HANGUL SYLLABLE JYAS")
(51164 . "HANGUL SYLLABLE JYASS")
(51165 . "HANGUL SYLLABLE JYANG")
(51166 . "HANGUL SYLLABLE JYAJ")
(51167 . "HANGUL SYLLABLE JYAC")
(51168 . "HANGUL SYLLABLE JYAK")
(51169 . "HANGUL SYLLABLE JYAT")
(51170 . "HANGUL SYLLABLE JYAP")
(51171 . "HANGUL SYLLABLE JYAH")
(51172 . "HANGUL SYLLABLE JYAE")
(51173 . "HANGUL SYLLABLE JYAEG")
(51174 . "HANGUL SYLLABLE JYAEGG")
(51175 . "HANGUL SYLLABLE JYAEGS")
(51176 . "HANGUL SYLLABLE JYAEN")
(51177 . "HANGUL SYLLABLE JYAENJ")
(51178 . "HANGUL SYLLABLE JYAENH")
(51179 . "HANGUL SYLLABLE JYAED")
(51180 . "HANGUL SYLLABLE JYAEL")
(51181 . "HANGUL SYLLABLE JYAELG")
(51182 . "HANGUL SYLLABLE JYAELM")
(51183 . "HANGUL SYLLABLE JYAELB")
(51184 . "HANGUL SYLLABLE JYAELS")
(51185 . "HANGUL SYLLABLE JYAELT")
(51186 . "HANGUL SYLLABLE JYAELP")
(51187 . "HANGUL SYLLABLE JYAELH")
(51188 . "HANGUL SYLLABLE JYAEM")
(51189 . "HANGUL SYLLABLE JYAEB")
(51190 . "HANGUL SYLLABLE JYAEBS")
(51191 . "HANGUL SYLLABLE JYAES")
(51192 . "HANGUL SYLLABLE JYAESS")
(51193 . "HANGUL SYLLABLE JYAENG")
(51194 . "HANGUL SYLLABLE JYAEJ")
(51195 . "HANGUL SYLLABLE JYAEC")
(51196 . "HANGUL SYLLABLE JYAEK")
(51197 . "HANGUL SYLLABLE JYAET")
(51198 . "HANGUL SYLLABLE JYAEP")
(51199 . "HANGUL SYLLABLE JYAEH")
(51200 . "HANGUL SYLLABLE JEO")
(51201 . "HANGUL SYLLABLE JEOG")
(51202 . "HANGUL SYLLABLE JEOGG")
(51203 . "HANGUL SYLLABLE JEOGS")
(51204 . "HANGUL SYLLABLE JEON")
(51205 . "HANGUL SYLLABLE JEONJ")
(51206 . "HANGUL SYLLABLE JEONH")
(51207 . "HANGUL SYLLABLE JEOD")
(51208 . "HANGUL SYLLABLE JEOL")
(51209 . "HANGUL SYLLABLE JEOLG")
(51210 . "HANGUL SYLLABLE JEOLM")
(51211 . "HANGUL SYLLABLE JEOLB")
(51212 . "HANGUL SYLLABLE JEOLS")
(51213 . "HANGUL SYLLABLE JEOLT")
(51214 . "HANGUL SYLLABLE JEOLP")
(51215 . "HANGUL SYLLABLE JEOLH")
(51216 . "HANGUL SYLLABLE JEOM")
(51217 . "HANGUL SYLLABLE JEOB")
(51218 . "HANGUL SYLLABLE JEOBS")
(51219 . "HANGUL SYLLABLE JEOS")
(51220 . "HANGUL SYLLABLE JEOSS")
(51221 . "HANGUL SYLLABLE JEONG")
(51222 . "HANGUL SYLLABLE JEOJ")
(51223 . "HANGUL SYLLABLE JEOC")
(51224 . "HANGUL SYLLABLE JEOK")
(51225 . "HANGUL SYLLABLE JEOT")
(51226 . "HANGUL SYLLABLE JEOP")
(51227 . "HANGUL SYLLABLE JEOH")
(51228 . "HANGUL SYLLABLE JE")
(51229 . "HANGUL SYLLABLE JEG")
(51230 . "HANGUL SYLLABLE JEGG")
(51231 . "HANGUL SYLLABLE JEGS")
(51232 . "HANGUL SYLLABLE JEN")
(51233 . "HANGUL SYLLABLE JENJ")
(51234 . "HANGUL SYLLABLE JENH")
(51235 . "HANGUL SYLLABLE JED")
(51236 . "HANGUL SYLLABLE JEL")
(51237 . "HANGUL SYLLABLE JELG")
(51238 . "HANGUL SYLLABLE JELM")
(51239 . "HANGUL SYLLABLE JELB")
(51240 . "HANGUL SYLLABLE JELS")
(51241 . "HANGUL SYLLABLE JELT")
(51242 . "HANGUL SYLLABLE JELP")
(51243 . "HANGUL SYLLABLE JELH")
(51244 . "HANGUL SYLLABLE JEM")
(51245 . "HANGUL SYLLABLE JEB")
(51246 . "HANGUL SYLLABLE JEBS")
(51247 . "HANGUL SYLLABLE JES")
(51248 . "HANGUL SYLLABLE JESS")
(51249 . "HANGUL SYLLABLE JENG")
(51250 . "HANGUL SYLLABLE JEJ")
(51251 . "HANGUL SYLLABLE JEC")
(51252 . "HANGUL SYLLABLE JEK")
(51253 . "HANGUL SYLLABLE JET")
(51254 . "HANGUL SYLLABLE JEP")
(51255 . "HANGUL SYLLABLE JEH")
(51256 . "HANGUL SYLLABLE JYEO")
(51257 . "HANGUL SYLLABLE JYEOG")
(51258 . "HANGUL SYLLABLE JYEOGG")
(51259 . "HANGUL SYLLABLE JYEOGS")
(51260 . "HANGUL SYLLABLE JYEON")
(51261 . "HANGUL SYLLABLE JYEONJ")
(51262 . "HANGUL SYLLABLE JYEONH")
(51263 . "HANGUL SYLLABLE JYEOD")
(51264 . "HANGUL SYLLABLE JYEOL")
(51265 . "HANGUL SYLLABLE JYEOLG")
(51266 . "HANGUL SYLLABLE JYEOLM")
(51267 . "HANGUL SYLLABLE JYEOLB")
(51268 . "HANGUL SYLLABLE JYEOLS")
(51269 . "HANGUL SYLLABLE JYEOLT")
(51270 . "HANGUL SYLLABLE JYEOLP")
(51271 . "HANGUL SYLLABLE JYEOLH")
(51272 . "HANGUL SYLLABLE JYEOM")
(51273 . "HANGUL SYLLABLE JYEOB")
(51274 . "HANGUL SYLLABLE JYEOBS")
(51275 . "HANGUL SYLLABLE JYEOS")
(51276 . "HANGUL SYLLABLE JYEOSS")
(51277 . "HANGUL SYLLABLE JYEONG")
(51278 . "HANGUL SYLLABLE JYEOJ")
(51279 . "HANGUL SYLLABLE JYEOC")
(51280 . "HANGUL SYLLABLE JYEOK")
(51281 . "HANGUL SYLLABLE JYEOT")
(51282 . "HANGUL SYLLABLE JYEOP")
(51283 . "HANGUL SYLLABLE JYEOH")
(51284 . "HANGUL SYLLABLE JYE")
(51285 . "HANGUL SYLLABLE JYEG")
(51286 . "HANGUL SYLLABLE JYEGG")
(51287 . "HANGUL SYLLABLE JYEGS")
(51288 . "HANGUL SYLLABLE JYEN")
(51289 . "HANGUL SYLLABLE JYENJ")
(51290 . "HANGUL SYLLABLE JYENH")
(51291 . "HANGUL SYLLABLE JYED")
(51292 . "HANGUL SYLLABLE JYEL")
(51293 . "HANGUL SYLLABLE JYELG")
(51294 . "HANGUL SYLLABLE JYELM")
(51295 . "HANGUL SYLLABLE JYELB")
(51296 . "HANGUL SYLLABLE JYELS")
(51297 . "HANGUL SYLLABLE JYELT")
(51298 . "HANGUL SYLLABLE JYELP")
(51299 . "HANGUL SYLLABLE JYELH")
(51300 . "HANGUL SYLLABLE JYEM")
(51301 . "HANGUL SYLLABLE JYEB")
(51302 . "HANGUL SYLLABLE JYEBS")
(51303 . "HANGUL SYLLABLE JYES")
(51304 . "HANGUL SYLLABLE JYESS")
(51305 . "HANGUL SYLLABLE JYENG")
(51306 . "HANGUL SYLLABLE JYEJ")
(51307 . "HANGUL SYLLABLE JYEC")
(51308 . "HANGUL SYLLABLE JYEK")
(51309 . "HANGUL SYLLABLE JYET")
(51310 . "HANGUL SYLLABLE JYEP")
(51311 . "HANGUL SYLLABLE JYEH")
(51312 . "HANGUL SYLLABLE JO")
(51313 . "HANGUL SYLLABLE JOG")
(51314 . "HANGUL SYLLABLE JOGG")
(51315 . "HANGUL SYLLABLE JOGS")
(51316 . "HANGUL SYLLABLE JON")
(51317 . "HANGUL SYLLABLE JONJ")
(51318 . "HANGUL SYLLABLE JONH")
(51319 . "HANGUL SYLLABLE JOD")
(51320 . "HANGUL SYLLABLE JOL")
(51321 . "HANGUL SYLLABLE JOLG")
(51322 . "HANGUL SYLLABLE JOLM")
(51323 . "HANGUL SYLLABLE JOLB")
(51324 . "HANGUL SYLLABLE JOLS")
(51325 . "HANGUL SYLLABLE JOLT")
(51326 . "HANGUL SYLLABLE JOLP")
(51327 . "HANGUL SYLLABLE JOLH")
(51328 . "HANGUL SYLLABLE JOM")
(51329 . "HANGUL SYLLABLE JOB")
(51330 . "HANGUL SYLLABLE JOBS")
(51331 . "HANGUL SYLLABLE JOS")
(51332 . "HANGUL SYLLABLE JOSS")
(51333 . "HANGUL SYLLABLE JONG")
(51334 . "HANGUL SYLLABLE JOJ")
(51335 . "HANGUL SYLLABLE JOC")
(51336 . "HANGUL SYLLABLE JOK")
(51337 . "HANGUL SYLLABLE JOT")
(51338 . "HANGUL SYLLABLE JOP")
(51339 . "HANGUL SYLLABLE JOH")
(51340 . "HANGUL SYLLABLE JWA")
(51341 . "HANGUL SYLLABLE JWAG")
(51342 . "HANGUL SYLLABLE JWAGG")
(51343 . "HANGUL SYLLABLE JWAGS")
(51344 . "HANGUL SYLLABLE JWAN")
(51345 . "HANGUL SYLLABLE JWANJ")
(51346 . "HANGUL SYLLABLE JWANH")
(51347 . "HANGUL SYLLABLE JWAD")
(51348 . "HANGUL SYLLABLE JWAL")
(51349 . "HANGUL SYLLABLE JWALG")
(51350 . "HANGUL SYLLABLE JWALM")
(51351 . "HANGUL SYLLABLE JWALB")
(51352 . "HANGUL SYLLABLE JWALS")
(51353 . "HANGUL SYLLABLE JWALT")
(51354 . "HANGUL SYLLABLE JWALP")
(51355 . "HANGUL SYLLABLE JWALH")
(51356 . "HANGUL SYLLABLE JWAM")
(51357 . "HANGUL SYLLABLE JWAB")
(51358 . "HANGUL SYLLABLE JWABS")
(51359 . "HANGUL SYLLABLE JWAS")
(51360 . "HANGUL SYLLABLE JWASS")
(51361 . "HANGUL SYLLABLE JWANG")
(51362 . "HANGUL SYLLABLE JWAJ")
(51363 . "HANGUL SYLLABLE JWAC")
(51364 . "HANGUL SYLLABLE JWAK")
(51365 . "HANGUL SYLLABLE JWAT")
(51366 . "HANGUL SYLLABLE JWAP")
(51367 . "HANGUL SYLLABLE JWAH")
(51368 . "HANGUL SYLLABLE JWAE")
(51369 . "HANGUL SYLLABLE JWAEG")
(51370 . "HANGUL SYLLABLE JWAEGG")
(51371 . "HANGUL SYLLABLE JWAEGS")
(51372 . "HANGUL SYLLABLE JWAEN")
(51373 . "HANGUL SYLLABLE JWAENJ")
(51374 . "HANGUL SYLLABLE JWAENH")
(51375 . "HANGUL SYLLABLE JWAED")
(51376 . "HANGUL SYLLABLE JWAEL")
(51377 . "HANGUL SYLLABLE JWAELG")
(51378 . "HANGUL SYLLABLE JWAELM")
(51379 . "HANGUL SYLLABLE JWAELB")
(51380 . "HANGUL SYLLABLE JWAELS")
(51381 . "HANGUL SYLLABLE JWAELT")
(51382 . "HANGUL SYLLABLE JWAELP")
(51383 . "HANGUL SYLLABLE JWAELH")
(51384 . "HANGUL SYLLABLE JWAEM")
(51385 . "HANGUL SYLLABLE JWAEB")
(51386 . "HANGUL SYLLABLE JWAEBS")
(51387 . "HANGUL SYLLABLE JWAES")
(51388 . "HANGUL SYLLABLE JWAESS")
(51389 . "HANGUL SYLLABLE JWAENG")
(51390 . "HANGUL SYLLABLE JWAEJ")
(51391 . "HANGUL SYLLABLE JWAEC")
(51392 . "HANGUL SYLLABLE JWAEK")
(51393 . "HANGUL SYLLABLE JWAET")
(51394 . "HANGUL SYLLABLE JWAEP")
(51395 . "HANGUL SYLLABLE JWAEH")
(51396 . "HANGUL SYLLABLE JOE")
(51397 . "HANGUL SYLLABLE JOEG")
(51398 . "HANGUL SYLLABLE JOEGG")
(51399 . "HANGUL SYLLABLE JOEGS")
(51400 . "HANGUL SYLLABLE JOEN")
(51401 . "HANGUL SYLLABLE JOENJ")
(51402 . "HANGUL SYLLABLE JOENH")
(51403 . "HANGUL SYLLABLE JOED")
(51404 . "HANGUL SYLLABLE JOEL")
(51405 . "HANGUL SYLLABLE JOELG")
(51406 . "HANGUL SYLLABLE JOELM")
(51407 . "HANGUL SYLLABLE JOELB")
(51408 . "HANGUL SYLLABLE JOELS")
(51409 . "HANGUL SYLLABLE JOELT")
(51410 . "HANGUL SYLLABLE JOELP")
(51411 . "HANGUL SYLLABLE JOELH")
(51412 . "HANGUL SYLLABLE JOEM")
(51413 . "HANGUL SYLLABLE JOEB")
(51414 . "HANGUL SYLLABLE JOEBS")
(51415 . "HANGUL SYLLABLE JOES")
(51416 . "HANGUL SYLLABLE JOESS")
(51417 . "HANGUL SYLLABLE JOENG")
(51418 . "HANGUL SYLLABLE JOEJ")
(51419 . "HANGUL SYLLABLE JOEC")
(51420 . "HANGUL SYLLABLE JOEK")
(51421 . "HANGUL SYLLABLE JOET")
(51422 . "HANGUL SYLLABLE JOEP")
(51423 . "HANGUL SYLLABLE JOEH")
(51424 . "HANGUL SYLLABLE JYO")
(51425 . "HANGUL SYLLABLE JYOG")
(51426 . "HANGUL SYLLABLE JYOGG")
(51427 . "HANGUL SYLLABLE JYOGS")
(51428 . "HANGUL SYLLABLE JYON")
(51429 . "HANGUL SYLLABLE JYONJ")
(51430 . "HANGUL SYLLABLE JYONH")
(51431 . "HANGUL SYLLABLE JYOD")
(51432 . "HANGUL SYLLABLE JYOL")
(51433 . "HANGUL SYLLABLE JYOLG")
(51434 . "HANGUL SYLLABLE JYOLM")
(51435 . "HANGUL SYLLABLE JYOLB")
(51436 . "HANGUL SYLLABLE JYOLS")
(51437 . "HANGUL SYLLABLE JYOLT")
(51438 . "HANGUL SYLLABLE JYOLP")
(51439 . "HANGUL SYLLABLE JYOLH")
(51440 . "HANGUL SYLLABLE JYOM")
(51441 . "HANGUL SYLLABLE JYOB")
(51442 . "HANGUL SYLLABLE JYOBS")
(51443 . "HANGUL SYLLABLE JYOS")
(51444 . "HANGUL SYLLABLE JYOSS")
(51445 . "HANGUL SYLLABLE JYONG")
(51446 . "HANGUL SYLLABLE JYOJ")
(51447 . "HANGUL SYLLABLE JYOC")
(51448 . "HANGUL SYLLABLE JYOK")
(51449 . "HANGUL SYLLABLE JYOT")
(51450 . "HANGUL SYLLABLE JYOP")
(51451 . "HANGUL SYLLABLE JYOH")
(51452 . "HANGUL SYLLABLE JU")
(51453 . "HANGUL SYLLABLE JUG")
(51454 . "HANGUL SYLLABLE JUGG")
(51455 . "HANGUL SYLLABLE JUGS")
(51456 . "HANGUL SYLLABLE JUN")
(51457 . "HANGUL SYLLABLE JUNJ")
(51458 . "HANGUL SYLLABLE JUNH")
(51459 . "HANGUL SYLLABLE JUD")
(51460 . "HANGUL SYLLABLE JUL")
(51461 . "HANGUL SYLLABLE JULG")
(51462 . "HANGUL SYLLABLE JULM")
(51463 . "HANGUL SYLLABLE JULB")
(51464 . "HANGUL SYLLABLE JULS")
(51465 . "HANGUL SYLLABLE JULT")
(51466 . "HANGUL SYLLABLE JULP")
(51467 . "HANGUL SYLLABLE JULH")
(51468 . "HANGUL SYLLABLE JUM")
(51469 . "HANGUL SYLLABLE JUB")
(51470 . "HANGUL SYLLABLE JUBS")
(51471 . "HANGUL SYLLABLE JUS")
(51472 . "HANGUL SYLLABLE JUSS")
(51473 . "HANGUL SYLLABLE JUNG")
(51474 . "HANGUL SYLLABLE JUJ")
(51475 . "HANGUL SYLLABLE JUC")
(51476 . "HANGUL SYLLABLE JUK")
(51477 . "HANGUL SYLLABLE JUT")
(51478 . "HANGUL SYLLABLE JUP")
(51479 . "HANGUL SYLLABLE JUH")
(51480 . "HANGUL SYLLABLE JWEO")
(51481 . "HANGUL SYLLABLE JWEOG")
(51482 . "HANGUL SYLLABLE JWEOGG")
(51483 . "HANGUL SYLLABLE JWEOGS")
(51484 . "HANGUL SYLLABLE JWEON")
(51485 . "HANGUL SYLLABLE JWEONJ")
(51486 . "HANGUL SYLLABLE JWEONH")
(51487 . "HANGUL SYLLABLE JWEOD")
(51488 . "HANGUL SYLLABLE JWEOL")
(51489 . "HANGUL SYLLABLE JWEOLG")
(51490 . "HANGUL SYLLABLE JWEOLM")
(51491 . "HANGUL SYLLABLE JWEOLB")
(51492 . "HANGUL SYLLABLE JWEOLS")
(51493 . "HANGUL SYLLABLE JWEOLT")
(51494 . "HANGUL SYLLABLE JWEOLP")
(51495 . "HANGUL SYLLABLE JWEOLH")
(51496 . "HANGUL SYLLABLE JWEOM")
(51497 . "HANGUL SYLLABLE JWEOB")
(51498 . "HANGUL SYLLABLE JWEOBS")
(51499 . "HANGUL SYLLABLE JWEOS")
(51500 . "HANGUL SYLLABLE JWEOSS")
(51501 . "HANGUL SYLLABLE JWEONG")
(51502 . "HANGUL SYLLABLE JWEOJ")
(51503 . "HANGUL SYLLABLE JWEOC")
(51504 . "HANGUL SYLLABLE JWEOK")
(51505 . "HANGUL SYLLABLE JWEOT")
(51506 . "HANGUL SYLLABLE JWEOP")
(51507 . "HANGUL SYLLABLE JWEOH")
(51508 . "HANGUL SYLLABLE JWE")
(51509 . "HANGUL SYLLABLE JWEG")
(51510 . "HANGUL SYLLABLE JWEGG")
(51511 . "HANGUL SYLLABLE JWEGS")
(51512 . "HANGUL SYLLABLE JWEN")
(51513 . "HANGUL SYLLABLE JWENJ")
(51514 . "HANGUL SYLLABLE JWENH")
(51515 . "HANGUL SYLLABLE JWED")
(51516 . "HANGUL SYLLABLE JWEL")
(51517 . "HANGUL SYLLABLE JWELG")
(51518 . "HANGUL SYLLABLE JWELM")
(51519 . "HANGUL SYLLABLE JWELB")
(51520 . "HANGUL SYLLABLE JWELS")
(51521 . "HANGUL SYLLABLE JWELT")
(51522 . "HANGUL SYLLABLE JWELP")
(51523 . "HANGUL SYLLABLE JWELH")
(51524 . "HANGUL SYLLABLE JWEM")
(51525 . "HANGUL SYLLABLE JWEB")
(51526 . "HANGUL SYLLABLE JWEBS")
(51527 . "HANGUL SYLLABLE JWES")
(51528 . "HANGUL SYLLABLE JWESS")
(51529 . "HANGUL SYLLABLE JWENG")
(51530 . "HANGUL SYLLABLE JWEJ")
(51531 . "HANGUL SYLLABLE JWEC")
(51532 . "HANGUL SYLLABLE JWEK")
(51533 . "HANGUL SYLLABLE JWET")
(51534 . "HANGUL SYLLABLE JWEP")
(51535 . "HANGUL SYLLABLE JWEH")
(51536 . "HANGUL SYLLABLE JWI")
(51537 . "HANGUL SYLLABLE JWIG")
(51538 . "HANGUL SYLLABLE JWIGG")
(51539 . "HANGUL SYLLABLE JWIGS")
(51540 . "HANGUL SYLLABLE JWIN")
(51541 . "HANGUL SYLLABLE JWINJ")
(51542 . "HANGUL SYLLABLE JWINH")
(51543 . "HANGUL SYLLABLE JWID")
(51544 . "HANGUL SYLLABLE JWIL")
(51545 . "HANGUL SYLLABLE JWILG")
(51546 . "HANGUL SYLLABLE JWILM")
(51547 . "HANGUL SYLLABLE JWILB")
(51548 . "HANGUL SYLLABLE JWILS")
(51549 . "HANGUL SYLLABLE JWILT")
(51550 . "HANGUL SYLLABLE JWILP")
(51551 . "HANGUL SYLLABLE JWILH")
(51552 . "HANGUL SYLLABLE JWIM")
(51553 . "HANGUL SYLLABLE JWIB")
(51554 . "HANGUL SYLLABLE JWIBS")
(51555 . "HANGUL SYLLABLE JWIS")
(51556 . "HANGUL SYLLABLE JWISS")
(51557 . "HANGUL SYLLABLE JWING")
(51558 . "HANGUL SYLLABLE JWIJ")
(51559 . "HANGUL SYLLABLE JWIC")
(51560 . "HANGUL SYLLABLE JWIK")
(51561 . "HANGUL SYLLABLE JWIT")
(51562 . "HANGUL SYLLABLE JWIP")
(51563 . "HANGUL SYLLABLE JWIH")
(51564 . "HANGUL SYLLABLE JYU")
(51565 . "HANGUL SYLLABLE JYUG")
(51566 . "HANGUL SYLLABLE JYUGG")
(51567 . "HANGUL SYLLABLE JYUGS")
(51568 . "HANGUL SYLLABLE JYUN")
(51569 . "HANGUL SYLLABLE JYUNJ")
(51570 . "HANGUL SYLLABLE JYUNH")
(51571 . "HANGUL SYLLABLE JYUD")
(51572 . "HANGUL SYLLABLE JYUL")
(51573 . "HANGUL SYLLABLE JYULG")
(51574 . "HANGUL SYLLABLE JYULM")
(51575 . "HANGUL SYLLABLE JYULB")
(51576 . "HANGUL SYLLABLE JYULS")
(51577 . "HANGUL SYLLABLE JYULT")
(51578 . "HANGUL SYLLABLE JYULP")
(51579 . "HANGUL SYLLABLE JYULH")
(51580 . "HANGUL SYLLABLE JYUM")
(51581 . "HANGUL SYLLABLE JYUB")
(51582 . "HANGUL SYLLABLE JYUBS")
(51583 . "HANGUL SYLLABLE JYUS")
(51584 . "HANGUL SYLLABLE JYUSS")
(51585 . "HANGUL SYLLABLE JYUNG")
(51586 . "HANGUL SYLLABLE JYUJ")
(51587 . "HANGUL SYLLABLE JYUC")
(51588 . "HANGUL SYLLABLE JYUK")
(51589 . "HANGUL SYLLABLE JYUT")
(51590 . "HANGUL SYLLABLE JYUP")
(51591 . "HANGUL SYLLABLE JYUH")
(51592 . "HANGUL SYLLABLE JEU")
(51593 . "HANGUL SYLLABLE JEUG")
(51594 . "HANGUL SYLLABLE JEUGG")
(51595 . "HANGUL SYLLABLE JEUGS")
(51596 . "HANGUL SYLLABLE JEUN")
(51597 . "HANGUL SYLLABLE JEUNJ")
(51598 . "HANGUL SYLLABLE JEUNH")
(51599 . "HANGUL SYLLABLE JEUD")
(51600 . "HANGUL SYLLABLE JEUL")
(51601 . "HANGUL SYLLABLE JEULG")
(51602 . "HANGUL SYLLABLE JEULM")
(51603 . "HANGUL SYLLABLE JEULB")
(51604 . "HANGUL SYLLABLE JEULS")
(51605 . "HANGUL SYLLABLE JEULT")
(51606 . "HANGUL SYLLABLE JEULP")
(51607 . "HANGUL SYLLABLE JEULH")
(51608 . "HANGUL SYLLABLE JEUM")
(51609 . "HANGUL SYLLABLE JEUB")
(51610 . "HANGUL SYLLABLE JEUBS")
(51611 . "HANGUL SYLLABLE JEUS")
(51612 . "HANGUL SYLLABLE JEUSS")
(51613 . "HANGUL SYLLABLE JEUNG")
(51614 . "HANGUL SYLLABLE JEUJ")
(51615 . "HANGUL SYLLABLE JEUC")
(51616 . "HANGUL SYLLABLE JEUK")
(51617 . "HANGUL SYLLABLE JEUT")
(51618 . "HANGUL SYLLABLE JEUP")
(51619 . "HANGUL SYLLABLE JEUH")
(51620 . "HANGUL SYLLABLE JYI")
(51621 . "HANGUL SYLLABLE JYIG")
(51622 . "HANGUL SYLLABLE JYIGG")
(51623 . "HANGUL SYLLABLE JYIGS")
(51624 . "HANGUL SYLLABLE JYIN")
(51625 . "HANGUL SYLLABLE JYINJ")
(51626 . "HANGUL SYLLABLE JYINH")
(51627 . "HANGUL SYLLABLE JYID")
(51628 . "HANGUL SYLLABLE JYIL")
(51629 . "HANGUL SYLLABLE JYILG")
(51630 . "HANGUL SYLLABLE JYILM")
(51631 . "HANGUL SYLLABLE JYILB")
(51632 . "HANGUL SYLLABLE JYILS")
(51633 . "HANGUL SYLLABLE JYILT")
(51634 . "HANGUL SYLLABLE JYILP")
(51635 . "HANGUL SYLLABLE JYILH")
(51636 . "HANGUL SYLLABLE JYIM")
(51637 . "HANGUL SYLLABLE JYIB")
(51638 . "HANGUL SYLLABLE JYIBS")
(51639 . "HANGUL SYLLABLE JYIS")
(51640 . "HANGUL SYLLABLE JYISS")
(51641 . "HANGUL SYLLABLE JYING")
(51642 . "HANGUL SYLLABLE JYIJ")
(51643 . "HANGUL SYLLABLE JYIC")
(51644 . "HANGUL SYLLABLE JYIK")
(51645 . "HANGUL SYLLABLE JYIT")
(51646 . "HANGUL SYLLABLE JYIP")
(51647 . "HANGUL SYLLABLE JYIH")
(51648 . "HANGUL SYLLABLE JI")
(51649 . "HANGUL SYLLABLE JIG")
(51650 . "HANGUL SYLLABLE JIGG")
(51651 . "HANGUL SYLLABLE JIGS")
(51652 . "HANGUL SYLLABLE JIN")
(51653 . "HANGUL SYLLABLE JINJ")
(51654 . "HANGUL SYLLABLE JINH")
(51655 . "HANGUL SYLLABLE JID")
(51656 . "HANGUL SYLLABLE JIL")
(51657 . "HANGUL SYLLABLE JILG")
(51658 . "HANGUL SYLLABLE JILM")
(51659 . "HANGUL SYLLABLE JILB")
(51660 . "HANGUL SYLLABLE JILS")
(51661 . "HANGUL SYLLABLE JILT")
(51662 . "HANGUL SYLLABLE JILP")
(51663 . "HANGUL SYLLABLE JILH")
(51664 . "HANGUL SYLLABLE JIM")
(51665 . "HANGUL SYLLABLE JIB")
(51666 . "HANGUL SYLLABLE JIBS")
(51667 . "HANGUL SYLLABLE JIS")
(51668 . "HANGUL SYLLABLE JISS")
(51669 . "HANGUL SYLLABLE JING")
(51670 . "HANGUL SYLLABLE JIJ")
(51671 . "HANGUL SYLLABLE JIC")
(51672 . "HANGUL SYLLABLE JIK")
(51673 . "HANGUL SYLLABLE JIT")
(51674 . "HANGUL SYLLABLE JIP")
(51675 . "HANGUL SYLLABLE JIH")
(51676 . "HANGUL SYLLABLE JJA")
(51677 . "HANGUL SYLLABLE JJAG")
(51678 . "HANGUL SYLLABLE JJAGG")
(51679 . "HANGUL SYLLABLE JJAGS")
(51680 . "HANGUL SYLLABLE JJAN")
(51681 . "HANGUL SYLLABLE JJANJ")
(51682 . "HANGUL SYLLABLE JJANH")
(51683 . "HANGUL SYLLABLE JJAD")
(51684 . "HANGUL SYLLABLE JJAL")
(51685 . "HANGUL SYLLABLE JJALG")
(51686 . "HANGUL SYLLABLE JJALM")
(51687 . "HANGUL SYLLABLE JJALB")
(51688 . "HANGUL SYLLABLE JJALS")
(51689 . "HANGUL SYLLABLE JJALT")
(51690 . "HANGUL SYLLABLE JJALP")
(51691 . "HANGUL SYLLABLE JJALH")
(51692 . "HANGUL SYLLABLE JJAM")
(51693 . "HANGUL SYLLABLE JJAB")
(51694 . "HANGUL SYLLABLE JJABS")
(51695 . "HANGUL SYLLABLE JJAS")
(51696 . "HANGUL SYLLABLE JJASS")
(51697 . "HANGUL SYLLABLE JJANG")
(51698 . "HANGUL SYLLABLE JJAJ")
(51699 . "HANGUL SYLLABLE JJAC")
(51700 . "HANGUL SYLLABLE JJAK")
(51701 . "HANGUL SYLLABLE JJAT")
(51702 . "HANGUL SYLLABLE JJAP")
(51703 . "HANGUL SYLLABLE JJAH")
(51704 . "HANGUL SYLLABLE JJAE")
(51705 . "HANGUL SYLLABLE JJAEG")
(51706 . "HANGUL SYLLABLE JJAEGG")
(51707 . "HANGUL SYLLABLE JJAEGS")
(51708 . "HANGUL SYLLABLE JJAEN")
(51709 . "HANGUL SYLLABLE JJAENJ")
(51710 . "HANGUL SYLLABLE JJAENH")
(51711 . "HANGUL SYLLABLE JJAED")
(51712 . "HANGUL SYLLABLE JJAEL")
(51713 . "HANGUL SYLLABLE JJAELG")
(51714 . "HANGUL SYLLABLE JJAELM")
(51715 . "HANGUL SYLLABLE JJAELB")
(51716 . "HANGUL SYLLABLE JJAELS")
(51717 . "HANGUL SYLLABLE JJAELT")
(51718 . "HANGUL SYLLABLE JJAELP")
(51719 . "HANGUL SYLLABLE JJAELH")
(51720 . "HANGUL SYLLABLE JJAEM")
(51721 . "HANGUL SYLLABLE JJAEB")
(51722 . "HANGUL SYLLABLE JJAEBS")
(51723 . "HANGUL SYLLABLE JJAES")
(51724 . "HANGUL SYLLABLE JJAESS")
(51725 . "HANGUL SYLLABLE JJAENG")
(51726 . "HANGUL SYLLABLE JJAEJ")
(51727 . "HANGUL SYLLABLE JJAEC")
(51728 . "HANGUL SYLLABLE JJAEK")
(51729 . "HANGUL SYLLABLE JJAET")
(51730 . "HANGUL SYLLABLE JJAEP")
(51731 . "HANGUL SYLLABLE JJAEH")
(51732 . "HANGUL SYLLABLE JJYA")
(51733 . "HANGUL SYLLABLE JJYAG")
(51734 . "HANGUL SYLLABLE JJYAGG")
(51735 . "HANGUL SYLLABLE JJYAGS")
(51736 . "HANGUL SYLLABLE JJYAN")
(51737 . "HANGUL SYLLABLE JJYANJ")
(51738 . "HANGUL SYLLABLE JJYANH")
(51739 . "HANGUL SYLLABLE JJYAD")
(51740 . "HANGUL SYLLABLE JJYAL")
(51741 . "HANGUL SYLLABLE JJYALG")
(51742 . "HANGUL SYLLABLE JJYALM")
(51743 . "HANGUL SYLLABLE JJYALB")
(51744 . "HANGUL SYLLABLE JJYALS")
(51745 . "HANGUL SYLLABLE JJYALT")
(51746 . "HANGUL SYLLABLE JJYALP")
(51747 . "HANGUL SYLLABLE JJYALH")
(51748 . "HANGUL SYLLABLE JJYAM")
(51749 . "HANGUL SYLLABLE JJYAB")
(51750 . "HANGUL SYLLABLE JJYABS")
(51751 . "HANGUL SYLLABLE JJYAS")
(51752 . "HANGUL SYLLABLE JJYASS")
(51753 . "HANGUL SYLLABLE JJYANG")
(51754 . "HANGUL SYLLABLE JJYAJ")
(51755 . "HANGUL SYLLABLE JJYAC")
(51756 . "HANGUL SYLLABLE JJYAK")
(51757 . "HANGUL SYLLABLE JJYAT")
(51758 . "HANGUL SYLLABLE JJYAP")
(51759 . "HANGUL SYLLABLE JJYAH")
(51760 . "HANGUL SYLLABLE JJYAE")
(51761 . "HANGUL SYLLABLE JJYAEG")
(51762 . "HANGUL SYLLABLE JJYAEGG")
(51763 . "HANGUL SYLLABLE JJYAEGS")
(51764 . "HANGUL SYLLABLE JJYAEN")
(51765 . "HANGUL SYLLABLE JJYAENJ")
(51766 . "HANGUL SYLLABLE JJYAENH")
(51767 . "HANGUL SYLLABLE JJYAED")
(51768 . "HANGUL SYLLABLE JJYAEL")
(51769 . "HANGUL SYLLABLE JJYAELG")
(51770 . "HANGUL SYLLABLE JJYAELM")
(51771 . "HANGUL SYLLABLE JJYAELB")
(51772 . "HANGUL SYLLABLE JJYAELS")
(51773 . "HANGUL SYLLABLE JJYAELT")
(51774 . "HANGUL SYLLABLE JJYAELP")
(51775 . "HANGUL SYLLABLE JJYAELH")
(51776 . "HANGUL SYLLABLE JJYAEM")
(51777 . "HANGUL SYLLABLE JJYAEB")
(51778 . "HANGUL SYLLABLE JJYAEBS")
(51779 . "HANGUL SYLLABLE JJYAES")
(51780 . "HANGUL SYLLABLE JJYAESS")
(51781 . "HANGUL SYLLABLE JJYAENG")
(51782 . "HANGUL SYLLABLE JJYAEJ")
(51783 . "HANGUL SYLLABLE JJYAEC")
(51784 . "HANGUL SYLLABLE JJYAEK")
(51785 . "HANGUL SYLLABLE JJYAET")
(51786 . "HANGUL SYLLABLE JJYAEP")
(51787 . "HANGUL SYLLABLE JJYAEH")
(51788 . "HANGUL SYLLABLE JJEO")
(51789 . "HANGUL SYLLABLE JJEOG")
(51790 . "HANGUL SYLLABLE JJEOGG")
(51791 . "HANGUL SYLLABLE JJEOGS")
(51792 . "HANGUL SYLLABLE JJEON")
(51793 . "HANGUL SYLLABLE JJEONJ")
(51794 . "HANGUL SYLLABLE JJEONH")
(51795 . "HANGUL SYLLABLE JJEOD")
(51796 . "HANGUL SYLLABLE JJEOL")
(51797 . "HANGUL SYLLABLE JJEOLG")
(51798 . "HANGUL SYLLABLE JJEOLM")
(51799 . "HANGUL SYLLABLE JJEOLB")
(51800 . "HANGUL SYLLABLE JJEOLS")
(51801 . "HANGUL SYLLABLE JJEOLT")
(51802 . "HANGUL SYLLABLE JJEOLP")
(51803 . "HANGUL SYLLABLE JJEOLH")
(51804 . "HANGUL SYLLABLE JJEOM")
(51805 . "HANGUL SYLLABLE JJEOB")
(51806 . "HANGUL SYLLABLE JJEOBS")
(51807 . "HANGUL SYLLABLE JJEOS")
(51808 . "HANGUL SYLLABLE JJEOSS")
(51809 . "HANGUL SYLLABLE JJEONG")
(51810 . "HANGUL SYLLABLE JJEOJ")
(51811 . "HANGUL SYLLABLE JJEOC")
(51812 . "HANGUL SYLLABLE JJEOK")
(51813 . "HANGUL SYLLABLE JJEOT")
(51814 . "HANGUL SYLLABLE JJEOP")
(51815 . "HANGUL SYLLABLE JJEOH")
(51816 . "HANGUL SYLLABLE JJE")
(51817 . "HANGUL SYLLABLE JJEG")
(51818 . "HANGUL SYLLABLE JJEGG")
(51819 . "HANGUL SYLLABLE JJEGS")
(51820 . "HANGUL SYLLABLE JJEN")
(51821 . "HANGUL SYLLABLE JJENJ")
(51822 . "HANGUL SYLLABLE JJENH")
(51823 . "HANGUL SYLLABLE JJED")
(51824 . "HANGUL SYLLABLE JJEL")
(51825 . "HANGUL SYLLABLE JJELG")
(51826 . "HANGUL SYLLABLE JJELM")
(51827 . "HANGUL SYLLABLE JJELB")
(51828 . "HANGUL SYLLABLE JJELS")
(51829 . "HANGUL SYLLABLE JJELT")
(51830 . "HANGUL SYLLABLE JJELP")
(51831 . "HANGUL SYLLABLE JJELH")
(51832 . "HANGUL SYLLABLE JJEM")
(51833 . "HANGUL SYLLABLE JJEB")
(51834 . "HANGUL SYLLABLE JJEBS")
(51835 . "HANGUL SYLLABLE JJES")
(51836 . "HANGUL SYLLABLE JJESS")
(51837 . "HANGUL SYLLABLE JJENG")
(51838 . "HANGUL SYLLABLE JJEJ")
(51839 . "HANGUL SYLLABLE JJEC")
(51840 . "HANGUL SYLLABLE JJEK")
(51841 . "HANGUL SYLLABLE JJET")
(51842 . "HANGUL SYLLABLE JJEP")
(51843 . "HANGUL SYLLABLE JJEH")
(51844 . "HANGUL SYLLABLE JJYEO")
(51845 . "HANGUL SYLLABLE JJYEOG")
(51846 . "HANGUL SYLLABLE JJYEOGG")
(51847 . "HANGUL SYLLABLE JJYEOGS")
(51848 . "HANGUL SYLLABLE JJYEON")
(51849 . "HANGUL SYLLABLE JJYEONJ")
(51850 . "HANGUL SYLLABLE JJYEONH")
(51851 . "HANGUL SYLLABLE JJYEOD")
(51852 . "HANGUL SYLLABLE JJYEOL")
(51853 . "HANGUL SYLLABLE JJYEOLG")
(51854 . "HANGUL SYLLABLE JJYEOLM")
(51855 . "HANGUL SYLLABLE JJYEOLB")
(51856 . "HANGUL SYLLABLE JJYEOLS")
(51857 . "HANGUL SYLLABLE JJYEOLT")
(51858 . "HANGUL SYLLABLE JJYEOLP")
(51859 . "HANGUL SYLLABLE JJYEOLH")
(51860 . "HANGUL SYLLABLE JJYEOM")
(51861 . "HANGUL SYLLABLE JJYEOB")
(51862 . "HANGUL SYLLABLE JJYEOBS")
(51863 . "HANGUL SYLLABLE JJYEOS")
(51864 . "HANGUL SYLLABLE JJYEOSS")
(51865 . "HANGUL SYLLABLE JJYEONG")
(51866 . "HANGUL SYLLABLE JJYEOJ")
(51867 . "HANGUL SYLLABLE JJYEOC")
(51868 . "HANGUL SYLLABLE JJYEOK")
(51869 . "HANGUL SYLLABLE JJYEOT")
(51870 . "HANGUL SYLLABLE JJYEOP")
(51871 . "HANGUL SYLLABLE JJYEOH")
(51872 . "HANGUL SYLLABLE JJYE")
(51873 . "HANGUL SYLLABLE JJYEG")
(51874 . "HANGUL SYLLABLE JJYEGG")
(51875 . "HANGUL SYLLABLE JJYEGS")
(51876 . "HANGUL SYLLABLE JJYEN")
(51877 . "HANGUL SYLLABLE JJYENJ")
(51878 . "HANGUL SYLLABLE JJYENH")
(51879 . "HANGUL SYLLABLE JJYED")
(51880 . "HANGUL SYLLABLE JJYEL")
(51881 . "HANGUL SYLLABLE JJYELG")
(51882 . "HANGUL SYLLABLE JJYELM")
(51883 . "HANGUL SYLLABLE JJYELB")
(51884 . "HANGUL SYLLABLE JJYELS")
(51885 . "HANGUL SYLLABLE JJYELT")
(51886 . "HANGUL SYLLABLE JJYELP")
(51887 . "HANGUL SYLLABLE JJYELH")
(51888 . "HANGUL SYLLABLE JJYEM")
(51889 . "HANGUL SYLLABLE JJYEB")
(51890 . "HANGUL SYLLABLE JJYEBS")
(51891 . "HANGUL SYLLABLE JJYES")
(51892 . "HANGUL SYLLABLE JJYESS")
(51893 . "HANGUL SYLLABLE JJYENG")
(51894 . "HANGUL SYLLABLE JJYEJ")
(51895 . "HANGUL SYLLABLE JJYEC")
(51896 . "HANGUL SYLLABLE JJYEK")
(51897 . "HANGUL SYLLABLE JJYET")
(51898 . "HANGUL SYLLABLE JJYEP")
(51899 . "HANGUL SYLLABLE JJYEH")
(51900 . "HANGUL SYLLABLE JJO")
(51901 . "HANGUL SYLLABLE JJOG")
(51902 . "HANGUL SYLLABLE JJOGG")
(51903 . "HANGUL SYLLABLE JJOGS")
(51904 . "HANGUL SYLLABLE JJON")
(51905 . "HANGUL SYLLABLE JJONJ")
(51906 . "HANGUL SYLLABLE JJONH")
(51907 . "HANGUL SYLLABLE JJOD")
(51908 . "HANGUL SYLLABLE JJOL")
(51909 . "HANGUL SYLLABLE JJOLG")
(51910 . "HANGUL SYLLABLE JJOLM")
(51911 . "HANGUL SYLLABLE JJOLB")
(51912 . "HANGUL SYLLABLE JJOLS")
(51913 . "HANGUL SYLLABLE JJOLT")
(51914 . "HANGUL SYLLABLE JJOLP")
(51915 . "HANGUL SYLLABLE JJOLH")
(51916 . "HANGUL SYLLABLE JJOM")
(51917 . "HANGUL SYLLABLE JJOB")
(51918 . "HANGUL SYLLABLE JJOBS")
(51919 . "HANGUL SYLLABLE JJOS")
(51920 . "HANGUL SYLLABLE JJOSS")
(51921 . "HANGUL SYLLABLE JJONG")
(51922 . "HANGUL SYLLABLE JJOJ")
(51923 . "HANGUL SYLLABLE JJOC")
(51924 . "HANGUL SYLLABLE JJOK")
(51925 . "HANGUL SYLLABLE JJOT")
(51926 . "HANGUL SYLLABLE JJOP")
(51927 . "HANGUL SYLLABLE JJOH")
(51928 . "HANGUL SYLLABLE JJWA")
(51929 . "HANGUL SYLLABLE JJWAG")
(51930 . "HANGUL SYLLABLE JJWAGG")
(51931 . "HANGUL SYLLABLE JJWAGS")
(51932 . "HANGUL SYLLABLE JJWAN")
(51933 . "HANGUL SYLLABLE JJWANJ")
(51934 . "HANGUL SYLLABLE JJWANH")
(51935 . "HANGUL SYLLABLE JJWAD")
(51936 . "HANGUL SYLLABLE JJWAL")
(51937 . "HANGUL SYLLABLE JJWALG")
(51938 . "HANGUL SYLLABLE JJWALM")
(51939 . "HANGUL SYLLABLE JJWALB")
(51940 . "HANGUL SYLLABLE JJWALS")
(51941 . "HANGUL SYLLABLE JJWALT")
(51942 . "HANGUL SYLLABLE JJWALP")
(51943 . "HANGUL SYLLABLE JJWALH")
(51944 . "HANGUL SYLLABLE JJWAM")
(51945 . "HANGUL SYLLABLE JJWAB")
(51946 . "HANGUL SYLLABLE JJWABS")
(51947 . "HANGUL SYLLABLE JJWAS")
(51948 . "HANGUL SYLLABLE JJWASS")
(51949 . "HANGUL SYLLABLE JJWANG")
(51950 . "HANGUL SYLLABLE JJWAJ")
(51951 . "HANGUL SYLLABLE JJWAC")
(51952 . "HANGUL SYLLABLE JJWAK")
(51953 . "HANGUL SYLLABLE JJWAT")
(51954 . "HANGUL SYLLABLE JJWAP")
(51955 . "HANGUL SYLLABLE JJWAH")
(51956 . "HANGUL SYLLABLE JJWAE")
(51957 . "HANGUL SYLLABLE JJWAEG")
(51958 . "HANGUL SYLLABLE JJWAEGG")
(51959 . "HANGUL SYLLABLE JJWAEGS")
(51960 . "HANGUL SYLLABLE JJWAEN")
(51961 . "HANGUL SYLLABLE JJWAENJ")
(51962 . "HANGUL SYLLABLE JJWAENH")
(51963 . "HANGUL SYLLABLE JJWAED")
(51964 . "HANGUL SYLLABLE JJWAEL")
(51965 . "HANGUL SYLLABLE JJWAELG")
(51966 . "HANGUL SYLLABLE JJWAELM")
(51967 . "HANGUL SYLLABLE JJWAELB")
(51968 . "HANGUL SYLLABLE JJWAELS")
(51969 . "HANGUL SYLLABLE JJWAELT")
(51970 . "HANGUL SYLLABLE JJWAELP")
(51971 . "HANGUL SYLLABLE JJWAELH")
(51972 . "HANGUL SYLLABLE JJWAEM")
(51973 . "HANGUL SYLLABLE JJWAEB")
(51974 . "HANGUL SYLLABLE JJWAEBS")
(51975 . "HANGUL SYLLABLE JJWAES")
(51976 . "HANGUL SYLLABLE JJWAESS")
(51977 . "HANGUL SYLLABLE JJWAENG")
(51978 . "HANGUL SYLLABLE JJWAEJ")
(51979 . "HANGUL SYLLABLE JJWAEC")
(51980 . "HANGUL SYLLABLE JJWAEK")
(51981 . "HANGUL SYLLABLE JJWAET")
(51982 . "HANGUL SYLLABLE JJWAEP")
(51983 . "HANGUL SYLLABLE JJWAEH")
(51984 . "HANGUL SYLLABLE JJOE")
(51985 . "HANGUL SYLLABLE JJOEG")
(51986 . "HANGUL SYLLABLE JJOEGG")
(51987 . "HANGUL SYLLABLE JJOEGS")
(51988 . "HANGUL SYLLABLE JJOEN")
(51989 . "HANGUL SYLLABLE JJOENJ")
(51990 . "HANGUL SYLLABLE JJOENH")
(51991 . "HANGUL SYLLABLE JJOED")
(51992 . "HANGUL SYLLABLE JJOEL")
(51993 . "HANGUL SYLLABLE JJOELG")
(51994 . "HANGUL SYLLABLE JJOELM")
(51995 . "HANGUL SYLLABLE JJOELB")
(51996 . "HANGUL SYLLABLE JJOELS")
(51997 . "HANGUL SYLLABLE JJOELT")
(51998 . "HANGUL SYLLABLE JJOELP")
(51999 . "HANGUL SYLLABLE JJOELH")
(52000 . "HANGUL SYLLABLE JJOEM")
(52001 . "HANGUL SYLLABLE JJOEB")
(52002 . "HANGUL SYLLABLE JJOEBS")
(52003 . "HANGUL SYLLABLE JJOES")
(52004 . "HANGUL SYLLABLE JJOESS")
(52005 . "HANGUL SYLLABLE JJOENG")
(52006 . "HANGUL SYLLABLE JJOEJ")
(52007 . "HANGUL SYLLABLE JJOEC")
(52008 . "HANGUL SYLLABLE JJOEK")
(52009 . "HANGUL SYLLABLE JJOET")
(52010 . "HANGUL SYLLABLE JJOEP")
(52011 . "HANGUL SYLLABLE JJOEH")
(52012 . "HANGUL SYLLABLE JJYO")
(52013 . "HANGUL SYLLABLE JJYOG")
(52014 . "HANGUL SYLLABLE JJYOGG")
(52015 . "HANGUL SYLLABLE JJYOGS")
(52016 . "HANGUL SYLLABLE JJYON")
(52017 . "HANGUL SYLLABLE JJYONJ")
(52018 . "HANGUL SYLLABLE JJYONH")
(52019 . "HANGUL SYLLABLE JJYOD")
(52020 . "HANGUL SYLLABLE JJYOL")
(52021 . "HANGUL SYLLABLE JJYOLG")
(52022 . "HANGUL SYLLABLE JJYOLM")
(52023 . "HANGUL SYLLABLE JJYOLB")
(52024 . "HANGUL SYLLABLE JJYOLS")
(52025 . "HANGUL SYLLABLE JJYOLT")
(52026 . "HANGUL SYLLABLE JJYOLP")
(52027 . "HANGUL SYLLABLE JJYOLH")
(52028 . "HANGUL SYLLABLE JJYOM")
(52029 . "HANGUL SYLLABLE JJYOB")
(52030 . "HANGUL SYLLABLE JJYOBS")
(52031 . "HANGUL SYLLABLE JJYOS")
(52032 . "HANGUL SYLLABLE JJYOSS")
(52033 . "HANGUL SYLLABLE JJYONG")
(52034 . "HANGUL SYLLABLE JJYOJ")
(52035 . "HANGUL SYLLABLE JJYOC")
(52036 . "HANGUL SYLLABLE JJYOK")
(52037 . "HANGUL SYLLABLE JJYOT")
(52038 . "HANGUL SYLLABLE JJYOP")
(52039 . "HANGUL SYLLABLE JJYOH")
(52040 . "HANGUL SYLLABLE JJU")
(52041 . "HANGUL SYLLABLE JJUG")
(52042 . "HANGUL SYLLABLE JJUGG")
(52043 . "HANGUL SYLLABLE JJUGS")
(52044 . "HANGUL SYLLABLE JJUN")
(52045 . "HANGUL SYLLABLE JJUNJ")
(52046 . "HANGUL SYLLABLE JJUNH")
(52047 . "HANGUL SYLLABLE JJUD")
(52048 . "HANGUL SYLLABLE JJUL")
(52049 . "HANGUL SYLLABLE JJULG")
(52050 . "HANGUL SYLLABLE JJULM")
(52051 . "HANGUL SYLLABLE JJULB")
(52052 . "HANGUL SYLLABLE JJULS")
(52053 . "HANGUL SYLLABLE JJULT")
(52054 . "HANGUL SYLLABLE JJULP")
(52055 . "HANGUL SYLLABLE JJULH")
(52056 . "HANGUL SYLLABLE JJUM")
(52057 . "HANGUL SYLLABLE JJUB")
(52058 . "HANGUL SYLLABLE JJUBS")
(52059 . "HANGUL SYLLABLE JJUS")
(52060 . "HANGUL SYLLABLE JJUSS")
(52061 . "HANGUL SYLLABLE JJUNG")
(52062 . "HANGUL SYLLABLE JJUJ")
(52063 . "HANGUL SYLLABLE JJUC")
(52064 . "HANGUL SYLLABLE JJUK")
(52065 . "HANGUL SYLLABLE JJUT")
(52066 . "HANGUL SYLLABLE JJUP")
(52067 . "HANGUL SYLLABLE JJUH")
(52068 . "HANGUL SYLLABLE JJWEO")
(52069 . "HANGUL SYLLABLE JJWEOG")
(52070 . "HANGUL SYLLABLE JJWEOGG")
(52071 . "HANGUL SYLLABLE JJWEOGS")
(52072 . "HANGUL SYLLABLE JJWEON")
(52073 . "HANGUL SYLLABLE JJWEONJ")
(52074 . "HANGUL SYLLABLE JJWEONH")
(52075 . "HANGUL SYLLABLE JJWEOD")
(52076 . "HANGUL SYLLABLE JJWEOL")
(52077 . "HANGUL SYLLABLE JJWEOLG")
(52078 . "HANGUL SYLLABLE JJWEOLM")
(52079 . "HANGUL SYLLABLE JJWEOLB")
(52080 . "HANGUL SYLLABLE JJWEOLS")
(52081 . "HANGUL SYLLABLE JJWEOLT")
(52082 . "HANGUL SYLLABLE JJWEOLP")
(52083 . "HANGUL SYLLABLE JJWEOLH")
(52084 . "HANGUL SYLLABLE JJWEOM")
(52085 . "HANGUL SYLLABLE JJWEOB")
(52086 . "HANGUL SYLLABLE JJWEOBS")
(52087 . "HANGUL SYLLABLE JJWEOS")
(52088 . "HANGUL SYLLABLE JJWEOSS")
(52089 . "HANGUL SYLLABLE JJWEONG")
(52090 . "HANGUL SYLLABLE JJWEOJ")
(52091 . "HANGUL SYLLABLE JJWEOC")
(52092 . "HANGUL SYLLABLE JJWEOK")
(52093 . "HANGUL SYLLABLE JJWEOT")
(52094 . "HANGUL SYLLABLE JJWEOP")
(52095 . "HANGUL SYLLABLE JJWEOH")
(52096 . "HANGUL SYLLABLE JJWE")
(52097 . "HANGUL SYLLABLE JJWEG")
(52098 . "HANGUL SYLLABLE JJWEGG")
(52099 . "HANGUL SYLLABLE JJWEGS")
(52100 . "HANGUL SYLLABLE JJWEN")
(52101 . "HANGUL SYLLABLE JJWENJ")
(52102 . "HANGUL SYLLABLE JJWENH")
(52103 . "HANGUL SYLLABLE JJWED")
(52104 . "HANGUL SYLLABLE JJWEL")
(52105 . "HANGUL SYLLABLE JJWELG")
(52106 . "HANGUL SYLLABLE JJWELM")
(52107 . "HANGUL SYLLABLE JJWELB")
(52108 . "HANGUL SYLLABLE JJWELS")
(52109 . "HANGUL SYLLABLE JJWELT")
(52110 . "HANGUL SYLLABLE JJWELP")
(52111 . "HANGUL SYLLABLE JJWELH")
(52112 . "HANGUL SYLLABLE JJWEM")
(52113 . "HANGUL SYLLABLE JJWEB")
(52114 . "HANGUL SYLLABLE JJWEBS")
(52115 . "HANGUL SYLLABLE JJWES")
(52116 . "HANGUL SYLLABLE JJWESS")
(52117 . "HANGUL SYLLABLE JJWENG")
(52118 . "HANGUL SYLLABLE JJWEJ")
(52119 . "HANGUL SYLLABLE JJWEC")
(52120 . "HANGUL SYLLABLE JJWEK")
(52121 . "HANGUL SYLLABLE JJWET")
(52122 . "HANGUL SYLLABLE JJWEP")
(52123 . "HANGUL SYLLABLE JJWEH")
(52124 . "HANGUL SYLLABLE JJWI")
(52125 . "HANGUL SYLLABLE JJWIG")
(52126 . "HANGUL SYLLABLE JJWIGG")
(52127 . "HANGUL SYLLABLE JJWIGS")
(52128 . "HANGUL SYLLABLE JJWIN")
(52129 . "HANGUL SYLLABLE JJWINJ")
(52130 . "HANGUL SYLLABLE JJWINH")
(52131 . "HANGUL SYLLABLE JJWID")
(52132 . "HANGUL SYLLABLE JJWIL")
(52133 . "HANGUL SYLLABLE JJWILG")
(52134 . "HANGUL SYLLABLE JJWILM")
(52135 . "HANGUL SYLLABLE JJWILB")
(52136 . "HANGUL SYLLABLE JJWILS")
(52137 . "HANGUL SYLLABLE JJWILT")
(52138 . "HANGUL SYLLABLE JJWILP")
(52139 . "HANGUL SYLLABLE JJWILH")
(52140 . "HANGUL SYLLABLE JJWIM")
(52141 . "HANGUL SYLLABLE JJWIB")
(52142 . "HANGUL SYLLABLE JJWIBS")
(52143 . "HANGUL SYLLABLE JJWIS")
(52144 . "HANGUL SYLLABLE JJWISS")
(52145 . "HANGUL SYLLABLE JJWING")
(52146 . "HANGUL SYLLABLE JJWIJ")
(52147 . "HANGUL SYLLABLE JJWIC")
(52148 . "HANGUL SYLLABLE JJWIK")
(52149 . "HANGUL SYLLABLE JJWIT")
(52150 . "HANGUL SYLLABLE JJWIP")
(52151 . "HANGUL SYLLABLE JJWIH")
(52152 . "HANGUL SYLLABLE JJYU")
(52153 . "HANGUL SYLLABLE JJYUG")
(52154 . "HANGUL SYLLABLE JJYUGG")
(52155 . "HANGUL SYLLABLE JJYUGS")
(52156 . "HANGUL SYLLABLE JJYUN")
(52157 . "HANGUL SYLLABLE JJYUNJ")
(52158 . "HANGUL SYLLABLE JJYUNH")
(52159 . "HANGUL SYLLABLE JJYUD")
(52160 . "HANGUL SYLLABLE JJYUL")
(52161 . "HANGUL SYLLABLE JJYULG")
(52162 . "HANGUL SYLLABLE JJYULM")
(52163 . "HANGUL SYLLABLE JJYULB")
(52164 . "HANGUL SYLLABLE JJYULS")
(52165 . "HANGUL SYLLABLE JJYULT")
(52166 . "HANGUL SYLLABLE JJYULP")
(52167 . "HANGUL SYLLABLE JJYULH")
(52168 . "HANGUL SYLLABLE JJYUM")
(52169 . "HANGUL SYLLABLE JJYUB")
(52170 . "HANGUL SYLLABLE JJYUBS")
(52171 . "HANGUL SYLLABLE JJYUS")
(52172 . "HANGUL SYLLABLE JJYUSS")
(52173 . "HANGUL SYLLABLE JJYUNG")
(52174 . "HANGUL SYLLABLE JJYUJ")
(52175 . "HANGUL SYLLABLE JJYUC")
(52176 . "HANGUL SYLLABLE JJYUK")
(52177 . "HANGUL SYLLABLE JJYUT")
(52178 . "HANGUL SYLLABLE JJYUP")
(52179 . "HANGUL SYLLABLE JJYUH")
(52180 . "HANGUL SYLLABLE JJEU")
(52181 . "HANGUL SYLLABLE JJEUG")
(52182 . "HANGUL SYLLABLE JJEUGG")
(52183 . "HANGUL SYLLABLE JJEUGS")
(52184 . "HANGUL SYLLABLE JJEUN")
(52185 . "HANGUL SYLLABLE JJEUNJ")
(52186 . "HANGUL SYLLABLE JJEUNH")
(52187 . "HANGUL SYLLABLE JJEUD")
(52188 . "HANGUL SYLLABLE JJEUL")
(52189 . "HANGUL SYLLABLE JJEULG")
(52190 . "HANGUL SYLLABLE JJEULM")
(52191 . "HANGUL SYLLABLE JJEULB")
(52192 . "HANGUL SYLLABLE JJEULS")
(52193 . "HANGUL SYLLABLE JJEULT")
(52194 . "HANGUL SYLLABLE JJEULP")
(52195 . "HANGUL SYLLABLE JJEULH")
(52196 . "HANGUL SYLLABLE JJEUM")
(52197 . "HANGUL SYLLABLE JJEUB")
(52198 . "HANGUL SYLLABLE JJEUBS")
(52199 . "HANGUL SYLLABLE JJEUS")
(52200 . "HANGUL SYLLABLE JJEUSS")
(52201 . "HANGUL SYLLABLE JJEUNG")
(52202 . "HANGUL SYLLABLE JJEUJ")
(52203 . "HANGUL SYLLABLE JJEUC")
(52204 . "HANGUL SYLLABLE JJEUK")
(52205 . "HANGUL SYLLABLE JJEUT")
(52206 . "HANGUL SYLLABLE JJEUP")
(52207 . "HANGUL SYLLABLE JJEUH")
(52208 . "HANGUL SYLLABLE JJYI")
(52209 . "HANGUL SYLLABLE JJYIG")
(52210 . "HANGUL SYLLABLE JJYIGG")
(52211 . "HANGUL SYLLABLE JJYIGS")
(52212 . "HANGUL SYLLABLE JJYIN")
(52213 . "HANGUL SYLLABLE JJYINJ")
(52214 . "HANGUL SYLLABLE JJYINH")
(52215 . "HANGUL SYLLABLE JJYID")
(52216 . "HANGUL SYLLABLE JJYIL")
(52217 . "HANGUL SYLLABLE JJYILG")
(52218 . "HANGUL SYLLABLE JJYILM")
(52219 . "HANGUL SYLLABLE JJYILB")
(52220 . "HANGUL SYLLABLE JJYILS")
(52221 . "HANGUL SYLLABLE JJYILT")
(52222 . "HANGUL SYLLABLE JJYILP")
(52223 . "HANGUL SYLLABLE JJYILH")
(52224 . "HANGUL SYLLABLE JJYIM")
(52225 . "HANGUL SYLLABLE JJYIB")
(52226 . "HANGUL SYLLABLE JJYIBS")
(52227 . "HANGUL SYLLABLE JJYIS")
(52228 . "HANGUL SYLLABLE JJYISS")
(52229 . "HANGUL SYLLABLE JJYING")
(52230 . "HANGUL SYLLABLE JJYIJ")
(52231 . "HANGUL SYLLABLE JJYIC")
(52232 . "HANGUL SYLLABLE JJYIK")
(52233 . "HANGUL SYLLABLE JJYIT")
(52234 . "HANGUL SYLLABLE JJYIP")
(52235 . "HANGUL SYLLABLE JJYIH")
(52236 . "HANGUL SYLLABLE JJI")
(52237 . "HANGUL SYLLABLE JJIG")
(52238 . "HANGUL SYLLABLE JJIGG")
(52239 . "HANGUL SYLLABLE JJIGS")
(52240 . "HANGUL SYLLABLE JJIN")
(52241 . "HANGUL SYLLABLE JJINJ")
(52242 . "HANGUL SYLLABLE JJINH")
(52243 . "HANGUL SYLLABLE JJID")
(52244 . "HANGUL SYLLABLE JJIL")
(52245 . "HANGUL SYLLABLE JJILG")
(52246 . "HANGUL SYLLABLE JJILM")
(52247 . "HANGUL SYLLABLE JJILB")
(52248 . "HANGUL SYLLABLE JJILS")
(52249 . "HANGUL SYLLABLE JJILT")
(52250 . "HANGUL SYLLABLE JJILP")
(52251 . "HANGUL SYLLABLE JJILH")
(52252 . "HANGUL SYLLABLE JJIM")
(52253 . "HANGUL SYLLABLE JJIB")
(52254 . "HANGUL SYLLABLE JJIBS")
(52255 . "HANGUL SYLLABLE JJIS")
(52256 . "HANGUL SYLLABLE JJISS")
(52257 . "HANGUL SYLLABLE JJING")
(52258 . "HANGUL SYLLABLE JJIJ")
(52259 . "HANGUL SYLLABLE JJIC")
(52260 . "HANGUL SYLLABLE JJIK")
(52261 . "HANGUL SYLLABLE JJIT")
(52262 . "HANGUL SYLLABLE JJIP")
(52263 . "HANGUL SYLLABLE JJIH")
(52264 . "HANGUL SYLLABLE CA")
(52265 . "HANGUL SYLLABLE CAG")
(52266 . "HANGUL SYLLABLE CAGG")
(52267 . "HANGUL SYLLABLE CAGS")
(52268 . "HANGUL SYLLABLE CAN")
(52269 . "HANGUL SYLLABLE CANJ")
(52270 . "HANGUL SYLLABLE CANH")
(52271 . "HANGUL SYLLABLE CAD")
(52272 . "HANGUL SYLLABLE CAL")
(52273 . "HANGUL SYLLABLE CALG")
(52274 . "HANGUL SYLLABLE CALM")
(52275 . "HANGUL SYLLABLE CALB")
(52276 . "HANGUL SYLLABLE CALS")
(52277 . "HANGUL SYLLABLE CALT")
(52278 . "HANGUL SYLLABLE CALP")
(52279 . "HANGUL SYLLABLE CALH")
(52280 . "HANGUL SYLLABLE CAM")
(52281 . "HANGUL SYLLABLE CAB")
(52282 . "HANGUL SYLLABLE CABS")
(52283 . "HANGUL SYLLABLE CAS")
(52284 . "HANGUL SYLLABLE CASS")
(52285 . "HANGUL SYLLABLE CANG")
(52286 . "HANGUL SYLLABLE CAJ")
(52287 . "HANGUL SYLLABLE CAC")
(52288 . "HANGUL SYLLABLE CAK")
(52289 . "HANGUL SYLLABLE CAT")
(52290 . "HANGUL SYLLABLE CAP")
(52291 . "HANGUL SYLLABLE CAH")
(52292 . "HANGUL SYLLABLE CAE")
(52293 . "HANGUL SYLLABLE CAEG")
(52294 . "HANGUL SYLLABLE CAEGG")
(52295 . "HANGUL SYLLABLE CAEGS")
(52296 . "HANGUL SYLLABLE CAEN")
(52297 . "HANGUL SYLLABLE CAENJ")
(52298 . "HANGUL SYLLABLE CAENH")
(52299 . "HANGUL SYLLABLE CAED")
(52300 . "HANGUL SYLLABLE CAEL")
(52301 . "HANGUL SYLLABLE CAELG")
(52302 . "HANGUL SYLLABLE CAELM")
(52303 . "HANGUL SYLLABLE CAELB")
(52304 . "HANGUL SYLLABLE CAELS")
(52305 . "HANGUL SYLLABLE CAELT")
(52306 . "HANGUL SYLLABLE CAELP")
(52307 . "HANGUL SYLLABLE CAELH")
(52308 . "HANGUL SYLLABLE CAEM")
(52309 . "HANGUL SYLLABLE CAEB")
(52310 . "HANGUL SYLLABLE CAEBS")
(52311 . "HANGUL SYLLABLE CAES")
(52312 . "HANGUL SYLLABLE CAESS")
(52313 . "HANGUL SYLLABLE CAENG")
(52314 . "HANGUL SYLLABLE CAEJ")
(52315 . "HANGUL SYLLABLE CAEC")
(52316 . "HANGUL SYLLABLE CAEK")
(52317 . "HANGUL SYLLABLE CAET")
(52318 . "HANGUL SYLLABLE CAEP")
(52319 . "HANGUL SYLLABLE CAEH")
(52320 . "HANGUL SYLLABLE CYA")
(52321 . "HANGUL SYLLABLE CYAG")
(52322 . "HANGUL SYLLABLE CYAGG")
(52323 . "HANGUL SYLLABLE CYAGS")
(52324 . "HANGUL SYLLABLE CYAN")
(52325 . "HANGUL SYLLABLE CYANJ")
(52326 . "HANGUL SYLLABLE CYANH")
(52327 . "HANGUL SYLLABLE CYAD")
(52328 . "HANGUL SYLLABLE CYAL")
(52329 . "HANGUL SYLLABLE CYALG")
(52330 . "HANGUL SYLLABLE CYALM")
(52331 . "HANGUL SYLLABLE CYALB")
(52332 . "HANGUL SYLLABLE CYALS")
(52333 . "HANGUL SYLLABLE CYALT")
(52334 . "HANGUL SYLLABLE CYALP")
(52335 . "HANGUL SYLLABLE CYALH")
(52336 . "HANGUL SYLLABLE CYAM")
(52337 . "HANGUL SYLLABLE CYAB")
(52338 . "HANGUL SYLLABLE CYABS")
(52339 . "HANGUL SYLLABLE CYAS")
(52340 . "HANGUL SYLLABLE CYASS")
(52341 . "HANGUL SYLLABLE CYANG")
(52342 . "HANGUL SYLLABLE CYAJ")
(52343 . "HANGUL SYLLABLE CYAC")
(52344 . "HANGUL SYLLABLE CYAK")
(52345 . "HANGUL SYLLABLE CYAT")
(52346 . "HANGUL SYLLABLE CYAP")
(52347 . "HANGUL SYLLABLE CYAH")
(52348 . "HANGUL SYLLABLE CYAE")
(52349 . "HANGUL SYLLABLE CYAEG")
(52350 . "HANGUL SYLLABLE CYAEGG")
(52351 . "HANGUL SYLLABLE CYAEGS")
(52352 . "HANGUL SYLLABLE CYAEN")
(52353 . "HANGUL SYLLABLE CYAENJ")
(52354 . "HANGUL SYLLABLE CYAENH")
(52355 . "HANGUL SYLLABLE CYAED")
(52356 . "HANGUL SYLLABLE CYAEL")
(52357 . "HANGUL SYLLABLE CYAELG")
(52358 . "HANGUL SYLLABLE CYAELM")
(52359 . "HANGUL SYLLABLE CYAELB")
(52360 . "HANGUL SYLLABLE CYAELS")
(52361 . "HANGUL SYLLABLE CYAELT")
(52362 . "HANGUL SYLLABLE CYAELP")
(52363 . "HANGUL SYLLABLE CYAELH")
(52364 . "HANGUL SYLLABLE CYAEM")
(52365 . "HANGUL SYLLABLE CYAEB")
(52366 . "HANGUL SYLLABLE CYAEBS")
(52367 . "HANGUL SYLLABLE CYAES")
(52368 . "HANGUL SYLLABLE CYAESS")
(52369 . "HANGUL SYLLABLE CYAENG")
(52370 . "HANGUL SYLLABLE CYAEJ")
(52371 . "HANGUL SYLLABLE CYAEC")
(52372 . "HANGUL SYLLABLE CYAEK")
(52373 . "HANGUL SYLLABLE CYAET")
(52374 . "HANGUL SYLLABLE CYAEP")
(52375 . "HANGUL SYLLABLE CYAEH")
(52376 . "HANGUL SYLLABLE CEO")
(52377 . "HANGUL SYLLABLE CEOG")
(52378 . "HANGUL SYLLABLE CEOGG")
(52379 . "HANGUL SYLLABLE CEOGS")
(52380 . "HANGUL SYLLABLE CEON")
(52381 . "HANGUL SYLLABLE CEONJ")
(52382 . "HANGUL SYLLABLE CEONH")
(52383 . "HANGUL SYLLABLE CEOD")
(52384 . "HANGUL SYLLABLE CEOL")
(52385 . "HANGUL SYLLABLE CEOLG")
(52386 . "HANGUL SYLLABLE CEOLM")
(52387 . "HANGUL SYLLABLE CEOLB")
(52388 . "HANGUL SYLLABLE CEOLS")
(52389 . "HANGUL SYLLABLE CEOLT")
(52390 . "HANGUL SYLLABLE CEOLP")
(52391 . "HANGUL SYLLABLE CEOLH")
(52392 . "HANGUL SYLLABLE CEOM")
(52393 . "HANGUL SYLLABLE CEOB")
(52394 . "HANGUL SYLLABLE CEOBS")
(52395 . "HANGUL SYLLABLE CEOS")
(52396 . "HANGUL SYLLABLE CEOSS")
(52397 . "HANGUL SYLLABLE CEONG")
(52398 . "HANGUL SYLLABLE CEOJ")
(52399 . "HANGUL SYLLABLE CEOC")
(52400 . "HANGUL SYLLABLE CEOK")
(52401 . "HANGUL SYLLABLE CEOT")
(52402 . "HANGUL SYLLABLE CEOP")
(52403 . "HANGUL SYLLABLE CEOH")
(52404 . "HANGUL SYLLABLE CE")
(52405 . "HANGUL SYLLABLE CEG")
(52406 . "HANGUL SYLLABLE CEGG")
(52407 . "HANGUL SYLLABLE CEGS")
(52408 . "HANGUL SYLLABLE CEN")
(52409 . "HANGUL SYLLABLE CENJ")
(52410 . "HANGUL SYLLABLE CENH")
(52411 . "HANGUL SYLLABLE CED")
(52412 . "HANGUL SYLLABLE CEL")
(52413 . "HANGUL SYLLABLE CELG")
(52414 . "HANGUL SYLLABLE CELM")
(52415 . "HANGUL SYLLABLE CELB")
(52416 . "HANGUL SYLLABLE CELS")
(52417 . "HANGUL SYLLABLE CELT")
(52418 . "HANGUL SYLLABLE CELP")
(52419 . "HANGUL SYLLABLE CELH")
(52420 . "HANGUL SYLLABLE CEM")
(52421 . "HANGUL SYLLABLE CEB")
(52422 . "HANGUL SYLLABLE CEBS")
(52423 . "HANGUL SYLLABLE CES")
(52424 . "HANGUL SYLLABLE CESS")
(52425 . "HANGUL SYLLABLE CENG")
(52426 . "HANGUL SYLLABLE CEJ")
(52427 . "HANGUL SYLLABLE CEC")
(52428 . "HANGUL SYLLABLE CEK")
(52429 . "HANGUL SYLLABLE CET")
(52430 . "HANGUL SYLLABLE CEP")
(52431 . "HANGUL SYLLABLE CEH")
(52432 . "HANGUL SYLLABLE CYEO")
(52433 . "HANGUL SYLLABLE CYEOG")
(52434 . "HANGUL SYLLABLE CYEOGG")
(52435 . "HANGUL SYLLABLE CYEOGS")
(52436 . "HANGUL SYLLABLE CYEON")
(52437 . "HANGUL SYLLABLE CYEONJ")
(52438 . "HANGUL SYLLABLE CYEONH")
(52439 . "HANGUL SYLLABLE CYEOD")
(52440 . "HANGUL SYLLABLE CYEOL")
(52441 . "HANGUL SYLLABLE CYEOLG")
(52442 . "HANGUL SYLLABLE CYEOLM")
(52443 . "HANGUL SYLLABLE CYEOLB")
(52444 . "HANGUL SYLLABLE CYEOLS")
(52445 . "HANGUL SYLLABLE CYEOLT")
(52446 . "HANGUL SYLLABLE CYEOLP")
(52447 . "HANGUL SYLLABLE CYEOLH")
(52448 . "HANGUL SYLLABLE CYEOM")
(52449 . "HANGUL SYLLABLE CYEOB")
(52450 . "HANGUL SYLLABLE CYEOBS")
(52451 . "HANGUL SYLLABLE CYEOS")
(52452 . "HANGUL SYLLABLE CYEOSS")
(52453 . "HANGUL SYLLABLE CYEONG")
(52454 . "HANGUL SYLLABLE CYEOJ")
(52455 . "HANGUL SYLLABLE CYEOC")
(52456 . "HANGUL SYLLABLE CYEOK")
(52457 . "HANGUL SYLLABLE CYEOT")
(52458 . "HANGUL SYLLABLE CYEOP")
(52459 . "HANGUL SYLLABLE CYEOH")
(52460 . "HANGUL SYLLABLE CYE")
(52461 . "HANGUL SYLLABLE CYEG")
(52462 . "HANGUL SYLLABLE CYEGG")
(52463 . "HANGUL SYLLABLE CYEGS")
(52464 . "HANGUL SYLLABLE CYEN")
(52465 . "HANGUL SYLLABLE CYENJ")
(52466 . "HANGUL SYLLABLE CYENH")
(52467 . "HANGUL SYLLABLE CYED")
(52468 . "HANGUL SYLLABLE CYEL")
(52469 . "HANGUL SYLLABLE CYELG")
(52470 . "HANGUL SYLLABLE CYELM")
(52471 . "HANGUL SYLLABLE CYELB")
(52472 . "HANGUL SYLLABLE CYELS")
(52473 . "HANGUL SYLLABLE CYELT")
(52474 . "HANGUL SYLLABLE CYELP")
(52475 . "HANGUL SYLLABLE CYELH")
(52476 . "HANGUL SYLLABLE CYEM")
(52477 . "HANGUL SYLLABLE CYEB")
(52478 . "HANGUL SYLLABLE CYEBS")
(52479 . "HANGUL SYLLABLE CYES")
(52480 . "HANGUL SYLLABLE CYESS")
(52481 . "HANGUL SYLLABLE CYENG")
(52482 . "HANGUL SYLLABLE CYEJ")
(52483 . "HANGUL SYLLABLE CYEC")
(52484 . "HANGUL SYLLABLE CYEK")
(52485 . "HANGUL SYLLABLE CYET")
(52486 . "HANGUL SYLLABLE CYEP")
(52487 . "HANGUL SYLLABLE CYEH")
(52488 . "HANGUL SYLLABLE CO")
(52489 . "HANGUL SYLLABLE COG")
(52490 . "HANGUL SYLLABLE COGG")
(52491 . "HANGUL SYLLABLE COGS")
(52492 . "HANGUL SYLLABLE CON")
(52493 . "HANGUL SYLLABLE CONJ")
(52494 . "HANGUL SYLLABLE CONH")
(52495 . "HANGUL SYLLABLE COD")
(52496 . "HANGUL SYLLABLE COL")
(52497 . "HANGUL SYLLABLE COLG")
(52498 . "HANGUL SYLLABLE COLM")
(52499 . "HANGUL SYLLABLE COLB")
(52500 . "HANGUL SYLLABLE COLS")
(52501 . "HANGUL SYLLABLE COLT")
(52502 . "HANGUL SYLLABLE COLP")
(52503 . "HANGUL SYLLABLE COLH")
(52504 . "HANGUL SYLLABLE COM")
(52505 . "HANGUL SYLLABLE COB")
(52506 . "HANGUL SYLLABLE COBS")
(52507 . "HANGUL SYLLABLE COS")
(52508 . "HANGUL SYLLABLE COSS")
(52509 . "HANGUL SYLLABLE CONG")
(52510 . "HANGUL SYLLABLE COJ")
(52511 . "HANGUL SYLLABLE COC")
(52512 . "HANGUL SYLLABLE COK")
(52513 . "HANGUL SYLLABLE COT")
(52514 . "HANGUL SYLLABLE COP")
(52515 . "HANGUL SYLLABLE COH")
(52516 . "HANGUL SYLLABLE CWA")
(52517 . "HANGUL SYLLABLE CWAG")
(52518 . "HANGUL SYLLABLE CWAGG")
(52519 . "HANGUL SYLLABLE CWAGS")
(52520 . "HANGUL SYLLABLE CWAN")
(52521 . "HANGUL SYLLABLE CWANJ")
(52522 . "HANGUL SYLLABLE CWANH")
(52523 . "HANGUL SYLLABLE CWAD")
(52524 . "HANGUL SYLLABLE CWAL")
(52525 . "HANGUL SYLLABLE CWALG")
(52526 . "HANGUL SYLLABLE CWALM")
(52527 . "HANGUL SYLLABLE CWALB")
(52528 . "HANGUL SYLLABLE CWALS")
(52529 . "HANGUL SYLLABLE CWALT")
(52530 . "HANGUL SYLLABLE CWALP")
(52531 . "HANGUL SYLLABLE CWALH")
(52532 . "HANGUL SYLLABLE CWAM")
(52533 . "HANGUL SYLLABLE CWAB")
(52534 . "HANGUL SYLLABLE CWABS")
(52535 . "HANGUL SYLLABLE CWAS")
(52536 . "HANGUL SYLLABLE CWASS")
(52537 . "HANGUL SYLLABLE CWANG")
(52538 . "HANGUL SYLLABLE CWAJ")
(52539 . "HANGUL SYLLABLE CWAC")
(52540 . "HANGUL SYLLABLE CWAK")
(52541 . "HANGUL SYLLABLE CWAT")
(52542 . "HANGUL SYLLABLE CWAP")
(52543 . "HANGUL SYLLABLE CWAH")
(52544 . "HANGUL SYLLABLE CWAE")
(52545 . "HANGUL SYLLABLE CWAEG")
(52546 . "HANGUL SYLLABLE CWAEGG")
(52547 . "HANGUL SYLLABLE CWAEGS")
(52548 . "HANGUL SYLLABLE CWAEN")
(52549 . "HANGUL SYLLABLE CWAENJ")
(52550 . "HANGUL SYLLABLE CWAENH")
(52551 . "HANGUL SYLLABLE CWAED")
(52552 . "HANGUL SYLLABLE CWAEL")
(52553 . "HANGUL SYLLABLE CWAELG")
(52554 . "HANGUL SYLLABLE CWAELM")
(52555 . "HANGUL SYLLABLE CWAELB")
(52556 . "HANGUL SYLLABLE CWAELS")
(52557 . "HANGUL SYLLABLE CWAELT")
(52558 . "HANGUL SYLLABLE CWAELP")
(52559 . "HANGUL SYLLABLE CWAELH")
(52560 . "HANGUL SYLLABLE CWAEM")
(52561 . "HANGUL SYLLABLE CWAEB")
(52562 . "HANGUL SYLLABLE CWAEBS")
(52563 . "HANGUL SYLLABLE CWAES")
(52564 . "HANGUL SYLLABLE CWAESS")
(52565 . "HANGUL SYLLABLE CWAENG")
(52566 . "HANGUL SYLLABLE CWAEJ")
(52567 . "HANGUL SYLLABLE CWAEC")
(52568 . "HANGUL SYLLABLE CWAEK")
(52569 . "HANGUL SYLLABLE CWAET")
(52570 . "HANGUL SYLLABLE CWAEP")
(52571 . "HANGUL SYLLABLE CWAEH")
(52572 . "HANGUL SYLLABLE COE")
(52573 . "HANGUL SYLLABLE COEG")
(52574 . "HANGUL SYLLABLE COEGG")
(52575 . "HANGUL SYLLABLE COEGS")
(52576 . "HANGUL SYLLABLE COEN")
(52577 . "HANGUL SYLLABLE COENJ")
(52578 . "HANGUL SYLLABLE COENH")
(52579 . "HANGUL SYLLABLE COED")
(52580 . "HANGUL SYLLABLE COEL")
(52581 . "HANGUL SYLLABLE COELG")
(52582 . "HANGUL SYLLABLE COELM")
(52583 . "HANGUL SYLLABLE COELB")
(52584 . "HANGUL SYLLABLE COELS")
(52585 . "HANGUL SYLLABLE COELT")
(52586 . "HANGUL SYLLABLE COELP")
(52587 . "HANGUL SYLLABLE COELH")
(52588 . "HANGUL SYLLABLE COEM")
(52589 . "HANGUL SYLLABLE COEB")
(52590 . "HANGUL SYLLABLE COEBS")
(52591 . "HANGUL SYLLABLE COES")
(52592 . "HANGUL SYLLABLE COESS")
(52593 . "HANGUL SYLLABLE COENG")
(52594 . "HANGUL SYLLABLE COEJ")
(52595 . "HANGUL SYLLABLE COEC")
(52596 . "HANGUL SYLLABLE COEK")
(52597 . "HANGUL SYLLABLE COET")
(52598 . "HANGUL SYLLABLE COEP")
(52599 . "HANGUL SYLLABLE COEH")
(52600 . "HANGUL SYLLABLE CYO")
(52601 . "HANGUL SYLLABLE CYOG")
(52602 . "HANGUL SYLLABLE CYOGG")
(52603 . "HANGUL SYLLABLE CYOGS")
(52604 . "HANGUL SYLLABLE CYON")
(52605 . "HANGUL SYLLABLE CYONJ")
(52606 . "HANGUL SYLLABLE CYONH")
(52607 . "HANGUL SYLLABLE CYOD")
(52608 . "HANGUL SYLLABLE CYOL")
(52609 . "HANGUL SYLLABLE CYOLG")
(52610 . "HANGUL SYLLABLE CYOLM")
(52611 . "HANGUL SYLLABLE CYOLB")
(52612 . "HANGUL SYLLABLE CYOLS")
(52613 . "HANGUL SYLLABLE CYOLT")
(52614 . "HANGUL SYLLABLE CYOLP")
(52615 . "HANGUL SYLLABLE CYOLH")
(52616 . "HANGUL SYLLABLE CYOM")
(52617 . "HANGUL SYLLABLE CYOB")
(52618 . "HANGUL SYLLABLE CYOBS")
(52619 . "HANGUL SYLLABLE CYOS")
(52620 . "HANGUL SYLLABLE CYOSS")
(52621 . "HANGUL SYLLABLE CYONG")
(52622 . "HANGUL SYLLABLE CYOJ")
(52623 . "HANGUL SYLLABLE CYOC")
(52624 . "HANGUL SYLLABLE CYOK")
(52625 . "HANGUL SYLLABLE CYOT")
(52626 . "HANGUL SYLLABLE CYOP")
(52627 . "HANGUL SYLLABLE CYOH")
(52628 . "HANGUL SYLLABLE CU")
(52629 . "HANGUL SYLLABLE CUG")
(52630 . "HANGUL SYLLABLE CUGG")
(52631 . "HANGUL SYLLABLE CUGS")
(52632 . "HANGUL SYLLABLE CUN")
(52633 . "HANGUL SYLLABLE CUNJ")
(52634 . "HANGUL SYLLABLE CUNH")
(52635 . "HANGUL SYLLABLE CUD")
(52636 . "HANGUL SYLLABLE CUL")
(52637 . "HANGUL SYLLABLE CULG")
(52638 . "HANGUL SYLLABLE CULM")
(52639 . "HANGUL SYLLABLE CULB")
(52640 . "HANGUL SYLLABLE CULS")
(52641 . "HANGUL SYLLABLE CULT")
(52642 . "HANGUL SYLLABLE CULP")
(52643 . "HANGUL SYLLABLE CULH")
(52644 . "HANGUL SYLLABLE CUM")
(52645 . "HANGUL SYLLABLE CUB")
(52646 . "HANGUL SYLLABLE CUBS")
(52647 . "HANGUL SYLLABLE CUS")
(52648 . "HANGUL SYLLABLE CUSS")
(52649 . "HANGUL SYLLABLE CUNG")
(52650 . "HANGUL SYLLABLE CUJ")
(52651 . "HANGUL SYLLABLE CUC")
(52652 . "HANGUL SYLLABLE CUK")
(52653 . "HANGUL SYLLABLE CUT")
(52654 . "HANGUL SYLLABLE CUP")
(52655 . "HANGUL SYLLABLE CUH")
(52656 . "HANGUL SYLLABLE CWEO")
(52657 . "HANGUL SYLLABLE CWEOG")
(52658 . "HANGUL SYLLABLE CWEOGG")
(52659 . "HANGUL SYLLABLE CWEOGS")
(52660 . "HANGUL SYLLABLE CWEON")
(52661 . "HANGUL SYLLABLE CWEONJ")
(52662 . "HANGUL SYLLABLE CWEONH")
(52663 . "HANGUL SYLLABLE CWEOD")
(52664 . "HANGUL SYLLABLE CWEOL")
(52665 . "HANGUL SYLLABLE CWEOLG")
(52666 . "HANGUL SYLLABLE CWEOLM")
(52667 . "HANGUL SYLLABLE CWEOLB")
(52668 . "HANGUL SYLLABLE CWEOLS")
(52669 . "HANGUL SYLLABLE CWEOLT")
(52670 . "HANGUL SYLLABLE CWEOLP")
(52671 . "HANGUL SYLLABLE CWEOLH")
(52672 . "HANGUL SYLLABLE CWEOM")
(52673 . "HANGUL SYLLABLE CWEOB")
(52674 . "HANGUL SYLLABLE CWEOBS")
(52675 . "HANGUL SYLLABLE CWEOS")
(52676 . "HANGUL SYLLABLE CWEOSS")
(52677 . "HANGUL SYLLABLE CWEONG")
(52678 . "HANGUL SYLLABLE CWEOJ")
(52679 . "HANGUL SYLLABLE CWEOC")
(52680 . "HANGUL SYLLABLE CWEOK")
(52681 . "HANGUL SYLLABLE CWEOT")
(52682 . "HANGUL SYLLABLE CWEOP")
(52683 . "HANGUL SYLLABLE CWEOH")
(52684 . "HANGUL SYLLABLE CWE")
(52685 . "HANGUL SYLLABLE CWEG")
(52686 . "HANGUL SYLLABLE CWEGG")
(52687 . "HANGUL SYLLABLE CWEGS")
(52688 . "HANGUL SYLLABLE CWEN")
(52689 . "HANGUL SYLLABLE CWENJ")
(52690 . "HANGUL SYLLABLE CWENH")
(52691 . "HANGUL SYLLABLE CWED")
(52692 . "HANGUL SYLLABLE CWEL")
(52693 . "HANGUL SYLLABLE CWELG")
(52694 . "HANGUL SYLLABLE CWELM")
(52695 . "HANGUL SYLLABLE CWELB")
(52696 . "HANGUL SYLLABLE CWELS")
(52697 . "HANGUL SYLLABLE CWELT")
(52698 . "HANGUL SYLLABLE CWELP")
(52699 . "HANGUL SYLLABLE CWELH")
(52700 . "HANGUL SYLLABLE CWEM")
(52701 . "HANGUL SYLLABLE CWEB")
(52702 . "HANGUL SYLLABLE CWEBS")
(52703 . "HANGUL SYLLABLE CWES")
(52704 . "HANGUL SYLLABLE CWESS")
(52705 . "HANGUL SYLLABLE CWENG")
(52706 . "HANGUL SYLLABLE CWEJ")
(52707 . "HANGUL SYLLABLE CWEC")
(52708 . "HANGUL SYLLABLE CWEK")
(52709 . "HANGUL SYLLABLE CWET")
(52710 . "HANGUL SYLLABLE CWEP")
(52711 . "HANGUL SYLLABLE CWEH")
(52712 . "HANGUL SYLLABLE CWI")
(52713 . "HANGUL SYLLABLE CWIG")
(52714 . "HANGUL SYLLABLE CWIGG")
(52715 . "HANGUL SYLLABLE CWIGS")
(52716 . "HANGUL SYLLABLE CWIN")
(52717 . "HANGUL SYLLABLE CWINJ")
(52718 . "HANGUL SYLLABLE CWINH")
(52719 . "HANGUL SYLLABLE CWID")
(52720 . "HANGUL SYLLABLE CWIL")
(52721 . "HANGUL SYLLABLE CWILG")
(52722 . "HANGUL SYLLABLE CWILM")
(52723 . "HANGUL SYLLABLE CWILB")
(52724 . "HANGUL SYLLABLE CWILS")
(52725 . "HANGUL SYLLABLE CWILT")
(52726 . "HANGUL SYLLABLE CWILP")
(52727 . "HANGUL SYLLABLE CWILH")
(52728 . "HANGUL SYLLABLE CWIM")
(52729 . "HANGUL SYLLABLE CWIB")
(52730 . "HANGUL SYLLABLE CWIBS")
(52731 . "HANGUL SYLLABLE CWIS")
(52732 . "HANGUL SYLLABLE CWISS")
(52733 . "HANGUL SYLLABLE CWING")
(52734 . "HANGUL SYLLABLE CWIJ")
(52735 . "HANGUL SYLLABLE CWIC")
(52736 . "HANGUL SYLLABLE CWIK")
(52737 . "HANGUL SYLLABLE CWIT")
(52738 . "HANGUL SYLLABLE CWIP")
(52739 . "HANGUL SYLLABLE CWIH")
(52740 . "HANGUL SYLLABLE CYU")
(52741 . "HANGUL SYLLABLE CYUG")
(52742 . "HANGUL SYLLABLE CYUGG")
(52743 . "HANGUL SYLLABLE CYUGS")
(52744 . "HANGUL SYLLABLE CYUN")
(52745 . "HANGUL SYLLABLE CYUNJ")
(52746 . "HANGUL SYLLABLE CYUNH")
(52747 . "HANGUL SYLLABLE CYUD")
(52748 . "HANGUL SYLLABLE CYUL")
(52749 . "HANGUL SYLLABLE CYULG")
(52750 . "HANGUL SYLLABLE CYULM")
(52751 . "HANGUL SYLLABLE CYULB")
(52752 . "HANGUL SYLLABLE CYULS")
(52753 . "HANGUL SYLLABLE CYULT")
(52754 . "HANGUL SYLLABLE CYULP")
(52755 . "HANGUL SYLLABLE CYULH")
(52756 . "HANGUL SYLLABLE CYUM")
(52757 . "HANGUL SYLLABLE CYUB")
(52758 . "HANGUL SYLLABLE CYUBS")
(52759 . "HANGUL SYLLABLE CYUS")
(52760 . "HANGUL SYLLABLE CYUSS")
(52761 . "HANGUL SYLLABLE CYUNG")
(52762 . "HANGUL SYLLABLE CYUJ")
(52763 . "HANGUL SYLLABLE CYUC")
(52764 . "HANGUL SYLLABLE CYUK")
(52765 . "HANGUL SYLLABLE CYUT")
(52766 . "HANGUL SYLLABLE CYUP")
(52767 . "HANGUL SYLLABLE CYUH")
(52768 . "HANGUL SYLLABLE CEU")
(52769 . "HANGUL SYLLABLE CEUG")
(52770 . "HANGUL SYLLABLE CEUGG")
(52771 . "HANGUL SYLLABLE CEUGS")
(52772 . "HANGUL SYLLABLE CEUN")
(52773 . "HANGUL SYLLABLE CEUNJ")
(52774 . "HANGUL SYLLABLE CEUNH")
(52775 . "HANGUL SYLLABLE CEUD")
(52776 . "HANGUL SYLLABLE CEUL")
(52777 . "HANGUL SYLLABLE CEULG")
(52778 . "HANGUL SYLLABLE CEULM")
(52779 . "HANGUL SYLLABLE CEULB")
(52780 . "HANGUL SYLLABLE CEULS")
(52781 . "HANGUL SYLLABLE CEULT")
(52782 . "HANGUL SYLLABLE CEULP")
(52783 . "HANGUL SYLLABLE CEULH")
(52784 . "HANGUL SYLLABLE CEUM")
(52785 . "HANGUL SYLLABLE CEUB")
(52786 . "HANGUL SYLLABLE CEUBS")
(52787 . "HANGUL SYLLABLE CEUS")
(52788 . "HANGUL SYLLABLE CEUSS")
(52789 . "HANGUL SYLLABLE CEUNG")
(52790 . "HANGUL SYLLABLE CEUJ")
(52791 . "HANGUL SYLLABLE CEUC")
(52792 . "HANGUL SYLLABLE CEUK")
(52793 . "HANGUL SYLLABLE CEUT")
(52794 . "HANGUL SYLLABLE CEUP")
(52795 . "HANGUL SYLLABLE CEUH")
(52796 . "HANGUL SYLLABLE CYI")
(52797 . "HANGUL SYLLABLE CYIG")
(52798 . "HANGUL SYLLABLE CYIGG")
(52799 . "HANGUL SYLLABLE CYIGS")
(52800 . "HANGUL SYLLABLE CYIN")
(52801 . "HANGUL SYLLABLE CYINJ")
(52802 . "HANGUL SYLLABLE CYINH")
(52803 . "HANGUL SYLLABLE CYID")
(52804 . "HANGUL SYLLABLE CYIL")
(52805 . "HANGUL SYLLABLE CYILG")
(52806 . "HANGUL SYLLABLE CYILM")
(52807 . "HANGUL SYLLABLE CYILB")
(52808 . "HANGUL SYLLABLE CYILS")
(52809 . "HANGUL SYLLABLE CYILT")
(52810 . "HANGUL SYLLABLE CYILP")
(52811 . "HANGUL SYLLABLE CYILH")
(52812 . "HANGUL SYLLABLE CYIM")
(52813 . "HANGUL SYLLABLE CYIB")
(52814 . "HANGUL SYLLABLE CYIBS")
(52815 . "HANGUL SYLLABLE CYIS")
(52816 . "HANGUL SYLLABLE CYISS")
(52817 . "HANGUL SYLLABLE CYING")
(52818 . "HANGUL SYLLABLE CYIJ")
(52819 . "HANGUL SYLLABLE CYIC")
(52820 . "HANGUL SYLLABLE CYIK")
(52821 . "HANGUL SYLLABLE CYIT")
(52822 . "HANGUL SYLLABLE CYIP")
(52823 . "HANGUL SYLLABLE CYIH")
(52824 . "HANGUL SYLLABLE CI")
(52825 . "HANGUL SYLLABLE CIG")
(52826 . "HANGUL SYLLABLE CIGG")
(52827 . "HANGUL SYLLABLE CIGS")
(52828 . "HANGUL SYLLABLE CIN")
(52829 . "HANGUL SYLLABLE CINJ")
(52830 . "HANGUL SYLLABLE CINH")
(52831 . "HANGUL SYLLABLE CID")
(52832 . "HANGUL SYLLABLE CIL")
(52833 . "HANGUL SYLLABLE CILG")
(52834 . "HANGUL SYLLABLE CILM")
(52835 . "HANGUL SYLLABLE CILB")
(52836 . "HANGUL SYLLABLE CILS")
(52837 . "HANGUL SYLLABLE CILT")
(52838 . "HANGUL SYLLABLE CILP")
(52839 . "HANGUL SYLLABLE CILH")
(52840 . "HANGUL SYLLABLE CIM")
(52841 . "HANGUL SYLLABLE CIB")
(52842 . "HANGUL SYLLABLE CIBS")
(52843 . "HANGUL SYLLABLE CIS")
(52844 . "HANGUL SYLLABLE CISS")
(52845 . "HANGUL SYLLABLE CING")
(52846 . "HANGUL SYLLABLE CIJ")
(52847 . "HANGUL SYLLABLE CIC")
(52848 . "HANGUL SYLLABLE CIK")
(52849 . "HANGUL SYLLABLE CIT")
(52850 . "HANGUL SYLLABLE CIP")
(52851 . "HANGUL SYLLABLE CIH")
(52852 . "HANGUL SYLLABLE KA")
(52853 . "HANGUL SYLLABLE KAG")
(52854 . "HANGUL SYLLABLE KAGG")
(52855 . "HANGUL SYLLABLE KAGS")
(52856 . "HANGUL SYLLABLE KAN")
(52857 . "HANGUL SYLLABLE KANJ")
(52858 . "HANGUL SYLLABLE KANH")
(52859 . "HANGUL SYLLABLE KAD")
(52860 . "HANGUL SYLLABLE KAL")
(52861 . "HANGUL SYLLABLE KALG")
(52862 . "HANGUL SYLLABLE KALM")
(52863 . "HANGUL SYLLABLE KALB")
(52864 . "HANGUL SYLLABLE KALS")
(52865 . "HANGUL SYLLABLE KALT")
(52866 . "HANGUL SYLLABLE KALP")
(52867 . "HANGUL SYLLABLE KALH")
(52868 . "HANGUL SYLLABLE KAM")
(52869 . "HANGUL SYLLABLE KAB")
(52870 . "HANGUL SYLLABLE KABS")
(52871 . "HANGUL SYLLABLE KAS")
(52872 . "HANGUL SYLLABLE KASS")
(52873 . "HANGUL SYLLABLE KANG")
(52874 . "HANGUL SYLLABLE KAJ")
(52875 . "HANGUL SYLLABLE KAC")
(52876 . "HANGUL SYLLABLE KAK")
(52877 . "HANGUL SYLLABLE KAT")
(52878 . "HANGUL SYLLABLE KAP")
(52879 . "HANGUL SYLLABLE KAH")
(52880 . "HANGUL SYLLABLE KAE")
(52881 . "HANGUL SYLLABLE KAEG")
(52882 . "HANGUL SYLLABLE KAEGG")
(52883 . "HANGUL SYLLABLE KAEGS")
(52884 . "HANGUL SYLLABLE KAEN")
(52885 . "HANGUL SYLLABLE KAENJ")
(52886 . "HANGUL SYLLABLE KAENH")
(52887 . "HANGUL SYLLABLE KAED")
(52888 . "HANGUL SYLLABLE KAEL")
(52889 . "HANGUL SYLLABLE KAELG")
(52890 . "HANGUL SYLLABLE KAELM")
(52891 . "HANGUL SYLLABLE KAELB")
(52892 . "HANGUL SYLLABLE KAELS")
(52893 . "HANGUL SYLLABLE KAELT")
(52894 . "HANGUL SYLLABLE KAELP")
(52895 . "HANGUL SYLLABLE KAELH")
(52896 . "HANGUL SYLLABLE KAEM")
(52897 . "HANGUL SYLLABLE KAEB")
(52898 . "HANGUL SYLLABLE KAEBS")
(52899 . "HANGUL SYLLABLE KAES")
(52900 . "HANGUL SYLLABLE KAESS")
(52901 . "HANGUL SYLLABLE KAENG")
(52902 . "HANGUL SYLLABLE KAEJ")
(52903 . "HANGUL SYLLABLE KAEC")
(52904 . "HANGUL SYLLABLE KAEK")
(52905 . "HANGUL SYLLABLE KAET")
(52906 . "HANGUL SYLLABLE KAEP")
(52907 . "HANGUL SYLLABLE KAEH")
(52908 . "HANGUL SYLLABLE KYA")
(52909 . "HANGUL SYLLABLE KYAG")
(52910 . "HANGUL SYLLABLE KYAGG")
(52911 . "HANGUL SYLLABLE KYAGS")
(52912 . "HANGUL SYLLABLE KYAN")
(52913 . "HANGUL SYLLABLE KYANJ")
(52914 . "HANGUL SYLLABLE KYANH")
(52915 . "HANGUL SYLLABLE KYAD")
(52916 . "HANGUL SYLLABLE KYAL")
(52917 . "HANGUL SYLLABLE KYALG")
(52918 . "HANGUL SYLLABLE KYALM")
(52919 . "HANGUL SYLLABLE KYALB")
(52920 . "HANGUL SYLLABLE KYALS")
(52921 . "HANGUL SYLLABLE KYALT")
(52922 . "HANGUL SYLLABLE KYALP")
(52923 . "HANGUL SYLLABLE KYALH")
(52924 . "HANGUL SYLLABLE KYAM")
(52925 . "HANGUL SYLLABLE KYAB")
(52926 . "HANGUL SYLLABLE KYABS")
(52927 . "HANGUL SYLLABLE KYAS")
(52928 . "HANGUL SYLLABLE KYASS")
(52929 . "HANGUL SYLLABLE KYANG")
(52930 . "HANGUL SYLLABLE KYAJ")
(52931 . "HANGUL SYLLABLE KYAC")
(52932 . "HANGUL SYLLABLE KYAK")
(52933 . "HANGUL SYLLABLE KYAT")
(52934 . "HANGUL SYLLABLE KYAP")
(52935 . "HANGUL SYLLABLE KYAH")
(52936 . "HANGUL SYLLABLE KYAE")
(52937 . "HANGUL SYLLABLE KYAEG")
(52938 . "HANGUL SYLLABLE KYAEGG")
(52939 . "HANGUL SYLLABLE KYAEGS")
(52940 . "HANGUL SYLLABLE KYAEN")
(52941 . "HANGUL SYLLABLE KYAENJ")
(52942 . "HANGUL SYLLABLE KYAENH")
(52943 . "HANGUL SYLLABLE KYAED")
(52944 . "HANGUL SYLLABLE KYAEL")
(52945 . "HANGUL SYLLABLE KYAELG")
(52946 . "HANGUL SYLLABLE KYAELM")
(52947 . "HANGUL SYLLABLE KYAELB")
(52948 . "HANGUL SYLLABLE KYAELS")
(52949 . "HANGUL SYLLABLE KYAELT")
(52950 . "HANGUL SYLLABLE KYAELP")
(52951 . "HANGUL SYLLABLE KYAELH")
(52952 . "HANGUL SYLLABLE KYAEM")
(52953 . "HANGUL SYLLABLE KYAEB")
(52954 . "HANGUL SYLLABLE KYAEBS")
(52955 . "HANGUL SYLLABLE KYAES")
(52956 . "HANGUL SYLLABLE KYAESS")
(52957 . "HANGUL SYLLABLE KYAENG")
(52958 . "HANGUL SYLLABLE KYAEJ")
(52959 . "HANGUL SYLLABLE KYAEC")
(52960 . "HANGUL SYLLABLE KYAEK")
(52961 . "HANGUL SYLLABLE KYAET")
(52962 . "HANGUL SYLLABLE KYAEP")
(52963 . "HANGUL SYLLABLE KYAEH")
(52964 . "HANGUL SYLLABLE KEO")
(52965 . "HANGUL SYLLABLE KEOG")
(52966 . "HANGUL SYLLABLE KEOGG")
(52967 . "HANGUL SYLLABLE KEOGS")
(52968 . "HANGUL SYLLABLE KEON")
(52969 . "HANGUL SYLLABLE KEONJ")
(52970 . "HANGUL SYLLABLE KEONH")
(52971 . "HANGUL SYLLABLE KEOD")
(52972 . "HANGUL SYLLABLE KEOL")
(52973 . "HANGUL SYLLABLE KEOLG")
(52974 . "HANGUL SYLLABLE KEOLM")
(52975 . "HANGUL SYLLABLE KEOLB")
(52976 . "HANGUL SYLLABLE KEOLS")
(52977 . "HANGUL SYLLABLE KEOLT")
(52978 . "HANGUL SYLLABLE KEOLP")
(52979 . "HANGUL SYLLABLE KEOLH")
(52980 . "HANGUL SYLLABLE KEOM")
(52981 . "HANGUL SYLLABLE KEOB")
(52982 . "HANGUL SYLLABLE KEOBS")
(52983 . "HANGUL SYLLABLE KEOS")
(52984 . "HANGUL SYLLABLE KEOSS")
(52985 . "HANGUL SYLLABLE KEONG")
(52986 . "HANGUL SYLLABLE KEOJ")
(52987 . "HANGUL SYLLABLE KEOC")
(52988 . "HANGUL SYLLABLE KEOK")
(52989 . "HANGUL SYLLABLE KEOT")
(52990 . "HANGUL SYLLABLE KEOP")
(52991 . "HANGUL SYLLABLE KEOH")
(52992 . "HANGUL SYLLABLE KE")
(52993 . "HANGUL SYLLABLE KEG")
(52994 . "HANGUL SYLLABLE KEGG")
(52995 . "HANGUL SYLLABLE KEGS")
(52996 . "HANGUL SYLLABLE KEN")
(52997 . "HANGUL SYLLABLE KENJ")
(52998 . "HANGUL SYLLABLE KENH")
(52999 . "HANGUL SYLLABLE KED")
(53000 . "HANGUL SYLLABLE KEL")
(53001 . "HANGUL SYLLABLE KELG")
(53002 . "HANGUL SYLLABLE KELM")
(53003 . "HANGUL SYLLABLE KELB")
(53004 . "HANGUL SYLLABLE KELS")
(53005 . "HANGUL SYLLABLE KELT")
(53006 . "HANGUL SYLLABLE KELP")
(53007 . "HANGUL SYLLABLE KELH")
(53008 . "HANGUL SYLLABLE KEM")
(53009 . "HANGUL SYLLABLE KEB")
(53010 . "HANGUL SYLLABLE KEBS")
(53011 . "HANGUL SYLLABLE KES")
(53012 . "HANGUL SYLLABLE KESS")
(53013 . "HANGUL SYLLABLE KENG")
(53014 . "HANGUL SYLLABLE KEJ")
(53015 . "HANGUL SYLLABLE KEC")
(53016 . "HANGUL SYLLABLE KEK")
(53017 . "HANGUL SYLLABLE KET")
(53018 . "HANGUL SYLLABLE KEP")
(53019 . "HANGUL SYLLABLE KEH")
(53020 . "HANGUL SYLLABLE KYEO")
(53021 . "HANGUL SYLLABLE KYEOG")
(53022 . "HANGUL SYLLABLE KYEOGG")
(53023 . "HANGUL SYLLABLE KYEOGS")
(53024 . "HANGUL SYLLABLE KYEON")
(53025 . "HANGUL SYLLABLE KYEONJ")
(53026 . "HANGUL SYLLABLE KYEONH")
(53027 . "HANGUL SYLLABLE KYEOD")
(53028 . "HANGUL SYLLABLE KYEOL")
(53029 . "HANGUL SYLLABLE KYEOLG")
(53030 . "HANGUL SYLLABLE KYEOLM")
(53031 . "HANGUL SYLLABLE KYEOLB")
(53032 . "HANGUL SYLLABLE KYEOLS")
(53033 . "HANGUL SYLLABLE KYEOLT")
(53034 . "HANGUL SYLLABLE KYEOLP")
(53035 . "HANGUL SYLLABLE KYEOLH")
(53036 . "HANGUL SYLLABLE KYEOM")
(53037 . "HANGUL SYLLABLE KYEOB")
(53038 . "HANGUL SYLLABLE KYEOBS")
(53039 . "HANGUL SYLLABLE KYEOS")
(53040 . "HANGUL SYLLABLE KYEOSS")
(53041 . "HANGUL SYLLABLE KYEONG")
(53042 . "HANGUL SYLLABLE KYEOJ")
(53043 . "HANGUL SYLLABLE KYEOC")
(53044 . "HANGUL SYLLABLE KYEOK")
(53045 . "HANGUL SYLLABLE KYEOT")
(53046 . "HANGUL SYLLABLE KYEOP")
(53047 . "HANGUL SYLLABLE KYEOH")
(53048 . "HANGUL SYLLABLE KYE")
(53049 . "HANGUL SYLLABLE KYEG")
(53050 . "HANGUL SYLLABLE KYEGG")
(53051 . "HANGUL SYLLABLE KYEGS")
(53052 . "HANGUL SYLLABLE KYEN")
(53053 . "HANGUL SYLLABLE KYENJ")
(53054 . "HANGUL SYLLABLE KYENH")
(53055 . "HANGUL SYLLABLE KYED")
(53056 . "HANGUL SYLLABLE KYEL")
(53057 . "HANGUL SYLLABLE KYELG")
(53058 . "HANGUL SYLLABLE KYELM")
(53059 . "HANGUL SYLLABLE KYELB")
(53060 . "HANGUL SYLLABLE KYELS")
(53061 . "HANGUL SYLLABLE KYELT")
(53062 . "HANGUL SYLLABLE KYELP")
(53063 . "HANGUL SYLLABLE KYELH")
(53064 . "HANGUL SYLLABLE KYEM")
(53065 . "HANGUL SYLLABLE KYEB")
(53066 . "HANGUL SYLLABLE KYEBS")
(53067 . "HANGUL SYLLABLE KYES")
(53068 . "HANGUL SYLLABLE KYESS")
(53069 . "HANGUL SYLLABLE KYENG")
(53070 . "HANGUL SYLLABLE KYEJ")
(53071 . "HANGUL SYLLABLE KYEC")
(53072 . "HANGUL SYLLABLE KYEK")
(53073 . "HANGUL SYLLABLE KYET")
(53074 . "HANGUL SYLLABLE KYEP")
(53075 . "HANGUL SYLLABLE KYEH")
(53076 . "HANGUL SYLLABLE KO")
(53077 . "HANGUL SYLLABLE KOG")
(53078 . "HANGUL SYLLABLE KOGG")
(53079 . "HANGUL SYLLABLE KOGS")
(53080 . "HANGUL SYLLABLE KON")
(53081 . "HANGUL SYLLABLE KONJ")
(53082 . "HANGUL SYLLABLE KONH")
(53083 . "HANGUL SYLLABLE KOD")
(53084 . "HANGUL SYLLABLE KOL")
(53085 . "HANGUL SYLLABLE KOLG")
(53086 . "HANGUL SYLLABLE KOLM")
(53087 . "HANGUL SYLLABLE KOLB")
(53088 . "HANGUL SYLLABLE KOLS")
(53089 . "HANGUL SYLLABLE KOLT")
(53090 . "HANGUL SYLLABLE KOLP")
(53091 . "HANGUL SYLLABLE KOLH")
(53092 . "HANGUL SYLLABLE KOM")
(53093 . "HANGUL SYLLABLE KOB")
(53094 . "HANGUL SYLLABLE KOBS")
(53095 . "HANGUL SYLLABLE KOS")
(53096 . "HANGUL SYLLABLE KOSS")
(53097 . "HANGUL SYLLABLE KONG")
(53098 . "HANGUL SYLLABLE KOJ")
(53099 . "HANGUL SYLLABLE KOC")
(53100 . "HANGUL SYLLABLE KOK")
(53101 . "HANGUL SYLLABLE KOT")
(53102 . "HANGUL SYLLABLE KOP")
(53103 . "HANGUL SYLLABLE KOH")
(53104 . "HANGUL SYLLABLE KWA")
(53105 . "HANGUL SYLLABLE KWAG")
(53106 . "HANGUL SYLLABLE KWAGG")
(53107 . "HANGUL SYLLABLE KWAGS")
(53108 . "HANGUL SYLLABLE KWAN")
(53109 . "HANGUL SYLLABLE KWANJ")
(53110 . "HANGUL SYLLABLE KWANH")
(53111 . "HANGUL SYLLABLE KWAD")
(53112 . "HANGUL SYLLABLE KWAL")
(53113 . "HANGUL SYLLABLE KWALG")
(53114 . "HANGUL SYLLABLE KWALM")
(53115 . "HANGUL SYLLABLE KWALB")
(53116 . "HANGUL SYLLABLE KWALS")
(53117 . "HANGUL SYLLABLE KWALT")
(53118 . "HANGUL SYLLABLE KWALP")
(53119 . "HANGUL SYLLABLE KWALH")
(53120 . "HANGUL SYLLABLE KWAM")
(53121 . "HANGUL SYLLABLE KWAB")
(53122 . "HANGUL SYLLABLE KWABS")
(53123 . "HANGUL SYLLABLE KWAS")
(53124 . "HANGUL SYLLABLE KWASS")
(53125 . "HANGUL SYLLABLE KWANG")
(53126 . "HANGUL SYLLABLE KWAJ")
(53127 . "HANGUL SYLLABLE KWAC")
(53128 . "HANGUL SYLLABLE KWAK")
(53129 . "HANGUL SYLLABLE KWAT")
(53130 . "HANGUL SYLLABLE KWAP")
(53131 . "HANGUL SYLLABLE KWAH")
(53132 . "HANGUL SYLLABLE KWAE")
(53133 . "HANGUL SYLLABLE KWAEG")
(53134 . "HANGUL SYLLABLE KWAEGG")
(53135 . "HANGUL SYLLABLE KWAEGS")
(53136 . "HANGUL SYLLABLE KWAEN")
(53137 . "HANGUL SYLLABLE KWAENJ")
(53138 . "HANGUL SYLLABLE KWAENH")
(53139 . "HANGUL SYLLABLE KWAED")
(53140 . "HANGUL SYLLABLE KWAEL")
(53141 . "HANGUL SYLLABLE KWAELG")
(53142 . "HANGUL SYLLABLE KWAELM")
(53143 . "HANGUL SYLLABLE KWAELB")
(53144 . "HANGUL SYLLABLE KWAELS")
(53145 . "HANGUL SYLLABLE KWAELT")
(53146 . "HANGUL SYLLABLE KWAELP")
(53147 . "HANGUL SYLLABLE KWAELH")
(53148 . "HANGUL SYLLABLE KWAEM")
(53149 . "HANGUL SYLLABLE KWAEB")
(53150 . "HANGUL SYLLABLE KWAEBS")
(53151 . "HANGUL SYLLABLE KWAES")
(53152 . "HANGUL SYLLABLE KWAESS")
(53153 . "HANGUL SYLLABLE KWAENG")
(53154 . "HANGUL SYLLABLE KWAEJ")
(53155 . "HANGUL SYLLABLE KWAEC")
(53156 . "HANGUL SYLLABLE KWAEK")
(53157 . "HANGUL SYLLABLE KWAET")
(53158 . "HANGUL SYLLABLE KWAEP")
(53159 . "HANGUL SYLLABLE KWAEH")
(53160 . "HANGUL SYLLABLE KOE")
(53161 . "HANGUL SYLLABLE KOEG")
(53162 . "HANGUL SYLLABLE KOEGG")
(53163 . "HANGUL SYLLABLE KOEGS")
(53164 . "HANGUL SYLLABLE KOEN")
(53165 . "HANGUL SYLLABLE KOENJ")
(53166 . "HANGUL SYLLABLE KOENH")
(53167 . "HANGUL SYLLABLE KOED")
(53168 . "HANGUL SYLLABLE KOEL")
(53169 . "HANGUL SYLLABLE KOELG")
(53170 . "HANGUL SYLLABLE KOELM")
(53171 . "HANGUL SYLLABLE KOELB")
(53172 . "HANGUL SYLLABLE KOELS")
(53173 . "HANGUL SYLLABLE KOELT")
(53174 . "HANGUL SYLLABLE KOELP")
(53175 . "HANGUL SYLLABLE KOELH")
(53176 . "HANGUL SYLLABLE KOEM")
(53177 . "HANGUL SYLLABLE KOEB")
(53178 . "HANGUL SYLLABLE KOEBS")
(53179 . "HANGUL SYLLABLE KOES")
(53180 . "HANGUL SYLLABLE KOESS")
(53181 . "HANGUL SYLLABLE KOENG")
(53182 . "HANGUL SYLLABLE KOEJ")
(53183 . "HANGUL SYLLABLE KOEC")
(53184 . "HANGUL SYLLABLE KOEK")
(53185 . "HANGUL SYLLABLE KOET")
(53186 . "HANGUL SYLLABLE KOEP")
(53187 . "HANGUL SYLLABLE KOEH")
(53188 . "HANGUL SYLLABLE KYO")
(53189 . "HANGUL SYLLABLE KYOG")
(53190 . "HANGUL SYLLABLE KYOGG")
(53191 . "HANGUL SYLLABLE KYOGS")
(53192 . "HANGUL SYLLABLE KYON")
(53193 . "HANGUL SYLLABLE KYONJ")
(53194 . "HANGUL SYLLABLE KYONH")
(53195 . "HANGUL SYLLABLE KYOD")
(53196 . "HANGUL SYLLABLE KYOL")
(53197 . "HANGUL SYLLABLE KYOLG")
(53198 . "HANGUL SYLLABLE KYOLM")
(53199 . "HANGUL SYLLABLE KYOLB")
(53200 . "HANGUL SYLLABLE KYOLS")
(53201 . "HANGUL SYLLABLE KYOLT")
(53202 . "HANGUL SYLLABLE KYOLP")
(53203 . "HANGUL SYLLABLE KYOLH")
(53204 . "HANGUL SYLLABLE KYOM")
(53205 . "HANGUL SYLLABLE KYOB")
(53206 . "HANGUL SYLLABLE KYOBS")
(53207 . "HANGUL SYLLABLE KYOS")
(53208 . "HANGUL SYLLABLE KYOSS")
(53209 . "HANGUL SYLLABLE KYONG")
(53210 . "HANGUL SYLLABLE KYOJ")
(53211 . "HANGUL SYLLABLE KYOC")
(53212 . "HANGUL SYLLABLE KYOK")
(53213 . "HANGUL SYLLABLE KYOT")
(53214 . "HANGUL SYLLABLE KYOP")
(53215 . "HANGUL SYLLABLE KYOH")
(53216 . "HANGUL SYLLABLE KU")
(53217 . "HANGUL SYLLABLE KUG")
(53218 . "HANGUL SYLLABLE KUGG")
(53219 . "HANGUL SYLLABLE KUGS")
(53220 . "HANGUL SYLLABLE KUN")
(53221 . "HANGUL SYLLABLE KUNJ")
(53222 . "HANGUL SYLLABLE KUNH")
(53223 . "HANGUL SYLLABLE KUD")
(53224 . "HANGUL SYLLABLE KUL")
(53225 . "HANGUL SYLLABLE KULG")
(53226 . "HANGUL SYLLABLE KULM")
(53227 . "HANGUL SYLLABLE KULB")
(53228 . "HANGUL SYLLABLE KULS")
(53229 . "HANGUL SYLLABLE KULT")
(53230 . "HANGUL SYLLABLE KULP")
(53231 . "HANGUL SYLLABLE KULH")
(53232 . "HANGUL SYLLABLE KUM")
(53233 . "HANGUL SYLLABLE KUB")
(53234 . "HANGUL SYLLABLE KUBS")
(53235 . "HANGUL SYLLABLE KUS")
(53236 . "HANGUL SYLLABLE KUSS")
(53237 . "HANGUL SYLLABLE KUNG")
(53238 . "HANGUL SYLLABLE KUJ")
(53239 . "HANGUL SYLLABLE KUC")
(53240 . "HANGUL SYLLABLE KUK")
(53241 . "HANGUL SYLLABLE KUT")
(53242 . "HANGUL SYLLABLE KUP")
(53243 . "HANGUL SYLLABLE KUH")
(53244 . "HANGUL SYLLABLE KWEO")
(53245 . "HANGUL SYLLABLE KWEOG")
(53246 . "HANGUL SYLLABLE KWEOGG")
(53247 . "HANGUL SYLLABLE KWEOGS")
(53248 . "HANGUL SYLLABLE KWEON")
(53249 . "HANGUL SYLLABLE KWEONJ")
(53250 . "HANGUL SYLLABLE KWEONH")
(53251 . "HANGUL SYLLABLE KWEOD")
(53252 . "HANGUL SYLLABLE KWEOL")
(53253 . "HANGUL SYLLABLE KWEOLG")
(53254 . "HANGUL SYLLABLE KWEOLM")
(53255 . "HANGUL SYLLABLE KWEOLB")
(53256 . "HANGUL SYLLABLE KWEOLS")
(53257 . "HANGUL SYLLABLE KWEOLT")
(53258 . "HANGUL SYLLABLE KWEOLP")
(53259 . "HANGUL SYLLABLE KWEOLH")
(53260 . "HANGUL SYLLABLE KWEOM")
(53261 . "HANGUL SYLLABLE KWEOB")
(53262 . "HANGUL SYLLABLE KWEOBS")
(53263 . "HANGUL SYLLABLE KWEOS")
(53264 . "HANGUL SYLLABLE KWEOSS")
(53265 . "HANGUL SYLLABLE KWEONG")
(53266 . "HANGUL SYLLABLE KWEOJ")
(53267 . "HANGUL SYLLABLE KWEOC")
(53268 . "HANGUL SYLLABLE KWEOK")
(53269 . "HANGUL SYLLABLE KWEOT")
(53270 . "HANGUL SYLLABLE KWEOP")
(53271 . "HANGUL SYLLABLE KWEOH")
(53272 . "HANGUL SYLLABLE KWE")
(53273 . "HANGUL SYLLABLE KWEG")
(53274 . "HANGUL SYLLABLE KWEGG")
(53275 . "HANGUL SYLLABLE KWEGS")
(53276 . "HANGUL SYLLABLE KWEN")
(53277 . "HANGUL SYLLABLE KWENJ")
(53278 . "HANGUL SYLLABLE KWENH")
(53279 . "HANGUL SYLLABLE KWED")
(53280 . "HANGUL SYLLABLE KWEL")
(53281 . "HANGUL SYLLABLE KWELG")
(53282 . "HANGUL SYLLABLE KWELM")
(53283 . "HANGUL SYLLABLE KWELB")
(53284 . "HANGUL SYLLABLE KWELS")
(53285 . "HANGUL SYLLABLE KWELT")
(53286 . "HANGUL SYLLABLE KWELP")
(53287 . "HANGUL SYLLABLE KWELH")
(53288 . "HANGUL SYLLABLE KWEM")
(53289 . "HANGUL SYLLABLE KWEB")
(53290 . "HANGUL SYLLABLE KWEBS")
(53291 . "HANGUL SYLLABLE KWES")
(53292 . "HANGUL SYLLABLE KWESS")
(53293 . "HANGUL SYLLABLE KWENG")
(53294 . "HANGUL SYLLABLE KWEJ")
(53295 . "HANGUL SYLLABLE KWEC")
(53296 . "HANGUL SYLLABLE KWEK")
(53297 . "HANGUL SYLLABLE KWET")
(53298 . "HANGUL SYLLABLE KWEP")
(53299 . "HANGUL SYLLABLE KWEH")
(53300 . "HANGUL SYLLABLE KWI")
(53301 . "HANGUL SYLLABLE KWIG")
(53302 . "HANGUL SYLLABLE KWIGG")
(53303 . "HANGUL SYLLABLE KWIGS")
(53304 . "HANGUL SYLLABLE KWIN")
(53305 . "HANGUL SYLLABLE KWINJ")
(53306 . "HANGUL SYLLABLE KWINH")
(53307 . "HANGUL SYLLABLE KWID")
(53308 . "HANGUL SYLLABLE KWIL")
(53309 . "HANGUL SYLLABLE KWILG")
(53310 . "HANGUL SYLLABLE KWILM")
(53311 . "HANGUL SYLLABLE KWILB")
(53312 . "HANGUL SYLLABLE KWILS")
(53313 . "HANGUL SYLLABLE KWILT")
(53314 . "HANGUL SYLLABLE KWILP")
(53315 . "HANGUL SYLLABLE KWILH")
(53316 . "HANGUL SYLLABLE KWIM")
(53317 . "HANGUL SYLLABLE KWIB")
(53318 . "HANGUL SYLLABLE KWIBS")
(53319 . "HANGUL SYLLABLE KWIS")
(53320 . "HANGUL SYLLABLE KWISS")
(53321 . "HANGUL SYLLABLE KWING")
(53322 . "HANGUL SYLLABLE KWIJ")
(53323 . "HANGUL SYLLABLE KWIC")
(53324 . "HANGUL SYLLABLE KWIK")
(53325 . "HANGUL SYLLABLE KWIT")
(53326 . "HANGUL SYLLABLE KWIP")
(53327 . "HANGUL SYLLABLE KWIH")
(53328 . "HANGUL SYLLABLE KYU")
(53329 . "HANGUL SYLLABLE KYUG")
(53330 . "HANGUL SYLLABLE KYUGG")
(53331 . "HANGUL SYLLABLE KYUGS")
(53332 . "HANGUL SYLLABLE KYUN")
(53333 . "HANGUL SYLLABLE KYUNJ")
(53334 . "HANGUL SYLLABLE KYUNH")
(53335 . "HANGUL SYLLABLE KYUD")
(53336 . "HANGUL SYLLABLE KYUL")
(53337 . "HANGUL SYLLABLE KYULG")
(53338 . "HANGUL SYLLABLE KYULM")
(53339 . "HANGUL SYLLABLE KYULB")
(53340 . "HANGUL SYLLABLE KYULS")
(53341 . "HANGUL SYLLABLE KYULT")
(53342 . "HANGUL SYLLABLE KYULP")
(53343 . "HANGUL SYLLABLE KYULH")
(53344 . "HANGUL SYLLABLE KYUM")
(53345 . "HANGUL SYLLABLE KYUB")
(53346 . "HANGUL SYLLABLE KYUBS")
(53347 . "HANGUL SYLLABLE KYUS")
(53348 . "HANGUL SYLLABLE KYUSS")
(53349 . "HANGUL SYLLABLE KYUNG")
(53350 . "HANGUL SYLLABLE KYUJ")
(53351 . "HANGUL SYLLABLE KYUC")
(53352 . "HANGUL SYLLABLE KYUK")
(53353 . "HANGUL SYLLABLE KYUT")
(53354 . "HANGUL SYLLABLE KYUP")
(53355 . "HANGUL SYLLABLE KYUH")
(53356 . "HANGUL SYLLABLE KEU")
(53357 . "HANGUL SYLLABLE KEUG")
(53358 . "HANGUL SYLLABLE KEUGG")
(53359 . "HANGUL SYLLABLE KEUGS")
(53360 . "HANGUL SYLLABLE KEUN")
(53361 . "HANGUL SYLLABLE KEUNJ")
(53362 . "HANGUL SYLLABLE KEUNH")
(53363 . "HANGUL SYLLABLE KEUD")
(53364 . "HANGUL SYLLABLE KEUL")
(53365 . "HANGUL SYLLABLE KEULG")
(53366 . "HANGUL SYLLABLE KEULM")
(53367 . "HANGUL SYLLABLE KEULB")
(53368 . "HANGUL SYLLABLE KEULS")
(53369 . "HANGUL SYLLABLE KEULT")
(53370 . "HANGUL SYLLABLE KEULP")
(53371 . "HANGUL SYLLABLE KEULH")
(53372 . "HANGUL SYLLABLE KEUM")
(53373 . "HANGUL SYLLABLE KEUB")
(53374 . "HANGUL SYLLABLE KEUBS")
(53375 . "HANGUL SYLLABLE KEUS")
(53376 . "HANGUL SYLLABLE KEUSS")
(53377 . "HANGUL SYLLABLE KEUNG")
(53378 . "HANGUL SYLLABLE KEUJ")
(53379 . "HANGUL SYLLABLE KEUC")
(53380 . "HANGUL SYLLABLE KEUK")
(53381 . "HANGUL SYLLABLE KEUT")
(53382 . "HANGUL SYLLABLE KEUP")
(53383 . "HANGUL SYLLABLE KEUH")
(53384 . "HANGUL SYLLABLE KYI")
(53385 . "HANGUL SYLLABLE KYIG")
(53386 . "HANGUL SYLLABLE KYIGG")
(53387 . "HANGUL SYLLABLE KYIGS")
(53388 . "HANGUL SYLLABLE KYIN")
(53389 . "HANGUL SYLLABLE KYINJ")
(53390 . "HANGUL SYLLABLE KYINH")
(53391 . "HANGUL SYLLABLE KYID")
(53392 . "HANGUL SYLLABLE KYIL")
(53393 . "HANGUL SYLLABLE KYILG")
(53394 . "HANGUL SYLLABLE KYILM")
(53395 . "HANGUL SYLLABLE KYILB")
(53396 . "HANGUL SYLLABLE KYILS")
(53397 . "HANGUL SYLLABLE KYILT")
(53398 . "HANGUL SYLLABLE KYILP")
(53399 . "HANGUL SYLLABLE KYILH")
(53400 . "HANGUL SYLLABLE KYIM")
(53401 . "HANGUL SYLLABLE KYIB")
(53402 . "HANGUL SYLLABLE KYIBS")
(53403 . "HANGUL SYLLABLE KYIS")
(53404 . "HANGUL SYLLABLE KYISS")
(53405 . "HANGUL SYLLABLE KYING")
(53406 . "HANGUL SYLLABLE KYIJ")
(53407 . "HANGUL SYLLABLE KYIC")
(53408 . "HANGUL SYLLABLE KYIK")
(53409 . "HANGUL SYLLABLE KYIT")
(53410 . "HANGUL SYLLABLE KYIP")
(53411 . "HANGUL SYLLABLE KYIH")
(53412 . "HANGUL SYLLABLE KI")
(53413 . "HANGUL SYLLABLE KIG")
(53414 . "HANGUL SYLLABLE KIGG")
(53415 . "HANGUL SYLLABLE KIGS")
(53416 . "HANGUL SYLLABLE KIN")
(53417 . "HANGUL SYLLABLE KINJ")
(53418 . "HANGUL SYLLABLE KINH")
(53419 . "HANGUL SYLLABLE KID")
(53420 . "HANGUL SYLLABLE KIL")
(53421 . "HANGUL SYLLABLE KILG")
(53422 . "HANGUL SYLLABLE KILM")
(53423 . "HANGUL SYLLABLE KILB")
(53424 . "HANGUL SYLLABLE KILS")
(53425 . "HANGUL SYLLABLE KILT")
(53426 . "HANGUL SYLLABLE KILP")
(53427 . "HANGUL SYLLABLE KILH")
(53428 . "HANGUL SYLLABLE KIM")
(53429 . "HANGUL SYLLABLE KIB")
(53430 . "HANGUL SYLLABLE KIBS")
(53431 . "HANGUL SYLLABLE KIS")
(53432 . "HANGUL SYLLABLE KISS")
(53433 . "HANGUL SYLLABLE KING")
(53434 . "HANGUL SYLLABLE KIJ")
(53435 . "HANGUL SYLLABLE KIC")
(53436 . "HANGUL SYLLABLE KIK")
(53437 . "HANGUL SYLLABLE KIT")
(53438 . "HANGUL SYLLABLE KIP")
(53439 . "HANGUL SYLLABLE KIH")
(53440 . "HANGUL SYLLABLE TA")
(53441 . "HANGUL SYLLABLE TAG")
(53442 . "HANGUL SYLLABLE TAGG")
(53443 . "HANGUL SYLLABLE TAGS")
(53444 . "HANGUL SYLLABLE TAN")
(53445 . "HANGUL SYLLABLE TANJ")
(53446 . "HANGUL SYLLABLE TANH")
(53447 . "HANGUL SYLLABLE TAD")
(53448 . "HANGUL SYLLABLE TAL")
(53449 . "HANGUL SYLLABLE TALG")
(53450 . "HANGUL SYLLABLE TALM")
(53451 . "HANGUL SYLLABLE TALB")
(53452 . "HANGUL SYLLABLE TALS")
(53453 . "HANGUL SYLLABLE TALT")
(53454 . "HANGUL SYLLABLE TALP")
(53455 . "HANGUL SYLLABLE TALH")
(53456 . "HANGUL SYLLABLE TAM")
(53457 . "HANGUL SYLLABLE TAB")
(53458 . "HANGUL SYLLABLE TABS")
(53459 . "HANGUL SYLLABLE TAS")
(53460 . "HANGUL SYLLABLE TASS")
(53461 . "HANGUL SYLLABLE TANG")
(53462 . "HANGUL SYLLABLE TAJ")
(53463 . "HANGUL SYLLABLE TAC")
(53464 . "HANGUL SYLLABLE TAK")
(53465 . "HANGUL SYLLABLE TAT")
(53466 . "HANGUL SYLLABLE TAP")
(53467 . "HANGUL SYLLABLE TAH")
(53468 . "HANGUL SYLLABLE TAE")
(53469 . "HANGUL SYLLABLE TAEG")
(53470 . "HANGUL SYLLABLE TAEGG")
(53471 . "HANGUL SYLLABLE TAEGS")
(53472 . "HANGUL SYLLABLE TAEN")
(53473 . "HANGUL SYLLABLE TAENJ")
(53474 . "HANGUL SYLLABLE TAENH")
(53475 . "HANGUL SYLLABLE TAED")
(53476 . "HANGUL SYLLABLE TAEL")
(53477 . "HANGUL SYLLABLE TAELG")
(53478 . "HANGUL SYLLABLE TAELM")
(53479 . "HANGUL SYLLABLE TAELB")
(53480 . "HANGUL SYLLABLE TAELS")
(53481 . "HANGUL SYLLABLE TAELT")
(53482 . "HANGUL SYLLABLE TAELP")
(53483 . "HANGUL SYLLABLE TAELH")
(53484 . "HANGUL SYLLABLE TAEM")
(53485 . "HANGUL SYLLABLE TAEB")
(53486 . "HANGUL SYLLABLE TAEBS")
(53487 . "HANGUL SYLLABLE TAES")
(53488 . "HANGUL SYLLABLE TAESS")
(53489 . "HANGUL SYLLABLE TAENG")
(53490 . "HANGUL SYLLABLE TAEJ")
(53491 . "HANGUL SYLLABLE TAEC")
(53492 . "HANGUL SYLLABLE TAEK")
(53493 . "HANGUL SYLLABLE TAET")
(53494 . "HANGUL SYLLABLE TAEP")
(53495 . "HANGUL SYLLABLE TAEH")
(53496 . "HANGUL SYLLABLE TYA")
(53497 . "HANGUL SYLLABLE TYAG")
(53498 . "HANGUL SYLLABLE TYAGG")
(53499 . "HANGUL SYLLABLE TYAGS")
(53500 . "HANGUL SYLLABLE TYAN")
(53501 . "HANGUL SYLLABLE TYANJ")
(53502 . "HANGUL SYLLABLE TYANH")
(53503 . "HANGUL SYLLABLE TYAD")
(53504 . "HANGUL SYLLABLE TYAL")
(53505 . "HANGUL SYLLABLE TYALG")
(53506 . "HANGUL SYLLABLE TYALM")
(53507 . "HANGUL SYLLABLE TYALB")
(53508 . "HANGUL SYLLABLE TYALS")
(53509 . "HANGUL SYLLABLE TYALT")
(53510 . "HANGUL SYLLABLE TYALP")
(53511 . "HANGUL SYLLABLE TYALH")
(53512 . "HANGUL SYLLABLE TYAM")
(53513 . "HANGUL SYLLABLE TYAB")
(53514 . "HANGUL SYLLABLE TYABS")
(53515 . "HANGUL SYLLABLE TYAS")
(53516 . "HANGUL SYLLABLE TYASS")
(53517 . "HANGUL SYLLABLE TYANG")
(53518 . "HANGUL SYLLABLE TYAJ")
(53519 . "HANGUL SYLLABLE TYAC")
(53520 . "HANGUL SYLLABLE TYAK")
(53521 . "HANGUL SYLLABLE TYAT")
(53522 . "HANGUL SYLLABLE TYAP")
(53523 . "HANGUL SYLLABLE TYAH")
(53524 . "HANGUL SYLLABLE TYAE")
(53525 . "HANGUL SYLLABLE TYAEG")
(53526 . "HANGUL SYLLABLE TYAEGG")
(53527 . "HANGUL SYLLABLE TYAEGS")
(53528 . "HANGUL SYLLABLE TYAEN")
(53529 . "HANGUL SYLLABLE TYAENJ")
(53530 . "HANGUL SYLLABLE TYAENH")
(53531 . "HANGUL SYLLABLE TYAED")
(53532 . "HANGUL SYLLABLE TYAEL")
(53533 . "HANGUL SYLLABLE TYAELG")
(53534 . "HANGUL SYLLABLE TYAELM")
(53535 . "HANGUL SYLLABLE TYAELB")
(53536 . "HANGUL SYLLABLE TYAELS")
(53537 . "HANGUL SYLLABLE TYAELT")
(53538 . "HANGUL SYLLABLE TYAELP")
(53539 . "HANGUL SYLLABLE TYAELH")
(53540 . "HANGUL SYLLABLE TYAEM")
(53541 . "HANGUL SYLLABLE TYAEB")
(53542 . "HANGUL SYLLABLE TYAEBS")
(53543 . "HANGUL SYLLABLE TYAES")
(53544 . "HANGUL SYLLABLE TYAESS")
(53545 . "HANGUL SYLLABLE TYAENG")
(53546 . "HANGUL SYLLABLE TYAEJ")
(53547 . "HANGUL SYLLABLE TYAEC")
(53548 . "HANGUL SYLLABLE TYAEK")
(53549 . "HANGUL SYLLABLE TYAET")
(53550 . "HANGUL SYLLABLE TYAEP")
(53551 . "HANGUL SYLLABLE TYAEH")
(53552 . "HANGUL SYLLABLE TEO")
(53553 . "HANGUL SYLLABLE TEOG")
(53554 . "HANGUL SYLLABLE TEOGG")
(53555 . "HANGUL SYLLABLE TEOGS")
(53556 . "HANGUL SYLLABLE TEON")
(53557 . "HANGUL SYLLABLE TEONJ")
(53558 . "HANGUL SYLLABLE TEONH")
(53559 . "HANGUL SYLLABLE TEOD")
(53560 . "HANGUL SYLLABLE TEOL")
(53561 . "HANGUL SYLLABLE TEOLG")
(53562 . "HANGUL SYLLABLE TEOLM")
(53563 . "HANGUL SYLLABLE TEOLB")
(53564 . "HANGUL SYLLABLE TEOLS")
(53565 . "HANGUL SYLLABLE TEOLT")
(53566 . "HANGUL SYLLABLE TEOLP")
(53567 . "HANGUL SYLLABLE TEOLH")
(53568 . "HANGUL SYLLABLE TEOM")
(53569 . "HANGUL SYLLABLE TEOB")
(53570 . "HANGUL SYLLABLE TEOBS")
(53571 . "HANGUL SYLLABLE TEOS")
(53572 . "HANGUL SYLLABLE TEOSS")
(53573 . "HANGUL SYLLABLE TEONG")
(53574 . "HANGUL SYLLABLE TEOJ")
(53575 . "HANGUL SYLLABLE TEOC")
(53576 . "HANGUL SYLLABLE TEOK")
(53577 . "HANGUL SYLLABLE TEOT")
(53578 . "HANGUL SYLLABLE TEOP")
(53579 . "HANGUL SYLLABLE TEOH")
(53580 . "HANGUL SYLLABLE TE")
(53581 . "HANGUL SYLLABLE TEG")
(53582 . "HANGUL SYLLABLE TEGG")
(53583 . "HANGUL SYLLABLE TEGS")
(53584 . "HANGUL SYLLABLE TEN")
(53585 . "HANGUL SYLLABLE TENJ")
(53586 . "HANGUL SYLLABLE TENH")
(53587 . "HANGUL SYLLABLE TED")
(53588 . "HANGUL SYLLABLE TEL")
(53589 . "HANGUL SYLLABLE TELG")
(53590 . "HANGUL SYLLABLE TELM")
(53591 . "HANGUL SYLLABLE TELB")
(53592 . "HANGUL SYLLABLE TELS")
(53593 . "HANGUL SYLLABLE TELT")
(53594 . "HANGUL SYLLABLE TELP")
(53595 . "HANGUL SYLLABLE TELH")
(53596 . "HANGUL SYLLABLE TEM")
(53597 . "HANGUL SYLLABLE TEB")
(53598 . "HANGUL SYLLABLE TEBS")
(53599 . "HANGUL SYLLABLE TES")
(53600 . "HANGUL SYLLABLE TESS")
(53601 . "HANGUL SYLLABLE TENG")
(53602 . "HANGUL SYLLABLE TEJ")
(53603 . "HANGUL SYLLABLE TEC")
(53604 . "HANGUL SYLLABLE TEK")
(53605 . "HANGUL SYLLABLE TET")
(53606 . "HANGUL SYLLABLE TEP")
(53607 . "HANGUL SYLLABLE TEH")
(53608 . "HANGUL SYLLABLE TYEO")
(53609 . "HANGUL SYLLABLE TYEOG")
(53610 . "HANGUL SYLLABLE TYEOGG")
(53611 . "HANGUL SYLLABLE TYEOGS")
(53612 . "HANGUL SYLLABLE TYEON")
(53613 . "HANGUL SYLLABLE TYEONJ")
(53614 . "HANGUL SYLLABLE TYEONH")
(53615 . "HANGUL SYLLABLE TYEOD")
(53616 . "HANGUL SYLLABLE TYEOL")
(53617 . "HANGUL SYLLABLE TYEOLG")
(53618 . "HANGUL SYLLABLE TYEOLM")
(53619 . "HANGUL SYLLABLE TYEOLB")
(53620 . "HANGUL SYLLABLE TYEOLS")
(53621 . "HANGUL SYLLABLE TYEOLT")
(53622 . "HANGUL SYLLABLE TYEOLP")
(53623 . "HANGUL SYLLABLE TYEOLH")
(53624 . "HANGUL SYLLABLE TYEOM")
(53625 . "HANGUL SYLLABLE TYEOB")
(53626 . "HANGUL SYLLABLE TYEOBS")
(53627 . "HANGUL SYLLABLE TYEOS")
(53628 . "HANGUL SYLLABLE TYEOSS")
(53629 . "HANGUL SYLLABLE TYEONG")
(53630 . "HANGUL SYLLABLE TYEOJ")
(53631 . "HANGUL SYLLABLE TYEOC")
(53632 . "HANGUL SYLLABLE TYEOK")
(53633 . "HANGUL SYLLABLE TYEOT")
(53634 . "HANGUL SYLLABLE TYEOP")
(53635 . "HANGUL SYLLABLE TYEOH")
(53636 . "HANGUL SYLLABLE TYE")
(53637 . "HANGUL SYLLABLE TYEG")
(53638 . "HANGUL SYLLABLE TYEGG")
(53639 . "HANGUL SYLLABLE TYEGS")
(53640 . "HANGUL SYLLABLE TYEN")
(53641 . "HANGUL SYLLABLE TYENJ")
(53642 . "HANGUL SYLLABLE TYENH")
(53643 . "HANGUL SYLLABLE TYED")
(53644 . "HANGUL SYLLABLE TYEL")
(53645 . "HANGUL SYLLABLE TYELG")
(53646 . "HANGUL SYLLABLE TYELM")
(53647 . "HANGUL SYLLABLE TYELB")
(53648 . "HANGUL SYLLABLE TYELS")
(53649 . "HANGUL SYLLABLE TYELT")
(53650 . "HANGUL SYLLABLE TYELP")
(53651 . "HANGUL SYLLABLE TYELH")
(53652 . "HANGUL SYLLABLE TYEM")
(53653 . "HANGUL SYLLABLE TYEB")
(53654 . "HANGUL SYLLABLE TYEBS")
(53655 . "HANGUL SYLLABLE TYES")
(53656 . "HANGUL SYLLABLE TYESS")
(53657 . "HANGUL SYLLABLE TYENG")
(53658 . "HANGUL SYLLABLE TYEJ")
(53659 . "HANGUL SYLLABLE TYEC")
(53660 . "HANGUL SYLLABLE TYEK")
(53661 . "HANGUL SYLLABLE TYET")
(53662 . "HANGUL SYLLABLE TYEP")
(53663 . "HANGUL SYLLABLE TYEH")
(53664 . "HANGUL SYLLABLE TO")
(53665 . "HANGUL SYLLABLE TOG")
(53666 . "HANGUL SYLLABLE TOGG")
(53667 . "HANGUL SYLLABLE TOGS")
(53668 . "HANGUL SYLLABLE TON")
(53669 . "HANGUL SYLLABLE TONJ")
(53670 . "HANGUL SYLLABLE TONH")
(53671 . "HANGUL SYLLABLE TOD")
(53672 . "HANGUL SYLLABLE TOL")
(53673 . "HANGUL SYLLABLE TOLG")
(53674 . "HANGUL SYLLABLE TOLM")
(53675 . "HANGUL SYLLABLE TOLB")
(53676 . "HANGUL SYLLABLE TOLS")
(53677 . "HANGUL SYLLABLE TOLT")
(53678 . "HANGUL SYLLABLE TOLP")
(53679 . "HANGUL SYLLABLE TOLH")
(53680 . "HANGUL SYLLABLE TOM")
(53681 . "HANGUL SYLLABLE TOB")
(53682 . "HANGUL SYLLABLE TOBS")
(53683 . "HANGUL SYLLABLE TOS")
(53684 . "HANGUL SYLLABLE TOSS")
(53685 . "HANGUL SYLLABLE TONG")
(53686 . "HANGUL SYLLABLE TOJ")
(53687 . "HANGUL SYLLABLE TOC")
(53688 . "HANGUL SYLLABLE TOK")
(53689 . "HANGUL SYLLABLE TOT")
(53690 . "HANGUL SYLLABLE TOP")
(53691 . "HANGUL SYLLABLE TOH")
(53692 . "HANGUL SYLLABLE TWA")
(53693 . "HANGUL SYLLABLE TWAG")
(53694 . "HANGUL SYLLABLE TWAGG")
(53695 . "HANGUL SYLLABLE TWAGS")
(53696 . "HANGUL SYLLABLE TWAN")
(53697 . "HANGUL SYLLABLE TWANJ")
(53698 . "HANGUL SYLLABLE TWANH")
(53699 . "HANGUL SYLLABLE TWAD")
(53700 . "HANGUL SYLLABLE TWAL")
(53701 . "HANGUL SYLLABLE TWALG")
(53702 . "HANGUL SYLLABLE TWALM")
(53703 . "HANGUL SYLLABLE TWALB")
(53704 . "HANGUL SYLLABLE TWALS")
(53705 . "HANGUL SYLLABLE TWALT")
(53706 . "HANGUL SYLLABLE TWALP")
(53707 . "HANGUL SYLLABLE TWALH")
(53708 . "HANGUL SYLLABLE TWAM")
(53709 . "HANGUL SYLLABLE TWAB")
(53710 . "HANGUL SYLLABLE TWABS")
(53711 . "HANGUL SYLLABLE TWAS")
(53712 . "HANGUL SYLLABLE TWASS")
(53713 . "HANGUL SYLLABLE TWANG")
(53714 . "HANGUL SYLLABLE TWAJ")
(53715 . "HANGUL SYLLABLE TWAC")
(53716 . "HANGUL SYLLABLE TWAK")
(53717 . "HANGUL SYLLABLE TWAT")
(53718 . "HANGUL SYLLABLE TWAP")
(53719 . "HANGUL SYLLABLE TWAH")
(53720 . "HANGUL SYLLABLE TWAE")
(53721 . "HANGUL SYLLABLE TWAEG")
(53722 . "HANGUL SYLLABLE TWAEGG")
(53723 . "HANGUL SYLLABLE TWAEGS")
(53724 . "HANGUL SYLLABLE TWAEN")
(53725 . "HANGUL SYLLABLE TWAENJ")
(53726 . "HANGUL SYLLABLE TWAENH")
(53727 . "HANGUL SYLLABLE TWAED")
(53728 . "HANGUL SYLLABLE TWAEL")
(53729 . "HANGUL SYLLABLE TWAELG")
(53730 . "HANGUL SYLLABLE TWAELM")
(53731 . "HANGUL SYLLABLE TWAELB")
(53732 . "HANGUL SYLLABLE TWAELS")
(53733 . "HANGUL SYLLABLE TWAELT")
(53734 . "HANGUL SYLLABLE TWAELP")
(53735 . "HANGUL SYLLABLE TWAELH")
(53736 . "HANGUL SYLLABLE TWAEM")
(53737 . "HANGUL SYLLABLE TWAEB")
(53738 . "HANGUL SYLLABLE TWAEBS")
(53739 . "HANGUL SYLLABLE TWAES")
(53740 . "HANGUL SYLLABLE TWAESS")
(53741 . "HANGUL SYLLABLE TWAENG")
(53742 . "HANGUL SYLLABLE TWAEJ")
(53743 . "HANGUL SYLLABLE TWAEC")
(53744 . "HANGUL SYLLABLE TWAEK")
(53745 . "HANGUL SYLLABLE TWAET")
(53746 . "HANGUL SYLLABLE TWAEP")
(53747 . "HANGUL SYLLABLE TWAEH")
(53748 . "HANGUL SYLLABLE TOE")
(53749 . "HANGUL SYLLABLE TOEG")
(53750 . "HANGUL SYLLABLE TOEGG")
(53751 . "HANGUL SYLLABLE TOEGS")
(53752 . "HANGUL SYLLABLE TOEN")
(53753 . "HANGUL SYLLABLE TOENJ")
(53754 . "HANGUL SYLLABLE TOENH")
(53755 . "HANGUL SYLLABLE TOED")
(53756 . "HANGUL SYLLABLE TOEL")
(53757 . "HANGUL SYLLABLE TOELG")
(53758 . "HANGUL SYLLABLE TOELM")
(53759 . "HANGUL SYLLABLE TOELB")
(53760 . "HANGUL SYLLABLE TOELS")
(53761 . "HANGUL SYLLABLE TOELT")
(53762 . "HANGUL SYLLABLE TOELP")
(53763 . "HANGUL SYLLABLE TOELH")
(53764 . "HANGUL SYLLABLE TOEM")
(53765 . "HANGUL SYLLABLE TOEB")
(53766 . "HANGUL SYLLABLE TOEBS")
(53767 . "HANGUL SYLLABLE TOES")
(53768 . "HANGUL SYLLABLE TOESS")
(53769 . "HANGUL SYLLABLE TOENG")
(53770 . "HANGUL SYLLABLE TOEJ")
(53771 . "HANGUL SYLLABLE TOEC")
(53772 . "HANGUL SYLLABLE TOEK")
(53773 . "HANGUL SYLLABLE TOET")
(53774 . "HANGUL SYLLABLE TOEP")
(53775 . "HANGUL SYLLABLE TOEH")
(53776 . "HANGUL SYLLABLE TYO")
(53777 . "HANGUL SYLLABLE TYOG")
(53778 . "HANGUL SYLLABLE TYOGG")
(53779 . "HANGUL SYLLABLE TYOGS")
(53780 . "HANGUL SYLLABLE TYON")
(53781 . "HANGUL SYLLABLE TYONJ")
(53782 . "HANGUL SYLLABLE TYONH")
(53783 . "HANGUL SYLLABLE TYOD")
(53784 . "HANGUL SYLLABLE TYOL")
(53785 . "HANGUL SYLLABLE TYOLG")
(53786 . "HANGUL SYLLABLE TYOLM")
(53787 . "HANGUL SYLLABLE TYOLB")
(53788 . "HANGUL SYLLABLE TYOLS")
(53789 . "HANGUL SYLLABLE TYOLT")
(53790 . "HANGUL SYLLABLE TYOLP")
(53791 . "HANGUL SYLLABLE TYOLH")
(53792 . "HANGUL SYLLABLE TYOM")
(53793 . "HANGUL SYLLABLE TYOB")
(53794 . "HANGUL SYLLABLE TYOBS")
(53795 . "HANGUL SYLLABLE TYOS")
(53796 . "HANGUL SYLLABLE TYOSS")
(53797 . "HANGUL SYLLABLE TYONG")
(53798 . "HANGUL SYLLABLE TYOJ")
(53799 . "HANGUL SYLLABLE TYOC")
(53800 . "HANGUL SYLLABLE TYOK")
(53801 . "HANGUL SYLLABLE TYOT")
(53802 . "HANGUL SYLLABLE TYOP")
(53803 . "HANGUL SYLLABLE TYOH")
(53804 . "HANGUL SYLLABLE TU")
(53805 . "HANGUL SYLLABLE TUG")
(53806 . "HANGUL SYLLABLE TUGG")
(53807 . "HANGUL SYLLABLE TUGS")
(53808 . "HANGUL SYLLABLE TUN")
(53809 . "HANGUL SYLLABLE TUNJ")
(53810 . "HANGUL SYLLABLE TUNH")
(53811 . "HANGUL SYLLABLE TUD")
(53812 . "HANGUL SYLLABLE TUL")
(53813 . "HANGUL SYLLABLE TULG")
(53814 . "HANGUL SYLLABLE TULM")
(53815 . "HANGUL SYLLABLE TULB")
(53816 . "HANGUL SYLLABLE TULS")
(53817 . "HANGUL SYLLABLE TULT")
(53818 . "HANGUL SYLLABLE TULP")
(53819 . "HANGUL SYLLABLE TULH")
(53820 . "HANGUL SYLLABLE TUM")
(53821 . "HANGUL SYLLABLE TUB")
(53822 . "HANGUL SYLLABLE TUBS")
(53823 . "HANGUL SYLLABLE TUS")
(53824 . "HANGUL SYLLABLE TUSS")
(53825 . "HANGUL SYLLABLE TUNG")
(53826 . "HANGUL SYLLABLE TUJ")
(53827 . "HANGUL SYLLABLE TUC")
(53828 . "HANGUL SYLLABLE TUK")
(53829 . "HANGUL SYLLABLE TUT")
(53830 . "HANGUL SYLLABLE TUP")
(53831 . "HANGUL SYLLABLE TUH")
(53832 . "HANGUL SYLLABLE TWEO")
(53833 . "HANGUL SYLLABLE TWEOG")
(53834 . "HANGUL SYLLABLE TWEOGG")
(53835 . "HANGUL SYLLABLE TWEOGS")
(53836 . "HANGUL SYLLABLE TWEON")
(53837 . "HANGUL SYLLABLE TWEONJ")
(53838 . "HANGUL SYLLABLE TWEONH")
(53839 . "HANGUL SYLLABLE TWEOD")
(53840 . "HANGUL SYLLABLE TWEOL")
(53841 . "HANGUL SYLLABLE TWEOLG")
(53842 . "HANGUL SYLLABLE TWEOLM")
(53843 . "HANGUL SYLLABLE TWEOLB")
(53844 . "HANGUL SYLLABLE TWEOLS")
(53845 . "HANGUL SYLLABLE TWEOLT")
(53846 . "HANGUL SYLLABLE TWEOLP")
(53847 . "HANGUL SYLLABLE TWEOLH")
(53848 . "HANGUL SYLLABLE TWEOM")
(53849 . "HANGUL SYLLABLE TWEOB")
(53850 . "HANGUL SYLLABLE TWEOBS")
(53851 . "HANGUL SYLLABLE TWEOS")
(53852 . "HANGUL SYLLABLE TWEOSS")
(53853 . "HANGUL SYLLABLE TWEONG")
(53854 . "HANGUL SYLLABLE TWEOJ")
(53855 . "HANGUL SYLLABLE TWEOC")
(53856 . "HANGUL SYLLABLE TWEOK")
(53857 . "HANGUL SYLLABLE TWEOT")
(53858 . "HANGUL SYLLABLE TWEOP")
(53859 . "HANGUL SYLLABLE TWEOH")
(53860 . "HANGUL SYLLABLE TWE")
(53861 . "HANGUL SYLLABLE TWEG")
(53862 . "HANGUL SYLLABLE TWEGG")
(53863 . "HANGUL SYLLABLE TWEGS")
(53864 . "HANGUL SYLLABLE TWEN")
(53865 . "HANGUL SYLLABLE TWENJ")
(53866 . "HANGUL SYLLABLE TWENH")
(53867 . "HANGUL SYLLABLE TWED")
(53868 . "HANGUL SYLLABLE TWEL")
(53869 . "HANGUL SYLLABLE TWELG")
(53870 . "HANGUL SYLLABLE TWELM")
(53871 . "HANGUL SYLLABLE TWELB")
(53872 . "HANGUL SYLLABLE TWELS")
(53873 . "HANGUL SYLLABLE TWELT")
(53874 . "HANGUL SYLLABLE TWELP")
(53875 . "HANGUL SYLLABLE TWELH")
(53876 . "HANGUL SYLLABLE TWEM")
(53877 . "HANGUL SYLLABLE TWEB")
(53878 . "HANGUL SYLLABLE TWEBS")
(53879 . "HANGUL SYLLABLE TWES")
(53880 . "HANGUL SYLLABLE TWESS")
(53881 . "HANGUL SYLLABLE TWENG")
(53882 . "HANGUL SYLLABLE TWEJ")
(53883 . "HANGUL SYLLABLE TWEC")
(53884 . "HANGUL SYLLABLE TWEK")
(53885 . "HANGUL SYLLABLE TWET")
(53886 . "HANGUL SYLLABLE TWEP")
(53887 . "HANGUL SYLLABLE TWEH")
(53888 . "HANGUL SYLLABLE TWI")
(53889 . "HANGUL SYLLABLE TWIG")
(53890 . "HANGUL SYLLABLE TWIGG")
(53891 . "HANGUL SYLLABLE TWIGS")
(53892 . "HANGUL SYLLABLE TWIN")
(53893 . "HANGUL SYLLABLE TWINJ")
(53894 . "HANGUL SYLLABLE TWINH")
(53895 . "HANGUL SYLLABLE TWID")
(53896 . "HANGUL SYLLABLE TWIL")
(53897 . "HANGUL SYLLABLE TWILG")
(53898 . "HANGUL SYLLABLE TWILM")
(53899 . "HANGUL SYLLABLE TWILB")
(53900 . "HANGUL SYLLABLE TWILS")
(53901 . "HANGUL SYLLABLE TWILT")
(53902 . "HANGUL SYLLABLE TWILP")
(53903 . "HANGUL SYLLABLE TWILH")
(53904 . "HANGUL SYLLABLE TWIM")
(53905 . "HANGUL SYLLABLE TWIB")
(53906 . "HANGUL SYLLABLE TWIBS")
(53907 . "HANGUL SYLLABLE TWIS")
(53908 . "HANGUL SYLLABLE TWISS")
(53909 . "HANGUL SYLLABLE TWING")
(53910 . "HANGUL SYLLABLE TWIJ")
(53911 . "HANGUL SYLLABLE TWIC")
(53912 . "HANGUL SYLLABLE TWIK")
(53913 . "HANGUL SYLLABLE TWIT")
(53914 . "HANGUL SYLLABLE TWIP")
(53915 . "HANGUL SYLLABLE TWIH")
(53916 . "HANGUL SYLLABLE TYU")
(53917 . "HANGUL SYLLABLE TYUG")
(53918 . "HANGUL SYLLABLE TYUGG")
(53919 . "HANGUL SYLLABLE TYUGS")
(53920 . "HANGUL SYLLABLE TYUN")
(53921 . "HANGUL SYLLABLE TYUNJ")
(53922 . "HANGUL SYLLABLE TYUNH")
(53923 . "HANGUL SYLLABLE TYUD")
(53924 . "HANGUL SYLLABLE TYUL")
(53925 . "HANGUL SYLLABLE TYULG")
(53926 . "HANGUL SYLLABLE TYULM")
(53927 . "HANGUL SYLLABLE TYULB")
(53928 . "HANGUL SYLLABLE TYULS")
(53929 . "HANGUL SYLLABLE TYULT")
(53930 . "HANGUL SYLLABLE TYULP")
(53931 . "HANGUL SYLLABLE TYULH")
(53932 . "HANGUL SYLLABLE TYUM")
(53933 . "HANGUL SYLLABLE TYUB")
(53934 . "HANGUL SYLLABLE TYUBS")
(53935 . "HANGUL SYLLABLE TYUS")
(53936 . "HANGUL SYLLABLE TYUSS")
(53937 . "HANGUL SYLLABLE TYUNG")
(53938 . "HANGUL SYLLABLE TYUJ")
(53939 . "HANGUL SYLLABLE TYUC")
(53940 . "HANGUL SYLLABLE TYUK")
(53941 . "HANGUL SYLLABLE TYUT")
(53942 . "HANGUL SYLLABLE TYUP")
(53943 . "HANGUL SYLLABLE TYUH")
(53944 . "HANGUL SYLLABLE TEU")
(53945 . "HANGUL SYLLABLE TEUG")
(53946 . "HANGUL SYLLABLE TEUGG")
(53947 . "HANGUL SYLLABLE TEUGS")
(53948 . "HANGUL SYLLABLE TEUN")
(53949 . "HANGUL SYLLABLE TEUNJ")
(53950 . "HANGUL SYLLABLE TEUNH")
(53951 . "HANGUL SYLLABLE TEUD")
(53952 . "HANGUL SYLLABLE TEUL")
(53953 . "HANGUL SYLLABLE TEULG")
(53954 . "HANGUL SYLLABLE TEULM")
(53955 . "HANGUL SYLLABLE TEULB")
(53956 . "HANGUL SYLLABLE TEULS")
(53957 . "HANGUL SYLLABLE TEULT")
(53958 . "HANGUL SYLLABLE TEULP")
(53959 . "HANGUL SYLLABLE TEULH")
(53960 . "HANGUL SYLLABLE TEUM")
(53961 . "HANGUL SYLLABLE TEUB")
(53962 . "HANGUL SYLLABLE TEUBS")
(53963 . "HANGUL SYLLABLE TEUS")
(53964 . "HANGUL SYLLABLE TEUSS")
(53965 . "HANGUL SYLLABLE TEUNG")
(53966 . "HANGUL SYLLABLE TEUJ")
(53967 . "HANGUL SYLLABLE TEUC")
(53968 . "HANGUL SYLLABLE TEUK")
(53969 . "HANGUL SYLLABLE TEUT")
(53970 . "HANGUL SYLLABLE TEUP")
(53971 . "HANGUL SYLLABLE TEUH")
(53972 . "HANGUL SYLLABLE TYI")
(53973 . "HANGUL SYLLABLE TYIG")
(53974 . "HANGUL SYLLABLE TYIGG")
(53975 . "HANGUL SYLLABLE TYIGS")
(53976 . "HANGUL SYLLABLE TYIN")
(53977 . "HANGUL SYLLABLE TYINJ")
(53978 . "HANGUL SYLLABLE TYINH")
(53979 . "HANGUL SYLLABLE TYID")
(53980 . "HANGUL SYLLABLE TYIL")
(53981 . "HANGUL SYLLABLE TYILG")
(53982 . "HANGUL SYLLABLE TYILM")
(53983 . "HANGUL SYLLABLE TYILB")
(53984 . "HANGUL SYLLABLE TYILS")
(53985 . "HANGUL SYLLABLE TYILT")
(53986 . "HANGUL SYLLABLE TYILP")
(53987 . "HANGUL SYLLABLE TYILH")
(53988 . "HANGUL SYLLABLE TYIM")
(53989 . "HANGUL SYLLABLE TYIB")
(53990 . "HANGUL SYLLABLE TYIBS")
(53991 . "HANGUL SYLLABLE TYIS")
(53992 . "HANGUL SYLLABLE TYISS")
(53993 . "HANGUL SYLLABLE TYING")
(53994 . "HANGUL SYLLABLE TYIJ")
(53995 . "HANGUL SYLLABLE TYIC")
(53996 . "HANGUL SYLLABLE TYIK")
(53997 . "HANGUL SYLLABLE TYIT")
(53998 . "HANGUL SYLLABLE TYIP")
(53999 . "HANGUL SYLLABLE TYIH")
(54000 . "HANGUL SYLLABLE TI")
(54001 . "HANGUL SYLLABLE TIG")
(54002 . "HANGUL SYLLABLE TIGG")
(54003 . "HANGUL SYLLABLE TIGS")
(54004 . "HANGUL SYLLABLE TIN")
(54005 . "HANGUL SYLLABLE TINJ")
(54006 . "HANGUL SYLLABLE TINH")
(54007 . "HANGUL SYLLABLE TID")
(54008 . "HANGUL SYLLABLE TIL")
(54009 . "HANGUL SYLLABLE TILG")
(54010 . "HANGUL SYLLABLE TILM")
(54011 . "HANGUL SYLLABLE TILB")
(54012 . "HANGUL SYLLABLE TILS")
(54013 . "HANGUL SYLLABLE TILT")
(54014 . "HANGUL SYLLABLE TILP")
(54015 . "HANGUL SYLLABLE TILH")
(54016 . "HANGUL SYLLABLE TIM")
(54017 . "HANGUL SYLLABLE TIB")
(54018 . "HANGUL SYLLABLE TIBS")
(54019 . "HANGUL SYLLABLE TIS")
(54020 . "HANGUL SYLLABLE TISS")
(54021 . "HANGUL SYLLABLE TING")
(54022 . "HANGUL SYLLABLE TIJ")
(54023 . "HANGUL SYLLABLE TIC")
(54024 . "HANGUL SYLLABLE TIK")
(54025 . "HANGUL SYLLABLE TIT")
(54026 . "HANGUL SYLLABLE TIP")
(54027 . "HANGUL SYLLABLE TIH")
(54028 . "HANGUL SYLLABLE PA")
(54029 . "HANGUL SYLLABLE PAG")
(54030 . "HANGUL SYLLABLE PAGG")
(54031 . "HANGUL SYLLABLE PAGS")
(54032 . "HANGUL SYLLABLE PAN")
(54033 . "HANGUL SYLLABLE PANJ")
(54034 . "HANGUL SYLLABLE PANH")
(54035 . "HANGUL SYLLABLE PAD")
(54036 . "HANGUL SYLLABLE PAL")
(54037 . "HANGUL SYLLABLE PALG")
(54038 . "HANGUL SYLLABLE PALM")
(54039 . "HANGUL SYLLABLE PALB")
(54040 . "HANGUL SYLLABLE PALS")
(54041 . "HANGUL SYLLABLE PALT")
(54042 . "HANGUL SYLLABLE PALP")
(54043 . "HANGUL SYLLABLE PALH")
(54044 . "HANGUL SYLLABLE PAM")
(54045 . "HANGUL SYLLABLE PAB")
(54046 . "HANGUL SYLLABLE PABS")
(54047 . "HANGUL SYLLABLE PAS")
(54048 . "HANGUL SYLLABLE PASS")
(54049 . "HANGUL SYLLABLE PANG")
(54050 . "HANGUL SYLLABLE PAJ")
(54051 . "HANGUL SYLLABLE PAC")
(54052 . "HANGUL SYLLABLE PAK")
(54053 . "HANGUL SYLLABLE PAT")
(54054 . "HANGUL SYLLABLE PAP")
(54055 . "HANGUL SYLLABLE PAH")
(54056 . "HANGUL SYLLABLE PAE")
(54057 . "HANGUL SYLLABLE PAEG")
(54058 . "HANGUL SYLLABLE PAEGG")
(54059 . "HANGUL SYLLABLE PAEGS")
(54060 . "HANGUL SYLLABLE PAEN")
(54061 . "HANGUL SYLLABLE PAENJ")
(54062 . "HANGUL SYLLABLE PAENH")
(54063 . "HANGUL SYLLABLE PAED")
(54064 . "HANGUL SYLLABLE PAEL")
(54065 . "HANGUL SYLLABLE PAELG")
(54066 . "HANGUL SYLLABLE PAELM")
(54067 . "HANGUL SYLLABLE PAELB")
(54068 . "HANGUL SYLLABLE PAELS")
(54069 . "HANGUL SYLLABLE PAELT")
(54070 . "HANGUL SYLLABLE PAELP")
(54071 . "HANGUL SYLLABLE PAELH")
(54072 . "HANGUL SYLLABLE PAEM")
(54073 . "HANGUL SYLLABLE PAEB")
(54074 . "HANGUL SYLLABLE PAEBS")
(54075 . "HANGUL SYLLABLE PAES")
(54076 . "HANGUL SYLLABLE PAESS")
(54077 . "HANGUL SYLLABLE PAENG")
(54078 . "HANGUL SYLLABLE PAEJ")
(54079 . "HANGUL SYLLABLE PAEC")
(54080 . "HANGUL SYLLABLE PAEK")
(54081 . "HANGUL SYLLABLE PAET")
(54082 . "HANGUL SYLLABLE PAEP")
(54083 . "HANGUL SYLLABLE PAEH")
(54084 . "HANGUL SYLLABLE PYA")
(54085 . "HANGUL SYLLABLE PYAG")
(54086 . "HANGUL SYLLABLE PYAGG")
(54087 . "HANGUL SYLLABLE PYAGS")
(54088 . "HANGUL SYLLABLE PYAN")
(54089 . "HANGUL SYLLABLE PYANJ")
(54090 . "HANGUL SYLLABLE PYANH")
(54091 . "HANGUL SYLLABLE PYAD")
(54092 . "HANGUL SYLLABLE PYAL")
(54093 . "HANGUL SYLLABLE PYALG")
(54094 . "HANGUL SYLLABLE PYALM")
(54095 . "HANGUL SYLLABLE PYALB")
(54096 . "HANGUL SYLLABLE PYALS")
(54097 . "HANGUL SYLLABLE PYALT")
(54098 . "HANGUL SYLLABLE PYALP")
(54099 . "HANGUL SYLLABLE PYALH")
(54100 . "HANGUL SYLLABLE PYAM")
(54101 . "HANGUL SYLLABLE PYAB")
(54102 . "HANGUL SYLLABLE PYABS")
(54103 . "HANGUL SYLLABLE PYAS")
(54104 . "HANGUL SYLLABLE PYASS")
(54105 . "HANGUL SYLLABLE PYANG")
(54106 . "HANGUL SYLLABLE PYAJ")
(54107 . "HANGUL SYLLABLE PYAC")
(54108 . "HANGUL SYLLABLE PYAK")
(54109 . "HANGUL SYLLABLE PYAT")
(54110 . "HANGUL SYLLABLE PYAP")
(54111 . "HANGUL SYLLABLE PYAH")
(54112 . "HANGUL SYLLABLE PYAE")
(54113 . "HANGUL SYLLABLE PYAEG")
(54114 . "HANGUL SYLLABLE PYAEGG")
(54115 . "HANGUL SYLLABLE PYAEGS")
(54116 . "HANGUL SYLLABLE PYAEN")
(54117 . "HANGUL SYLLABLE PYAENJ")
(54118 . "HANGUL SYLLABLE PYAENH")
(54119 . "HANGUL SYLLABLE PYAED")
(54120 . "HANGUL SYLLABLE PYAEL")
(54121 . "HANGUL SYLLABLE PYAELG")
(54122 . "HANGUL SYLLABLE PYAELM")
(54123 . "HANGUL SYLLABLE PYAELB")
(54124 . "HANGUL SYLLABLE PYAELS")
(54125 . "HANGUL SYLLABLE PYAELT")
(54126 . "HANGUL SYLLABLE PYAELP")
(54127 . "HANGUL SYLLABLE PYAELH")
(54128 . "HANGUL SYLLABLE PYAEM")
(54129 . "HANGUL SYLLABLE PYAEB")
(54130 . "HANGUL SYLLABLE PYAEBS")
(54131 . "HANGUL SYLLABLE PYAES")
(54132 . "HANGUL SYLLABLE PYAESS")
(54133 . "HANGUL SYLLABLE PYAENG")
(54134 . "HANGUL SYLLABLE PYAEJ")
(54135 . "HANGUL SYLLABLE PYAEC")
(54136 . "HANGUL SYLLABLE PYAEK")
(54137 . "HANGUL SYLLABLE PYAET")
(54138 . "HANGUL SYLLABLE PYAEP")
(54139 . "HANGUL SYLLABLE PYAEH")
(54140 . "HANGUL SYLLABLE PEO")
(54141 . "HANGUL SYLLABLE PEOG")
(54142 . "HANGUL SYLLABLE PEOGG")
(54143 . "HANGUL SYLLABLE PEOGS")
(54144 . "HANGUL SYLLABLE PEON")
(54145 . "HANGUL SYLLABLE PEONJ")
(54146 . "HANGUL SYLLABLE PEONH")
(54147 . "HANGUL SYLLABLE PEOD")
(54148 . "HANGUL SYLLABLE PEOL")
(54149 . "HANGUL SYLLABLE PEOLG")
(54150 . "HANGUL SYLLABLE PEOLM")
(54151 . "HANGUL SYLLABLE PEOLB")
(54152 . "HANGUL SYLLABLE PEOLS")
(54153 . "HANGUL SYLLABLE PEOLT")
(54154 . "HANGUL SYLLABLE PEOLP")
(54155 . "HANGUL SYLLABLE PEOLH")
(54156 . "HANGUL SYLLABLE PEOM")
(54157 . "HANGUL SYLLABLE PEOB")
(54158 . "HANGUL SYLLABLE PEOBS")
(54159 . "HANGUL SYLLABLE PEOS")
(54160 . "HANGUL SYLLABLE PEOSS")
(54161 . "HANGUL SYLLABLE PEONG")
(54162 . "HANGUL SYLLABLE PEOJ")
(54163 . "HANGUL SYLLABLE PEOC")
(54164 . "HANGUL SYLLABLE PEOK")
(54165 . "HANGUL SYLLABLE PEOT")
(54166 . "HANGUL SYLLABLE PEOP")
(54167 . "HANGUL SYLLABLE PEOH")
(54168 . "HANGUL SYLLABLE PE")
(54169 . "HANGUL SYLLABLE PEG")
(54170 . "HANGUL SYLLABLE PEGG")
(54171 . "HANGUL SYLLABLE PEGS")
(54172 . "HANGUL SYLLABLE PEN")
(54173 . "HANGUL SYLLABLE PENJ")
(54174 . "HANGUL SYLLABLE PENH")
(54175 . "HANGUL SYLLABLE PED")
(54176 . "HANGUL SYLLABLE PEL")
(54177 . "HANGUL SYLLABLE PELG")
(54178 . "HANGUL SYLLABLE PELM")
(54179 . "HANGUL SYLLABLE PELB")
(54180 . "HANGUL SYLLABLE PELS")
(54181 . "HANGUL SYLLABLE PELT")
(54182 . "HANGUL SYLLABLE PELP")
(54183 . "HANGUL SYLLABLE PELH")
(54184 . "HANGUL SYLLABLE PEM")
(54185 . "HANGUL SYLLABLE PEB")
(54186 . "HANGUL SYLLABLE PEBS")
(54187 . "HANGUL SYLLABLE PES")
(54188 . "HANGUL SYLLABLE PESS")
(54189 . "HANGUL SYLLABLE PENG")
(54190 . "HANGUL SYLLABLE PEJ")
(54191 . "HANGUL SYLLABLE PEC")
(54192 . "HANGUL SYLLABLE PEK")
(54193 . "HANGUL SYLLABLE PET")
(54194 . "HANGUL SYLLABLE PEP")
(54195 . "HANGUL SYLLABLE PEH")
(54196 . "HANGUL SYLLABLE PYEO")
(54197 . "HANGUL SYLLABLE PYEOG")
(54198 . "HANGUL SYLLABLE PYEOGG")
(54199 . "HANGUL SYLLABLE PYEOGS")
(54200 . "HANGUL SYLLABLE PYEON")
(54201 . "HANGUL SYLLABLE PYEONJ")
(54202 . "HANGUL SYLLABLE PYEONH")
(54203 . "HANGUL SYLLABLE PYEOD")
(54204 . "HANGUL SYLLABLE PYEOL")
(54205 . "HANGUL SYLLABLE PYEOLG")
(54206 . "HANGUL SYLLABLE PYEOLM")
(54207 . "HANGUL SYLLABLE PYEOLB")
(54208 . "HANGUL SYLLABLE PYEOLS")
(54209 . "HANGUL SYLLABLE PYEOLT")
(54210 . "HANGUL SYLLABLE PYEOLP")
(54211 . "HANGUL SYLLABLE PYEOLH")
(54212 . "HANGUL SYLLABLE PYEOM")
(54213 . "HANGUL SYLLABLE PYEOB")
(54214 . "HANGUL SYLLABLE PYEOBS")
(54215 . "HANGUL SYLLABLE PYEOS")
(54216 . "HANGUL SYLLABLE PYEOSS")
(54217 . "HANGUL SYLLABLE PYEONG")
(54218 . "HANGUL SYLLABLE PYEOJ")
(54219 . "HANGUL SYLLABLE PYEOC")
(54220 . "HANGUL SYLLABLE PYEOK")
(54221 . "HANGUL SYLLABLE PYEOT")
(54222 . "HANGUL SYLLABLE PYEOP")
(54223 . "HANGUL SYLLABLE PYEOH")
(54224 . "HANGUL SYLLABLE PYE")
(54225 . "HANGUL SYLLABLE PYEG")
(54226 . "HANGUL SYLLABLE PYEGG")
(54227 . "HANGUL SYLLABLE PYEGS")
(54228 . "HANGUL SYLLABLE PYEN")
(54229 . "HANGUL SYLLABLE PYENJ")
(54230 . "HANGUL SYLLABLE PYENH")
(54231 . "HANGUL SYLLABLE PYED")
(54232 . "HANGUL SYLLABLE PYEL")
(54233 . "HANGUL SYLLABLE PYELG")
(54234 . "HANGUL SYLLABLE PYELM")
(54235 . "HANGUL SYLLABLE PYELB")
(54236 . "HANGUL SYLLABLE PYELS")
(54237 . "HANGUL SYLLABLE PYELT")
(54238 . "HANGUL SYLLABLE PYELP")
(54239 . "HANGUL SYLLABLE PYELH")
(54240 . "HANGUL SYLLABLE PYEM")
(54241 . "HANGUL SYLLABLE PYEB")
(54242 . "HANGUL SYLLABLE PYEBS")
(54243 . "HANGUL SYLLABLE PYES")
(54244 . "HANGUL SYLLABLE PYESS")
(54245 . "HANGUL SYLLABLE PYENG")
(54246 . "HANGUL SYLLABLE PYEJ")
(54247 . "HANGUL SYLLABLE PYEC")
(54248 . "HANGUL SYLLABLE PYEK")
(54249 . "HANGUL SYLLABLE PYET")
(54250 . "HANGUL SYLLABLE PYEP")
(54251 . "HANGUL SYLLABLE PYEH")
(54252 . "HANGUL SYLLABLE PO")
(54253 . "HANGUL SYLLABLE POG")
(54254 . "HANGUL SYLLABLE POGG")
(54255 . "HANGUL SYLLABLE POGS")
(54256 . "HANGUL SYLLABLE PON")
(54257 . "HANGUL SYLLABLE PONJ")
(54258 . "HANGUL SYLLABLE PONH")
(54259 . "HANGUL SYLLABLE POD")
(54260 . "HANGUL SYLLABLE POL")
(54261 . "HANGUL SYLLABLE POLG")
(54262 . "HANGUL SYLLABLE POLM")
(54263 . "HANGUL SYLLABLE POLB")
(54264 . "HANGUL SYLLABLE POLS")
(54265 . "HANGUL SYLLABLE POLT")
(54266 . "HANGUL SYLLABLE POLP")
(54267 . "HANGUL SYLLABLE POLH")
(54268 . "HANGUL SYLLABLE POM")
(54269 . "HANGUL SYLLABLE POB")
(54270 . "HANGUL SYLLABLE POBS")
(54271 . "HANGUL SYLLABLE POS")
(54272 . "HANGUL SYLLABLE POSS")
(54273 . "HANGUL SYLLABLE PONG")
(54274 . "HANGUL SYLLABLE POJ")
(54275 . "HANGUL SYLLABLE POC")
(54276 . "HANGUL SYLLABLE POK")
(54277 . "HANGUL SYLLABLE POT")
(54278 . "HANGUL SYLLABLE POP")
(54279 . "HANGUL SYLLABLE POH")
(54280 . "HANGUL SYLLABLE PWA")
(54281 . "HANGUL SYLLABLE PWAG")
(54282 . "HANGUL SYLLABLE PWAGG")
(54283 . "HANGUL SYLLABLE PWAGS")
(54284 . "HANGUL SYLLABLE PWAN")
(54285 . "HANGUL SYLLABLE PWANJ")
(54286 . "HANGUL SYLLABLE PWANH")
(54287 . "HANGUL SYLLABLE PWAD")
(54288 . "HANGUL SYLLABLE PWAL")
(54289 . "HANGUL SYLLABLE PWALG")
(54290 . "HANGUL SYLLABLE PWALM")
(54291 . "HANGUL SYLLABLE PWALB")
(54292 . "HANGUL SYLLABLE PWALS")
(54293 . "HANGUL SYLLABLE PWALT")
(54294 . "HANGUL SYLLABLE PWALP")
(54295 . "HANGUL SYLLABLE PWALH")
(54296 . "HANGUL SYLLABLE PWAM")
(54297 . "HANGUL SYLLABLE PWAB")
(54298 . "HANGUL SYLLABLE PWABS")
(54299 . "HANGUL SYLLABLE PWAS")
(54300 . "HANGUL SYLLABLE PWASS")
(54301 . "HANGUL SYLLABLE PWANG")
(54302 . "HANGUL SYLLABLE PWAJ")
(54303 . "HANGUL SYLLABLE PWAC")
(54304 . "HANGUL SYLLABLE PWAK")
(54305 . "HANGUL SYLLABLE PWAT")
(54306 . "HANGUL SYLLABLE PWAP")
(54307 . "HANGUL SYLLABLE PWAH")
(54308 . "HANGUL SYLLABLE PWAE")
(54309 . "HANGUL SYLLABLE PWAEG")
(54310 . "HANGUL SYLLABLE PWAEGG")
(54311 . "HANGUL SYLLABLE PWAEGS")
(54312 . "HANGUL SYLLABLE PWAEN")
(54313 . "HANGUL SYLLABLE PWAENJ")
(54314 . "HANGUL SYLLABLE PWAENH")
(54315 . "HANGUL SYLLABLE PWAED")
(54316 . "HANGUL SYLLABLE PWAEL")
(54317 . "HANGUL SYLLABLE PWAELG")
(54318 . "HANGUL SYLLABLE PWAELM")
(54319 . "HANGUL SYLLABLE PWAELB")
(54320 . "HANGUL SYLLABLE PWAELS")
(54321 . "HANGUL SYLLABLE PWAELT")
(54322 . "HANGUL SYLLABLE PWAELP")
(54323 . "HANGUL SYLLABLE PWAELH")
(54324 . "HANGUL SYLLABLE PWAEM")
(54325 . "HANGUL SYLLABLE PWAEB")
(54326 . "HANGUL SYLLABLE PWAEBS")
(54327 . "HANGUL SYLLABLE PWAES")
(54328 . "HANGUL SYLLABLE PWAESS")
(54329 . "HANGUL SYLLABLE PWAENG")
(54330 . "HANGUL SYLLABLE PWAEJ")
(54331 . "HANGUL SYLLABLE PWAEC")
(54332 . "HANGUL SYLLABLE PWAEK")
(54333 . "HANGUL SYLLABLE PWAET")
(54334 . "HANGUL SYLLABLE PWAEP")
(54335 . "HANGUL SYLLABLE PWAEH")
(54336 . "HANGUL SYLLABLE POE")
(54337 . "HANGUL SYLLABLE POEG")
(54338 . "HANGUL SYLLABLE POEGG")
(54339 . "HANGUL SYLLABLE POEGS")
(54340 . "HANGUL SYLLABLE POEN")
(54341 . "HANGUL SYLLABLE POENJ")
(54342 . "HANGUL SYLLABLE POENH")
(54343 . "HANGUL SYLLABLE POED")
(54344 . "HANGUL SYLLABLE POEL")
(54345 . "HANGUL SYLLABLE POELG")
(54346 . "HANGUL SYLLABLE POELM")
(54347 . "HANGUL SYLLABLE POELB")
(54348 . "HANGUL SYLLABLE POELS")
(54349 . "HANGUL SYLLABLE POELT")
(54350 . "HANGUL SYLLABLE POELP")
(54351 . "HANGUL SYLLABLE POELH")
(54352 . "HANGUL SYLLABLE POEM")
(54353 . "HANGUL SYLLABLE POEB")
(54354 . "HANGUL SYLLABLE POEBS")
(54355 . "HANGUL SYLLABLE POES")
(54356 . "HANGUL SYLLABLE POESS")
(54357 . "HANGUL SYLLABLE POENG")
(54358 . "HANGUL SYLLABLE POEJ")
(54359 . "HANGUL SYLLABLE POEC")
(54360 . "HANGUL SYLLABLE POEK")
(54361 . "HANGUL SYLLABLE POET")
(54362 . "HANGUL SYLLABLE POEP")
(54363 . "HANGUL SYLLABLE POEH")
(54364 . "HANGUL SYLLABLE PYO")
(54365 . "HANGUL SYLLABLE PYOG")
(54366 . "HANGUL SYLLABLE PYOGG")
(54367 . "HANGUL SYLLABLE PYOGS")
(54368 . "HANGUL SYLLABLE PYON")
(54369 . "HANGUL SYLLABLE PYONJ")
(54370 . "HANGUL SYLLABLE PYONH")
(54371 . "HANGUL SYLLABLE PYOD")
(54372 . "HANGUL SYLLABLE PYOL")
(54373 . "HANGUL SYLLABLE PYOLG")
(54374 . "HANGUL SYLLABLE PYOLM")
(54375 . "HANGUL SYLLABLE PYOLB")
(54376 . "HANGUL SYLLABLE PYOLS")
(54377 . "HANGUL SYLLABLE PYOLT")
(54378 . "HANGUL SYLLABLE PYOLP")
(54379 . "HANGUL SYLLABLE PYOLH")
(54380 . "HANGUL SYLLABLE PYOM")
(54381 . "HANGUL SYLLABLE PYOB")
(54382 . "HANGUL SYLLABLE PYOBS")
(54383 . "HANGUL SYLLABLE PYOS")
(54384 . "HANGUL SYLLABLE PYOSS")
(54385 . "HANGUL SYLLABLE PYONG")
(54386 . "HANGUL SYLLABLE PYOJ")
(54387 . "HANGUL SYLLABLE PYOC")
(54388 . "HANGUL SYLLABLE PYOK")
(54389 . "HANGUL SYLLABLE PYOT")
(54390 . "HANGUL SYLLABLE PYOP")
(54391 . "HANGUL SYLLABLE PYOH")
(54392 . "HANGUL SYLLABLE PU")
(54393 . "HANGUL SYLLABLE PUG")
(54394 . "HANGUL SYLLABLE PUGG")
(54395 . "HANGUL SYLLABLE PUGS")
(54396 . "HANGUL SYLLABLE PUN")
(54397 . "HANGUL SYLLABLE PUNJ")
(54398 . "HANGUL SYLLABLE PUNH")
(54399 . "HANGUL SYLLABLE PUD")
(54400 . "HANGUL SYLLABLE PUL")
(54401 . "HANGUL SYLLABLE PULG")
(54402 . "HANGUL SYLLABLE PULM")
(54403 . "HANGUL SYLLABLE PULB")
(54404 . "HANGUL SYLLABLE PULS")
(54405 . "HANGUL SYLLABLE PULT")
(54406 . "HANGUL SYLLABLE PULP")
(54407 . "HANGUL SYLLABLE PULH")
(54408 . "HANGUL SYLLABLE PUM")
(54409 . "HANGUL SYLLABLE PUB")
(54410 . "HANGUL SYLLABLE PUBS")
(54411 . "HANGUL SYLLABLE PUS")
(54412 . "HANGUL SYLLABLE PUSS")
(54413 . "HANGUL SYLLABLE PUNG")
(54414 . "HANGUL SYLLABLE PUJ")
(54415 . "HANGUL SYLLABLE PUC")
(54416 . "HANGUL SYLLABLE PUK")
(54417 . "HANGUL SYLLABLE PUT")
(54418 . "HANGUL SYLLABLE PUP")
(54419 . "HANGUL SYLLABLE PUH")
(54420 . "HANGUL SYLLABLE PWEO")
(54421 . "HANGUL SYLLABLE PWEOG")
(54422 . "HANGUL SYLLABLE PWEOGG")
(54423 . "HANGUL SYLLABLE PWEOGS")
(54424 . "HANGUL SYLLABLE PWEON")
(54425 . "HANGUL SYLLABLE PWEONJ")
(54426 . "HANGUL SYLLABLE PWEONH")
(54427 . "HANGUL SYLLABLE PWEOD")
(54428 . "HANGUL SYLLABLE PWEOL")
(54429 . "HANGUL SYLLABLE PWEOLG")
(54430 . "HANGUL SYLLABLE PWEOLM")
(54431 . "HANGUL SYLLABLE PWEOLB")
(54432 . "HANGUL SYLLABLE PWEOLS")
(54433 . "HANGUL SYLLABLE PWEOLT")
(54434 . "HANGUL SYLLABLE PWEOLP")
(54435 . "HANGUL SYLLABLE PWEOLH")
(54436 . "HANGUL SYLLABLE PWEOM")
(54437 . "HANGUL SYLLABLE PWEOB")
(54438 . "HANGUL SYLLABLE PWEOBS")
(54439 . "HANGUL SYLLABLE PWEOS")
(54440 . "HANGUL SYLLABLE PWEOSS")
(54441 . "HANGUL SYLLABLE PWEONG")
(54442 . "HANGUL SYLLABLE PWEOJ")
(54443 . "HANGUL SYLLABLE PWEOC")
(54444 . "HANGUL SYLLABLE PWEOK")
(54445 . "HANGUL SYLLABLE PWEOT")
(54446 . "HANGUL SYLLABLE PWEOP")
(54447 . "HANGUL SYLLABLE PWEOH")
(54448 . "HANGUL SYLLABLE PWE")
(54449 . "HANGUL SYLLABLE PWEG")
(54450 . "HANGUL SYLLABLE PWEGG")
(54451 . "HANGUL SYLLABLE PWEGS")
(54452 . "HANGUL SYLLABLE PWEN")
(54453 . "HANGUL SYLLABLE PWENJ")
(54454 . "HANGUL SYLLABLE PWENH")
(54455 . "HANGUL SYLLABLE PWED")
(54456 . "HANGUL SYLLABLE PWEL")
(54457 . "HANGUL SYLLABLE PWELG")
(54458 . "HANGUL SYLLABLE PWELM")
(54459 . "HANGUL SYLLABLE PWELB")
(54460 . "HANGUL SYLLABLE PWELS")
(54461 . "HANGUL SYLLABLE PWELT")
(54462 . "HANGUL SYLLABLE PWELP")
(54463 . "HANGUL SYLLABLE PWELH")
(54464 . "HANGUL SYLLABLE PWEM")
(54465 . "HANGUL SYLLABLE PWEB")
(54466 . "HANGUL SYLLABLE PWEBS")
(54467 . "HANGUL SYLLABLE PWES")
(54468 . "HANGUL SYLLABLE PWESS")
(54469 . "HANGUL SYLLABLE PWENG")
(54470 . "HANGUL SYLLABLE PWEJ")
(54471 . "HANGUL SYLLABLE PWEC")
(54472 . "HANGUL SYLLABLE PWEK")
(54473 . "HANGUL SYLLABLE PWET")
(54474 . "HANGUL SYLLABLE PWEP")
(54475 . "HANGUL SYLLABLE PWEH")
(54476 . "HANGUL SYLLABLE PWI")
(54477 . "HANGUL SYLLABLE PWIG")
(54478 . "HANGUL SYLLABLE PWIGG")
(54479 . "HANGUL SYLLABLE PWIGS")
(54480 . "HANGUL SYLLABLE PWIN")
(54481 . "HANGUL SYLLABLE PWINJ")
(54482 . "HANGUL SYLLABLE PWINH")
(54483 . "HANGUL SYLLABLE PWID")
(54484 . "HANGUL SYLLABLE PWIL")
(54485 . "HANGUL SYLLABLE PWILG")
(54486 . "HANGUL SYLLABLE PWILM")
(54487 . "HANGUL SYLLABLE PWILB")
(54488 . "HANGUL SYLLABLE PWILS")
(54489 . "HANGUL SYLLABLE PWILT")
(54490 . "HANGUL SYLLABLE PWILP")
(54491 . "HANGUL SYLLABLE PWILH")
(54492 . "HANGUL SYLLABLE PWIM")
(54493 . "HANGUL SYLLABLE PWIB")
(54494 . "HANGUL SYLLABLE PWIBS")
(54495 . "HANGUL SYLLABLE PWIS")
(54496 . "HANGUL SYLLABLE PWISS")
(54497 . "HANGUL SYLLABLE PWING")
(54498 . "HANGUL SYLLABLE PWIJ")
(54499 . "HANGUL SYLLABLE PWIC")
(54500 . "HANGUL SYLLABLE PWIK")
(54501 . "HANGUL SYLLABLE PWIT")
(54502 . "HANGUL SYLLABLE PWIP")
(54503 . "HANGUL SYLLABLE PWIH")
(54504 . "HANGUL SYLLABLE PYU")
(54505 . "HANGUL SYLLABLE PYUG")
(54506 . "HANGUL SYLLABLE PYUGG")
(54507 . "HANGUL SYLLABLE PYUGS")
(54508 . "HANGUL SYLLABLE PYUN")
(54509 . "HANGUL SYLLABLE PYUNJ")
(54510 . "HANGUL SYLLABLE PYUNH")
(54511 . "HANGUL SYLLABLE PYUD")
(54512 . "HANGUL SYLLABLE PYUL")
(54513 . "HANGUL SYLLABLE PYULG")
(54514 . "HANGUL SYLLABLE PYULM")
(54515 . "HANGUL SYLLABLE PYULB")
(54516 . "HANGUL SYLLABLE PYULS")
(54517 . "HANGUL SYLLABLE PYULT")
(54518 . "HANGUL SYLLABLE PYULP")
(54519 . "HANGUL SYLLABLE PYULH")
(54520 . "HANGUL SYLLABLE PYUM")
(54521 . "HANGUL SYLLABLE PYUB")
(54522 . "HANGUL SYLLABLE PYUBS")
(54523 . "HANGUL SYLLABLE PYUS")
(54524 . "HANGUL SYLLABLE PYUSS")
(54525 . "HANGUL SYLLABLE PYUNG")
(54526 . "HANGUL SYLLABLE PYUJ")
(54527 . "HANGUL SYLLABLE PYUC")
(54528 . "HANGUL SYLLABLE PYUK")
(54529 . "HANGUL SYLLABLE PYUT")
(54530 . "HANGUL SYLLABLE PYUP")
(54531 . "HANGUL SYLLABLE PYUH")
(54532 . "HANGUL SYLLABLE PEU")
(54533 . "HANGUL SYLLABLE PEUG")
(54534 . "HANGUL SYLLABLE PEUGG")
(54535 . "HANGUL SYLLABLE PEUGS")
(54536 . "HANGUL SYLLABLE PEUN")
(54537 . "HANGUL SYLLABLE PEUNJ")
(54538 . "HANGUL SYLLABLE PEUNH")
(54539 . "HANGUL SYLLABLE PEUD")
(54540 . "HANGUL SYLLABLE PEUL")
(54541 . "HANGUL SYLLABLE PEULG")
(54542 . "HANGUL SYLLABLE PEULM")
(54543 . "HANGUL SYLLABLE PEULB")
(54544 . "HANGUL SYLLABLE PEULS")
(54545 . "HANGUL SYLLABLE PEULT")
(54546 . "HANGUL SYLLABLE PEULP")
(54547 . "HANGUL SYLLABLE PEULH")
(54548 . "HANGUL SYLLABLE PEUM")
(54549 . "HANGUL SYLLABLE PEUB")
(54550 . "HANGUL SYLLABLE PEUBS")
(54551 . "HANGUL SYLLABLE PEUS")
(54552 . "HANGUL SYLLABLE PEUSS")
(54553 . "HANGUL SYLLABLE PEUNG")
(54554 . "HANGUL SYLLABLE PEUJ")
(54555 . "HANGUL SYLLABLE PEUC")
(54556 . "HANGUL SYLLABLE PEUK")
(54557 . "HANGUL SYLLABLE PEUT")
(54558 . "HANGUL SYLLABLE PEUP")
(54559 . "HANGUL SYLLABLE PEUH")
(54560 . "HANGUL SYLLABLE PYI")
(54561 . "HANGUL SYLLABLE PYIG")
(54562 . "HANGUL SYLLABLE PYIGG")
(54563 . "HANGUL SYLLABLE PYIGS")
(54564 . "HANGUL SYLLABLE PYIN")
(54565 . "HANGUL SYLLABLE PYINJ")
(54566 . "HANGUL SYLLABLE PYINH")
(54567 . "HANGUL SYLLABLE PYID")
(54568 . "HANGUL SYLLABLE PYIL")
(54569 . "HANGUL SYLLABLE PYILG")
(54570 . "HANGUL SYLLABLE PYILM")
(54571 . "HANGUL SYLLABLE PYILB")
(54572 . "HANGUL SYLLABLE PYILS")
(54573 . "HANGUL SYLLABLE PYILT")
(54574 . "HANGUL SYLLABLE PYILP")
(54575 . "HANGUL SYLLABLE PYILH")
(54576 . "HANGUL SYLLABLE PYIM")
(54577 . "HANGUL SYLLABLE PYIB")
(54578 . "HANGUL SYLLABLE PYIBS")
(54579 . "HANGUL SYLLABLE PYIS")
(54580 . "HANGUL SYLLABLE PYISS")
(54581 . "HANGUL SYLLABLE PYING")
(54582 . "HANGUL SYLLABLE PYIJ")
(54583 . "HANGUL SYLLABLE PYIC")
(54584 . "HANGUL SYLLABLE PYIK")
(54585 . "HANGUL SYLLABLE PYIT")
(54586 . "HANGUL SYLLABLE PYIP")
(54587 . "HANGUL SYLLABLE PYIH")
(54588 . "HANGUL SYLLABLE PI")
(54589 . "HANGUL SYLLABLE PIG")
(54590 . "HANGUL SYLLABLE PIGG")
(54591 . "HANGUL SYLLABLE PIGS")
(54592 . "HANGUL SYLLABLE PIN")
(54593 . "HANGUL SYLLABLE PINJ")
(54594 . "HANGUL SYLLABLE PINH")
(54595 . "HANGUL SYLLABLE PID")
(54596 . "HANGUL SYLLABLE PIL")
(54597 . "HANGUL SYLLABLE PILG")
(54598 . "HANGUL SYLLABLE PILM")
(54599 . "HANGUL SYLLABLE PILB")
(54600 . "HANGUL SYLLABLE PILS")
(54601 . "HANGUL SYLLABLE PILT")
(54602 . "HANGUL SYLLABLE PILP")
(54603 . "HANGUL SYLLABLE PILH")
(54604 . "HANGUL SYLLABLE PIM")
(54605 . "HANGUL SYLLABLE PIB")
(54606 . "HANGUL SYLLABLE PIBS")
(54607 . "HANGUL SYLLABLE PIS")
(54608 . "HANGUL SYLLABLE PISS")
(54609 . "HANGUL SYLLABLE PING")
(54610 . "HANGUL SYLLABLE PIJ")
(54611 . "HANGUL SYLLABLE PIC")
(54612 . "HANGUL SYLLABLE PIK")
(54613 . "HANGUL SYLLABLE PIT")
(54614 . "HANGUL SYLLABLE PIP")
(54615 . "HANGUL SYLLABLE PIH")
(54616 . "HANGUL SYLLABLE HA")
(54617 . "HANGUL SYLLABLE HAG")
(54618 . "HANGUL SYLLABLE HAGG")
(54619 . "HANGUL SYLLABLE HAGS")
(54620 . "HANGUL SYLLABLE HAN")
(54621 . "HANGUL SYLLABLE HANJ")
(54622 . "HANGUL SYLLABLE HANH")
(54623 . "HANGUL SYLLABLE HAD")
(54624 . "HANGUL SYLLABLE HAL")
(54625 . "HANGUL SYLLABLE HALG")
(54626 . "HANGUL SYLLABLE HALM")
(54627 . "HANGUL SYLLABLE HALB")
(54628 . "HANGUL SYLLABLE HALS")
(54629 . "HANGUL SYLLABLE HALT")
(54630 . "HANGUL SYLLABLE HALP")
(54631 . "HANGUL SYLLABLE HALH")
(54632 . "HANGUL SYLLABLE HAM")
(54633 . "HANGUL SYLLABLE HAB")
(54634 . "HANGUL SYLLABLE HABS")
(54635 . "HANGUL SYLLABLE HAS")
(54636 . "HANGUL SYLLABLE HASS")
(54637 . "HANGUL SYLLABLE HANG")
(54638 . "HANGUL SYLLABLE HAJ")
(54639 . "HANGUL SYLLABLE HAC")
(54640 . "HANGUL SYLLABLE HAK")
(54641 . "HANGUL SYLLABLE HAT")
(54642 . "HANGUL SYLLABLE HAP")
(54643 . "HANGUL SYLLABLE HAH")
(54644 . "HANGUL SYLLABLE HAE")
(54645 . "HANGUL SYLLABLE HAEG")
(54646 . "HANGUL SYLLABLE HAEGG")
(54647 . "HANGUL SYLLABLE HAEGS")
(54648 . "HANGUL SYLLABLE HAEN")
(54649 . "HANGUL SYLLABLE HAENJ")
(54650 . "HANGUL SYLLABLE HAENH")
(54651 . "HANGUL SYLLABLE HAED")
(54652 . "HANGUL SYLLABLE HAEL")
(54653 . "HANGUL SYLLABLE HAELG")
(54654 . "HANGUL SYLLABLE HAELM")
(54655 . "HANGUL SYLLABLE HAELB")
(54656 . "HANGUL SYLLABLE HAELS")
(54657 . "HANGUL SYLLABLE HAELT")
(54658 . "HANGUL SYLLABLE HAELP")
(54659 . "HANGUL SYLLABLE HAELH")
(54660 . "HANGUL SYLLABLE HAEM")
(54661 . "HANGUL SYLLABLE HAEB")
(54662 . "HANGUL SYLLABLE HAEBS")
(54663 . "HANGUL SYLLABLE HAES")
(54664 . "HANGUL SYLLABLE HAESS")
(54665 . "HANGUL SYLLABLE HAENG")
(54666 . "HANGUL SYLLABLE HAEJ")
(54667 . "HANGUL SYLLABLE HAEC")
(54668 . "HANGUL SYLLABLE HAEK")
(54669 . "HANGUL SYLLABLE HAET")
(54670 . "HANGUL SYLLABLE HAEP")
(54671 . "HANGUL SYLLABLE HAEH")
(54672 . "HANGUL SYLLABLE HYA")
(54673 . "HANGUL SYLLABLE HYAG")
(54674 . "HANGUL SYLLABLE HYAGG")
(54675 . "HANGUL SYLLABLE HYAGS")
(54676 . "HANGUL SYLLABLE HYAN")
(54677 . "HANGUL SYLLABLE HYANJ")
(54678 . "HANGUL SYLLABLE HYANH")
(54679 . "HANGUL SYLLABLE HYAD")
(54680 . "HANGUL SYLLABLE HYAL")
(54681 . "HANGUL SYLLABLE HYALG")
(54682 . "HANGUL SYLLABLE HYALM")
(54683 . "HANGUL SYLLABLE HYALB")
(54684 . "HANGUL SYLLABLE HYALS")
(54685 . "HANGUL SYLLABLE HYALT")
(54686 . "HANGUL SYLLABLE HYALP")
(54687 . "HANGUL SYLLABLE HYALH")
(54688 . "HANGUL SYLLABLE HYAM")
(54689 . "HANGUL SYLLABLE HYAB")
(54690 . "HANGUL SYLLABLE HYABS")
(54691 . "HANGUL SYLLABLE HYAS")
(54692 . "HANGUL SYLLABLE HYASS")
(54693 . "HANGUL SYLLABLE HYANG")
(54694 . "HANGUL SYLLABLE HYAJ")
(54695 . "HANGUL SYLLABLE HYAC")
(54696 . "HANGUL SYLLABLE HYAK")
(54697 . "HANGUL SYLLABLE HYAT")
(54698 . "HANGUL SYLLABLE HYAP")
(54699 . "HANGUL SYLLABLE HYAH")
(54700 . "HANGUL SYLLABLE HYAE")
(54701 . "HANGUL SYLLABLE HYAEG")
(54702 . "HANGUL SYLLABLE HYAEGG")
(54703 . "HANGUL SYLLABLE HYAEGS")
(54704 . "HANGUL SYLLABLE HYAEN")
(54705 . "HANGUL SYLLABLE HYAENJ")
(54706 . "HANGUL SYLLABLE HYAENH")
(54707 . "HANGUL SYLLABLE HYAED")
(54708 . "HANGUL SYLLABLE HYAEL")
(54709 . "HANGUL SYLLABLE HYAELG")
(54710 . "HANGUL SYLLABLE HYAELM")
(54711 . "HANGUL SYLLABLE HYAELB")
(54712 . "HANGUL SYLLABLE HYAELS")
(54713 . "HANGUL SYLLABLE HYAELT")
(54714 . "HANGUL SYLLABLE HYAELP")
(54715 . "HANGUL SYLLABLE HYAELH")
(54716 . "HANGUL SYLLABLE HYAEM")
(54717 . "HANGUL SYLLABLE HYAEB")
(54718 . "HANGUL SYLLABLE HYAEBS")
(54719 . "HANGUL SYLLABLE HYAES")
(54720 . "HANGUL SYLLABLE HYAESS")
(54721 . "HANGUL SYLLABLE HYAENG")
(54722 . "HANGUL SYLLABLE HYAEJ")
(54723 . "HANGUL SYLLABLE HYAEC")
(54724 . "HANGUL SYLLABLE HYAEK")
(54725 . "HANGUL SYLLABLE HYAET")
(54726 . "HANGUL SYLLABLE HYAEP")
(54727 . "HANGUL SYLLABLE HYAEH")
(54728 . "HANGUL SYLLABLE HEO")
(54729 . "HANGUL SYLLABLE HEOG")
(54730 . "HANGUL SYLLABLE HEOGG")
(54731 . "HANGUL SYLLABLE HEOGS")
(54732 . "HANGUL SYLLABLE HEON")
(54733 . "HANGUL SYLLABLE HEONJ")
(54734 . "HANGUL SYLLABLE HEONH")
(54735 . "HANGUL SYLLABLE HEOD")
(54736 . "HANGUL SYLLABLE HEOL")
(54737 . "HANGUL SYLLABLE HEOLG")
(54738 . "HANGUL SYLLABLE HEOLM")
(54739 . "HANGUL SYLLABLE HEOLB")
(54740 . "HANGUL SYLLABLE HEOLS")
(54741 . "HANGUL SYLLABLE HEOLT")
(54742 . "HANGUL SYLLABLE HEOLP")
(54743 . "HANGUL SYLLABLE HEOLH")
(54744 . "HANGUL SYLLABLE HEOM")
(54745 . "HANGUL SYLLABLE HEOB")
(54746 . "HANGUL SYLLABLE HEOBS")
(54747 . "HANGUL SYLLABLE HEOS")
(54748 . "HANGUL SYLLABLE HEOSS")
(54749 . "HANGUL SYLLABLE HEONG")
(54750 . "HANGUL SYLLABLE HEOJ")
(54751 . "HANGUL SYLLABLE HEOC")
(54752 . "HANGUL SYLLABLE HEOK")
(54753 . "HANGUL SYLLABLE HEOT")
(54754 . "HANGUL SYLLABLE HEOP")
(54755 . "HANGUL SYLLABLE HEOH")
(54756 . "HANGUL SYLLABLE HE")
(54757 . "HANGUL SYLLABLE HEG")
(54758 . "HANGUL SYLLABLE HEGG")
(54759 . "HANGUL SYLLABLE HEGS")
(54760 . "HANGUL SYLLABLE HEN")
(54761 . "HANGUL SYLLABLE HENJ")
(54762 . "HANGUL SYLLABLE HENH")
(54763 . "HANGUL SYLLABLE HED")
(54764 . "HANGUL SYLLABLE HEL")
(54765 . "HANGUL SYLLABLE HELG")
(54766 . "HANGUL SYLLABLE HELM")
(54767 . "HANGUL SYLLABLE HELB")
(54768 . "HANGUL SYLLABLE HELS")
(54769 . "HANGUL SYLLABLE HELT")
(54770 . "HANGUL SYLLABLE HELP")
(54771 . "HANGUL SYLLABLE HELH")
(54772 . "HANGUL SYLLABLE HEM")
(54773 . "HANGUL SYLLABLE HEB")
(54774 . "HANGUL SYLLABLE HEBS")
(54775 . "HANGUL SYLLABLE HES")
(54776 . "HANGUL SYLLABLE HESS")
(54777 . "HANGUL SYLLABLE HENG")
(54778 . "HANGUL SYLLABLE HEJ")
(54779 . "HANGUL SYLLABLE HEC")
(54780 . "HANGUL SYLLABLE HEK")
(54781 . "HANGUL SYLLABLE HET")
(54782 . "HANGUL SYLLABLE HEP")
(54783 . "HANGUL SYLLABLE HEH")
(54784 . "HANGUL SYLLABLE HYEO")
(54785 . "HANGUL SYLLABLE HYEOG")
(54786 . "HANGUL SYLLABLE HYEOGG")
(54787 . "HANGUL SYLLABLE HYEOGS")
(54788 . "HANGUL SYLLABLE HYEON")
(54789 . "HANGUL SYLLABLE HYEONJ")
(54790 . "HANGUL SYLLABLE HYEONH")
(54791 . "HANGUL SYLLABLE HYEOD")
(54792 . "HANGUL SYLLABLE HYEOL")
(54793 . "HANGUL SYLLABLE HYEOLG")
(54794 . "HANGUL SYLLABLE HYEOLM")
(54795 . "HANGUL SYLLABLE HYEOLB")
(54796 . "HANGUL SYLLABLE HYEOLS")
(54797 . "HANGUL SYLLABLE HYEOLT")
(54798 . "HANGUL SYLLABLE HYEOLP")
(54799 . "HANGUL SYLLABLE HYEOLH")
(54800 . "HANGUL SYLLABLE HYEOM")
(54801 . "HANGUL SYLLABLE HYEOB")
(54802 . "HANGUL SYLLABLE HYEOBS")
(54803 . "HANGUL SYLLABLE HYEOS")
(54804 . "HANGUL SYLLABLE HYEOSS")
(54805 . "HANGUL SYLLABLE HYEONG")
(54806 . "HANGUL SYLLABLE HYEOJ")
(54807 . "HANGUL SYLLABLE HYEOC")
(54808 . "HANGUL SYLLABLE HYEOK")
(54809 . "HANGUL SYLLABLE HYEOT")
(54810 . "HANGUL SYLLABLE HYEOP")
(54811 . "HANGUL SYLLABLE HYEOH")
(54812 . "HANGUL SYLLABLE HYE")
(54813 . "HANGUL SYLLABLE HYEG")
(54814 . "HANGUL SYLLABLE HYEGG")
(54815 . "HANGUL SYLLABLE HYEGS")
(54816 . "HANGUL SYLLABLE HYEN")
(54817 . "HANGUL SYLLABLE HYENJ")
(54818 . "HANGUL SYLLABLE HYENH")
(54819 . "HANGUL SYLLABLE HYED")
(54820 . "HANGUL SYLLABLE HYEL")
(54821 . "HANGUL SYLLABLE HYELG")
(54822 . "HANGUL SYLLABLE HYELM")
(54823 . "HANGUL SYLLABLE HYELB")
(54824 . "HANGUL SYLLABLE HYELS")
(54825 . "HANGUL SYLLABLE HYELT")
(54826 . "HANGUL SYLLABLE HYELP")
(54827 . "HANGUL SYLLABLE HYELH")
(54828 . "HANGUL SYLLABLE HYEM")
(54829 . "HANGUL SYLLABLE HYEB")
(54830 . "HANGUL SYLLABLE HYEBS")
(54831 . "HANGUL SYLLABLE HYES")
(54832 . "HANGUL SYLLABLE HYESS")
(54833 . "HANGUL SYLLABLE HYENG")
(54834 . "HANGUL SYLLABLE HYEJ")
(54835 . "HANGUL SYLLABLE HYEC")
(54836 . "HANGUL SYLLABLE HYEK")
(54837 . "HANGUL SYLLABLE HYET")
(54838 . "HANGUL SYLLABLE HYEP")
(54839 . "HANGUL SYLLABLE HYEH")
(54840 . "HANGUL SYLLABLE HO")
(54841 . "HANGUL SYLLABLE HOG")
(54842 . "HANGUL SYLLABLE HOGG")
(54843 . "HANGUL SYLLABLE HOGS")
(54844 . "HANGUL SYLLABLE HON")
(54845 . "HANGUL SYLLABLE HONJ")
(54846 . "HANGUL SYLLABLE HONH")
(54847 . "HANGUL SYLLABLE HOD")
(54848 . "HANGUL SYLLABLE HOL")
(54849 . "HANGUL SYLLABLE HOLG")
(54850 . "HANGUL SYLLABLE HOLM")
(54851 . "HANGUL SYLLABLE HOLB")
(54852 . "HANGUL SYLLABLE HOLS")
(54853 . "HANGUL SYLLABLE HOLT")
(54854 . "HANGUL SYLLABLE HOLP")
(54855 . "HANGUL SYLLABLE HOLH")
(54856 . "HANGUL SYLLABLE HOM")
(54857 . "HANGUL SYLLABLE HOB")
(54858 . "HANGUL SYLLABLE HOBS")
(54859 . "HANGUL SYLLABLE HOS")
(54860 . "HANGUL SYLLABLE HOSS")
(54861 . "HANGUL SYLLABLE HONG")
(54862 . "HANGUL SYLLABLE HOJ")
(54863 . "HANGUL SYLLABLE HOC")
(54864 . "HANGUL SYLLABLE HOK")
(54865 . "HANGUL SYLLABLE HOT")
(54866 . "HANGUL SYLLABLE HOP")
(54867 . "HANGUL SYLLABLE HOH")
(54868 . "HANGUL SYLLABLE HWA")
(54869 . "HANGUL SYLLABLE HWAG")
(54870 . "HANGUL SYLLABLE HWAGG")
(54871 . "HANGUL SYLLABLE HWAGS")
(54872 . "HANGUL SYLLABLE HWAN")
(54873 . "HANGUL SYLLABLE HWANJ")
(54874 . "HANGUL SYLLABLE HWANH")
(54875 . "HANGUL SYLLABLE HWAD")
(54876 . "HANGUL SYLLABLE HWAL")
(54877 . "HANGUL SYLLABLE HWALG")
(54878 . "HANGUL SYLLABLE HWALM")
(54879 . "HANGUL SYLLABLE HWALB")
(54880 . "HANGUL SYLLABLE HWALS")
(54881 . "HANGUL SYLLABLE HWALT")
(54882 . "HANGUL SYLLABLE HWALP")
(54883 . "HANGUL SYLLABLE HWALH")
(54884 . "HANGUL SYLLABLE HWAM")
(54885 . "HANGUL SYLLABLE HWAB")
(54886 . "HANGUL SYLLABLE HWABS")
(54887 . "HANGUL SYLLABLE HWAS")
(54888 . "HANGUL SYLLABLE HWASS")
(54889 . "HANGUL SYLLABLE HWANG")
(54890 . "HANGUL SYLLABLE HWAJ")
(54891 . "HANGUL SYLLABLE HWAC")
(54892 . "HANGUL SYLLABLE HWAK")
(54893 . "HANGUL SYLLABLE HWAT")
(54894 . "HANGUL SYLLABLE HWAP")
(54895 . "HANGUL SYLLABLE HWAH")
(54896 . "HANGUL SYLLABLE HWAE")
(54897 . "HANGUL SYLLABLE HWAEG")
(54898 . "HANGUL SYLLABLE HWAEGG")
(54899 . "HANGUL SYLLABLE HWAEGS")
(54900 . "HANGUL SYLLABLE HWAEN")
(54901 . "HANGUL SYLLABLE HWAENJ")
(54902 . "HANGUL SYLLABLE HWAENH")
(54903 . "HANGUL SYLLABLE HWAED")
(54904 . "HANGUL SYLLABLE HWAEL")
(54905 . "HANGUL SYLLABLE HWAELG")
(54906 . "HANGUL SYLLABLE HWAELM")
(54907 . "HANGUL SYLLABLE HWAELB")
(54908 . "HANGUL SYLLABLE HWAELS")
(54909 . "HANGUL SYLLABLE HWAELT")
(54910 . "HANGUL SYLLABLE HWAELP")
(54911 . "HANGUL SYLLABLE HWAELH")
(54912 . "HANGUL SYLLABLE HWAEM")
(54913 . "HANGUL SYLLABLE HWAEB")
(54914 . "HANGUL SYLLABLE HWAEBS")
(54915 . "HANGUL SYLLABLE HWAES")
(54916 . "HANGUL SYLLABLE HWAESS")
(54917 . "HANGUL SYLLABLE HWAENG")
(54918 . "HANGUL SYLLABLE HWAEJ")
(54919 . "HANGUL SYLLABLE HWAEC")
(54920 . "HANGUL SYLLABLE HWAEK")
(54921 . "HANGUL SYLLABLE HWAET")
(54922 . "HANGUL SYLLABLE HWAEP")
(54923 . "HANGUL SYLLABLE HWAEH")
(54924 . "HANGUL SYLLABLE HOE")
(54925 . "HANGUL SYLLABLE HOEG")
(54926 . "HANGUL SYLLABLE HOEGG")
(54927 . "HANGUL SYLLABLE HOEGS")
(54928 . "HANGUL SYLLABLE HOEN")
(54929 . "HANGUL SYLLABLE HOENJ")
(54930 . "HANGUL SYLLABLE HOENH")
(54931 . "HANGUL SYLLABLE HOED")
(54932 . "HANGUL SYLLABLE HOEL")
(54933 . "HANGUL SYLLABLE HOELG")
(54934 . "HANGUL SYLLABLE HOELM")
(54935 . "HANGUL SYLLABLE HOELB")
(54936 . "HANGUL SYLLABLE HOELS")
(54937 . "HANGUL SYLLABLE HOELT")
(54938 . "HANGUL SYLLABLE HOELP")
(54939 . "HANGUL SYLLABLE HOELH")
(54940 . "HANGUL SYLLABLE HOEM")
(54941 . "HANGUL SYLLABLE HOEB")
(54942 . "HANGUL SYLLABLE HOEBS")
(54943 . "HANGUL SYLLABLE HOES")
(54944 . "HANGUL SYLLABLE HOESS")
(54945 . "HANGUL SYLLABLE HOENG")
(54946 . "HANGUL SYLLABLE HOEJ")
(54947 . "HANGUL SYLLABLE HOEC")
(54948 . "HANGUL SYLLABLE HOEK")
(54949 . "HANGUL SYLLABLE HOET")
(54950 . "HANGUL SYLLABLE HOEP")
(54951 . "HANGUL SYLLABLE HOEH")
(54952 . "HANGUL SYLLABLE HYO")
(54953 . "HANGUL SYLLABLE HYOG")
(54954 . "HANGUL SYLLABLE HYOGG")
(54955 . "HANGUL SYLLABLE HYOGS")
(54956 . "HANGUL SYLLABLE HYON")
(54957 . "HANGUL SYLLABLE HYONJ")
(54958 . "HANGUL SYLLABLE HYONH")
(54959 . "HANGUL SYLLABLE HYOD")
(54960 . "HANGUL SYLLABLE HYOL")
(54961 . "HANGUL SYLLABLE HYOLG")
(54962 . "HANGUL SYLLABLE HYOLM")
(54963 . "HANGUL SYLLABLE HYOLB")
(54964 . "HANGUL SYLLABLE HYOLS")
(54965 . "HANGUL SYLLABLE HYOLT")
(54966 . "HANGUL SYLLABLE HYOLP")
(54967 . "HANGUL SYLLABLE HYOLH")
(54968 . "HANGUL SYLLABLE HYOM")
(54969 . "HANGUL SYLLABLE HYOB")
(54970 . "HANGUL SYLLABLE HYOBS")
(54971 . "HANGUL SYLLABLE HYOS")
(54972 . "HANGUL SYLLABLE HYOSS")
(54973 . "HANGUL SYLLABLE HYONG")
(54974 . "HANGUL SYLLABLE HYOJ")
(54975 . "HANGUL SYLLABLE HYOC")
(54976 . "HANGUL SYLLABLE HYOK")
(54977 . "HANGUL SYLLABLE HYOT")
(54978 . "HANGUL SYLLABLE HYOP")
(54979 . "HANGUL SYLLABLE HYOH")
(54980 . "HANGUL SYLLABLE HU")
(54981 . "HANGUL SYLLABLE HUG")
(54982 . "HANGUL SYLLABLE HUGG")
(54983 . "HANGUL SYLLABLE HUGS")
(54984 . "HANGUL SYLLABLE HUN")
(54985 . "HANGUL SYLLABLE HUNJ")
(54986 . "HANGUL SYLLABLE HUNH")
(54987 . "HANGUL SYLLABLE HUD")
(54988 . "HANGUL SYLLABLE HUL")
(54989 . "HANGUL SYLLABLE HULG")
(54990 . "HANGUL SYLLABLE HULM")
(54991 . "HANGUL SYLLABLE HULB")
(54992 . "HANGUL SYLLABLE HULS")
(54993 . "HANGUL SYLLABLE HULT")
(54994 . "HANGUL SYLLABLE HULP")
(54995 . "HANGUL SYLLABLE HULH")
(54996 . "HANGUL SYLLABLE HUM")
(54997 . "HANGUL SYLLABLE HUB")
(54998 . "HANGUL SYLLABLE HUBS")
(54999 . "HANGUL SYLLABLE HUS")
(55000 . "HANGUL SYLLABLE HUSS")
(55001 . "HANGUL SYLLABLE HUNG")
(55002 . "HANGUL SYLLABLE HUJ")
(55003 . "HANGUL SYLLABLE HUC")
(55004 . "HANGUL SYLLABLE HUK")
(55005 . "HANGUL SYLLABLE HUT")
(55006 . "HANGUL SYLLABLE HUP")
(55007 . "HANGUL SYLLABLE HUH")
(55008 . "HANGUL SYLLABLE HWEO")
(55009 . "HANGUL SYLLABLE HWEOG")
(55010 . "HANGUL SYLLABLE HWEOGG")
(55011 . "HANGUL SYLLABLE HWEOGS")
(55012 . "HANGUL SYLLABLE HWEON")
(55013 . "HANGUL SYLLABLE HWEONJ")
(55014 . "HANGUL SYLLABLE HWEONH")
(55015 . "HANGUL SYLLABLE HWEOD")
(55016 . "HANGUL SYLLABLE HWEOL")
(55017 . "HANGUL SYLLABLE HWEOLG")
(55018 . "HANGUL SYLLABLE HWEOLM")
(55019 . "HANGUL SYLLABLE HWEOLB")
(55020 . "HANGUL SYLLABLE HWEOLS")
(55021 . "HANGUL SYLLABLE HWEOLT")
(55022 . "HANGUL SYLLABLE HWEOLP")
(55023 . "HANGUL SYLLABLE HWEOLH")
(55024 . "HANGUL SYLLABLE HWEOM")
(55025 . "HANGUL SYLLABLE HWEOB")
(55026 . "HANGUL SYLLABLE HWEOBS")
(55027 . "HANGUL SYLLABLE HWEOS")
(55028 . "HANGUL SYLLABLE HWEOSS")
(55029 . "HANGUL SYLLABLE HWEONG")
(55030 . "HANGUL SYLLABLE HWEOJ")
(55031 . "HANGUL SYLLABLE HWEOC")
(55032 . "HANGUL SYLLABLE HWEOK")
(55033 . "HANGUL SYLLABLE HWEOT")
(55034 . "HANGUL SYLLABLE HWEOP")
(55035 . "HANGUL SYLLABLE HWEOH")
(55036 . "HANGUL SYLLABLE HWE")
(55037 . "HANGUL SYLLABLE HWEG")
(55038 . "HANGUL SYLLABLE HWEGG")
(55039 . "HANGUL SYLLABLE HWEGS")
(55040 . "HANGUL SYLLABLE HWEN")
(55041 . "HANGUL SYLLABLE HWENJ")
(55042 . "HANGUL SYLLABLE HWENH")
(55043 . "HANGUL SYLLABLE HWED")
(55044 . "HANGUL SYLLABLE HWEL")
(55045 . "HANGUL SYLLABLE HWELG")
(55046 . "HANGUL SYLLABLE HWELM")
(55047 . "HANGUL SYLLABLE HWELB")
(55048 . "HANGUL SYLLABLE HWELS")
(55049 . "HANGUL SYLLABLE HWELT")
(55050 . "HANGUL SYLLABLE HWELP")
(55051 . "HANGUL SYLLABLE HWELH")
(55052 . "HANGUL SYLLABLE HWEM")
(55053 . "HANGUL SYLLABLE HWEB")
(55054 . "HANGUL SYLLABLE HWEBS")
(55055 . "HANGUL SYLLABLE HWES")
(55056 . "HANGUL SYLLABLE HWESS")
(55057 . "HANGUL SYLLABLE HWENG")
(55058 . "HANGUL SYLLABLE HWEJ")
(55059 . "HANGUL SYLLABLE HWEC")
(55060 . "HANGUL SYLLABLE HWEK")
(55061 . "HANGUL SYLLABLE HWET")
(55062 . "HANGUL SYLLABLE HWEP")
(55063 . "HANGUL SYLLABLE HWEH")
(55064 . "HANGUL SYLLABLE HWI")
(55065 . "HANGUL SYLLABLE HWIG")
(55066 . "HANGUL SYLLABLE HWIGG")
(55067 . "HANGUL SYLLABLE HWIGS")
(55068 . "HANGUL SYLLABLE HWIN")
(55069 . "HANGUL SYLLABLE HWINJ")
(55070 . "HANGUL SYLLABLE HWINH")
(55071 . "HANGUL SYLLABLE HWID")
(55072 . "HANGUL SYLLABLE HWIL")
(55073 . "HANGUL SYLLABLE HWILG")
(55074 . "HANGUL SYLLABLE HWILM")
(55075 . "HANGUL SYLLABLE HWILB")
(55076 . "HANGUL SYLLABLE HWILS")
(55077 . "HANGUL SYLLABLE HWILT")
(55078 . "HANGUL SYLLABLE HWILP")
(55079 . "HANGUL SYLLABLE HWILH")
(55080 . "HANGUL SYLLABLE HWIM")
(55081 . "HANGUL SYLLABLE HWIB")
(55082 . "HANGUL SYLLABLE HWIBS")
(55083 . "HANGUL SYLLABLE HWIS")
(55084 . "HANGUL SYLLABLE HWISS")
(55085 . "HANGUL SYLLABLE HWING")
(55086 . "HANGUL SYLLABLE HWIJ")
(55087 . "HANGUL SYLLABLE HWIC")
(55088 . "HANGUL SYLLABLE HWIK")
(55089 . "HANGUL SYLLABLE HWIT")
(55090 . "HANGUL SYLLABLE HWIP")
(55091 . "HANGUL SYLLABLE HWIH")
(55092 . "HANGUL SYLLABLE HYU")
(55093 . "HANGUL SYLLABLE HYUG")
(55094 . "HANGUL SYLLABLE HYUGG")
(55095 . "HANGUL SYLLABLE HYUGS")
(55096 . "HANGUL SYLLABLE HYUN")
(55097 . "HANGUL SYLLABLE HYUNJ")
(55098 . "HANGUL SYLLABLE HYUNH")
(55099 . "HANGUL SYLLABLE HYUD")
(55100 . "HANGUL SYLLABLE HYUL")
(55101 . "HANGUL SYLLABLE HYULG")
(55102 . "HANGUL SYLLABLE HYULM")
(55103 . "HANGUL SYLLABLE HYULB")
(55104 . "HANGUL SYLLABLE HYULS")
(55105 . "HANGUL SYLLABLE HYULT")
(55106 . "HANGUL SYLLABLE HYULP")
(55107 . "HANGUL SYLLABLE HYULH")
(55108 . "HANGUL SYLLABLE HYUM")
(55109 . "HANGUL SYLLABLE HYUB")
(55110 . "HANGUL SYLLABLE HYUBS")
(55111 . "HANGUL SYLLABLE HYUS")
(55112 . "HANGUL SYLLABLE HYUSS")
(55113 . "HANGUL SYLLABLE HYUNG")
(55114 . "HANGUL SYLLABLE HYUJ")
(55115 . "HANGUL SYLLABLE HYUC")
(55116 . "HANGUL SYLLABLE HYUK")
(55117 . "HANGUL SYLLABLE HYUT")
(55118 . "HANGUL SYLLABLE HYUP")
(55119 . "HANGUL SYLLABLE HYUH")
(55120 . "HANGUL SYLLABLE HEU")
(55121 . "HANGUL SYLLABLE HEUG")
(55122 . "HANGUL SYLLABLE HEUGG")
(55123 . "HANGUL SYLLABLE HEUGS")
(55124 . "HANGUL SYLLABLE HEUN")
(55125 . "HANGUL SYLLABLE HEUNJ")
(55126 . "HANGUL SYLLABLE HEUNH")
(55127 . "HANGUL SYLLABLE HEUD")
(55128 . "HANGUL SYLLABLE HEUL")
(55129 . "HANGUL SYLLABLE HEULG")
(55130 . "HANGUL SYLLABLE HEULM")
(55131 . "HANGUL SYLLABLE HEULB")
(55132 . "HANGUL SYLLABLE HEULS")
(55133 . "HANGUL SYLLABLE HEULT")
(55134 . "HANGUL SYLLABLE HEULP")
(55135 . "HANGUL SYLLABLE HEULH")
(55136 . "HANGUL SYLLABLE HEUM")
(55137 . "HANGUL SYLLABLE HEUB")
(55138 . "HANGUL SYLLABLE HEUBS")
(55139 . "HANGUL SYLLABLE HEUS")
(55140 . "HANGUL SYLLABLE HEUSS")
(55141 . "HANGUL SYLLABLE HEUNG")
(55142 . "HANGUL SYLLABLE HEUJ")
(55143 . "HANGUL SYLLABLE HEUC")
(55144 . "HANGUL SYLLABLE HEUK")
(55145 . "HANGUL SYLLABLE HEUT")
(55146 . "HANGUL SYLLABLE HEUP")
(55147 . "HANGUL SYLLABLE HEUH")
(55148 . "HANGUL SYLLABLE HYI")
(55149 . "HANGUL SYLLABLE HYIG")
(55150 . "HANGUL SYLLABLE HYIGG")
(55151 . "HANGUL SYLLABLE HYIGS")
(55152 . "HANGUL SYLLABLE HYIN")
(55153 . "HANGUL SYLLABLE HYINJ")
(55154 . "HANGUL SYLLABLE HYINH")
(55155 . "HANGUL SYLLABLE HYID")
(55156 . "HANGUL SYLLABLE HYIL")
(55157 . "HANGUL SYLLABLE HYILG")
(55158 . "HANGUL SYLLABLE HYILM")
(55159 . "HANGUL SYLLABLE HYILB")
(55160 . "HANGUL SYLLABLE HYILS")
(55161 . "HANGUL SYLLABLE HYILT")
(55162 . "HANGUL SYLLABLE HYILP")
(55163 . "HANGUL SYLLABLE HYILH")
(55164 . "HANGUL SYLLABLE HYIM")
(55165 . "HANGUL SYLLABLE HYIB")
(55166 . "HANGUL SYLLABLE HYIBS")
(55167 . "HANGUL SYLLABLE HYIS")
(55168 . "HANGUL SYLLABLE HYISS")
(55169 . "HANGUL SYLLABLE HYING")
(55170 . "HANGUL SYLLABLE HYIJ")
(55171 . "HANGUL SYLLABLE HYIC")
(55172 . "HANGUL SYLLABLE HYIK")
(55173 . "HANGUL SYLLABLE HYIT")
(55174 . "HANGUL SYLLABLE HYIP")
(55175 . "HANGUL SYLLABLE HYIH")
(55176 . "HANGUL SYLLABLE HI")
(55177 . "HANGUL SYLLABLE HIG")
(55178 . "HANGUL SYLLABLE HIGG")
(55179 . "HANGUL SYLLABLE HIGS")
(55180 . "HANGUL SYLLABLE HIN")
(55181 . "HANGUL SYLLABLE HINJ")
(55182 . "HANGUL SYLLABLE HINH")
(55183 . "HANGUL SYLLABLE HID")
(55184 . "HANGUL SYLLABLE HIL")
(55185 . "HANGUL SYLLABLE HILG")
(55186 . "HANGUL SYLLABLE HILM")
(55187 . "HANGUL SYLLABLE HILB")
(55188 . "HANGUL SYLLABLE HILS")
(55189 . "HANGUL SYLLABLE HILT")
(55190 . "HANGUL SYLLABLE HILP")
(55191 . "HANGUL SYLLABLE HILH")
(55192 . "HANGUL SYLLABLE HIM")
(55193 . "HANGUL SYLLABLE HIB")
(55194 . "HANGUL SYLLABLE HIBS")
(55195 . "HANGUL SYLLABLE HIS")
(55196 . "HANGUL SYLLABLE HISS")
(55197 . "HANGUL SYLLABLE HING")
(55198 . "HANGUL SYLLABLE HIJ")
(55199 . "HANGUL SYLLABLE HIC")
(55200 . "HANGUL SYLLABLE HIK")
(55201 . "HANGUL SYLLABLE HIT")
(55202 . "HANGUL SYLLABLE HIP")
(55203 . "HANGUL SYLLABLE HIH")
((55204 . 55216) . #f)
(55216 . "HANGUL JUNGSEONG O-YEO")
(55217 . "HANGUL JUNGSEONG O-O-I")
(55218 . "HANGUL JUNGSEONG YO-A")
(55219 . "HANGUL JUNGSEONG YO-AE")
(55220 . "HANGUL JUNGSEONG YO-EO")
(55221 . "HANGUL JUNGSEONG U-YEO")
(55222 . "HANGUL JUNGSEONG U-I-I")
(55223 . "HANGUL JUNGSEONG YU-AE")
(55224 . "HANGUL JUNGSEONG YU-O")
(55225 . "HANGUL JUNGSEONG EU-A")
(55226 . "HANGUL JUNGSEONG EU-EO")
(55227 . "HANGUL JUNGSEONG EU-E")
(55228 . "HANGUL JUNGSEONG EU-O")
(55229 . "HANGUL JUNGSEONG I-YA-O")
(55230 . "HANGUL JUNGSEONG I-YAE")
(55231 . "HANGUL JUNGSEONG I-YEO")
(55232 . "HANGUL JUNGSEONG I-YE")
(55233 . "HANGUL JUNGSEONG I-O-I")
(55234 . "HANGUL JUNGSEONG I-YO")
(55235 . "HANGUL JUNGSEONG I-YU")
(55236 . "HANGUL JUNGSEONG I-I")
(55237 . "HANGUL JUNGSEONG ARAEA-A")
(55238 . "HANGUL JUNGSEONG ARAEA-E")
((55239 . 55243) . #f)
(55243 . "HANGUL JONGSEONG NIEUN-RIEUL")
(55244 . "HANGUL JONGSEONG NIEUN-CHIEUCH")
(55245 . "HANGUL JONGSEONG SSANGTIKEUT")
(55246 . "HANGUL JONGSEONG SSANGTIKEUT-PIEUP")
(55247 . "HANGUL JONGSEONG TIKEUT-PIEUP")
(55248 . "HANGUL JONGSEONG TIKEUT-SIOS")
(55249 . "HANGUL JONGSEONG TIKEUT-SIOS-KIYEOK")
(55250 . "HANGUL JONGSEONG TIKEUT-CIEUC")
(55251 . "HANGUL JONGSEONG TIKEUT-CHIEUCH")
(55252 . "HANGUL JONGSEONG TIKEUT-THIEUTH")
(55253 . "HANGUL JONGSEONG RIEUL-SSANGKIYEOK")
(55254 . "HANGUL JONGSEONG RIEUL-KIYEOK-HIEUH")
(55255 . "HANGUL JONGSEONG SSANGRIEUL-KHIEUKH")
(55256 . "HANGUL JONGSEONG RIEUL-MIEUM-HIEUH")
(55257 . "HANGUL JONGSEONG RIEUL-PIEUP-TIKEUT")
(55258 . "HANGUL JONGSEONG RIEUL-PIEUP-PHIEUPH")
(55259 . "HANGUL JONGSEONG RIEUL-YESIEUNG")
(55260 . "HANGUL JONGSEONG RIEUL-YEORINHIEUH-HIEUH")
(55261 . "HANGUL JONGSEONG KAPYEOUNRIEUL")
(55262 . "HANGUL JONGSEONG MIEUM-NIEUN")
(55263 . "HANGUL JONGSEONG MIEUM-SSANGNIEUN")
(55264 . "HANGUL JONGSEONG SSANGMIEUM")
(55265 . "HANGUL JONGSEONG MIEUM-PIEUP-SIOS")
(55266 . "HANGUL JONGSEONG MIEUM-CIEUC")
(55267 . "HANGUL JONGSEONG PIEUP-TIKEUT")
(55268 . "HANGUL JONGSEONG PIEUP-RIEUL-PHIEUPH")
(55269 . "HANGUL JONGSEONG PIEUP-MIEUM")
(55270 . "HANGUL JONGSEONG SSANGPIEUP")
(55271 . "HANGUL JONGSEONG PIEUP-SIOS-TIKEUT")
(55272 . "HANGUL JONGSEONG PIEUP-CIEUC")
(55273 . "HANGUL JONGSEONG PIEUP-CHIEUCH")
(55274 . "HANGUL JONGSEONG SIOS-MIEUM")
(55275 . "HANGUL JONGSEONG SIOS-KAPYEOUNPIEUP")
(55276 . "HANGUL JONGSEONG SSANGSIOS-KIYEOK")
(55277 . "HANGUL JONGSEONG SSANGSIOS-TIKEUT")
(55278 . "HANGUL JONGSEONG SIOS-PANSIOS")
(55279 . "HANGUL JONGSEONG SIOS-CIEUC")
(55280 . "HANGUL JONGSEONG SIOS-CHIEUCH")
(55281 . "HANGUL JONGSEONG SIOS-THIEUTH")
(55282 . "HANGUL JONGSEONG SIOS-HIEUH")
(55283 . "HANGUL JONGSEONG PANSIOS-PIEUP")
(55284 . "HANGUL JONGSEONG PANSIOS-KAPYEOUNPIEUP")
(55285 . "HANGUL JONGSEONG YESIEUNG-MIEUM")
(55286 . "HANGUL JONGSEONG YESIEUNG-HIEUH")
(55287 . "HANGUL JONGSEONG CIEUC-PIEUP")
(55288 . "HANGUL JONGSEONG CIEUC-SSANGPIEUP")
(55289 . "HANGUL JONGSEONG SSANGCIEUC")
(55290 . "HANGUL JONGSEONG PHIEUPH-SIOS")
(55291 . "HANGUL JONGSEONG PHIEUPH-THIEUTH")
((55292 . 63744) . #f)
((63744 . 64256) . "CJK COMPATIBILITY IDEOGRAPH-#")
(64256 . "LATIN SMALL LIGATURE FF")
(64257 . "LATIN SMALL LIGATURE FI")
(64258 . "LATIN SMALL LIGATURE FL")
(64259 . "LATIN SMALL LIGATURE FFI")
(64260 . "LATIN SMALL LIGATURE FFL")
(64261 . "LATIN SMALL LIGATURE LONG S T")
(64262 . "LATIN SMALL LIGATURE ST")
((64263 . 64275) . #f)
(64275 . "ARMENIAN SMALL LIGATURE MEN NOW")
(64276 . "ARMENIAN SMALL LIGATURE MEN ECH")
(64277 . "ARMENIAN SMALL LIGATURE MEN INI")
(64278 . "ARMENIAN SMALL LIGATURE VEW NOW")
(64279 . "ARMENIAN SMALL LIGATURE MEN XEH")
((64280 . 64285) . #f)
(64285 . "HEBREW LETTER YOD WITH HIRIQ")
(64286 . "HEBREW POINT JUDEO-SPANISH VARIKA")
(64287 . "HEBREW LIGATURE YIDDISH YOD YOD PATAH")
(64288 . "HEBREW LETTER ALTERNATIVE AYIN")
(64289 . "HEBREW LETTER WIDE ALEF")
(64290 . "HEBREW LETTER WIDE DALET")
(64291 . "HEBREW LETTER WIDE HE")
(64292 . "HEBREW LETTER WIDE KAF")
(64293 . "HEBREW LETTER WIDE LAMED")
(64294 . "HEBREW LETTER WIDE FINAL MEM")
(64295 . "HEBREW LETTER WIDE RESH")
(64296 . "HEBREW LETTER WIDE TAV")
(64297 . "HEBREW LETTER ALTERNATIVE PLUS SIGN")
(64298 . "HEBREW LETTER SHIN WITH SHIN DOT")
(64299 . "HEBREW LETTER SHIN WITH SIN DOT")
(64300 . "HEBREW LETTER SHIN WITH DAGESH AND SHIN DOT")
(64301 . "HEBREW LETTER SHIN WITH DAGESH AND SIN DOT")
(64302 . "HEBREW LETTER ALEF WITH PATAH")
(64303 . "HEBREW LETTER ALEF WITH QAMATS")
(64304 . "HEBREW LETTER ALEF WITH MAPIQ")
(64305 . "HEBREW LETTER BET WITH DAGESH")
(64306 . "HEBREW LETTER GIMEL WITH DAGESH")
(64307 . "HEBREW LETTER DALET WITH DAGESH")
(64308 . "HEBREW LETTER HE WITH MAPIQ")
(64309 . "HEBREW LETTER VAV WITH DAGESH")
(64310 . "HEBREW LETTER ZAYIN WITH DAGESH")
(64311 . #f)
(64312 . "HEBREW LETTER TET WITH DAGESH")
(64313 . "HEBREW LETTER YOD WITH DAGESH")
(64314 . "HEBREW LETTER FINAL KAF WITH DAGESH")
(64315 . "HEBREW LETTER KAF WITH DAGESH")
(64316 . "HEBREW LETTER LAMED WITH DAGESH")
(64317 . #f)
(64318 . "HEBREW LETTER MEM WITH DAGESH")
(64319 . #f)
(64320 . "HEBREW LETTER NUN WITH DAGESH")
(64321 . "HEBREW LETTER SAMEKH WITH DAGESH")
(64322 . #f)
(64323 . "HEBREW LETTER FINAL PE WITH DAGESH")
(64324 . "HEBREW LETTER PE WITH DAGESH")
(64325 . #f)
(64326 . "HEBREW LETTER TSADI WITH DAGESH")
(64327 . "HEBREW LETTER QOF WITH DAGESH")
(64328 . "HEBREW LETTER RESH WITH DAGESH")
(64329 . "HEBREW LETTER SHIN WITH DAGESH")
(64330 . "HEBREW LETTER TAV WITH DAGESH")
(64331 . "HEBREW LETTER VAV WITH HOLAM")
(64332 . "HEBREW LETTER BET WITH RAFE")
(64333 . "HEBREW LETTER KAF WITH RAFE")
(64334 . "HEBREW LETTER PE WITH RAFE")
(64335 . "HEBREW LIGATURE ALEF LAMED")
(64336 . "ARABIC LETTER ALEF WASLA ISOLATED FORM")
(64337 . "ARABIC LETTER ALEF WASLA FINAL FORM")
(64338 . "ARABIC LETTER BEEH ISOLATED FORM")
(64339 . "ARABIC LETTER BEEH FINAL FORM")
(64340 . "ARABIC LETTER BEEH INITIAL FORM")
(64341 . "ARABIC LETTER BEEH MEDIAL FORM")
(64342 . "ARABIC LETTER PEH ISOLATED FORM")
(64343 . "ARABIC LETTER PEH FINAL FORM")
(64344 . "ARABIC LETTER PEH INITIAL FORM")
(64345 . "ARABIC LETTER PEH MEDIAL FORM")
(64346 . "ARABIC LETTER BEHEH ISOLATED FORM")
(64347 . "ARABIC LETTER BEHEH FINAL FORM")
(64348 . "ARABIC LETTER BEHEH INITIAL FORM")
(64349 . "ARABIC LETTER BEHEH MEDIAL FORM")
(64350 . "ARABIC LETTER TTEHEH ISOLATED FORM")
(64351 . "ARABIC LETTER TTEHEH FINAL FORM")
(64352 . "ARABIC LETTER TTEHEH INITIAL FORM")
(64353 . "ARABIC LETTER TTEHEH MEDIAL FORM")
(64354 . "ARABIC LETTER TEHEH ISOLATED FORM")
(64355 . "ARABIC LETTER TEHEH FINAL FORM")
(64356 . "ARABIC LETTER TEHEH INITIAL FORM")
(64357 . "ARABIC LETTER TEHEH MEDIAL FORM")
(64358 . "ARABIC LETTER TTEH ISOLATED FORM")
(64359 . "ARABIC LETTER TTEH FINAL FORM")
(64360 . "ARABIC LETTER TTEH INITIAL FORM")
(64361 . "ARABIC LETTER TTEH MEDIAL FORM")
(64362 . "ARABIC LETTER VEH ISOLATED FORM")
(64363 . "ARABIC LETTER VEH FINAL FORM")
(64364 . "ARABIC LETTER VEH INITIAL FORM")
(64365 . "ARABIC LETTER VEH MEDIAL FORM")
(64366 . "ARABIC LETTER PEHEH ISOLATED FORM")
(64367 . "ARABIC LETTER PEHEH FINAL FORM")
(64368 . "ARABIC LETTER PEHEH INITIAL FORM")
(64369 . "ARABIC LETTER PEHEH MEDIAL FORM")
(64370 . "ARABIC LETTER DYEH ISOLATED FORM")
(64371 . "ARABIC LETTER DYEH FINAL FORM")
(64372 . "ARABIC LETTER DYEH INITIAL FORM")
(64373 . "ARABIC LETTER DYEH MEDIAL FORM")
(64374 . "ARABIC LETTER NYEH ISOLATED FORM")
(64375 . "ARABIC LETTER NYEH FINAL FORM")
(64376 . "ARABIC LETTER NYEH INITIAL FORM")
(64377 . "ARABIC LETTER NYEH MEDIAL FORM")
(64378 . "ARABIC LETTER TCHEH ISOLATED FORM")
(64379 . "ARABIC LETTER TCHEH FINAL FORM")
(64380 . "ARABIC LETTER TCHEH INITIAL FORM")
(64381 . "ARABIC LETTER TCHEH MEDIAL FORM")
(64382 . "ARABIC LETTER TCHEHEH ISOLATED FORM")
(64383 . "ARABIC LETTER TCHEHEH FINAL FORM")
(64384 . "ARABIC LETTER TCHEHEH INITIAL FORM")
(64385 . "ARABIC LETTER TCHEHEH MEDIAL FORM")
(64386 . "ARABIC LETTER DDAHAL ISOLATED FORM")
(64387 . "ARABIC LETTER DDAHAL FINAL FORM")
(64388 . "ARABIC LETTER DAHAL ISOLATED FORM")
(64389 . "ARABIC LETTER DAHAL FINAL FORM")
(64390 . "ARABIC LETTER DUL ISOLATED FORM")
(64391 . "ARABIC LETTER DUL FINAL FORM")
(64392 . "ARABIC LETTER DDAL ISOLATED FORM")
(64393 . "ARABIC LETTER DDAL FINAL FORM")
(64394 . "ARABIC LETTER JEH ISOLATED FORM")
(64395 . "ARABIC LETTER JEH FINAL FORM")
(64396 . "ARABIC LETTER RREH ISOLATED FORM")
(64397 . "ARABIC LETTER RREH FINAL FORM")
(64398 . "ARABIC LETTER KEHEH ISOLATED FORM")
(64399 . "ARABIC LETTER KEHEH FINAL FORM")
(64400 . "ARABIC LETTER KEHEH INITIAL FORM")
(64401 . "ARABIC LETTER KEHEH MEDIAL FORM")
(64402 . "ARABIC LETTER GAF ISOLATED FORM")
(64403 . "ARABIC LETTER GAF FINAL FORM")
(64404 . "ARABIC LETTER GAF INITIAL FORM")
(64405 . "ARABIC LETTER GAF MEDIAL FORM")
(64406 . "ARABIC LETTER GUEH ISOLATED FORM")
(64407 . "ARABIC LETTER GUEH FINAL FORM")
(64408 . "ARABIC LETTER GUEH INITIAL FORM")
(64409 . "ARABIC LETTER GUEH MEDIAL FORM")
(64410 . "ARABIC LETTER NGOEH ISOLATED FORM")
(64411 . "ARABIC LETTER NGOEH FINAL FORM")
(64412 . "ARABIC LETTER NGOEH INITIAL FORM")
(64413 . "ARABIC LETTER NGOEH MEDIAL FORM")
(64414 . "ARABIC LETTER NOON GHUNNA ISOLATED FORM")
(64415 . "ARABIC LETTER NOON GHUNNA FINAL FORM")
(64416 . "ARABIC LETTER RNOON ISOLATED FORM")
(64417 . "ARABIC LETTER RNOON FINAL FORM")
(64418 . "ARABIC LETTER RNOON INITIAL FORM")
(64419 . "ARABIC LETTER RNOON MEDIAL FORM")
(64420 . "ARABIC LETTER HEH WITH YEH ABOVE ISOLATED FORM")
(64421 . "ARABIC LETTER HEH WITH YEH ABOVE FINAL FORM")
(64422 . "ARABIC LETTER HEH GOAL ISOLATED FORM")
(64423 . "ARABIC LETTER HEH GOAL FINAL FORM")
(64424 . "ARABIC LETTER HEH GOAL INITIAL FORM")
(64425 . "ARABIC LETTER HEH GOAL MEDIAL FORM")
(64426 . "ARABIC LETTER HEH DOACHASHMEE ISOLATED FORM")
(64427 . "ARABIC LETTER HEH DOACHASHMEE FINAL FORM")
(64428 . "ARABIC LETTER HEH DOACHASHMEE INITIAL FORM")
(64429 . "ARABIC LETTER HEH DOACHASHMEE MEDIAL FORM")
(64430 . "ARABIC LETTER YEH BARREE ISOLATED FORM")
(64431 . "ARABIC LETTER YEH BARREE FINAL FORM")
(64432 . "ARABIC LETTER YEH BARREE WITH HAMZA ABOVE ISOLATED FORM")
(64433 . "ARABIC LETTER YEH BARREE WITH HAMZA ABOVE FINAL FORM")
(64434 . "ARABIC SYMBOL DOT ABOVE")
(64435 . "ARABIC SYMBOL DOT BELOW")
(64436 . "ARABIC SYMBOL TWO DOTS ABOVE")
(64437 . "ARABIC SYMBOL TWO DOTS BELOW")
(64438 . "ARABIC SYMBOL THREE DOTS ABOVE")
(64439 . "ARABIC SYMBOL THREE DOTS BELOW")
(64440 . "ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS ABOVE")
(64441 . "ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS BELOW")
(64442 . "ARABIC SYMBOL FOUR DOTS ABOVE")
(64443 . "ARABIC SYMBOL FOUR DOTS BELOW")
(64444 . "ARABIC SYMBOL DOUBLE VERTICAL BAR BELOW")
(64445 . "ARABIC SYMBOL TWO DOTS VERTICALLY ABOVE")
(64446 . "ARABIC SYMBOL TWO DOTS VERTICALLY BELOW")
(64447 . "ARABIC SYMBOL RING")
(64448 . "ARABIC SYMBOL SMALL TAH ABOVE")
(64449 . "ARABIC SYMBOL SMALL TAH BELOW")
((64450 . 64467) . #f)
(64467 . "ARABIC LETTER NG ISOLATED FORM")
(64468 . "ARABIC LETTER NG FINAL FORM")
(64469 . "ARABIC LETTER NG INITIAL FORM")
(64470 . "ARABIC LETTER NG MEDIAL FORM")
(64471 . "ARABIC LETTER U ISOLATED FORM")
(64472 . "ARABIC LETTER U FINAL FORM")
(64473 . "ARABIC LETTER OE ISOLATED FORM")
(64474 . "ARABIC LETTER OE FINAL FORM")
(64475 . "ARABIC LETTER YU ISOLATED FORM")
(64476 . "ARABIC LETTER YU FINAL FORM")
(64477 . "ARABIC LETTER U WITH HAMZA ABOVE ISOLATED FORM")
(64478 . "ARABIC LETTER VE ISOLATED FORM")
(64479 . "ARABIC LETTER VE FINAL FORM")
(64480 . "ARABIC LETTER KIRGHIZ OE ISOLATED FORM")
(64481 . "ARABIC LETTER KIRGHIZ OE FINAL FORM")
(64482 . "ARABIC LETTER KIRGHIZ YU ISOLATED FORM")
(64483 . "ARABIC LETTER KIRGHIZ YU FINAL FORM")
(64484 . "ARABIC LETTER E ISOLATED FORM")
(64485 . "ARABIC LETTER E FINAL FORM")
(64486 . "ARABIC LETTER E INITIAL FORM")
(64487 . "ARABIC LETTER E MEDIAL FORM")
(64488 . "ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA INITIAL FORM")
(64489 . "ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA MEDIAL FORM")
(64490 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF ISOLATED FORM")
(64491 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF FINAL FORM")
(64492 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE ISOLATED FORM")
(64493 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE FINAL FORM")
(64494 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW ISOLATED FORM")
(64495 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW FINAL FORM")
(64496 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U ISOLATED FORM")
(64497 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U FINAL FORM")
(64498 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE ISOLATED FORM")
(64499 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE FINAL FORM")
(64500 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU ISOLATED FORM")
(64501 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU FINAL FORM")
(64502 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E ISOLATED FORM")
(64503 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E FINAL FORM")
(64504 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E INITIAL FORM")
(64505 . "ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM")
(64506 . "ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM")
(64507 . "ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA INITIAL FORM")
(64508 . "ARABIC LETTER FARSI YEH ISOLATED FORM")
(64509 . "ARABIC LETTER FARSI YEH FINAL FORM")
(64510 . "ARABIC LETTER FARSI YEH INITIAL FORM")
(64511 . "ARABIC LETTER FARSI YEH MEDIAL FORM")
(64512 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM ISOLATED FORM")
(64513 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH ISOLATED FORM")
(64514 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM ISOLATED FORM")
(64515 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM")
(64516 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH ISOLATED FORM")
(64517 . "ARABIC LIGATURE BEH WITH JEEM ISOLATED FORM")
(64518 . "ARABIC LIGATURE BEH WITH HAH ISOLATED FORM")
(64519 . "ARABIC LIGATURE BEH WITH KHAH ISOLATED FORM")
(64520 . "ARABIC LIGATURE BEH WITH MEEM ISOLATED FORM")
(64521 . "ARABIC LIGATURE BEH WITH ALEF MAKSURA ISOLATED FORM")
(64522 . "ARABIC LIGATURE BEH WITH YEH ISOLATED FORM")
(64523 . "ARABIC LIGATURE TEH WITH JEEM ISOLATED FORM")
(64524 . "ARABIC LIGATURE TEH WITH HAH ISOLATED FORM")
(64525 . "ARABIC LIGATURE TEH WITH KHAH ISOLATED FORM")
(64526 . "ARABIC LIGATURE TEH WITH MEEM ISOLATED FORM")
(64527 . "ARABIC LIGATURE TEH WITH ALEF MAKSURA ISOLATED FORM")
(64528 . "ARABIC LIGATURE TEH WITH YEH ISOLATED FORM")
(64529 . "ARABIC LIGATURE THEH WITH JEEM ISOLATED FORM")
(64530 . "ARABIC LIGATURE THEH WITH MEEM ISOLATED FORM")
(64531 . "ARABIC LIGATURE THEH WITH ALEF MAKSURA ISOLATED FORM")
(64532 . "ARABIC LIGATURE THEH WITH YEH ISOLATED FORM")
(64533 . "ARABIC LIGATURE JEEM WITH HAH ISOLATED FORM")
(64534 . "ARABIC LIGATURE JEEM WITH MEEM ISOLATED FORM")
(64535 . "ARABIC LIGATURE HAH WITH JEEM ISOLATED FORM")
(64536 . "ARABIC LIGATURE HAH WITH MEEM ISOLATED FORM")
(64537 . "ARABIC LIGATURE KHAH WITH JEEM ISOLATED FORM")
(64538 . "ARABIC LIGATURE KHAH WITH HAH ISOLATED FORM")
(64539 . "ARABIC LIGATURE KHAH WITH MEEM ISOLATED FORM")
(64540 . "ARABIC LIGATURE SEEN WITH JEEM ISOLATED FORM")
(64541 . "ARABIC LIGATURE SEEN WITH HAH ISOLATED FORM")
(64542 . "ARABIC LIGATURE SEEN WITH KHAH ISOLATED FORM")
(64543 . "ARABIC LIGATURE SEEN WITH MEEM ISOLATED FORM")
(64544 . "ARABIC LIGATURE SAD WITH HAH ISOLATED FORM")
(64545 . "ARABIC LIGATURE SAD WITH MEEM ISOLATED FORM")
(64546 . "ARABIC LIGATURE DAD WITH JEEM ISOLATED FORM")
(64547 . "ARABIC LIGATURE DAD WITH HAH ISOLATED FORM")
(64548 . "ARABIC LIGATURE DAD WITH KHAH ISOLATED FORM")
(64549 . "ARABIC LIGATURE DAD WITH MEEM ISOLATED FORM")
(64550 . "ARABIC LIGATURE TAH WITH HAH ISOLATED FORM")
(64551 . "ARABIC LIGATURE TAH WITH MEEM ISOLATED FORM")
(64552 . "ARABIC LIGATURE ZAH WITH MEEM ISOLATED FORM")
(64553 . "ARABIC LIGATURE AIN WITH JEEM ISOLATED FORM")
(64554 . "ARABIC LIGATURE AIN WITH MEEM ISOLATED FORM")
(64555 . "ARABIC LIGATURE GHAIN WITH JEEM ISOLATED FORM")
(64556 . "ARABIC LIGATURE GHAIN WITH MEEM ISOLATED FORM")
(64557 . "ARABIC LIGATURE FEH WITH JEEM ISOLATED FORM")
(64558 . "ARABIC LIGATURE FEH WITH HAH ISOLATED FORM")
(64559 . "ARABIC LIGATURE FEH WITH KHAH ISOLATED FORM")
(64560 . "ARABIC LIGATURE FEH WITH MEEM ISOLATED FORM")
(64561 . "ARABIC LIGATURE FEH WITH ALEF MAKSURA ISOLATED FORM")
(64562 . "ARABIC LIGATURE FEH WITH YEH ISOLATED FORM")
(64563 . "ARABIC LIGATURE QAF WITH HAH ISOLATED FORM")
(64564 . "ARABIC LIGATURE QAF WITH MEEM ISOLATED FORM")
(64565 . "ARABIC LIGATURE QAF WITH ALEF MAKSURA ISOLATED FORM")
(64566 . "ARABIC LIGATURE QAF WITH YEH ISOLATED FORM")
(64567 . "ARABIC LIGATURE KAF WITH ALEF ISOLATED FORM")
(64568 . "ARABIC LIGATURE KAF WITH JEEM ISOLATED FORM")
(64569 . "ARABIC LIGATURE KAF WITH HAH ISOLATED FORM")
(64570 . "ARABIC LIGATURE KAF WITH KHAH ISOLATED FORM")
(64571 . "ARABIC LIGATURE KAF WITH LAM ISOLATED FORM")
(64572 . "ARABIC LIGATURE KAF WITH MEEM ISOLATED FORM")
(64573 . "ARABIC LIGATURE KAF WITH ALEF MAKSURA ISOLATED FORM")
(64574 . "ARABIC LIGATURE KAF WITH YEH ISOLATED FORM")
(64575 . "ARABIC LIGATURE LAM WITH JEEM ISOLATED FORM")
(64576 . "ARABIC LIGATURE LAM WITH HAH ISOLATED FORM")
(64577 . "ARABIC LIGATURE LAM WITH KHAH ISOLATED FORM")
(64578 . "ARABIC LIGATURE LAM WITH MEEM ISOLATED FORM")
(64579 . "ARABIC LIGATURE LAM WITH ALEF MAKSURA ISOLATED FORM")
(64580 . "ARABIC LIGATURE LAM WITH YEH ISOLATED FORM")
(64581 . "ARABIC LIGATURE MEEM WITH JEEM ISOLATED FORM")
(64582 . "ARABIC LIGATURE MEEM WITH HAH ISOLATED FORM")
(64583 . "ARABIC LIGATURE MEEM WITH KHAH ISOLATED FORM")
(64584 . "ARABIC LIGATURE MEEM WITH MEEM ISOLATED FORM")
(64585 . "ARABIC LIGATURE MEEM WITH ALEF MAKSURA ISOLATED FORM")
(64586 . "ARABIC LIGATURE MEEM WITH YEH ISOLATED FORM")
(64587 . "ARABIC LIGATURE NOON WITH JEEM ISOLATED FORM")
(64588 . "ARABIC LIGATURE NOON WITH HAH ISOLATED FORM")
(64589 . "ARABIC LIGATURE NOON WITH KHAH ISOLATED FORM")
(64590 . "ARABIC LIGATURE NOON WITH MEEM ISOLATED FORM")
(64591 . "ARABIC LIGATURE NOON WITH ALEF MAKSURA ISOLATED FORM")
(64592 . "ARABIC LIGATURE NOON WITH YEH ISOLATED FORM")
(64593 . "ARABIC LIGATURE HEH WITH JEEM ISOLATED FORM")
(64594 . "ARABIC LIGATURE HEH WITH MEEM ISOLATED FORM")
(64595 . "ARABIC LIGATURE HEH WITH ALEF MAKSURA ISOLATED FORM")
(64596 . "ARABIC LIGATURE HEH WITH YEH ISOLATED FORM")
(64597 . "ARABIC LIGATURE YEH WITH JEEM ISOLATED FORM")
(64598 . "ARABIC LIGATURE YEH WITH HAH ISOLATED FORM")
(64599 . "ARABIC LIGATURE YEH WITH KHAH ISOLATED FORM")
(64600 . "ARABIC LIGATURE YEH WITH MEEM ISOLATED FORM")
(64601 . "ARABIC LIGATURE YEH WITH ALEF MAKSURA ISOLATED FORM")
(64602 . "ARABIC LIGATURE YEH WITH YEH ISOLATED FORM")
(64603 . "ARABIC LIGATURE THAL WITH SUPERSCRIPT ALEF ISOLATED FORM")
(64604 . "ARABIC LIGATURE REH WITH SUPERSCRIPT ALEF ISOLATED FORM")
(64605 . "ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF ISOLATED FORM")
(64606 . "ARABIC LIGATURE SHADDA WITH DAMMATAN ISOLATED FORM")
(64607 . "ARABIC LIGATURE SHADDA WITH KASRATAN ISOLATED FORM")
(64608 . "ARABIC LIGATURE SHADDA WITH FATHA ISOLATED FORM")
(64609 . "ARABIC LIGATURE SHADDA WITH DAMMA ISOLATED FORM")
(64610 . "ARABIC LIGATURE SHADDA WITH KASRA ISOLATED FORM")
(64611 . "ARABIC LIGATURE SHADDA WITH SUPERSCRIPT ALEF ISOLATED FORM")
(64612 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH REH FINAL FORM")
(64613 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ZAIN FINAL FORM")
(64614 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM FINAL FORM")
(64615 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH NOON FINAL FORM")
(64616 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM")
(64617 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH FINAL FORM")
(64618 . "ARABIC LIGATURE BEH WITH REH FINAL FORM")
(64619 . "ARABIC LIGATURE BEH WITH ZAIN FINAL FORM")
(64620 . "ARABIC LIGATURE BEH WITH MEEM FINAL FORM")
(64621 . "ARABIC LIGATURE BEH WITH NOON FINAL FORM")
(64622 . "ARABIC LIGATURE BEH WITH ALEF MAKSURA FINAL FORM")
(64623 . "ARABIC LIGATURE BEH WITH YEH FINAL FORM")
(64624 . "ARABIC LIGATURE TEH WITH REH FINAL FORM")
(64625 . "ARABIC LIGATURE TEH WITH ZAIN FINAL FORM")
(64626 . "ARABIC LIGATURE TEH WITH MEEM FINAL FORM")
(64627 . "ARABIC LIGATURE TEH WITH NOON FINAL FORM")
(64628 . "ARABIC LIGATURE TEH WITH ALEF MAKSURA FINAL FORM")
(64629 . "ARABIC LIGATURE TEH WITH YEH FINAL FORM")
(64630 . "ARABIC LIGATURE THEH WITH REH FINAL FORM")
(64631 . "ARABIC LIGATURE THEH WITH ZAIN FINAL FORM")
(64632 . "ARABIC LIGATURE THEH WITH MEEM FINAL FORM")
(64633 . "ARABIC LIGATURE THEH WITH NOON FINAL FORM")
(64634 . "ARABIC LIGATURE THEH WITH ALEF MAKSURA FINAL FORM")
(64635 . "ARABIC LIGATURE THEH WITH YEH FINAL FORM")
(64636 . "ARABIC LIGATURE FEH WITH ALEF MAKSURA FINAL FORM")
(64637 . "ARABIC LIGATURE FEH WITH YEH FINAL FORM")
(64638 . "ARABIC LIGATURE QAF WITH ALEF MAKSURA FINAL FORM")
(64639 . "ARABIC LIGATURE QAF WITH YEH FINAL FORM")
(64640 . "ARABIC LIGATURE KAF WITH ALEF FINAL FORM")
(64641 . "ARABIC LIGATURE KAF WITH LAM FINAL FORM")
(64642 . "ARABIC LIGATURE KAF WITH MEEM FINAL FORM")
(64643 . "ARABIC LIGATURE KAF WITH ALEF MAKSURA FINAL FORM")
(64644 . "ARABIC LIGATURE KAF WITH YEH FINAL FORM")
(64645 . "ARABIC LIGATURE LAM WITH MEEM FINAL FORM")
(64646 . "ARABIC LIGATURE LAM WITH ALEF MAKSURA FINAL FORM")
(64647 . "ARABIC LIGATURE LAM WITH YEH FINAL FORM")
(64648 . "ARABIC LIGATURE MEEM WITH ALEF FINAL FORM")
(64649 . "ARABIC LIGATURE MEEM WITH MEEM FINAL FORM")
(64650 . "ARABIC LIGATURE NOON WITH REH FINAL FORM")
(64651 . "ARABIC LIGATURE NOON WITH ZAIN FINAL FORM")
(64652 . "ARABIC LIGATURE NOON WITH MEEM FINAL FORM")
(64653 . "ARABIC LIGATURE NOON WITH NOON FINAL FORM")
(64654 . "ARABIC LIGATURE NOON WITH ALEF MAKSURA FINAL FORM")
(64655 . "ARABIC LIGATURE NOON WITH YEH FINAL FORM")
(64656 . "ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF FINAL FORM")
(64657 . "ARABIC LIGATURE YEH WITH REH FINAL FORM")
(64658 . "ARABIC LIGATURE YEH WITH ZAIN FINAL FORM")
(64659 . "ARABIC LIGATURE YEH WITH MEEM FINAL FORM")
(64660 . "ARABIC LIGATURE YEH WITH NOON FINAL FORM")
(64661 . "ARABIC LIGATURE YEH WITH ALEF MAKSURA FINAL FORM")
(64662 . "ARABIC LIGATURE YEH WITH YEH FINAL FORM")
(64663 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM INITIAL FORM")
(64664 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH INITIAL FORM")
(64665 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH KHAH INITIAL FORM")
(64666 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM INITIAL FORM")
(64667 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH INITIAL FORM")
(64668 . "ARABIC LIGATURE BEH WITH JEEM INITIAL FORM")
(64669 . "ARABIC LIGATURE BEH WITH HAH INITIAL FORM")
(64670 . "ARABIC LIGATURE BEH WITH KHAH INITIAL FORM")
(64671 . "ARABIC LIGATURE BEH WITH MEEM INITIAL FORM")
(64672 . "ARABIC LIGATURE BEH WITH HEH INITIAL FORM")
(64673 . "ARABIC LIGATURE TEH WITH JEEM INITIAL FORM")
(64674 . "ARABIC LIGATURE TEH WITH HAH INITIAL FORM")
(64675 . "ARABIC LIGATURE TEH WITH KHAH INITIAL FORM")
(64676 . "ARABIC LIGATURE TEH WITH MEEM INITIAL FORM")
(64677 . "ARABIC LIGATURE TEH WITH HEH INITIAL FORM")
(64678 . "ARABIC LIGATURE THEH WITH MEEM INITIAL FORM")
(64679 . "ARABIC LIGATURE JEEM WITH HAH INITIAL FORM")
(64680 . "ARABIC LIGATURE JEEM WITH MEEM INITIAL FORM")
(64681 . "ARABIC LIGATURE HAH WITH JEEM INITIAL FORM")
(64682 . "ARABIC LIGATURE HAH WITH MEEM INITIAL FORM")
(64683 . "ARABIC LIGATURE KHAH WITH JEEM INITIAL FORM")
(64684 . "ARABIC LIGATURE KHAH WITH MEEM INITIAL FORM")
(64685 . "ARABIC LIGATURE SEEN WITH JEEM INITIAL FORM")
(64686 . "ARABIC LIGATURE SEEN WITH HAH INITIAL FORM")
(64687 . "ARABIC LIGATURE SEEN WITH KHAH INITIAL FORM")
(64688 . "ARABIC LIGATURE SEEN WITH MEEM INITIAL FORM")
(64689 . "ARABIC LIGATURE SAD WITH HAH INITIAL FORM")
(64690 . "ARABIC LIGATURE SAD WITH KHAH INITIAL FORM")
(64691 . "ARABIC LIGATURE SAD WITH MEEM INITIAL FORM")
(64692 . "ARABIC LIGATURE DAD WITH JEEM INITIAL FORM")
(64693 . "ARABIC LIGATURE DAD WITH HAH INITIAL FORM")
(64694 . "ARABIC LIGATURE DAD WITH KHAH INITIAL FORM")
(64695 . "ARABIC LIGATURE DAD WITH MEEM INITIAL FORM")
(64696 . "ARABIC LIGATURE TAH WITH HAH INITIAL FORM")
(64697 . "ARABIC LIGATURE ZAH WITH MEEM INITIAL FORM")
(64698 . "ARABIC LIGATURE AIN WITH JEEM INITIAL FORM")
(64699 . "ARABIC LIGATURE AIN WITH MEEM INITIAL FORM")
(64700 . "ARABIC LIGATURE GHAIN WITH JEEM INITIAL FORM")
(64701 . "ARABIC LIGATURE GHAIN WITH MEEM INITIAL FORM")
(64702 . "ARABIC LIGATURE FEH WITH JEEM INITIAL FORM")
(64703 . "ARABIC LIGATURE FEH WITH HAH INITIAL FORM")
(64704 . "ARABIC LIGATURE FEH WITH KHAH INITIAL FORM")
(64705 . "ARABIC LIGATURE FEH WITH MEEM INITIAL FORM")
(64706 . "ARABIC LIGATURE QAF WITH HAH INITIAL FORM")
(64707 . "ARABIC LIGATURE QAF WITH MEEM INITIAL FORM")
(64708 . "ARABIC LIGATURE KAF WITH JEEM INITIAL FORM")
(64709 . "ARABIC LIGATURE KAF WITH HAH INITIAL FORM")
(64710 . "ARABIC LIGATURE KAF WITH KHAH INITIAL FORM")
(64711 . "ARABIC LIGATURE KAF WITH LAM INITIAL FORM")
(64712 . "ARABIC LIGATURE KAF WITH MEEM INITIAL FORM")
(64713 . "ARABIC LIGATURE LAM WITH JEEM INITIAL FORM")
(64714 . "ARABIC LIGATURE LAM WITH HAH INITIAL FORM")
(64715 . "ARABIC LIGATURE LAM WITH KHAH INITIAL FORM")
(64716 . "ARABIC LIGATURE LAM WITH MEEM INITIAL FORM")
(64717 . "ARABIC LIGATURE LAM WITH HEH INITIAL FORM")
(64718 . "ARABIC LIGATURE MEEM WITH JEEM INITIAL FORM")
(64719 . "ARABIC LIGATURE MEEM WITH HAH INITIAL FORM")
(64720 . "ARABIC LIGATURE MEEM WITH KHAH INITIAL FORM")
(64721 . "ARABIC LIGATURE MEEM WITH MEEM INITIAL FORM")
(64722 . "ARABIC LIGATURE NOON WITH JEEM INITIAL FORM")
(64723 . "ARABIC LIGATURE NOON WITH HAH INITIAL FORM")
(64724 . "ARABIC LIGATURE NOON WITH KHAH INITIAL FORM")
(64725 . "ARABIC LIGATURE NOON WITH MEEM INITIAL FORM")
(64726 . "ARABIC LIGATURE NOON WITH HEH INITIAL FORM")
(64727 . "ARABIC LIGATURE HEH WITH JEEM INITIAL FORM")
(64728 . "ARABIC LIGATURE HEH WITH MEEM INITIAL FORM")
(64729 . "ARABIC LIGATURE HEH WITH SUPERSCRIPT ALEF INITIAL FORM")
(64730 . "ARABIC LIGATURE YEH WITH JEEM INITIAL FORM")
(64731 . "ARABIC LIGATURE YEH WITH HAH INITIAL FORM")
(64732 . "ARABIC LIGATURE YEH WITH KHAH INITIAL FORM")
(64733 . "ARABIC LIGATURE YEH WITH MEEM INITIAL FORM")
(64734 . "ARABIC LIGATURE YEH WITH HEH INITIAL FORM")
(64735 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM MEDIAL FORM")
(64736 . "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH MEDIAL FORM")
(64737 . "ARABIC LIGATURE BEH WITH MEEM MEDIAL FORM")
(64738 . "ARABIC LIGATURE BEH WITH HEH MEDIAL FORM")
(64739 . "ARABIC LIGATURE TEH WITH MEEM MEDIAL FORM")
(64740 . "ARABIC LIGATURE TEH WITH HEH MEDIAL FORM")
(64741 . "ARABIC LIGATURE THEH WITH MEEM MEDIAL FORM")
(64742 . "ARABIC LIGATURE THEH WITH HEH MEDIAL FORM")
(64743 . "ARABIC LIGATURE SEEN WITH MEEM MEDIAL FORM")
(64744 . "ARABIC LIGATURE SEEN WITH HEH MEDIAL FORM")
(64745 . "ARABIC LIGATURE SHEEN WITH MEEM MEDIAL FORM")
(64746 . "ARABIC LIGATURE SHEEN WITH HEH MEDIAL FORM")
(64747 . "ARABIC LIGATURE KAF WITH LAM MEDIAL FORM")
(64748 . "ARABIC LIGATURE KAF WITH MEEM MEDIAL FORM")
(64749 . "ARABIC LIGATURE LAM WITH MEEM MEDIAL FORM")
(64750 . "ARABIC LIGATURE NOON WITH MEEM MEDIAL FORM")
(64751 . "ARABIC LIGATURE NOON WITH HEH MEDIAL FORM")
(64752 . "ARABIC LIGATURE YEH WITH MEEM MEDIAL FORM")
(64753 . "ARABIC LIGATURE YEH WITH HEH MEDIAL FORM")
(64754 . "ARABIC LIGATURE SHADDA WITH FATHA MEDIAL FORM")
(64755 . "ARABIC LIGATURE SHADDA WITH DAMMA MEDIAL FORM")
(64756 . "ARABIC LIGATURE SHADDA WITH KASRA MEDIAL FORM")
(64757 . "ARABIC LIGATURE TAH WITH ALEF MAKSURA ISOLATED FORM")
(64758 . "ARABIC LIGATURE TAH WITH YEH ISOLATED FORM")
(64759 . "ARABIC LIGATURE AIN WITH ALEF MAKSURA ISOLATED FORM")
(64760 . "ARABIC LIGATURE AIN WITH YEH ISOLATED FORM")
(64761 . "ARABIC LIGATURE GHAIN WITH ALEF MAKSURA ISOLATED FORM")
(64762 . "ARABIC LIGATURE GHAIN WITH YEH ISOLATED FORM")
(64763 . "ARABIC LIGATURE SEEN WITH ALEF MAKSURA ISOLATED FORM")
(64764 . "ARABIC LIGATURE SEEN WITH YEH ISOLATED FORM")
(64765 . "ARABIC LIGATURE SHEEN WITH ALEF MAKSURA ISOLATED FORM")
(64766 . "ARABIC LIGATURE SHEEN WITH YEH ISOLATED FORM")
(64767 . "ARABIC LIGATURE HAH WITH ALEF MAKSURA ISOLATED FORM")
(64768 . "ARABIC LIGATURE HAH WITH YEH ISOLATED FORM")
(64769 . "ARABIC LIGATURE JEEM WITH ALEF MAKSURA ISOLATED FORM")
(64770 . "ARABIC LIGATURE JEEM WITH YEH ISOLATED FORM")
(64771 . "ARABIC LIGATURE KHAH WITH ALEF MAKSURA ISOLATED FORM")
(64772 . "ARABIC LIGATURE KHAH WITH YEH ISOLATED FORM")
(64773 . "ARABIC LIGATURE SAD WITH ALEF MAKSURA ISOLATED FORM")
(64774 . "ARABIC LIGATURE SAD WITH YEH ISOLATED FORM")
(64775 . "ARABIC LIGATURE DAD WITH ALEF MAKSURA ISOLATED FORM")
(64776 . "ARABIC LIGATURE DAD WITH YEH ISOLATED FORM")
(64777 . "ARABIC LIGATURE SHEEN WITH JEEM ISOLATED FORM")
(64778 . "ARABIC LIGATURE SHEEN WITH HAH ISOLATED FORM")
(64779 . "ARABIC LIGATURE SHEEN WITH KHAH ISOLATED FORM")
(64780 . "ARABIC LIGATURE SHEEN WITH MEEM ISOLATED FORM")
(64781 . "ARABIC LIGATURE SHEEN WITH REH ISOLATED FORM")
(64782 . "ARABIC LIGATURE SEEN WITH REH ISOLATED FORM")
(64783 . "ARABIC LIGATURE SAD WITH REH ISOLATED FORM")
(64784 . "ARABIC LIGATURE DAD WITH REH ISOLATED FORM")
(64785 . "ARABIC LIGATURE TAH WITH ALEF MAKSURA FINAL FORM")
(64786 . "ARABIC LIGATURE TAH WITH YEH FINAL FORM")
(64787 . "ARABIC LIGATURE AIN WITH ALEF MAKSURA FINAL FORM")
(64788 . "ARABIC LIGATURE AIN WITH YEH FINAL FORM")
(64789 . "ARABIC LIGATURE GHAIN WITH ALEF MAKSURA FINAL FORM")
(64790 . "ARABIC LIGATURE GHAIN WITH YEH FINAL FORM")
(64791 . "ARABIC LIGATURE SEEN WITH ALEF MAKSURA FINAL FORM")
(64792 . "ARABIC LIGATURE SEEN WITH YEH FINAL FORM")
(64793 . "ARABIC LIGATURE SHEEN WITH ALEF MAKSURA FINAL FORM")
(64794 . "ARABIC LIGATURE SHEEN WITH YEH FINAL FORM")
(64795 . "ARABIC LIGATURE HAH WITH ALEF MAKSURA FINAL FORM")
(64796 . "ARABIC LIGATURE HAH WITH YEH FINAL FORM")
(64797 . "ARABIC LIGATURE JEEM WITH ALEF MAKSURA FINAL FORM")
(64798 . "ARABIC LIGATURE JEEM WITH YEH FINAL FORM")
(64799 . "ARABIC LIGATURE KHAH WITH ALEF MAKSURA FINAL FORM")
(64800 . "ARABIC LIGATURE KHAH WITH YEH FINAL FORM")
(64801 . "ARABIC LIGATURE SAD WITH ALEF MAKSURA FINAL FORM")
(64802 . "ARABIC LIGATURE SAD WITH YEH FINAL FORM")
(64803 . "ARABIC LIGATURE DAD WITH ALEF MAKSURA FINAL FORM")
(64804 . "ARABIC LIGATURE DAD WITH YEH FINAL FORM")
(64805 . "ARABIC LIGATURE SHEEN WITH JEEM FINAL FORM")
(64806 . "ARABIC LIGATURE SHEEN WITH HAH FINAL FORM")
(64807 . "ARABIC LIGATURE SHEEN WITH KHAH FINAL FORM")
(64808 . "ARABIC LIGATURE SHEEN WITH MEEM FINAL FORM")
(64809 . "ARABIC LIGATURE SHEEN WITH REH FINAL FORM")
(64810 . "ARABIC LIGATURE SEEN WITH REH FINAL FORM")
(64811 . "ARABIC LIGATURE SAD WITH REH FINAL FORM")
(64812 . "ARABIC LIGATURE DAD WITH REH FINAL FORM")
(64813 . "ARABIC LIGATURE SHEEN WITH JEEM INITIAL FORM")
(64814 . "ARABIC LIGATURE SHEEN WITH HAH INITIAL FORM")
(64815 . "ARABIC LIGATURE SHEEN WITH KHAH INITIAL FORM")
(64816 . "ARABIC LIGATURE SHEEN WITH MEEM INITIAL FORM")
(64817 . "ARABIC LIGATURE SEEN WITH HEH INITIAL FORM")
(64818 . "ARABIC LIGATURE SHEEN WITH HEH INITIAL FORM")
(64819 . "ARABIC LIGATURE TAH WITH MEEM INITIAL FORM")
(64820 . "ARABIC LIGATURE SEEN WITH JEEM MEDIAL FORM")
(64821 . "ARABIC LIGATURE SEEN WITH HAH MEDIAL FORM")
(64822 . "ARABIC LIGATURE SEEN WITH KHAH MEDIAL FORM")
(64823 . "ARABIC LIGATURE SHEEN WITH JEEM MEDIAL FORM")
(64824 . "ARABIC LIGATURE SHEEN WITH HAH MEDIAL FORM")
(64825 . "ARABIC LIGATURE SHEEN WITH KHAH MEDIAL FORM")
(64826 . "ARABIC LIGATURE TAH WITH MEEM MEDIAL FORM")
(64827 . "ARABIC LIGATURE ZAH WITH MEEM MEDIAL FORM")
(64828 . "ARABIC LIGATURE ALEF WITH FATHATAN FINAL FORM")
(64829 . "ARABIC LIGATURE ALEF WITH FATHATAN ISOLATED FORM")
(64830 . "ORNATE LEFT PARENTHESIS")
(64831 . "ORNATE RIGHT PARENTHESIS")
((64832 . 64848) . #f)
(64848 . "ARABIC LIGATURE TEH WITH JEEM WITH MEEM INITIAL FORM")
(64849 . "ARABIC LIGATURE TEH WITH HAH WITH JEEM FINAL FORM")
(64850 . "ARABIC LIGATURE TEH WITH HAH WITH JEEM INITIAL FORM")
(64851 . "ARABIC LIGATURE TEH WITH HAH WITH MEEM INITIAL FORM")
(64852 . "ARABIC LIGATURE TEH WITH KHAH WITH MEEM INITIAL FORM")
(64853 . "ARABIC LIGATURE TEH WITH MEEM WITH JEEM INITIAL FORM")
(64854 . "ARABIC LIGATURE TEH WITH MEEM WITH HAH INITIAL FORM")
(64855 . "ARABIC LIGATURE TEH WITH MEEM WITH KHAH INITIAL FORM")
(64856 . "ARABIC LIGATURE JEEM WITH MEEM WITH HAH FINAL FORM")
(64857 . "ARABIC LIGATURE JEEM WITH MEEM WITH HAH INITIAL FORM")
(64858 . "ARABIC LIGATURE HAH WITH MEEM WITH YEH FINAL FORM")
(64859 . "ARABIC LIGATURE HAH WITH MEEM WITH ALEF MAKSURA FINAL FORM")
(64860 . "ARABIC LIGATURE SEEN WITH HAH WITH JEEM INITIAL FORM")
(64861 . "ARABIC LIGATURE SEEN WITH JEEM WITH HAH INITIAL FORM")
(64862 . "ARABIC LIGATURE SEEN WITH JEEM WITH ALEF MAKSURA FINAL FORM")
(64863 . "ARABIC LIGATURE SEEN WITH MEEM WITH HAH FINAL FORM")
(64864 . "ARABIC LIGATURE SEEN WITH MEEM WITH HAH INITIAL FORM")
(64865 . "ARABIC LIGATURE SEEN WITH MEEM WITH JEEM INITIAL FORM")
(64866 . "ARABIC LIGATURE SEEN WITH MEEM WITH MEEM FINAL FORM")
(64867 . "ARABIC LIGATURE SEEN WITH MEEM WITH MEEM INITIAL FORM")
(64868 . "ARABIC LIGATURE SAD WITH HAH WITH HAH FINAL FORM")
(64869 . "ARABIC LIGATURE SAD WITH HAH WITH HAH INITIAL FORM")
(64870 . "ARABIC LIGATURE SAD WITH MEEM WITH MEEM FINAL FORM")
(64871 . "ARABIC LIGATURE SHEEN WITH HAH WITH MEEM FINAL FORM")
(64872 . "ARABIC LIGATURE SHEEN WITH HAH WITH MEEM INITIAL FORM")
(64873 . "ARABIC LIGATURE SHEEN WITH JEEM WITH YEH FINAL FORM")
(64874 . "ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH FINAL FORM")
(64875 . "ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH INITIAL FORM")
(64876 . "ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM FINAL FORM")
(64877 . "ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM INITIAL FORM")
(64878 . "ARABIC LIGATURE DAD WITH HAH WITH ALEF MAKSURA FINAL FORM")
(64879 . "ARABIC LIGATURE DAD WITH KHAH WITH MEEM FINAL FORM")
(64880 . "ARABIC LIGATURE DAD WITH KHAH WITH MEEM INITIAL FORM")
(64881 . "ARABIC LIGATURE TAH WITH MEEM WITH HAH FINAL FORM")
(64882 . "ARABIC LIGATURE TAH WITH MEEM WITH HAH INITIAL FORM")
(64883 . "ARABIC LIGATURE TAH WITH MEEM WITH MEEM INITIAL FORM")
(64884 . "ARABIC LIGATURE TAH WITH MEEM WITH YEH FINAL FORM")
(64885 . "ARABIC LIGATURE AIN WITH JEEM WITH MEEM FINAL FORM")
(64886 . "ARABIC LIGATURE AIN WITH MEEM WITH MEEM FINAL FORM")
(64887 . "ARABIC LIGATURE AIN WITH MEEM WITH MEEM INITIAL FORM")
(64888 . "ARABIC LIGATURE AIN WITH MEEM WITH ALEF MAKSURA FINAL FORM")
(64889 . "ARABIC LIGATURE GHAIN WITH MEEM WITH MEEM FINAL FORM")
(64890 . "ARABIC LIGATURE GHAIN WITH MEEM WITH YEH FINAL FORM")
(64891 . "ARABIC LIGATURE GHAIN WITH MEEM WITH ALEF MAKSURA FINAL FORM")
(64892 . "ARABIC LIGATURE FEH WITH KHAH WITH MEEM FINAL FORM")
(64893 . "ARABIC LIGATURE FEH WITH KHAH WITH MEEM INITIAL FORM")
(64894 . "ARABIC LIGATURE QAF WITH MEEM WITH HAH FINAL FORM")
(64895 . "ARABIC LIGATURE QAF WITH MEEM WITH MEEM FINAL FORM")
(64896 . "ARABIC LIGATURE LAM WITH HAH WITH MEEM FINAL FORM")
(64897 . "ARABIC LIGATURE LAM WITH HAH WITH YEH FINAL FORM")
(64898 . "ARABIC LIGATURE LAM WITH HAH WITH ALEF MAKSURA FINAL FORM")
(64899 . "ARABIC LIGATURE LAM WITH JEEM WITH JEEM INITIAL FORM")
(64900 . "ARABIC LIGATURE LAM WITH JEEM WITH JEEM FINAL FORM")
(64901 . "ARABIC LIGATURE LAM WITH KHAH WITH MEEM FINAL FORM")
(64902 . "ARABIC LIGATURE LAM WITH KHAH WITH MEEM INITIAL FORM")
(64903 . "ARABIC LIGATURE LAM WITH MEEM WITH HAH FINAL FORM")
(64904 . "ARABIC LIGATURE LAM WITH MEEM WITH HAH INITIAL FORM")
(64905 . "ARABIC LIGATURE MEEM WITH HAH WITH JEEM INITIAL FORM")
(64906 . "ARABIC LIGATURE MEEM WITH HAH WITH MEEM INITIAL FORM")
(64907 . "ARABIC LIGATURE MEEM WITH HAH WITH YEH FINAL FORM")
(64908 . "ARABIC LIGATURE MEEM WITH JEEM WITH HAH INITIAL FORM")
(64909 . "ARABIC LIGATURE MEEM WITH JEEM WITH MEEM INITIAL FORM")
(64910 . "ARABIC LIGATURE MEEM WITH KHAH WITH JEEM INITIAL FORM")
(64911 . "ARABIC LIGATURE MEEM WITH KHAH WITH MEEM INITIAL FORM")
((64912 . 64914) . #f)
(64914 . "ARABIC LIGATURE MEEM WITH JEEM WITH KHAH INITIAL FORM")
(64915 . "ARABIC LIGATURE HEH WITH MEEM WITH JEEM INITIAL FORM")
(64916 . "ARABIC LIGATURE HEH WITH MEEM WITH MEEM INITIAL FORM")
(64917 . "ARABIC LIGATURE NOON WITH HAH WITH MEEM INITIAL FORM")
(64918 . "ARABIC LIGATURE NOON WITH HAH WITH ALEF MAKSURA FINAL FORM")
(64919 . "ARABIC LIGATURE NOON WITH JEEM WITH MEEM FINAL FORM")
(64920 . "ARABIC LIGATURE NOON WITH JEEM WITH MEEM INITIAL FORM")
(64921 . "ARABIC LIGATURE NOON WITH JEEM WITH ALEF MAKSURA FINAL FORM")
(64922 . "ARABIC LIGATURE NOON WITH MEEM WITH YEH FINAL FORM")
(64923 . "ARABIC LIGATURE NOON WITH MEEM WITH ALEF MAKSURA FINAL FORM")
(64924 . "ARABIC LIGATURE YEH WITH MEEM WITH MEEM FINAL FORM")
(64925 . "ARABIC LIGATURE YEH WITH MEEM WITH MEEM INITIAL FORM")
(64926 . "ARABIC LIGATURE BEH WITH KHAH WITH YEH FINAL FORM")
(64927 . "ARABIC LIGATURE TEH WITH JEEM WITH YEH FINAL FORM")
(64928 . "ARABIC LIGATURE TEH WITH JEEM WITH ALEF MAKSURA FINAL FORM")
(64929 . "ARABIC LIGATURE TEH WITH KHAH WITH YEH FINAL FORM")
(64930 . "ARABIC LIGATURE TEH WITH KHAH WITH ALEF MAKSURA FINAL FORM")
(64931 . "ARABIC LIGATURE TEH WITH MEEM WITH YEH FINAL FORM")
(64932 . "ARABIC LIGATURE TEH WITH MEEM WITH ALEF MAKSURA FINAL FORM")
(64933 . "ARABIC LIGATURE JEEM WITH MEEM WITH YEH FINAL FORM")
(64934 . "ARABIC LIGATURE JEEM WITH HAH WITH ALEF MAKSURA FINAL FORM")
(64935 . "ARABIC LIGATURE JEEM WITH MEEM WITH ALEF MAKSURA FINAL FORM")
(64936 . "ARABIC LIGATURE SEEN WITH KHAH WITH ALEF MAKSURA FINAL FORM")
(64937 . "ARABIC LIGATURE SAD WITH HAH WITH YEH FINAL FORM")
(64938 . "ARABIC LIGATURE SHEEN WITH HAH WITH YEH FINAL FORM")
(64939 . "ARABIC LIGATURE DAD WITH HAH WITH YEH FINAL FORM")
(64940 . "ARABIC LIGATURE LAM WITH JEEM WITH YEH FINAL FORM")
(64941 . "ARABIC LIGATURE LAM WITH MEEM WITH YEH FINAL FORM")
(64942 . "ARABIC LIGATURE YEH WITH HAH WITH YEH FINAL FORM")
(64943 . "ARABIC LIGATURE YEH WITH JEEM WITH YEH FINAL FORM")
(64944 . "ARABIC LIGATURE YEH WITH MEEM WITH YEH FINAL FORM")
(64945 . "ARABIC LIGATURE MEEM WITH MEEM WITH YEH FINAL FORM")
(64946 . "ARABIC LIGATURE QAF WITH MEEM WITH YEH FINAL FORM")
(64947 . "ARABIC LIGATURE NOON WITH HAH WITH YEH FINAL FORM")
(64948 . "ARABIC LIGATURE QAF WITH MEEM WITH HAH INITIAL FORM")
(64949 . "ARABIC LIGATURE LAM WITH HAH WITH MEEM INITIAL FORM")
(64950 . "ARABIC LIGATURE AIN WITH MEEM WITH YEH FINAL FORM")
(64951 . "ARABIC LIGATURE KAF WITH MEEM WITH YEH FINAL FORM")
(64952 . "ARABIC LIGATURE NOON WITH JEEM WITH HAH INITIAL FORM")
(64953 . "ARABIC LIGATURE MEEM WITH KHAH WITH YEH FINAL FORM")
(64954 . "ARABIC LIGATURE LAM WITH JEEM WITH MEEM INITIAL FORM")
(64955 . "ARABIC LIGATURE KAF WITH MEEM WITH MEEM FINAL FORM")
(64956 . "ARABIC LIGATURE LAM WITH JEEM WITH MEEM FINAL FORM")
(64957 . "ARABIC LIGATURE NOON WITH JEEM WITH HAH FINAL FORM")
(64958 . "ARABIC LIGATURE JEEM WITH HAH WITH YEH FINAL FORM")
(64959 . "ARABIC LIGATURE HAH WITH JEEM WITH YEH FINAL FORM")
(64960 . "ARABIC LIGATURE MEEM WITH JEEM WITH YEH FINAL FORM")
(64961 . "ARABIC LIGATURE FEH WITH MEEM WITH YEH FINAL FORM")
(64962 . "ARABIC LIGATURE BEH WITH HAH WITH YEH FINAL FORM")
(64963 . "ARABIC LIGATURE KAF WITH MEEM WITH MEEM INITIAL FORM")
(64964 . "ARABIC LIGATURE AIN WITH JEEM WITH MEEM INITIAL FORM")
(64965 . "ARABIC LIGATURE SAD WITH MEEM WITH MEEM INITIAL FORM")
(64966 . "ARABIC LIGATURE SEEN WITH KHAH WITH YEH FINAL FORM")
(64967 . "ARABIC LIGATURE NOON WITH JEEM WITH YEH FINAL FORM")
((64968 . 65008) . #f)
(65008 . "ARABIC LIGATURE SALLA USED AS KORANIC STOP SIGN ISOLATED FORM")
(65009 . "ARABIC LIGATURE QALA USED AS KORANIC STOP SIGN ISOLATED FORM")
(65010 . "ARABIC LIGATURE ALLAH ISOLATED FORM")
(65011 . "ARABIC LIGATURE AKBAR ISOLATED FORM")
(65012 . "ARABIC LIGATURE MOHAMMAD ISOLATED FORM")
(65013 . "ARABIC LIGATURE SALAM ISOLATED FORM")
(65014 . "ARABIC LIGATURE RASOUL ISOLATED FORM")
(65015 . "ARABIC LIGATURE ALAYHE ISOLATED FORM")
(65016 . "ARABIC LIGATURE WASALLAM ISOLATED FORM")
(65017 . "ARABIC LIGATURE SALLA ISOLATED FORM")
(65018 . "ARABIC LIGATURE SALLALLAHOU ALAYHE WASALLAM")
(65019 . "ARABIC LIGATURE JALLAJALALOUHOU")
(65020 . "RIAL SIGN")
(65021 . "ARABIC LIGATURE BISMILLAH AR-RAHMAN AR-RAHEEM")
((65022 . 65024) . #f)
(65024 . "VARIATION SELECTOR-1")
(65025 . "VARIATION SELECTOR-2")
(65026 . "VARIATION SELECTOR-3")
(65027 . "VARIATION SELECTOR-4")
(65028 . "VARIATION SELECTOR-5")
(65029 . "VARIATION SELECTOR-6")
(65030 . "VARIATION SELECTOR-7")
(65031 . "VARIATION SELECTOR-8")
(65032 . "VARIATION SELECTOR-9")
(65033 . "VARIATION SELECTOR-10")
(65034 . "VARIATION SELECTOR-11")
(65035 . "VARIATION SELECTOR-12")
(65036 . "VARIATION SELECTOR-13")
(65037 . "VARIATION SELECTOR-14")
(65038 . "VARIATION SELECTOR-15")
(65039 . "VARIATION SELECTOR-16")
(65040 . "PRESENTATION FORM FOR VERTICAL COMMA")
(65041 . "PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC COMMA")
(65042 . "PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC FULL STOP")
(65043 . "PRESENTATION FORM FOR VERTICAL COLON")
(65044 . "PRESENTATION FORM FOR VERTICAL SEMICOLON")
(65045 . "PRESENTATION FORM FOR VERTICAL EXCLAMATION MARK")
(65046 . "PRESENTATION FORM FOR VERTICAL QUESTION MARK")
(65047 . "PRESENTATION FORM FOR VERTICAL LEFT WHITE LENTICULAR BRACKET")
(65048 . "PRESENTATION FORM FOR VERTICAL RIGHT WHITE LENTICULAR BRAKCET")
(65049 . "PRESENTATION FORM FOR VERTICAL HORIZONTAL ELLIPSIS")
((65050 . 65056) . #f)
(65056 . "COMBINING LIGATURE LEFT HALF")
(65057 . "COMBINING LIGATURE RIGHT HALF")
(65058 . "COMBINING DOUBLE TILDE LEFT HALF")
(65059 . "COMBINING DOUBLE TILDE RIGHT HALF")
(65060 . "COMBINING MACRON LEFT HALF")
(65061 . "COMBINING MACRON RIGHT HALF")
(65062 . "COMBINING CONJOINING MACRON")
(65063 . "COMBINING LIGATURE LEFT HALF BELOW")
(65064 . "COMBINING LIGATURE RIGHT HALF BELOW")
(65065 . "COMBINING TILDE LEFT HALF BELOW")
(65066 . "COMBINING TILDE RIGHT HALF BELOW")
(65067 . "COMBINING MACRON LEFT HALF BELOW")
(65068 . "COMBINING MACRON RIGHT HALF BELOW")
(65069 . "COMBINING CONJOINING MACRON BELOW")
(65070 . "COMBINING CYRILLIC TITLO LEFT HALF")
(65071 . "COMBINING CYRILLIC TITLO RIGHT HALF")
(65072 . "PRESENTATION FORM FOR VERTICAL TWO DOT LEADER")
(65073 . "PRESENTATION FORM FOR VERTICAL EM DASH")
(65074 . "PRESENTATION FORM FOR VERTICAL EN DASH")
(65075 . "PRESENTATION FORM FOR VERTICAL LOW LINE")
(65076 . "PRESENTATION FORM FOR VERTICAL WAVY LOW LINE")
(65077 . "PRESENTATION FORM FOR VERTICAL LEFT PARENTHESIS")
(65078 . "PRESENTATION FORM FOR VERTICAL RIGHT PARENTHESIS")
(65079 . "PRESENTATION FORM FOR VERTICAL LEFT CURLY BRACKET")
(65080 . "PRESENTATION FORM FOR VERTICAL RIGHT CURLY BRACKET")
(65081 . "PRESENTATION FORM FOR VERTICAL LEFT TORTOISE SHELL BRACKET")
(65082 . "PRESENTATION FORM FOR VERTICAL RIGHT TORTOISE SHELL BRACKET")
(65083 . "PRESENTATION FORM FOR VERTICAL LEFT BLACK LENTICULAR BRACKET")
(65084 . "PRESENTATION FORM FOR VERTICAL RIGHT BLACK LENTICULAR BRACKET")
(65085 . "PRESENTATION FORM FOR VERTICAL LEFT DOUBLE ANGLE BRACKET")
(65086 . "PRESENTATION FORM FOR VERTICAL RIGHT DOUBLE ANGLE BRACKET")
(65087 . "PRESENTATION FORM FOR VERTICAL LEFT ANGLE BRACKET")
(65088 . "PRESENTATION FORM FOR VERTICAL RIGHT ANGLE BRACKET")
(65089 . "PRESENTATION FORM FOR VERTICAL LEFT CORNER BRACKET")
(65090 . "PRESENTATION FORM FOR VERTICAL RIGHT CORNER BRACKET")
(65091 . "PRESENTATION FORM FOR VERTICAL LEFT WHITE CORNER BRACKET")
(65092 . "PRESENTATION FORM FOR VERTICAL RIGHT WHITE CORNER BRACKET")
(65093 . "SESAME DOT")
(65094 . "WHITE SESAME DOT")
(65095 . "PRESENTATION FORM FOR VERTICAL LEFT SQUARE BRACKET")
(65096 . "PRESENTATION FORM FOR VERTICAL RIGHT SQUARE BRACKET")
(65097 . "DASHED OVERLINE")
(65098 . "CENTRELINE OVERLINE")
(65099 . "WAVY OVERLINE")
(65100 . "DOUBLE WAVY OVERLINE")
(65101 . "DASHED LOW LINE")
(65102 . "CENTRELINE LOW LINE")
(65103 . "WAVY LOW LINE")
(65104 . "SMALL COMMA")
(65105 . "SMALL IDEOGRAPHIC COMMA")
(65106 . "SMALL FULL STOP")
(65107 . #f)
(65108 . "SMALL SEMICOLON")
(65109 . "SMALL COLON")
(65110 . "SMALL QUESTION MARK")
(65111 . "SMALL EXCLAMATION MARK")
(65112 . "SMALL EM DASH")
(65113 . "SMALL LEFT PARENTHESIS")
(65114 . "SMALL RIGHT PARENTHESIS")
(65115 . "SMALL LEFT CURLY BRACKET")
(65116 . "SMALL RIGHT CURLY BRACKET")
(65117 . "SMALL LEFT TORTOISE SHELL BRACKET")
(65118 . "SMALL RIGHT TORTOISE SHELL BRACKET")
(65119 . "SMALL NUMBER SIGN")
(65120 . "SMALL AMPERSAND")
(65121 . "SMALL ASTERISK")
(65122 . "SMALL PLUS SIGN")
(65123 . "SMALL HYPHEN-MINUS")
(65124 . "SMALL LESS-THAN SIGN")
(65125 . "SMALL GREATER-THAN SIGN")
(65126 . "SMALL EQUALS SIGN")
(65127 . #f)
(65128 . "SMALL REVERSE SOLIDUS")
(65129 . "SMALL DOLLAR SIGN")
(65130 . "SMALL PERCENT SIGN")
(65131 . "SMALL COMMERCIAL AT")
((65132 . 65136) . #f)
(65136 . "ARABIC FATHATAN ISOLATED FORM")
(65137 . "ARABIC TATWEEL WITH FATHATAN ABOVE")
(65138 . "ARABIC DAMMATAN ISOLATED FORM")
(65139 . "ARABIC TAIL FRAGMENT")
(65140 . "ARABIC KASRATAN ISOLATED FORM")
(65141 . #f)
(65142 . "ARABIC FATHA ISOLATED FORM")
(65143 . "ARABIC FATHA MEDIAL FORM")
(65144 . "ARABIC DAMMA ISOLATED FORM")
(65145 . "ARABIC DAMMA MEDIAL FORM")
(65146 . "ARABIC KASRA ISOLATED FORM")
(65147 . "ARABIC KASRA MEDIAL FORM")
(65148 . "ARABIC SHADDA ISOLATED FORM")
(65149 . "ARABIC SHADDA MEDIAL FORM")
(65150 . "ARABIC SUKUN ISOLATED FORM")
(65151 . "ARABIC SUKUN MEDIAL FORM")
(65152 . "ARABIC LETTER HAMZA ISOLATED FORM")
(65153 . "ARABIC LETTER ALEF WITH MADDA ABOVE ISOLATED FORM")
(65154 . "ARABIC LETTER ALEF WITH MADDA ABOVE FINAL FORM")
(65155 . "ARABIC LETTER ALEF WITH HAMZA ABOVE ISOLATED FORM")
(65156 . "ARABIC LETTER ALEF WITH HAMZA ABOVE FINAL FORM")
(65157 . "ARABIC LETTER WAW WITH HAMZA ABOVE ISOLATED FORM")
(65158 . "ARABIC LETTER WAW WITH HAMZA ABOVE FINAL FORM")
(65159 . "ARABIC LETTER ALEF WITH HAMZA BELOW ISOLATED FORM")
(65160 . "ARABIC LETTER ALEF WITH HAMZA BELOW FINAL FORM")
(65161 . "ARABIC LETTER YEH WITH HAMZA ABOVE ISOLATED FORM")
(65162 . "ARABIC LETTER YEH WITH HAMZA ABOVE FINAL FORM")
(65163 . "ARABIC LETTER YEH WITH HAMZA ABOVE INITIAL FORM")
(65164 . "ARABIC LETTER YEH WITH HAMZA ABOVE MEDIAL FORM")
(65165 . "ARABIC LETTER ALEF ISOLATED FORM")
(65166 . "ARABIC LETTER ALEF FINAL FORM")
(65167 . "ARABIC LETTER BEH ISOLATED FORM")
(65168 . "ARABIC LETTER BEH FINAL FORM")
(65169 . "ARABIC LETTER BEH INITIAL FORM")
(65170 . "ARABIC LETTER BEH MEDIAL FORM")
(65171 . "ARABIC LETTER TEH MARBUTA ISOLATED FORM")
(65172 . "ARABIC LETTER TEH MARBUTA FINAL FORM")
(65173 . "ARABIC LETTER TEH ISOLATED FORM")
(65174 . "ARABIC LETTER TEH FINAL FORM")
(65175 . "ARABIC LETTER TEH INITIAL FORM")
(65176 . "ARABIC LETTER TEH MEDIAL FORM")
(65177 . "ARABIC LETTER THEH ISOLATED FORM")
(65178 . "ARABIC LETTER THEH FINAL FORM")
(65179 . "ARABIC LETTER THEH INITIAL FORM")
(65180 . "ARABIC LETTER THEH MEDIAL FORM")
(65181 . "ARABIC LETTER JEEM ISOLATED FORM")
(65182 . "ARABIC LETTER JEEM FINAL FORM")
(65183 . "ARABIC LETTER JEEM INITIAL FORM")
(65184 . "ARABIC LETTER JEEM MEDIAL FORM")
(65185 . "ARABIC LETTER HAH ISOLATED FORM")
(65186 . "ARABIC LETTER HAH FINAL FORM")
(65187 . "ARABIC LETTER HAH INITIAL FORM")
(65188 . "ARABIC LETTER HAH MEDIAL FORM")
(65189 . "ARABIC LETTER KHAH ISOLATED FORM")
(65190 . "ARABIC LETTER KHAH FINAL FORM")
(65191 . "ARABIC LETTER KHAH INITIAL FORM")
(65192 . "ARABIC LETTER KHAH MEDIAL FORM")
(65193 . "ARABIC LETTER DAL ISOLATED FORM")
(65194 . "ARABIC LETTER DAL FINAL FORM")
(65195 . "ARABIC LETTER THAL ISOLATED FORM")
(65196 . "ARABIC LETTER THAL FINAL FORM")
(65197 . "ARABIC LETTER REH ISOLATED FORM")
(65198 . "ARABIC LETTER REH FINAL FORM")
(65199 . "ARABIC LETTER ZAIN ISOLATED FORM")
(65200 . "ARABIC LETTER ZAIN FINAL FORM")
(65201 . "ARABIC LETTER SEEN ISOLATED FORM")
(65202 . "ARABIC LETTER SEEN FINAL FORM")
(65203 . "ARABIC LETTER SEEN INITIAL FORM")
(65204 . "ARABIC LETTER SEEN MEDIAL FORM")
(65205 . "ARABIC LETTER SHEEN ISOLATED FORM")
(65206 . "ARABIC LETTER SHEEN FINAL FORM")
(65207 . "ARABIC LETTER SHEEN INITIAL FORM")
(65208 . "ARABIC LETTER SHEEN MEDIAL FORM")
(65209 . "ARABIC LETTER SAD ISOLATED FORM")
(65210 . "ARABIC LETTER SAD FINAL FORM")
(65211 . "ARABIC LETTER SAD INITIAL FORM")
(65212 . "ARABIC LETTER SAD MEDIAL FORM")
(65213 . "ARABIC LETTER DAD ISOLATED FORM")
(65214 . "ARABIC LETTER DAD FINAL FORM")
(65215 . "ARABIC LETTER DAD INITIAL FORM")
(65216 . "ARABIC LETTER DAD MEDIAL FORM")
(65217 . "ARABIC LETTER TAH ISOLATED FORM")
(65218 . "ARABIC LETTER TAH FINAL FORM")
(65219 . "ARABIC LETTER TAH INITIAL FORM")
(65220 . "ARABIC LETTER TAH MEDIAL FORM")
(65221 . "ARABIC LETTER ZAH ISOLATED FORM")
(65222 . "ARABIC LETTER ZAH FINAL FORM")
(65223 . "ARABIC LETTER ZAH INITIAL FORM")
(65224 . "ARABIC LETTER ZAH MEDIAL FORM")
(65225 . "ARABIC LETTER AIN ISOLATED FORM")
(65226 . "ARABIC LETTER AIN FINAL FORM")
(65227 . "ARABIC LETTER AIN INITIAL FORM")
(65228 . "ARABIC LETTER AIN MEDIAL FORM")
(65229 . "ARABIC LETTER GHAIN ISOLATED FORM")
(65230 . "ARABIC LETTER GHAIN FINAL FORM")
(65231 . "ARABIC LETTER GHAIN INITIAL FORM")
(65232 . "ARABIC LETTER GHAIN MEDIAL FORM")
(65233 . "ARABIC LETTER FEH ISOLATED FORM")
(65234 . "ARABIC LETTER FEH FINAL FORM")
(65235 . "ARABIC LETTER FEH INITIAL FORM")
(65236 . "ARABIC LETTER FEH MEDIAL FORM")
(65237 . "ARABIC LETTER QAF ISOLATED FORM")
(65238 . "ARABIC LETTER QAF FINAL FORM")
(65239 . "ARABIC LETTER QAF INITIAL FORM")
(65240 . "ARABIC LETTER QAF MEDIAL FORM")
(65241 . "ARABIC LETTER KAF ISOLATED FORM")
(65242 . "ARABIC LETTER KAF FINAL FORM")
(65243 . "ARABIC LETTER KAF INITIAL FORM")
(65244 . "ARABIC LETTER KAF MEDIAL FORM")
(65245 . "ARABIC LETTER LAM ISOLATED FORM")
(65246 . "ARABIC LETTER LAM FINAL FORM")
(65247 . "ARABIC LETTER LAM INITIAL FORM")
(65248 . "ARABIC LETTER LAM MEDIAL FORM")
(65249 . "ARABIC LETTER MEEM ISOLATED FORM")
(65250 . "ARABIC LETTER MEEM FINAL FORM")
(65251 . "ARABIC LETTER MEEM INITIAL FORM")
(65252 . "ARABIC LETTER MEEM MEDIAL FORM")
(65253 . "ARABIC LETTER NOON ISOLATED FORM")
(65254 . "ARABIC LETTER NOON FINAL FORM")
(65255 . "ARABIC LETTER NOON INITIAL FORM")
(65256 . "ARABIC LETTER NOON MEDIAL FORM")
(65257 . "ARABIC LETTER HEH ISOLATED FORM")
(65258 . "ARABIC LETTER HEH FINAL FORM")
(65259 . "ARABIC LETTER HEH INITIAL FORM")
(65260 . "ARABIC LETTER HEH MEDIAL FORM")
(65261 . "ARABIC LETTER WAW ISOLATED FORM")
(65262 . "ARABIC LETTER WAW FINAL FORM")
(65263 . "ARABIC LETTER ALEF MAKSURA ISOLATED FORM")
(65264 . "ARABIC LETTER ALEF MAKSURA FINAL FORM")
(65265 . "ARABIC LETTER YEH ISOLATED FORM")
(65266 . "ARABIC LETTER YEH FINAL FORM")
(65267 . "ARABIC LETTER YEH INITIAL FORM")
(65268 . "ARABIC LETTER YEH MEDIAL FORM")
(65269 . "ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE ISOLATED FORM")
(65270 . "ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE FINAL FORM")
(65271 . "ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE ISOLATED FORM")
(65272 . "ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE FINAL FORM")
(65273 . "ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW ISOLATED FORM")
(65274 . "ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW FINAL FORM")
(65275 . "ARABIC LIGATURE LAM WITH ALEF ISOLATED FORM")
(65276 . "ARABIC LIGATURE LAM WITH ALEF FINAL FORM")
((65277 . 65279) . #f)
(65279 . "ZERO WIDTH NO-BREAK SPACE")
(65280 . #f)
(65281 . "FULLWIDTH EXCLAMATION MARK")
(65282 . "FULLWIDTH QUOTATION MARK")
(65283 . "FULLWIDTH NUMBER SIGN")
(65284 . "FULLWIDTH DOLLAR SIGN")
(65285 . "FULLWIDTH PERCENT SIGN")
(65286 . "FULLWIDTH AMPERSAND")
(65287 . "FULLWIDTH APOSTROPHE")
(65288 . "FULLWIDTH LEFT PARENTHESIS")
(65289 . "FULLWIDTH RIGHT PARENTHESIS")
(65290 . "FULLWIDTH ASTERISK")
(65291 . "FULLWIDTH PLUS SIGN")
(65292 . "FULLWIDTH COMMA")
(65293 . "FULLWIDTH HYPHEN-MINUS")
(65294 . "FULLWIDTH FULL STOP")
(65295 . "FULLWIDTH SOLIDUS")
(65296 . "FULLWIDTH DIGIT ZERO")
(65297 . "FULLWIDTH DIGIT ONE")
(65298 . "FULLWIDTH DIGIT TWO")
(65299 . "FULLWIDTH DIGIT THREE")
(65300 . "FULLWIDTH DIGIT FOUR")
(65301 . "FULLWIDTH DIGIT FIVE")
(65302 . "FULLWIDTH DIGIT SIX")
(65303 . "FULLWIDTH DIGIT SEVEN")
(65304 . "FULLWIDTH DIGIT EIGHT")
(65305 . "FULLWIDTH DIGIT NINE")
(65306 . "FULLWIDTH COLON")
(65307 . "FULLWIDTH SEMICOLON")
(65308 . "FULLWIDTH LESS-THAN SIGN")
(65309 . "FULLWIDTH EQUALS SIGN")
(65310 . "FULLWIDTH GREATER-THAN SIGN")
(65311 . "FULLWIDTH QUESTION MARK")
(65312 . "FULLWIDTH COMMERCIAL AT")
(65313 . "FULLWIDTH LATIN CAPITAL LETTER A")
(65314 . "FULLWIDTH LATIN CAPITAL LETTER B")
(65315 . "FULLWIDTH LATIN CAPITAL LETTER C")
(65316 . "FULLWIDTH LATIN CAPITAL LETTER D")
(65317 . "FULLWIDTH LATIN CAPITAL LETTER E")
(65318 . "FULLWIDTH LATIN CAPITAL LETTER F")
(65319 . "FULLWIDTH LATIN CAPITAL LETTER G")
(65320 . "FULLWIDTH LATIN CAPITAL LETTER H")
(65321 . "FULLWIDTH LATIN CAPITAL LETTER I")
(65322 . "FULLWIDTH LATIN CAPITAL LETTER J")
(65323 . "FULLWIDTH LATIN CAPITAL LETTER K")
(65324 . "FULLWIDTH LATIN CAPITAL LETTER L")
(65325 . "FULLWIDTH LATIN CAPITAL LETTER M")
(65326 . "FULLWIDTH LATIN CAPITAL LETTER N")
(65327 . "FULLWIDTH LATIN CAPITAL LETTER O")
(65328 . "FULLWIDTH LATIN CAPITAL LETTER P")
(65329 . "FULLWIDTH LATIN CAPITAL LETTER Q")
(65330 . "FULLWIDTH LATIN CAPITAL LETTER R")
(65331 . "FULLWIDTH LATIN CAPITAL LETTER S")
(65332 . "FULLWIDTH LATIN CAPITAL LETTER T")
(65333 . "FULLWIDTH LATIN CAPITAL LETTER U")
(65334 . "FULLWIDTH LATIN CAPITAL LETTER V")
(65335 . "FULLWIDTH LATIN CAPITAL LETTER W")
(65336 . "FULLWIDTH LATIN CAPITAL LETTER X")
(65337 . "FULLWIDTH LATIN CAPITAL LETTER Y")
(65338 . "FULLWIDTH LATIN CAPITAL LETTER Z")
(65339 . "FULLWIDTH LEFT SQUARE BRACKET")
(65340 . "FULLWIDTH REVERSE SOLIDUS")
(65341 . "FULLWIDTH RIGHT SQUARE BRACKET")
(65342 . "FULLWIDTH CIRCUMFLEX ACCENT")
(65343 . "FULLWIDTH LOW LINE")
(65344 . "FULLWIDTH GRAVE ACCENT")
(65345 . "FULLWIDTH LATIN SMALL LETTER A")
(65346 . "FULLWIDTH LATIN SMALL LETTER B")
(65347 . "FULLWIDTH LATIN SMALL LETTER C")
(65348 . "FULLWIDTH LATIN SMALL LETTER D")
(65349 . "FULLWIDTH LATIN SMALL LETTER E")
(65350 . "FULLWIDTH LATIN SMALL LETTER F")
(65351 . "FULLWIDTH LATIN SMALL LETTER G")
(65352 . "FULLWIDTH LATIN SMALL LETTER H")
(65353 . "FULLWIDTH LATIN SMALL LETTER I")
(65354 . "FULLWIDTH LATIN SMALL LETTER J")
(65355 . "FULLWIDTH LATIN SMALL LETTER K")
(65356 . "FULLWIDTH LATIN SMALL LETTER L")
(65357 . "FULLWIDTH LATIN SMALL LETTER M")
(65358 . "FULLWIDTH LATIN SMALL LETTER N")
(65359 . "FULLWIDTH LATIN SMALL LETTER O")
(65360 . "FULLWIDTH LATIN SMALL LETTER P")
(65361 . "FULLWIDTH LATIN SMALL LETTER Q")
(65362 . "FULLWIDTH LATIN SMALL LETTER R")
(65363 . "FULLWIDTH LATIN SMALL LETTER S")
(65364 . "FULLWIDTH LATIN SMALL LETTER T")
(65365 . "FULLWIDTH LATIN SMALL LETTER U")
(65366 . "FULLWIDTH LATIN SMALL LETTER V")
(65367 . "FULLWIDTH LATIN SMALL LETTER W")
(65368 . "FULLWIDTH LATIN SMALL LETTER X")
(65369 . "FULLWIDTH LATIN SMALL LETTER Y")
(65370 . "FULLWIDTH LATIN SMALL LETTER Z")
(65371 . "FULLWIDTH LEFT CURLY BRACKET")
(65372 . "FULLWIDTH VERTICAL LINE")
(65373 . "FULLWIDTH RIGHT CURLY BRACKET")
(65374 . "FULLWIDTH TILDE")
(65375 . "FULLWIDTH LEFT WHITE PARENTHESIS")
(65376 . "FULLWIDTH RIGHT WHITE PARENTHESIS")
(65377 . "HALFWIDTH IDEOGRAPHIC FULL STOP")
(65378 . "HALFWIDTH LEFT CORNER BRACKET")
(65379 . "HALFWIDTH RIGHT CORNER BRACKET")
(65380 . "HALFWIDTH IDEOGRAPHIC COMMA")
(65381 . "HALFWIDTH KATAKANA MIDDLE DOT")
(65382 . "HALFWIDTH KATAKANA LETTER WO")
(65383 . "HALFWIDTH KATAKANA LETTER SMALL A")
(65384 . "HALFWIDTH KATAKANA LETTER SMALL I")
(65385 . "HALFWIDTH KATAKANA LETTER SMALL U")
(65386 . "HALFWIDTH KATAKANA LETTER SMALL E")
(65387 . "HALFWIDTH KATAKANA LETTER SMALL O")
(65388 . "HALFWIDTH KATAKANA LETTER SMALL YA")
(65389 . "HALFWIDTH KATAKANA LETTER SMALL YU")
(65390 . "HALFWIDTH KATAKANA LETTER SMALL YO")
(65391 . "HALFWIDTH KATAKANA LETTER SMALL TU")
(65392 . "HALFWIDTH KATAKANA-HIRAGANA PROLONGED SOUND MARK")
(65393 . "HALFWIDTH KATAKANA LETTER A")
(65394 . "HALFWIDTH KATAKANA LETTER I")
(65395 . "HALFWIDTH KATAKANA LETTER U")
(65396 . "HALFWIDTH KATAKANA LETTER E")
(65397 . "HALFWIDTH KATAKANA LETTER O")
(65398 . "HALFWIDTH KATAKANA LETTER KA")
(65399 . "HALFWIDTH KATAKANA LETTER KI")
(65400 . "HALFWIDTH KATAKANA LETTER KU")
(65401 . "HALFWIDTH KATAKANA LETTER KE")
(65402 . "HALFWIDTH KATAKANA LETTER KO")
(65403 . "HALFWIDTH KATAKANA LETTER SA")
(65404 . "HALFWIDTH KATAKANA LETTER SI")
(65405 . "HALFWIDTH KATAKANA LETTER SU")
(65406 . "HALFWIDTH KATAKANA LETTER SE")
(65407 . "HALFWIDTH KATAKANA LETTER SO")
(65408 . "HALFWIDTH KATAKANA LETTER TA")
(65409 . "HALFWIDTH KATAKANA LETTER TI")
(65410 . "HALFWIDTH KATAKANA LETTER TU")
(65411 . "HALFWIDTH KATAKANA LETTER TE")
(65412 . "HALFWIDTH KATAKANA LETTER TO")
(65413 . "HALFWIDTH KATAKANA LETTER NA")
(65414 . "HALFWIDTH KATAKANA LETTER NI")
(65415 . "HALFWIDTH KATAKANA LETTER NU")
(65416 . "HALFWIDTH KATAKANA LETTER NE")
(65417 . "HALFWIDTH KATAKANA LETTER NO")
(65418 . "HALFWIDTH KATAKANA LETTER HA")
(65419 . "HALFWIDTH KATAKANA LETTER HI")
(65420 . "HALFWIDTH KATAKANA LETTER HU")
(65421 . "HALFWIDTH KATAKANA LETTER HE")
(65422 . "HALFWIDTH KATAKANA LETTER HO")
(65423 . "HALFWIDTH KATAKANA LETTER MA")
(65424 . "HALFWIDTH KATAKANA LETTER MI")
(65425 . "HALFWIDTH KATAKANA LETTER MU")
(65426 . "HALFWIDTH KATAKANA LETTER ME")
(65427 . "HALFWIDTH KATAKANA LETTER MO")
(65428 . "HALFWIDTH KATAKANA LETTER YA")
(65429 . "HALFWIDTH KATAKANA LETTER YU")
(65430 . "HALFWIDTH KATAKANA LETTER YO")
(65431 . "HALFWIDTH KATAKANA LETTER RA")
(65432 . "HALFWIDTH KATAKANA LETTER RI")
(65433 . "HALFWIDTH KATAKANA LETTER RU")
(65434 . "HALFWIDTH KATAKANA LETTER RE")
(65435 . "HALFWIDTH KATAKANA LETTER RO")
(65436 . "HALFWIDTH KATAKANA LETTER WA")
(65437 . "HALFWIDTH KATAKANA LETTER N")
(65438 . "HALFWIDTH KATAKANA VOICED SOUND MARK")
(65439 . "HALFWIDTH KATAKANA SEMI-VOICED SOUND MARK")
(65440 . "HALFWIDTH HANGUL FILLER")
(65441 . "HALFWIDTH HANGUL LETTER KIYEOK")
(65442 . "HALFWIDTH HANGUL LETTER SSANGKIYEOK")
(65443 . "HALFWIDTH HANGUL LETTER KIYEOK-SIOS")
(65444 . "HALFWIDTH HANGUL LETTER NIEUN")
(65445 . "HALFWIDTH HANGUL LETTER NIEUN-CIEUC")
(65446 . "HALFWIDTH HANGUL LETTER NIEUN-HIEUH")
(65447 . "HALFWIDTH HANGUL LETTER TIKEUT")
(65448 . "HALFWIDTH HANGUL LETTER SSANGTIKEUT")
(65449 . "HALFWIDTH HANGUL LETTER RIEUL")
(65450 . "HALFWIDTH HANGUL LETTER RIEUL-KIYEOK")
(65451 . "HALFWIDTH HANGUL LETTER RIEUL-MIEUM")
(65452 . "HALFWIDTH HANGUL LETTER RIEUL-PIEUP")
(65453 . "HALFWIDTH HANGUL LETTER RIEUL-SIOS")
(65454 . "HALFWIDTH HANGUL LETTER RIEUL-THIEUTH")
(65455 . "HALFWIDTH HANGUL LETTER RIEUL-PHIEUPH")
(65456 . "HALFWIDTH HANGUL LETTER RIEUL-HIEUH")
(65457 . "HALFWIDTH HANGUL LETTER MIEUM")
(65458 . "HALFWIDTH HANGUL LETTER PIEUP")
(65459 . "HALFWIDTH HANGUL LETTER SSANGPIEUP")
(65460 . "HALFWIDTH HANGUL LETTER PIEUP-SIOS")
(65461 . "HALFWIDTH HANGUL LETTER SIOS")
(65462 . "HALFWIDTH HANGUL LETTER SSANGSIOS")
(65463 . "HALFWIDTH HANGUL LETTER IEUNG")
(65464 . "HALFWIDTH HANGUL LETTER CIEUC")
(65465 . "HALFWIDTH HANGUL LETTER SSANGCIEUC")
(65466 . "HALFWIDTH HANGUL LETTER CHIEUCH")
(65467 . "HALFWIDTH HANGUL LETTER KHIEUKH")
(65468 . "HALFWIDTH HANGUL LETTER THIEUTH")
(65469 . "HALFWIDTH HANGUL LETTER PHIEUPH")
(65470 . "HALFWIDTH HANGUL LETTER HIEUH")
((65471 . 65474) . #f)
(65474 . "HALFWIDTH HANGUL LETTER A")
(65475 . "HALFWIDTH HANGUL LETTER AE")
(65476 . "HALFWIDTH HANGUL LETTER YA")
(65477 . "HALFWIDTH HANGUL LETTER YAE")
(65478 . "HALFWIDTH HANGUL LETTER EO")
(65479 . "HALFWIDTH HANGUL LETTER E")
((65480 . 65482) . #f)
(65482 . "HALFWIDTH HANGUL LETTER YEO")
(65483 . "HALFWIDTH HANGUL LETTER YE")
(65484 . "HALFWIDTH HANGUL LETTER O")
(65485 . "HALFWIDTH HANGUL LETTER WA")
(65486 . "HALFWIDTH HANGUL LETTER WAE")
(65487 . "HALFWIDTH HANGUL LETTER OE")
((65488 . 65490) . #f)
(65490 . "HALFWIDTH HANGUL LETTER YO")
(65491 . "HALFWIDTH HANGUL LETTER U")
(65492 . "HALFWIDTH HANGUL LETTER WEO")
(65493 . "HALFWIDTH HANGUL LETTER WE")
(65494 . "HALFWIDTH HANGUL LETTER WI")
(65495 . "HALFWIDTH HANGUL LETTER YU")
((65496 . 65498) . #f)
(65498 . "HALFWIDTH HANGUL LETTER EU")
(65499 . "HALFWIDTH HANGUL LETTER YI")
(65500 . "HALFWIDTH HANGUL LETTER I")
((65501 . 65504) . #f)
(65504 . "FULLWIDTH CENT SIGN")
(65505 . "FULLWIDTH POUND SIGN")
(65506 . "FULLWIDTH NOT SIGN")
(65507 . "FULLWIDTH MACRON")
(65508 . "FULLWIDTH BROKEN BAR")
(65509 . "FULLWIDTH YEN SIGN")
(65510 . "FULLWIDTH WON SIGN")
(65511 . #f)
(65512 . "HALFWIDTH FORMS LIGHT VERTICAL")
(65513 . "HALFWIDTH LEFTWARDS ARROW")
(65514 . "HALFWIDTH UPWARDS ARROW")
(65515 . "HALFWIDTH RIGHTWARDS ARROW")
(65516 . "HALFWIDTH DOWNWARDS ARROW")
(65517 . "HALFWIDTH BLACK SQUARE")
(65518 . "HALFWIDTH WHITE CIRCLE")
((65519 . 65529) . #f)
(65529 . "INTERLINEAR ANNOTATION ANCHOR")
(65530 . "INTERLINEAR ANNOTATION SEPARATOR")
(65531 . "INTERLINEAR ANNOTATION TERMINATOR")
(65532 . "OBJECT REPLACEMENT CHARACTER")
(65533 . "REPLACEMENT CHARACTER")
((65534 . 65536) . #f)
(65536 . "LINEAR B SYLLABLE B008 A")
(65537 . "LINEAR B SYLLABLE B038 E")
(65538 . "LINEAR B SYLLABLE B028 I")
(65539 . "LINEAR B SYLLABLE B061 O")
(65540 . "LINEAR B SYLLABLE B010 U")
(65541 . "LINEAR B SYLLABLE B001 DA")
(65542 . "LINEAR B SYLLABLE B045 DE")
(65543 . "LINEAR B SYLLABLE B007 DI")
(65544 . "LINEAR B SYLLABLE B014 DO")
(65545 . "LINEAR B SYLLABLE B051 DU")
(65546 . "LINEAR B SYLLABLE B057 JA")
(65547 . "LINEAR B SYLLABLE B046 JE")
(65548 . #f)
(65549 . "LINEAR B SYLLABLE B036 JO")
(65550 . "LINEAR B SYLLABLE B065 JU")
(65551 . "LINEAR B SYLLABLE B077 KA")
(65552 . "LINEAR B SYLLABLE B044 KE")
(65553 . "LINEAR B SYLLABLE B067 KI")
(65554 . "LINEAR B SYLLABLE B070 KO")
(65555 . "LINEAR B SYLLABLE B081 KU")
(65556 . "LINEAR B SYLLABLE B080 MA")
(65557 . "LINEAR B SYLLABLE B013 ME")
(65558 . "LINEAR B SYLLABLE B073 MI")
(65559 . "LINEAR B SYLLABLE B015 MO")
(65560 . "LINEAR B SYLLABLE B023 MU")
(65561 . "LINEAR B SYLLABLE B006 NA")
(65562 . "LINEAR B SYLLABLE B024 NE")
(65563 . "LINEAR B SYLLABLE B030 NI")
(65564 . "LINEAR B SYLLABLE B052 NO")
(65565 . "LINEAR B SYLLABLE B055 NU")
(65566 . "LINEAR B SYLLABLE B003 PA")
(65567 . "LINEAR B SYLLABLE B072 PE")
(65568 . "LINEAR B SYLLABLE B039 PI")
(65569 . "LINEAR B SYLLABLE B011 PO")
(65570 . "LINEAR B SYLLABLE B050 PU")
(65571 . "LINEAR B SYLLABLE B016 QA")
(65572 . "LINEAR B SYLLABLE B078 QE")
(65573 . "LINEAR B SYLLABLE B021 QI")
(65574 . "LINEAR B SYLLABLE B032 QO")
(65575 . #f)
(65576 . "LINEAR B SYLLABLE B060 RA")
(65577 . "LINEAR B SYLLABLE B027 RE")
(65578 . "LINEAR B SYLLABLE B053 RI")
(65579 . "LINEAR B SYLLABLE B002 RO")
(65580 . "LINEAR B SYLLABLE B026 RU")
(65581 . "LINEAR B SYLLABLE B031 SA")
(65582 . "LINEAR B SYLLABLE B009 SE")
(65583 . "LINEAR B SYLLABLE B041 SI")
(65584 . "LINEAR B SYLLABLE B012 SO")
(65585 . "LINEAR B SYLLABLE B058 SU")
(65586 . "LINEAR B SYLLABLE B059 TA")
(65587 . "LINEAR B SYLLABLE B004 TE")
(65588 . "LINEAR B SYLLABLE B037 TI")
(65589 . "LINEAR B SYLLABLE B005 TO")
(65590 . "LINEAR B SYLLABLE B069 TU")
(65591 . "LINEAR B SYLLABLE B054 WA")
(65592 . "LINEAR B SYLLABLE B075 WE")
(65593 . "LINEAR B SYLLABLE B040 WI")
(65594 . "LINEAR B SYLLABLE B042 WO")
(65595 . #f)
(65596 . "LINEAR B SYLLABLE B017 ZA")
(65597 . "LINEAR B SYLLABLE B074 ZE")
(65598 . #f)
(65599 . "LINEAR B SYLLABLE B020 ZO")
(65600 . "LINEAR B SYLLABLE B025 A2")
(65601 . "LINEAR B SYLLABLE B043 A3")
(65602 . "LINEAR B SYLLABLE B085 AU")
(65603 . "LINEAR B SYLLABLE B071 DWE")
(65604 . "LINEAR B SYLLABLE B090 DWO")
(65605 . "LINEAR B SYLLABLE B048 NWA")
(65606 . "LINEAR B SYLLABLE B029 PU2")
(65607 . "LINEAR B SYLLABLE B062 PTE")
(65608 . "LINEAR B SYLLABLE B076 RA2")
(65609 . "LINEAR B SYLLABLE B033 RA3")
(65610 . "LINEAR B SYLLABLE B068 RO2")
(65611 . "LINEAR B SYLLABLE B066 TA2")
(65612 . "LINEAR B SYLLABLE B087 TWE")
(65613 . "LINEAR B SYLLABLE B091 TWO")
((65614 . 65616) . #f)
(65616 . "LINEAR B SYMBOL B018")
(65617 . "LINEAR B SYMBOL B019")
(65618 . "LINEAR B SYMBOL B022")
(65619 . "LINEAR B SYMBOL B034")
(65620 . "LINEAR B SYMBOL B047")
(65621 . "LINEAR B SYMBOL B049")
(65622 . "LINEAR B SYMBOL B056")
(65623 . "LINEAR B SYMBOL B063")
(65624 . "LINEAR B SYMBOL B064")
(65625 . "LINEAR B SYMBOL B079")
(65626 . "LINEAR B SYMBOL B082")
(65627 . "LINEAR B SYMBOL B083")
(65628 . "LINEAR B SYMBOL B086")
(65629 . "LINEAR B SYMBOL B089")
((65630 . 65664) . #f)
(65664 . "LINEAR B IDEOGRAM B100 MAN")
(65665 . "LINEAR B IDEOGRAM B102 WOMAN")
(65666 . "LINEAR B IDEOGRAM B104 DEER")
(65667 . "LINEAR B IDEOGRAM B105 EQUID")
(65668 . "LINEAR B IDEOGRAM B105F MARE")
(65669 . "LINEAR B IDEOGRAM B105M STALLION")
(65670 . "LINEAR B IDEOGRAM B106F EWE")
(65671 . "LINEAR B IDEOGRAM B106M RAM")
(65672 . "LINEAR B IDEOGRAM B107F SHE-GOAT")
(65673 . "LINEAR B IDEOGRAM B107M HE-GOAT")
(65674 . "LINEAR B IDEOGRAM B108F SOW")
(65675 . "LINEAR B IDEOGRAM B108M BOAR")
(65676 . "LINEAR B IDEOGRAM B109F COW")
(65677 . "LINEAR B IDEOGRAM B109M BULL")
(65678 . "LINEAR B IDEOGRAM B120 WHEAT")
(65679 . "LINEAR B IDEOGRAM B121 BARLEY")
(65680 . "LINEAR B IDEOGRAM B122 OLIVE")
(65681 . "LINEAR B IDEOGRAM B123 SPICE")
(65682 . "LINEAR B IDEOGRAM B125 CYPERUS")
(65683 . "LINEAR B MONOGRAM B127 KAPO")
(65684 . "LINEAR B MONOGRAM B128 KANAKO")
(65685 . "LINEAR B IDEOGRAM B130 OIL")
(65686 . "LINEAR B IDEOGRAM B131 WINE")
(65687 . "LINEAR B IDEOGRAM B132")
(65688 . "LINEAR B MONOGRAM B133 AREPA")
(65689 . "LINEAR B MONOGRAM B135 MERI")
(65690 . "LINEAR B IDEOGRAM B140 BRONZE")
(65691 . "LINEAR B IDEOGRAM B141 GOLD")
(65692 . "LINEAR B IDEOGRAM B142")
(65693 . "LINEAR B IDEOGRAM B145 WOOL")
(65694 . "LINEAR B IDEOGRAM B146")
(65695 . "LINEAR B IDEOGRAM B150")
(65696 . "LINEAR B IDEOGRAM B151 HORN")
(65697 . "LINEAR B IDEOGRAM B152")
(65698 . "LINEAR B IDEOGRAM B153")
(65699 . "LINEAR B IDEOGRAM B154")
(65700 . "LINEAR B MONOGRAM B156 TURO2")
(65701 . "LINEAR B IDEOGRAM B157")
(65702 . "LINEAR B IDEOGRAM B158")
(65703 . "LINEAR B IDEOGRAM B159 CLOTH")
(65704 . "LINEAR B IDEOGRAM B160")
(65705 . "LINEAR B IDEOGRAM B161")
(65706 . "LINEAR B IDEOGRAM B162 GARMENT")
(65707 . "LINEAR B IDEOGRAM B163 ARMOUR")
(65708 . "LINEAR B IDEOGRAM B164")
(65709 . "LINEAR B IDEOGRAM B165")
(65710 . "LINEAR B IDEOGRAM B166")
(65711 . "LINEAR B IDEOGRAM B167")
(65712 . "LINEAR B IDEOGRAM B168")
(65713 . "LINEAR B IDEOGRAM B169")
(65714 . "LINEAR B IDEOGRAM B170")
(65715 . "LINEAR B IDEOGRAM B171")
(65716 . "LINEAR B IDEOGRAM B172")
(65717 . "LINEAR B IDEOGRAM B173 MONTH")
(65718 . "LINEAR B IDEOGRAM B174")
(65719 . "LINEAR B IDEOGRAM B176 TREE")
(65720 . "LINEAR B IDEOGRAM B177")
(65721 . "LINEAR B IDEOGRAM B178")
(65722 . "LINEAR B IDEOGRAM B179")
(65723 . "LINEAR B IDEOGRAM B180")
(65724 . "LINEAR B IDEOGRAM B181")
(65725 . "LINEAR B IDEOGRAM B182")
(65726 . "LINEAR B IDEOGRAM B183")
(65727 . "LINEAR B IDEOGRAM B184")
(65728 . "LINEAR B IDEOGRAM B185")
(65729 . "LINEAR B IDEOGRAM B189")
(65730 . "LINEAR B IDEOGRAM B190")
(65731 . "LINEAR B IDEOGRAM B191 HELMET")
(65732 . "LINEAR B IDEOGRAM B220 FOOTSTOOL")
(65733 . "LINEAR B IDEOGRAM B225 BATHTUB")
(65734 . "LINEAR B IDEOGRAM B230 SPEAR")
(65735 . "LINEAR B IDEOGRAM B231 ARROW")
(65736 . "LINEAR B IDEOGRAM B232")
(65737 . "LINEAR B IDEOGRAM B233 SWORD")
(65738 . "LINEAR B IDEOGRAM B234")
(65739 . "LINEAR B IDEOGRAM B236")
(65740 . "LINEAR B IDEOGRAM B240 WHEELED CHARIOT")
(65741 . "LINEAR B IDEOGRAM B241 CHARIOT")
(65742 . "LINEAR B IDEOGRAM B242 CHARIOT FRAME")
(65743 . "LINEAR B IDEOGRAM B243 WHEEL")
(65744 . "LINEAR B IDEOGRAM B245")
(65745 . "LINEAR B IDEOGRAM B246")
(65746 . "LINEAR B MONOGRAM B247 DIPTE")
(65747 . "LINEAR B IDEOGRAM B248")
(65748 . "LINEAR B IDEOGRAM B249")
(65749 . "LINEAR B IDEOGRAM B251")
(65750 . "LINEAR B IDEOGRAM B252")
(65751 . "LINEAR B IDEOGRAM B253")
(65752 . "LINEAR B IDEOGRAM B254 DART")
(65753 . "LINEAR B IDEOGRAM B255")
(65754 . "LINEAR B IDEOGRAM B256")
(65755 . "LINEAR B IDEOGRAM B257")
(65756 . "LINEAR B IDEOGRAM B258")
(65757 . "LINEAR B IDEOGRAM B259")
(65758 . "LINEAR B IDEOGRAM VESSEL B155")
(65759 . "LINEAR B IDEOGRAM VESSEL B200")
(65760 . "LINEAR B IDEOGRAM VESSEL B201")
(65761 . "LINEAR B IDEOGRAM VESSEL B202")
(65762 . "LINEAR B IDEOGRAM VESSEL B203")
(65763 . "LINEAR B IDEOGRAM VESSEL B204")
(65764 . "LINEAR B IDEOGRAM VESSEL B205")
(65765 . "LINEAR B IDEOGRAM VESSEL B206")
(65766 . "LINEAR B IDEOGRAM VESSEL B207")
(65767 . "LINEAR B IDEOGRAM VESSEL B208")
(65768 . "LINEAR B IDEOGRAM VESSEL B209")
(65769 . "LINEAR B IDEOGRAM VESSEL B210")
(65770 . "LINEAR B IDEOGRAM VESSEL B211")
(65771 . "LINEAR B IDEOGRAM VESSEL B212")
(65772 . "LINEAR B IDEOGRAM VESSEL B213")
(65773 . "LINEAR B IDEOGRAM VESSEL B214")
(65774 . "LINEAR B IDEOGRAM VESSEL B215")
(65775 . "LINEAR B IDEOGRAM VESSEL B216")
(65776 . "LINEAR B IDEOGRAM VESSEL B217")
(65777 . "LINEAR B IDEOGRAM VESSEL B218")
(65778 . "LINEAR B IDEOGRAM VESSEL B219")
(65779 . "LINEAR B IDEOGRAM VESSEL B221")
(65780 . "LINEAR B IDEOGRAM VESSEL B222")
(65781 . "LINEAR B IDEOGRAM VESSEL B226")
(65782 . "LINEAR B IDEOGRAM VESSEL B227")
(65783 . "LINEAR B IDEOGRAM VESSEL B228")
(65784 . "LINEAR B IDEOGRAM VESSEL B229")
(65785 . "LINEAR B IDEOGRAM VESSEL B250")
(65786 . "LINEAR B IDEOGRAM VESSEL B305")
((65787 . 65792) . #f)
(65792 . "AEGEAN WORD SEPARATOR LINE")
(65793 . "AEGEAN WORD SEPARATOR DOT")
(65794 . "AEGEAN CHECK MARK")
((65795 . 65799) . #f)
(65799 . "AEGEAN NUMBER ONE")
(65800 . "AEGEAN NUMBER TWO")
(65801 . "AEGEAN NUMBER THREE")
(65802 . "AEGEAN NUMBER FOUR")
(65803 . "AEGEAN NUMBER FIVE")
(65804 . "AEGEAN NUMBER SIX")
(65805 . "AEGEAN NUMBER SEVEN")
(65806 . "AEGEAN NUMBER EIGHT")
(65807 . "AEGEAN NUMBER NINE")
(65808 . "AEGEAN NUMBER TEN")
(65809 . "AEGEAN NUMBER TWENTY")
(65810 . "AEGEAN NUMBER THIRTY")
(65811 . "AEGEAN NUMBER FORTY")
(65812 . "AEGEAN NUMBER FIFTY")
(65813 . "AEGEAN NUMBER SIXTY")
(65814 . "AEGEAN NUMBER SEVENTY")
(65815 . "AEGEAN NUMBER EIGHTY")
(65816 . "AEGEAN NUMBER NINETY")
(65817 . "AEGEAN NUMBER ONE HUNDRED")
(65818 . "AEGEAN NUMBER TWO HUNDRED")
(65819 . "AEGEAN NUMBER THREE HUNDRED")
(65820 . "AEGEAN NUMBER FOUR HUNDRED")
(65821 . "AEGEAN NUMBER FIVE HUNDRED")
(65822 . "AEGEAN NUMBER SIX HUNDRED")
(65823 . "AEGEAN NUMBER SEVEN HUNDRED")
(65824 . "AEGEAN NUMBER EIGHT HUNDRED")
(65825 . "AEGEAN NUMBER NINE HUNDRED")
(65826 . "AEGEAN NUMBER ONE THOUSAND")
(65827 . "AEGEAN NUMBER TWO THOUSAND")
(65828 . "AEGEAN NUMBER THREE THOUSAND")
(65829 . "AEGEAN NUMBER FOUR THOUSAND")
(65830 . "AEGEAN NUMBER FIVE THOUSAND")
(65831 . "AEGEAN NUMBER SIX THOUSAND")
(65832 . "AEGEAN NUMBER SEVEN THOUSAND")
(65833 . "AEGEAN NUMBER EIGHT THOUSAND")
(65834 . "AEGEAN NUMBER NINE THOUSAND")
(65835 . "AEGEAN NUMBER TEN THOUSAND")
(65836 . "AEGEAN NUMBER TWENTY THOUSAND")
(65837 . "AEGEAN NUMBER THIRTY THOUSAND")
(65838 . "AEGEAN NUMBER FORTY THOUSAND")
(65839 . "AEGEAN NUMBER FIFTY THOUSAND")
(65840 . "AEGEAN NUMBER SIXTY THOUSAND")
(65841 . "AEGEAN NUMBER SEVENTY THOUSAND")
(65842 . "AEGEAN NUMBER EIGHTY THOUSAND")
(65843 . "AEGEAN NUMBER NINETY THOUSAND")
((65844 . 65847) . #f)
(65847 . "AEGEAN WEIGHT BASE UNIT")
(65848 . "AEGEAN WEIGHT FIRST SUBUNIT")
(65849 . "AEGEAN WEIGHT SECOND SUBUNIT")
(65850 . "AEGEAN WEIGHT THIRD SUBUNIT")
(65851 . "AEGEAN WEIGHT FOURTH SUBUNIT")
(65852 . "AEGEAN DRY MEASURE FIRST SUBUNIT")
(65853 . "AEGEAN LIQUID MEASURE FIRST SUBUNIT")
(65854 . "AEGEAN MEASURE SECOND SUBUNIT")
(65855 . "AEGEAN MEASURE THIRD SUBUNIT")
(65856 . "GREEK ACROPHONIC ATTIC ONE QUARTER")
(65857 . "GREEK ACROPHONIC ATTIC ONE HALF")
(65858 . "GREEK ACROPHONIC ATTIC ONE DRACHMA")
(65859 . "GREEK ACROPHONIC ATTIC FIVE")
(65860 . "GREEK ACROPHONIC ATTIC FIFTY")
(65861 . "GREEK ACROPHONIC ATTIC FIVE HUNDRED")
(65862 . "GREEK ACROPHONIC ATTIC FIVE THOUSAND")
(65863 . "GREEK ACROPHONIC ATTIC FIFTY THOUSAND")
(65864 . "GREEK ACROPHONIC ATTIC FIVE TALENTS")
(65865 . "GREEK ACROPHONIC ATTIC TEN TALENTS")
(65866 . "GREEK ACROPHONIC ATTIC FIFTY TALENTS")
(65867 . "GREEK ACROPHONIC ATTIC ONE HUNDRED TALENTS")
(65868 . "GREEK ACROPHONIC ATTIC FIVE HUNDRED TALENTS")
(65869 . "GREEK ACROPHONIC ATTIC ONE THOUSAND TALENTS")
(65870 . "GREEK ACROPHONIC ATTIC FIVE THOUSAND TALENTS")
(65871 . "GREEK ACROPHONIC ATTIC FIVE STATERS")
(65872 . "GREEK ACROPHONIC ATTIC TEN STATERS")
(65873 . "GREEK ACROPHONIC ATTIC FIFTY STATERS")
(65874 . "GREEK ACROPHONIC ATTIC ONE HUNDRED STATERS")
(65875 . "GREEK ACROPHONIC ATTIC FIVE HUNDRED STATERS")
(65876 . "GREEK ACROPHONIC ATTIC ONE THOUSAND STATERS")
(65877 . "GREEK ACROPHONIC ATTIC TEN THOUSAND STATERS")
(65878 . "GREEK ACROPHONIC ATTIC FIFTY THOUSAND STATERS")
(65879 . "GREEK ACROPHONIC ATTIC TEN MNAS")
(65880 . "GREEK ACROPHONIC HERAEUM ONE PLETHRON")
(65881 . "GREEK ACROPHONIC THESPIAN ONE")
(65882 . "GREEK ACROPHONIC HERMIONIAN ONE")
(65883 . "GREEK ACROPHONIC EPIDAUREAN TWO")
(65884 . "GREEK ACROPHONIC THESPIAN TWO")
(65885 . "GREEK ACROPHONIC CYRENAIC TWO DRACHMAS")
(65886 . "GREEK ACROPHONIC EPIDAUREAN TWO DRACHMAS")
(65887 . "GREEK ACROPHONIC TROEZENIAN FIVE")
(65888 . "GREEK ACROPHONIC TROEZENIAN TEN")
(65889 . "GREEK ACROPHONIC TROEZENIAN TEN ALTERNATE FORM")
(65890 . "GREEK ACROPHONIC HERMIONIAN TEN")
(65891 . "GREEK ACROPHONIC MESSENIAN TEN")
(65892 . "GREEK ACROPHONIC THESPIAN TEN")
(65893 . "GREEK ACROPHONIC THESPIAN THIRTY")
(65894 . "GREEK ACROPHONIC TROEZENIAN FIFTY")
(65895 . "GREEK ACROPHONIC TROEZENIAN FIFTY ALTERNATE FORM")
(65896 . "GREEK ACROPHONIC HERMIONIAN FIFTY")
(65897 . "GREEK ACROPHONIC THESPIAN FIFTY")
(65898 . "GREEK ACROPHONIC THESPIAN ONE HUNDRED")
(65899 . "GREEK ACROPHONIC THESPIAN THREE HUNDRED")
(65900 . "GREEK ACROPHONIC EPIDAUREAN FIVE HUNDRED")
(65901 . "GREEK ACROPHONIC TROEZENIAN FIVE HUNDRED")
(65902 . "GREEK ACROPHONIC THESPIAN FIVE HUNDRED")
(65903 . "GREEK ACROPHONIC CARYSTIAN FIVE HUNDRED")
(65904 . "GREEK ACROPHONIC NAXIAN FIVE HUNDRED")
(65905 . "GREEK ACROPHONIC THESPIAN ONE THOUSAND")
(65906 . "GREEK ACROPHONIC THESPIAN FIVE THOUSAND")
(65907 . "GREEK ACROPHONIC DELPHIC FIVE MNAS")
(65908 . "GREEK ACROPHONIC STRATIAN FIFTY MNAS")
(65909 . "GREEK ONE HALF SIGN")
(65910 . "GREEK ONE HALF SIGN ALTERNATE FORM")
(65911 . "GREEK TWO THIRDS SIGN")
(65912 . "GREEK THREE QUARTERS SIGN")
(65913 . "GREEK YEAR SIGN")
(65914 . "GREEK TALENT SIGN")
(65915 . "GREEK DRACHMA SIGN")
(65916 . "GREEK OBOL SIGN")
(65917 . "GREEK TWO OBOLS SIGN")
(65918 . "GREEK THREE OBOLS SIGN")
(65919 . "GREEK FOUR OBOLS SIGN")
(65920 . "GREEK FIVE OBOLS SIGN")
(65921 . "GREEK METRETES SIGN")
(65922 . "GREEK KYATHOS BASE SIGN")
(65923 . "GREEK LITRA SIGN")
(65924 . "GREEK OUNKIA SIGN")
(65925 . "GREEK XESTES SIGN")
(65926 . "GREEK ARTABE SIGN")
(65927 . "GREEK AROURA SIGN")
(65928 . "GREEK GRAMMA SIGN")
(65929 . "GREEK TRYBLION BASE SIGN")
(65930 . "GREEK ZERO SIGN")
(65931 . "GREEK ONE QUARTER SIGN")
(65932 . "GREEK SINUSOID SIGN")
(65933 . "GREEK INDICTION SIGN")
(65934 . "NOMISMA SIGN")
(65935 . #f)
(65936 . "ROMAN SEXTANS SIGN")
(65937 . "ROMAN UNCIA SIGN")
(65938 . "ROMAN SEMUNCIA SIGN")
(65939 . "ROMAN SEXTULA SIGN")
(65940 . "ROMAN DIMIDIA SEXTULA SIGN")
(65941 . "ROMAN SILIQUA SIGN")
(65942 . "ROMAN DENARIUS SIGN")
(65943 . "ROMAN QUINARIUS SIGN")
(65944 . "ROMAN SESTERTIUS SIGN")
(65945 . "ROMAN DUPONDIUS SIGN")
(65946 . "ROMAN AS SIGN")
(65947 . "ROMAN CENTURIAL SIGN")
((65948 . 65952) . #f)
(65952 . "GREEK SYMBOL TAU RHO")
((65953 . 66000) . #f)
(66000 . "PHAISTOS DISC SIGN PEDESTRIAN")
(66001 . "PHAISTOS DISC SIGN PLUMED HEAD")
(66002 . "PHAISTOS DISC SIGN TATTOOED HEAD")
(66003 . "PHAISTOS DISC SIGN CAPTIVE")
(66004 . "PHAISTOS DISC SIGN CHILD")
(66005 . "PHAISTOS DISC SIGN WOMAN")
(66006 . "PHAISTOS DISC SIGN HELMET")
(66007 . "PHAISTOS DISC SIGN GAUNTLET")
(66008 . "PHAISTOS DISC SIGN TIARA")
(66009 . "PHAISTOS DISC SIGN ARROW")
(66010 . "PHAISTOS DISC SIGN BOW")
(66011 . "PHAISTOS DISC SIGN SHIELD")
(66012 . "PHAISTOS DISC SIGN CLUB")
(66013 . "PHAISTOS DISC SIGN MANACLES")
(66014 . "PHAISTOS DISC SIGN MATTOCK")
(66015 . "PHAISTOS DISC SIGN SAW")
(66016 . "PHAISTOS DISC SIGN LID")
(66017 . "PHAISTOS DISC SIGN BOOMERANG")
(66018 . "PHAISTOS DISC SIGN CARPENTRY PLANE")
(66019 . "PHAISTOS DISC SIGN DOLIUM")
(66020 . "PHAISTOS DISC SIGN COMB")
(66021 . "PHAISTOS DISC SIGN SLING")
(66022 . "PHAISTOS DISC SIGN COLUMN")
(66023 . "PHAISTOS DISC SIGN BEEHIVE")
(66024 . "PHAISTOS DISC SIGN SHIP")
(66025 . "PHAISTOS DISC SIGN HORN")
(66026 . "PHAISTOS DISC SIGN HIDE")
(66027 . "PHAISTOS DISC SIGN BULLS LEG")
(66028 . "PHAISTOS DISC SIGN CAT")
(66029 . "PHAISTOS DISC SIGN RAM")
(66030 . "PHAISTOS DISC SIGN EAGLE")
(66031 . "PHAISTOS DISC SIGN DOVE")
(66032 . "PHAISTOS DISC SIGN TUNNY")
(66033 . "PHAISTOS DISC SIGN BEE")
(66034 . "PHAISTOS DISC SIGN PLANE TREE")
(66035 . "PHAISTOS DISC SIGN VINE")
(66036 . "PHAISTOS DISC SIGN PAPYRUS")
(66037 . "PHAISTOS DISC SIGN ROSETTE")
(66038 . "PHAISTOS DISC SIGN LILY")
(66039 . "PHAISTOS DISC SIGN OX BACK")
(66040 . "PHAISTOS DISC SIGN FLUTE")
(66041 . "PHAISTOS DISC SIGN GRATER")
(66042 . "PHAISTOS DISC SIGN STRAINER")
(66043 . "PHAISTOS DISC SIGN SMALL AXE")
(66044 . "PHAISTOS DISC SIGN WAVY BAND")
(66045 . "PHAISTOS DISC SIGN COMBINING OBLIQUE STROKE")
((66046 . 66176) . #f)
(66176 . "LYCIAN LETTER A")
(66177 . "LYCIAN LETTER E")
(66178 . "LYCIAN LETTER B")
(66179 . "LYCIAN LETTER BH")
(66180 . "LYCIAN LETTER G")
(66181 . "LYCIAN LETTER D")
(66182 . "LYCIAN LETTER I")
(66183 . "LYCIAN LETTER W")
(66184 . "LYCIAN LETTER Z")
(66185 . "LYCIAN LETTER TH")
(66186 . "LYCIAN LETTER J")
(66187 . "LYCIAN LETTER K")
(66188 . "LYCIAN LETTER Q")
(66189 . "LYCIAN LETTER L")
(66190 . "LYCIAN LETTER M")
(66191 . "LYCIAN LETTER N")
(66192 . "LYCIAN LETTER MM")
(66193 . "LYCIAN LETTER NN")
(66194 . "LYCIAN LETTER U")
(66195 . "LYCIAN LETTER P")
(66196 . "LYCIAN LETTER KK")
(66197 . "LYCIAN LETTER R")
(66198 . "LYCIAN LETTER S")
(66199 . "LYCIAN LETTER T")
(66200 . "LYCIAN LETTER TT")
(66201 . "LYCIAN LETTER AN")
(66202 . "LYCIAN LETTER EN")
(66203 . "LYCIAN LETTER H")
(66204 . "LYCIAN LETTER X")
((66205 . 66208) . #f)
(66208 . "CARIAN LETTER A")
(66209 . "CARIAN LETTER P2")
(66210 . "CARIAN LETTER D")
(66211 . "CARIAN LETTER L")
(66212 . "CARIAN LETTER UUU")
(66213 . "CARIAN LETTER R")
(66214 . "CARIAN LETTER LD")
(66215 . "CARIAN LETTER A2")
(66216 . "CARIAN LETTER Q")
(66217 . "CARIAN LETTER B")
(66218 . "CARIAN LETTER M")
(66219 . "CARIAN LETTER O")
(66220 . "CARIAN LETTER D2")
(66221 . "CARIAN LETTER T")
(66222 . "CARIAN LETTER SH")
(66223 . "CARIAN LETTER SH2")
(66224 . "CARIAN LETTER S")
(66225 . "CARIAN LETTER C-18")
(66226 . "CARIAN LETTER U")
(66227 . "CARIAN LETTER NN")
(66228 . "CARIAN LETTER X")
(66229 . "CARIAN LETTER N")
(66230 . "CARIAN LETTER TT2")
(66231 . "CARIAN LETTER P")
(66232 . "CARIAN LETTER SS")
(66233 . "CARIAN LETTER I")
(66234 . "CARIAN LETTER E")
(66235 . "CARIAN LETTER UUUU")
(66236 . "CARIAN LETTER K")
(66237 . "CARIAN LETTER K2")
(66238 . "CARIAN LETTER ND")
(66239 . "CARIAN LETTER UU")
(66240 . "CARIAN LETTER G")
(66241 . "CARIAN LETTER G2")
(66242 . "CARIAN LETTER ST")
(66243 . "CARIAN LETTER ST2")
(66244 . "CARIAN LETTER NG")
(66245 . "CARIAN LETTER II")
(66246 . "CARIAN LETTER C-39")
(66247 . "CARIAN LETTER TT")
(66248 . "CARIAN LETTER UUU2")
(66249 . "CARIAN LETTER RR")
(66250 . "CARIAN LETTER MB")
(66251 . "CARIAN LETTER MB2")
(66252 . "CARIAN LETTER MB3")
(66253 . "CARIAN LETTER MB4")
(66254 . "CARIAN LETTER LD2")
(66255 . "CARIAN LETTER E2")
(66256 . "CARIAN LETTER UUU3")
((66257 . 66272) . #f)
(66272 . "COPTIC EPACT THOUSANDS MARK")
(66273 . "COPTIC EPACT DIGIT ONE")
(66274 . "COPTIC EPACT DIGIT TWO")
(66275 . "COPTIC EPACT DIGIT THREE")
(66276 . "COPTIC EPACT DIGIT FOUR")
(66277 . "COPTIC EPACT DIGIT FIVE")
(66278 . "COPTIC EPACT DIGIT SIX")
(66279 . "COPTIC EPACT DIGIT SEVEN")
(66280 . "COPTIC EPACT DIGIT EIGHT")
(66281 . "COPTIC EPACT DIGIT NINE")
(66282 . "COPTIC EPACT NUMBER TEN")
(66283 . "COPTIC EPACT NUMBER TWENTY")
(66284 . "COPTIC EPACT NUMBER THIRTY")
(66285 . "COPTIC EPACT NUMBER FORTY")
(66286 . "COPTIC EPACT NUMBER FIFTY")
(66287 . "COPTIC EPACT NUMBER SIXTY")
(66288 . "COPTIC EPACT NUMBER SEVENTY")
(66289 . "COPTIC EPACT NUMBER EIGHTY")
(66290 . "COPTIC EPACT NUMBER NINETY")
(66291 . "COPTIC EPACT NUMBER ONE HUNDRED")
(66292 . "COPTIC EPACT NUMBER TWO HUNDRED")
(66293 . "COPTIC EPACT NUMBER THREE HUNDRED")
(66294 . "COPTIC EPACT NUMBER FOUR HUNDRED")
(66295 . "COPTIC EPACT NUMBER FIVE HUNDRED")
(66296 . "COPTIC EPACT NUMBER SIX HUNDRED")
(66297 . "COPTIC EPACT NUMBER SEVEN HUNDRED")
(66298 . "COPTIC EPACT NUMBER EIGHT HUNDRED")
(66299 . "COPTIC EPACT NUMBER NINE HUNDRED")
((66300 . 66304) . #f)
(66304 . "OLD ITALIC LETTER A")
(66305 . "OLD ITALIC LETTER BE")
(66306 . "OLD ITALIC LETTER KE")
(66307 . "OLD ITALIC LETTER DE")
(66308 . "OLD ITALIC LETTER E")
(66309 . "OLD ITALIC LETTER VE")
(66310 . "OLD ITALIC LETTER ZE")
(66311 . "OLD ITALIC LETTER HE")
(66312 . "OLD ITALIC LETTER THE")
(66313 . "OLD ITALIC LETTER I")
(66314 . "OLD ITALIC LETTER KA")
(66315 . "OLD ITALIC LETTER EL")
(66316 . "OLD ITALIC LETTER EM")
(66317 . "OLD ITALIC LETTER EN")
(66318 . "OLD ITALIC LETTER ESH")
(66319 . "OLD ITALIC LETTER O")
(66320 . "OLD ITALIC LETTER PE")
(66321 . "OLD ITALIC LETTER SHE")
(66322 . "OLD ITALIC LETTER KU")
(66323 . "OLD ITALIC LETTER ER")
(66324 . "OLD ITALIC LETTER ES")
(66325 . "OLD ITALIC LETTER TE")
(66326 . "OLD ITALIC LETTER U")
(66327 . "OLD ITALIC LETTER EKS")
(66328 . "OLD ITALIC LETTER PHE")
(66329 . "OLD ITALIC LETTER KHE")
(66330 . "OLD ITALIC LETTER EF")
(66331 . "OLD ITALIC LETTER ERS")
(66332 . "OLD ITALIC LETTER CHE")
(66333 . "OLD ITALIC LETTER II")
(66334 . "OLD ITALIC LETTER UU")
(66335 . "OLD ITALIC LETTER ESS")
(66336 . "OLD ITALIC NUMERAL ONE")
(66337 . "OLD ITALIC NUMERAL FIVE")
(66338 . "OLD ITALIC NUMERAL TEN")
(66339 . "OLD ITALIC NUMERAL FIFTY")
((66340 . 66352) . #f)
(66352 . "GOTHIC LETTER AHSA")
(66353 . "GOTHIC LETTER BAIRKAN")
(66354 . "GOTHIC LETTER GIBA")
(66355 . "GOTHIC LETTER DAGS")
(66356 . "GOTHIC LETTER AIHVUS")
(66357 . "GOTHIC LETTER QAIRTHRA")
(66358 . "GOTHIC LETTER IUJA")
(66359 . "GOTHIC LETTER HAGL")
(66360 . "GOTHIC LETTER THIUTH")
(66361 . "GOTHIC LETTER EIS")
(66362 . "GOTHIC LETTER KUSMA")
(66363 . "GOTHIC LETTER LAGUS")
(66364 . "GOTHIC LETTER MANNA")
(66365 . "GOTHIC LETTER NAUTHS")
(66366 . "GOTHIC LETTER JER")
(66367 . "GOTHIC LETTER URUS")
(66368 . "GOTHIC LETTER PAIRTHRA")
(66369 . "GOTHIC LETTER NINETY")
(66370 . "GOTHIC LETTER RAIDA")
(66371 . "GOTHIC LETTER SAUIL")
(66372 . "GOTHIC LETTER TEIWS")
(66373 . "GOTHIC LETTER WINJA")
(66374 . "GOTHIC LETTER FAIHU")
(66375 . "GOTHIC LETTER IGGWS")
(66376 . "GOTHIC LETTER HWAIR")
(66377 . "GOTHIC LETTER OTHAL")
(66378 . "GOTHIC LETTER NINE HUNDRED")
((66379 . 66384) . #f)
(66384 . "OLD PERMIC LETTER AN")
(66385 . "OLD PERMIC LETTER BUR")
(66386 . "OLD PERMIC LETTER GAI")
(66387 . "OLD PERMIC LETTER DOI")
(66388 . "OLD PERMIC LETTER E")
(66389 . "OLD PERMIC LETTER ZHOI")
(66390 . "OLD PERMIC LETTER DZHOI")
(66391 . "OLD PERMIC LETTER ZATA")
(66392 . "OLD PERMIC LETTER DZITA")
(66393 . "OLD PERMIC LETTER I")
(66394 . "OLD PERMIC LETTER KOKE")
(66395 . "OLD PERMIC LETTER LEI")
(66396 . "OLD PERMIC LETTER MENOE")
(66397 . "OLD PERMIC LETTER NENOE")
(66398 . "OLD PERMIC LETTER VOOI")
(66399 . "OLD PERMIC LETTER PEEI")
(66400 . "OLD PERMIC LETTER REI")
(66401 . "OLD PERMIC LETTER SII")
(66402 . "OLD PERMIC LETTER TAI")
(66403 . "OLD PERMIC LETTER U")
(66404 . "OLD PERMIC LETTER CHERY")
(66405 . "OLD PERMIC LETTER SHOOI")
(66406 . "OLD PERMIC LETTER SHCHOOI")
(66407 . "OLD PERMIC LETTER YRY")
(66408 . "OLD PERMIC LETTER YERU")
(66409 . "OLD PERMIC LETTER O")
(66410 . "OLD PERMIC LETTER OO")
(66411 . "OLD PERMIC LETTER EF")
(66412 . "OLD PERMIC LETTER HA")
(66413 . "OLD PERMIC LETTER TSIU")
(66414 . "OLD PERMIC LETTER VER")
(66415 . "OLD PERMIC LETTER YER")
(66416 . "OLD PERMIC LETTER YERI")
(66417 . "OLD PERMIC LETTER YAT")
(66418 . "OLD PERMIC LETTER IE")
(66419 . "OLD PERMIC LETTER YU")
(66420 . "OLD PERMIC LETTER YA")
(66421 . "OLD PERMIC LETTER IA")
(66422 . "COMBINING OLD PERMIC LETTER AN")
(66423 . "COMBINING OLD PERMIC LETTER DOI")
(66424 . "COMBINING OLD PERMIC LETTER ZATA")
(66425 . "COMBINING OLD PERMIC LETTER NENOE")
(66426 . "COMBINING OLD PERMIC LETTER SII")
((66427 . 66432) . #f)
(66432 . "UGARITIC LETTER ALPA")
(66433 . "UGARITIC LETTER BETA")
(66434 . "UGARITIC LETTER GAMLA")
(66435 . "UGARITIC LETTER KHA")
(66436 . "UGARITIC LETTER DELTA")
(66437 . "UGARITIC LETTER HO")
(66438 . "UGARITIC LETTER WO")
(66439 . "UGARITIC LETTER ZETA")
(66440 . "UGARITIC LETTER HOTA")
(66441 . "UGARITIC LETTER TET")
(66442 . "UGARITIC LETTER YOD")
(66443 . "UGARITIC LETTER KAF")
(66444 . "UGARITIC LETTER SHIN")
(66445 . "UGARITIC LETTER LAMDA")
(66446 . "UGARITIC LETTER MEM")
(66447 . "UGARITIC LETTER DHAL")
(66448 . "UGARITIC LETTER NUN")
(66449 . "UGARITIC LETTER ZU")
(66450 . "UGARITIC LETTER SAMKA")
(66451 . "UGARITIC LETTER AIN")
(66452 . "UGARITIC LETTER PU")
(66453 . "UGARITIC LETTER SADE")
(66454 . "UGARITIC LETTER QOPA")
(66455 . "UGARITIC LETTER RASHA")
(66456 . "UGARITIC LETTER THANNA")
(66457 . "UGARITIC LETTER GHAIN")
(66458 . "UGARITIC LETTER TO")
(66459 . "UGARITIC LETTER I")
(66460 . "UGARITIC LETTER U")
(66461 . "UGARITIC LETTER SSU")
(66462 . #f)
(66463 . "UGARITIC WORD DIVIDER")
(66464 . "OLD PERSIAN SIGN A")
(66465 . "OLD PERSIAN SIGN I")
(66466 . "OLD PERSIAN SIGN U")
(66467 . "OLD PERSIAN SIGN KA")
(66468 . "OLD PERSIAN SIGN KU")
(66469 . "OLD PERSIAN SIGN GA")
(66470 . "OLD PERSIAN SIGN GU")
(66471 . "OLD PERSIAN SIGN XA")
(66472 . "OLD PERSIAN SIGN CA")
(66473 . "OLD PERSIAN SIGN JA")
(66474 . "OLD PERSIAN SIGN JI")
(66475 . "OLD PERSIAN SIGN TA")
(66476 . "OLD PERSIAN SIGN TU")
(66477 . "OLD PERSIAN SIGN DA")
(66478 . "OLD PERSIAN SIGN DI")
(66479 . "OLD PERSIAN SIGN DU")
(66480 . "OLD PERSIAN SIGN THA")
(66481 . "OLD PERSIAN SIGN PA")
(66482 . "OLD PERSIAN SIGN BA")
(66483 . "OLD PERSIAN SIGN FA")
(66484 . "OLD PERSIAN SIGN NA")
(66485 . "OLD PERSIAN SIGN NU")
(66486 . "OLD PERSIAN SIGN MA")
(66487 . "OLD PERSIAN SIGN MI")
(66488 . "OLD PERSIAN SIGN MU")
(66489 . "OLD PERSIAN SIGN YA")
(66490 . "OLD PERSIAN SIGN VA")
(66491 . "OLD PERSIAN SIGN VI")
(66492 . "OLD PERSIAN SIGN RA")
(66493 . "OLD PERSIAN SIGN RU")
(66494 . "OLD PERSIAN SIGN LA")
(66495 . "OLD PERSIAN SIGN SA")
(66496 . "OLD PERSIAN SIGN ZA")
(66497 . "OLD PERSIAN SIGN SHA")
(66498 . "OLD PERSIAN SIGN SSA")
(66499 . "OLD PERSIAN SIGN HA")
((66500 . 66504) . #f)
(66504 . "OLD PERSIAN SIGN AURAMAZDAA")
(66505 . "OLD PERSIAN SIGN AURAMAZDAA-2")
(66506 . "OLD PERSIAN SIGN AURAMAZDAAHA")
(66507 . "OLD PERSIAN SIGN XSHAAYATHIYA")
(66508 . "OLD PERSIAN SIGN DAHYAAUSH")
(66509 . "OLD PERSIAN SIGN DAHYAAUSH-2")
(66510 . "OLD PERSIAN SIGN BAGA")
(66511 . "OLD PERSIAN SIGN BUUMISH")
(66512 . "OLD PERSIAN WORD DIVIDER")
(66513 . "OLD PERSIAN NUMBER ONE")
(66514 . "OLD PERSIAN NUMBER TWO")
(66515 . "OLD PERSIAN NUMBER TEN")
(66516 . "OLD PERSIAN NUMBER TWENTY")
(66517 . "OLD PERSIAN NUMBER HUNDRED")
((66518 . 66560) . #f)
(66560 . "DESERET CAPITAL LETTER LONG I")
(66561 . "DESERET CAPITAL LETTER LONG E")
(66562 . "DESERET CAPITAL LETTER LONG A")
(66563 . "DESERET CAPITAL LETTER LONG AH")
(66564 . "DESERET CAPITAL LETTER LONG O")
(66565 . "DESERET CAPITAL LETTER LONG OO")
(66566 . "DESERET CAPITAL LETTER SHORT I")
(66567 . "DESERET CAPITAL LETTER SHORT E")
(66568 . "DESERET CAPITAL LETTER SHORT A")
(66569 . "DESERET CAPITAL LETTER SHORT AH")
(66570 . "DESERET CAPITAL LETTER SHORT O")
(66571 . "DESERET CAPITAL LETTER SHORT OO")
(66572 . "DESERET CAPITAL LETTER AY")
(66573 . "DESERET CAPITAL LETTER OW")
(66574 . "DESERET CAPITAL LETTER WU")
(66575 . "DESERET CAPITAL LETTER YEE")
(66576 . "DESERET CAPITAL LETTER H")
(66577 . "DESERET CAPITAL LETTER PEE")
(66578 . "DESERET CAPITAL LETTER BEE")
(66579 . "DESERET CAPITAL LETTER TEE")
(66580 . "DESERET CAPITAL LETTER DEE")
(66581 . "DESERET CAPITAL LETTER CHEE")
(66582 . "DESERET CAPITAL LETTER JEE")
(66583 . "DESERET CAPITAL LETTER KAY")
(66584 . "DESERET CAPITAL LETTER GAY")
(66585 . "DESERET CAPITAL LETTER EF")
(66586 . "DESERET CAPITAL LETTER VEE")
(66587 . "DESERET CAPITAL LETTER ETH")
(66588 . "DESERET CAPITAL LETTER THEE")
(66589 . "DESERET CAPITAL LETTER ES")
(66590 . "DESERET CAPITAL LETTER ZEE")
(66591 . "DESERET CAPITAL LETTER ESH")
(66592 . "DESERET CAPITAL LETTER ZHEE")
(66593 . "DESERET CAPITAL LETTER ER")
(66594 . "DESERET CAPITAL LETTER EL")
(66595 . "DESERET CAPITAL LETTER EM")
(66596 . "DESERET CAPITAL LETTER EN")
(66597 . "DESERET CAPITAL LETTER ENG")
(66598 . "DESERET CAPITAL LETTER OI")
(66599 . "DESERET CAPITAL LETTER EW")
(66600 . "DESERET SMALL LETTER LONG I")
(66601 . "DESERET SMALL LETTER LONG E")
(66602 . "DESERET SMALL LETTER LONG A")
(66603 . "DESERET SMALL LETTER LONG AH")
(66604 . "DESERET SMALL LETTER LONG O")
(66605 . "DESERET SMALL LETTER LONG OO")
(66606 . "DESERET SMALL LETTER SHORT I")
(66607 . "DESERET SMALL LETTER SHORT E")
(66608 . "DESERET SMALL LETTER SHORT A")
(66609 . "DESERET SMALL LETTER SHORT AH")
(66610 . "DESERET SMALL LETTER SHORT O")
(66611 . "DESERET SMALL LETTER SHORT OO")
(66612 . "DESERET SMALL LETTER AY")
(66613 . "DESERET SMALL LETTER OW")
(66614 . "DESERET SMALL LETTER WU")
(66615 . "DESERET SMALL LETTER YEE")
(66616 . "DESERET SMALL LETTER H")
(66617 . "DESERET SMALL LETTER PEE")
(66618 . "DESERET SMALL LETTER BEE")
(66619 . "DESERET SMALL LETTER TEE")
(66620 . "DESERET SMALL LETTER DEE")
(66621 . "DESERET SMALL LETTER CHEE")
(66622 . "DESERET SMALL LETTER JEE")
(66623 . "DESERET SMALL LETTER KAY")
(66624 . "DESERET SMALL LETTER GAY")
(66625 . "DESERET SMALL LETTER EF")
(66626 . "DESERET SMALL LETTER VEE")
(66627 . "DESERET SMALL LETTER ETH")
(66628 . "DESERET SMALL LETTER THEE")
(66629 . "DESERET SMALL LETTER ES")
(66630 . "DESERET SMALL LETTER ZEE")
(66631 . "DESERET SMALL LETTER ESH")
(66632 . "DESERET SMALL LETTER ZHEE")
(66633 . "DESERET SMALL LETTER ER")
(66634 . "DESERET SMALL LETTER EL")
(66635 . "DESERET SMALL LETTER EM")
(66636 . "DESERET SMALL LETTER EN")
(66637 . "DESERET SMALL LETTER ENG")
(66638 . "DESERET SMALL LETTER OI")
(66639 . "DESERET SMALL LETTER EW")
(66640 . "SHAVIAN LETTER PEEP")
(66641 . "SHAVIAN LETTER TOT")
(66642 . "SHAVIAN LETTER KICK")
(66643 . "SHAVIAN LETTER FEE")
(66644 . "SHAVIAN LETTER THIGH")
(66645 . "SHAVIAN LETTER SO")
(66646 . "SHAVIAN LETTER SURE")
(66647 . "SHAVIAN LETTER CHURCH")
(66648 . "SHAVIAN LETTER YEA")
(66649 . "SHAVIAN LETTER HUNG")
(66650 . "SHAVIAN LETTER BIB")
(66651 . "SHAVIAN LETTER DEAD")
(66652 . "SHAVIAN LETTER GAG")
(66653 . "SHAVIAN LETTER VOW")
(66654 . "SHAVIAN LETTER THEY")
(66655 . "SHAVIAN LETTER ZOO")
(66656 . "SHAVIAN LETTER MEASURE")
(66657 . "SHAVIAN LETTER JUDGE")
(66658 . "SHAVIAN LETTER WOE")
(66659 . "SHAVIAN LETTER HA-HA")
(66660 . "SHAVIAN LETTER LOLL")
(66661 . "SHAVIAN LETTER MIME")
(66662 . "SHAVIAN LETTER IF")
(66663 . "SHAVIAN LETTER EGG")
(66664 . "SHAVIAN LETTER ASH")
(66665 . "SHAVIAN LETTER ADO")
(66666 . "SHAVIAN LETTER ON")
(66667 . "SHAVIAN LETTER WOOL")
(66668 . "SHAVIAN LETTER OUT")
(66669 . "SHAVIAN LETTER AH")
(66670 . "SHAVIAN LETTER ROAR")
(66671 . "SHAVIAN LETTER NUN")
(66672 . "SHAVIAN LETTER EAT")
(66673 . "SHAVIAN LETTER AGE")
(66674 . "SHAVIAN LETTER ICE")
(66675 . "SHAVIAN LETTER UP")
(66676 . "SHAVIAN LETTER OAK")
(66677 . "SHAVIAN LETTER OOZE")
(66678 . "SHAVIAN LETTER OIL")
(66679 . "SHAVIAN LETTER AWE")
(66680 . "SHAVIAN LETTER ARE")
(66681 . "SHAVIAN LETTER OR")
(66682 . "SHAVIAN LETTER AIR")
(66683 . "SHAVIAN LETTER ERR")
(66684 . "SHAVIAN LETTER ARRAY")
(66685 . "SHAVIAN LETTER EAR")
(66686 . "SHAVIAN LETTER IAN")
(66687 . "SHAVIAN LETTER YEW")
(66688 . "OSMANYA LETTER ALEF")
(66689 . "OSMANYA LETTER BA")
(66690 . "OSMANYA LETTER TA")
(66691 . "OSMANYA LETTER JA")
(66692 . "OSMANYA LETTER XA")
(66693 . "OSMANYA LETTER KHA")
(66694 . "OSMANYA LETTER DEEL")
(66695 . "OSMANYA LETTER RA")
(66696 . "OSMANYA LETTER SA")
(66697 . "OSMANYA LETTER SHIIN")
(66698 . "OSMANYA LETTER DHA")
(66699 . "OSMANYA LETTER CAYN")
(66700 . "OSMANYA LETTER GA")
(66701 . "OSMANYA LETTER FA")
(66702 . "OSMANYA LETTER QAAF")
(66703 . "OSMANYA LETTER KAAF")
(66704 . "OSMANYA LETTER LAAN")
(66705 . "OSMANYA LETTER MIIN")
(66706 . "OSMANYA LETTER NUUN")
(66707 . "OSMANYA LETTER WAW")
(66708 . "OSMANYA LETTER HA")
(66709 . "OSMANYA LETTER YA")
(66710 . "OSMANYA LETTER A")
(66711 . "OSMANYA LETTER E")
(66712 . "OSMANYA LETTER I")
(66713 . "OSMANYA LETTER O")
(66714 . "OSMANYA LETTER U")
(66715 . "OSMANYA LETTER AA")
(66716 . "OSMANYA LETTER EE")
(66717 . "OSMANYA LETTER OO")
((66718 . 66720) . #f)
(66720 . "OSMANYA DIGIT ZERO")
(66721 . "OSMANYA DIGIT ONE")
(66722 . "OSMANYA DIGIT TWO")
(66723 . "OSMANYA DIGIT THREE")
(66724 . "OSMANYA DIGIT FOUR")
(66725 . "OSMANYA DIGIT FIVE")
(66726 . "OSMANYA DIGIT SIX")
(66727 . "OSMANYA DIGIT SEVEN")
(66728 . "OSMANYA DIGIT EIGHT")
(66729 . "OSMANYA DIGIT NINE")
((66730 . 66736) . #f)
(66736 . "OSAGE CAPITAL LETTER A")
(66737 . "OSAGE CAPITAL LETTER AI")
(66738 . "OSAGE CAPITAL LETTER AIN")
(66739 . "OSAGE CAPITAL LETTER AH")
(66740 . "OSAGE CAPITAL LETTER BRA")
(66741 . "OSAGE CAPITAL LETTER CHA")
(66742 . "OSAGE CAPITAL LETTER EHCHA")
(66743 . "OSAGE CAPITAL LETTER E")
(66744 . "OSAGE CAPITAL LETTER EIN")
(66745 . "OSAGE CAPITAL LETTER HA")
(66746 . "OSAGE CAPITAL LETTER HYA")
(66747 . "OSAGE CAPITAL LETTER I")
(66748 . "OSAGE CAPITAL LETTER KA")
(66749 . "OSAGE CAPITAL LETTER EHKA")
(66750 . "OSAGE CAPITAL LETTER KYA")
(66751 . "OSAGE CAPITAL LETTER LA")
(66752 . "OSAGE CAPITAL LETTER MA")
(66753 . "OSAGE CAPITAL LETTER NA")
(66754 . "OSAGE CAPITAL LETTER O")
(66755 . "OSAGE CAPITAL LETTER OIN")
(66756 . "OSAGE CAPITAL LETTER PA")
(66757 . "OSAGE CAPITAL LETTER EHPA")
(66758 . "OSAGE CAPITAL LETTER SA")
(66759 . "OSAGE CAPITAL LETTER SHA")
(66760 . "OSAGE CAPITAL LETTER TA")
(66761 . "OSAGE CAPITAL LETTER EHTA")
(66762 . "OSAGE CAPITAL LETTER TSA")
(66763 . "OSAGE CAPITAL LETTER EHTSA")
(66764 . "OSAGE CAPITAL LETTER TSHA")
(66765 . "OSAGE CAPITAL LETTER DHA")
(66766 . "OSAGE CAPITAL LETTER U")
(66767 . "OSAGE CAPITAL LETTER WA")
(66768 . "OSAGE CAPITAL LETTER KHA")
(66769 . "OSAGE CAPITAL LETTER GHA")
(66770 . "OSAGE CAPITAL LETTER ZA")
(66771 . "OSAGE CAPITAL LETTER ZHA")
((66772 . 66776) . #f)
(66776 . "OSAGE SMALL LETTER A")
(66777 . "OSAGE SMALL LETTER AI")
(66778 . "OSAGE SMALL LETTER AIN")
(66779 . "OSAGE SMALL LETTER AH")
(66780 . "OSAGE SMALL LETTER BRA")
(66781 . "OSAGE SMALL LETTER CHA")
(66782 . "OSAGE SMALL LETTER EHCHA")
(66783 . "OSAGE SMALL LETTER E")
(66784 . "OSAGE SMALL LETTER EIN")
(66785 . "OSAGE SMALL LETTER HA")
(66786 . "OSAGE SMALL LETTER HYA")
(66787 . "OSAGE SMALL LETTER I")
(66788 . "OSAGE SMALL LETTER KA")
(66789 . "OSAGE SMALL LETTER EHKA")
(66790 . "OSAGE SMALL LETTER KYA")
(66791 . "OSAGE SMALL LETTER LA")
(66792 . "OSAGE SMALL LETTER MA")
(66793 . "OSAGE SMALL LETTER NA")
(66794 . "OSAGE SMALL LETTER O")
(66795 . "OSAGE SMALL LETTER OIN")
(66796 . "OSAGE SMALL LETTER PA")
(66797 . "OSAGE SMALL LETTER EHPA")
(66798 . "OSAGE SMALL LETTER SA")
(66799 . "OSAGE SMALL LETTER SHA")
(66800 . "OSAGE SMALL LETTER TA")
(66801 . "OSAGE SMALL LETTER EHTA")
(66802 . "OSAGE SMALL LETTER TSA")
(66803 . "OSAGE SMALL LETTER EHTSA")
(66804 . "OSAGE SMALL LETTER TSHA")
(66805 . "OSAGE SMALL LETTER DHA")
(66806 . "OSAGE SMALL LETTER U")
(66807 . "OSAGE SMALL LETTER WA")
(66808 . "OSAGE SMALL LETTER KHA")
(66809 . "OSAGE SMALL LETTER GHA")
(66810 . "OSAGE SMALL LETTER ZA")
(66811 . "OSAGE SMALL LETTER ZHA")
((66812 . 66816) . #f)
(66816 . "ELBASAN LETTER A")
(66817 . "ELBASAN LETTER BE")
(66818 . "ELBASAN LETTER CE")
(66819 . "ELBASAN LETTER CHE")
(66820 . "ELBASAN LETTER DE")
(66821 . "ELBASAN LETTER NDE")
(66822 . "ELBASAN LETTER DHE")
(66823 . "ELBASAN LETTER EI")
(66824 . "ELBASAN LETTER E")
(66825 . "ELBASAN LETTER FE")
(66826 . "ELBASAN LETTER GE")
(66827 . "ELBASAN LETTER GJE")
(66828 . "ELBASAN LETTER HE")
(66829 . "ELBASAN LETTER I")
(66830 . "ELBASAN LETTER JE")
(66831 . "ELBASAN LETTER KE")
(66832 . "ELBASAN LETTER LE")
(66833 . "ELBASAN LETTER LLE")
(66834 . "ELBASAN LETTER ME")
(66835 . "ELBASAN LETTER NE")
(66836 . "ELBASAN LETTER NA")
(66837 . "ELBASAN LETTER NJE")
(66838 . "ELBASAN LETTER O")
(66839 . "ELBASAN LETTER PE")
(66840 . "ELBASAN LETTER QE")
(66841 . "ELBASAN LETTER RE")
(66842 . "ELBASAN LETTER RRE")
(66843 . "ELBASAN LETTER SE")
(66844 . "ELBASAN LETTER SHE")
(66845 . "ELBASAN LETTER TE")
(66846 . "ELBASAN LETTER THE")
(66847 . "ELBASAN LETTER U")
(66848 . "ELBASAN LETTER VE")
(66849 . "ELBASAN LETTER XE")
(66850 . "ELBASAN LETTER Y")
(66851 . "ELBASAN LETTER ZE")
(66852 . "ELBASAN LETTER ZHE")
(66853 . "ELBASAN LETTER GHE")
(66854 . "ELBASAN LETTER GHAMMA")
(66855 . "ELBASAN LETTER KHE")
((66856 . 66864) . #f)
(66864 . "CAUCASIAN ALBANIAN LETTER ALT")
(66865 . "CAUCASIAN ALBANIAN LETTER BET")
(66866 . "CAUCASIAN ALBANIAN LETTER GIM")
(66867 . "CAUCASIAN ALBANIAN LETTER DAT")
(66868 . "CAUCASIAN ALBANIAN LETTER EB")
(66869 . "CAUCASIAN ALBANIAN LETTER ZARL")
(66870 . "CAUCASIAN ALBANIAN LETTER EYN")
(66871 . "CAUCASIAN ALBANIAN LETTER ZHIL")
(66872 . "CAUCASIAN ALBANIAN LETTER TAS")
(66873 . "CAUCASIAN ALBANIAN LETTER CHA")
(66874 . "CAUCASIAN ALBANIAN LETTER YOWD")
(66875 . "CAUCASIAN ALBANIAN LETTER ZHA")
(66876 . "CAUCASIAN ALBANIAN LETTER IRB")
(66877 . "CAUCASIAN ALBANIAN LETTER SHA")
(66878 . "CAUCASIAN ALBANIAN LETTER LAN")
(66879 . "CAUCASIAN ALBANIAN LETTER INYA")
(66880 . "CAUCASIAN ALBANIAN LETTER XEYN")
(66881 . "CAUCASIAN ALBANIAN LETTER DYAN")
(66882 . "CAUCASIAN ALBANIAN LETTER CAR")
(66883 . "CAUCASIAN ALBANIAN LETTER JHOX")
(66884 . "CAUCASIAN ALBANIAN LETTER KAR")
(66885 . "CAUCASIAN ALBANIAN LETTER LYIT")
(66886 . "CAUCASIAN ALBANIAN LETTER HEYT")
(66887 . "CAUCASIAN ALBANIAN LETTER QAY")
(66888 . "CAUCASIAN ALBANIAN LETTER AOR")
(66889 . "CAUCASIAN ALBANIAN LETTER CHOY")
(66890 . "CAUCASIAN ALBANIAN LETTER CHI")
(66891 . "CAUCASIAN ALBANIAN LETTER CYAY")
(66892 . "CAUCASIAN ALBANIAN LETTER MAQ")
(66893 . "CAUCASIAN ALBANIAN LETTER QAR")
(66894 . "CAUCASIAN ALBANIAN LETTER NOWC")
(66895 . "CAUCASIAN ALBANIAN LETTER DZYAY")
(66896 . "CAUCASIAN ALBANIAN LETTER SHAK")
(66897 . "CAUCASIAN ALBANIAN LETTER JAYN")
(66898 . "CAUCASIAN ALBANIAN LETTER ON")
(66899 . "CAUCASIAN ALBANIAN LETTER TYAY")
(66900 . "CAUCASIAN ALBANIAN LETTER FAM")
(66901 . "CAUCASIAN ALBANIAN LETTER DZAY")
(66902 . "CAUCASIAN ALBANIAN LETTER CHAT")
(66903 . "CAUCASIAN ALBANIAN LETTER PEN")
(66904 . "CAUCASIAN ALBANIAN LETTER GHEYS")
(66905 . "CAUCASIAN ALBANIAN LETTER RAT")
(66906 . "CAUCASIAN ALBANIAN LETTER SEYK")
(66907 . "CAUCASIAN ALBANIAN LETTER VEYZ")
(66908 . "CAUCASIAN ALBANIAN LETTER TIWR")
(66909 . "CAUCASIAN ALBANIAN LETTER SHOY")
(66910 . "CAUCASIAN ALBANIAN LETTER IWN")
(66911 . "CAUCASIAN ALBANIAN LETTER CYAW")
(66912 . "CAUCASIAN ALBANIAN LETTER CAYN")
(66913 . "CAUCASIAN ALBANIAN LETTER YAYD")
(66914 . "CAUCASIAN ALBANIAN LETTER PIWR")
(66915 . "CAUCASIAN ALBANIAN LETTER KIW")
((66916 . 66927) . #f)
(66927 . "CAUCASIAN ALBANIAN CITATION MARK")
((66928 . 67072) . #f)
(67072 . "LINEAR A SIGN AB001")
(67073 . "LINEAR A SIGN AB002")
(67074 . "LINEAR A SIGN AB003")
(67075 . "LINEAR A SIGN AB004")
(67076 . "LINEAR A SIGN AB005")
(67077 . "LINEAR A SIGN AB006")
(67078 . "LINEAR A SIGN AB007")
(67079 . "LINEAR A SIGN AB008")
(67080 . "LINEAR A SIGN AB009")
(67081 . "LINEAR A SIGN AB010")
(67082 . "LINEAR A SIGN AB011")
(67083 . "LINEAR A SIGN AB013")
(67084 . "LINEAR A SIGN AB016")
(67085 . "LINEAR A SIGN AB017")
(67086 . "LINEAR A SIGN AB020")
(67087 . "LINEAR A SIGN AB021")
(67088 . "LINEAR A SIGN AB021F")
(67089 . "LINEAR A SIGN AB021M")
(67090 . "LINEAR A SIGN AB022")
(67091 . "LINEAR A SIGN AB022F")
(67092 . "LINEAR A SIGN AB022M")
(67093 . "LINEAR A SIGN AB023")
(67094 . "LINEAR A SIGN AB023M")
(67095 . "LINEAR A SIGN AB024")
(67096 . "LINEAR A SIGN AB026")
(67097 . "LINEAR A SIGN AB027")
(67098 . "LINEAR A SIGN AB028")
(67099 . "LINEAR A SIGN A028B")
(67100 . "LINEAR A SIGN AB029")
(67101 . "LINEAR A SIGN AB030")
(67102 . "LINEAR A SIGN AB031")
(67103 . "LINEAR A SIGN AB034")
(67104 . "LINEAR A SIGN AB037")
(67105 . "LINEAR A SIGN AB038")
(67106 . "LINEAR A SIGN AB039")
(67107 . "LINEAR A SIGN AB040")
(67108 . "LINEAR A SIGN AB041")
(67109 . "LINEAR A SIGN AB044")
(67110 . "LINEAR A SIGN AB045")
(67111 . "LINEAR A SIGN AB046")
(67112 . "LINEAR A SIGN AB047")
(67113 . "LINEAR A SIGN AB048")
(67114 . "LINEAR A SIGN AB049")
(67115 . "LINEAR A SIGN AB050")
(67116 . "LINEAR A SIGN AB051")
(67117 . "LINEAR A SIGN AB053")
(67118 . "LINEAR A SIGN AB054")
(67119 . "LINEAR A SIGN AB055")
(67120 . "LINEAR A SIGN AB056")
(67121 . "LINEAR A SIGN AB057")
(67122 . "LINEAR A SIGN AB058")
(67123 . "LINEAR A SIGN AB059")
(67124 . "LINEAR A SIGN AB060")
(67125 . "LINEAR A SIGN AB061")
(67126 . "LINEAR A SIGN AB065")
(67127 . "LINEAR A SIGN AB066")
(67128 . "LINEAR A SIGN AB067")
(67129 . "LINEAR A SIGN AB069")
(67130 . "LINEAR A SIGN AB070")
(67131 . "LINEAR A SIGN AB073")
(67132 . "LINEAR A SIGN AB074")
(67133 . "LINEAR A SIGN AB076")
(67134 . "LINEAR A SIGN AB077")
(67135 . "LINEAR A SIGN AB078")
(67136 . "LINEAR A SIGN AB079")
(67137 . "LINEAR A SIGN AB080")
(67138 . "LINEAR A SIGN AB081")
(67139 . "LINEAR A SIGN AB082")
(67140 . "LINEAR A SIGN AB085")
(67141 . "LINEAR A SIGN AB086")
(67142 . "LINEAR A SIGN AB087")
(67143 . "LINEAR A SIGN A100-102")
(67144 . "LINEAR A SIGN AB118")
(67145 . "LINEAR A SIGN AB120")
(67146 . "LINEAR A SIGN A120B")
(67147 . "LINEAR A SIGN AB122")
(67148 . "LINEAR A SIGN AB123")
(67149 . "LINEAR A SIGN AB131A")
(67150 . "LINEAR A SIGN AB131B")
(67151 . "LINEAR A SIGN A131C")
(67152 . "LINEAR A SIGN AB164")
(67153 . "LINEAR A SIGN AB171")
(67154 . "LINEAR A SIGN AB180")
(67155 . "LINEAR A SIGN AB188")
(67156 . "LINEAR A SIGN AB191")
(67157 . "LINEAR A SIGN A301")
(67158 . "LINEAR A SIGN A302")
(67159 . "LINEAR A SIGN A303")
(67160 . "LINEAR A SIGN A304")
(67161 . "LINEAR A SIGN A305")
(67162 . "LINEAR A SIGN A306")
(67163 . "LINEAR A SIGN A307")
(67164 . "LINEAR A SIGN A308")
(67165 . "LINEAR A SIGN A309A")
(67166 . "LINEAR A SIGN A309B")
(67167 . "LINEAR A SIGN A309C")
(67168 . "LINEAR A SIGN A310")
(67169 . "LINEAR A SIGN A311")
(67170 . "LINEAR A SIGN A312")
(67171 . "LINEAR A SIGN A313A")
(67172 . "LINEAR A SIGN A313B")
(67173 . "LINEAR A SIGN A313C")
(67174 . "LINEAR A SIGN A314")
(67175 . "LINEAR A SIGN A315")
(67176 . "LINEAR A SIGN A316")
(67177 . "LINEAR A SIGN A317")
(67178 . "LINEAR A SIGN A318")
(67179 . "LINEAR A SIGN A319")
(67180 . "LINEAR A SIGN A320")
(67181 . "LINEAR A SIGN A321")
(67182 . "LINEAR A SIGN A322")
(67183 . "LINEAR A SIGN A323")
(67184 . "LINEAR A SIGN A324")
(67185 . "LINEAR A SIGN A325")
(67186 . "LINEAR A SIGN A326")
(67187 . "LINEAR A SIGN A327")
(67188 . "LINEAR A SIGN A328")
(67189 . "LINEAR A SIGN A329")
(67190 . "LINEAR A SIGN A330")
(67191 . "LINEAR A SIGN A331")
(67192 . "LINEAR A SIGN A332")
(67193 . "LINEAR A SIGN A333")
(67194 . "LINEAR A SIGN A334")
(67195 . "LINEAR A SIGN A335")
(67196 . "LINEAR A SIGN A336")
(67197 . "LINEAR A SIGN A337")
(67198 . "LINEAR A SIGN A338")
(67199 . "LINEAR A SIGN A339")
(67200 . "LINEAR A SIGN A340")
(67201 . "LINEAR A SIGN A341")
(67202 . "LINEAR A SIGN A342")
(67203 . "LINEAR A SIGN A343")
(67204 . "LINEAR A SIGN A344")
(67205 . "LINEAR A SIGN A345")
(67206 . "LINEAR A SIGN A346")
(67207 . "LINEAR A SIGN A347")
(67208 . "LINEAR A SIGN A348")
(67209 . "LINEAR A SIGN A349")
(67210 . "LINEAR A SIGN A350")
(67211 . "LINEAR A SIGN A351")
(67212 . "LINEAR A SIGN A352")
(67213 . "LINEAR A SIGN A353")
(67214 . "LINEAR A SIGN A354")
(67215 . "LINEAR A SIGN A355")
(67216 . "LINEAR A SIGN A356")
(67217 . "LINEAR A SIGN A357")
(67218 . "LINEAR A SIGN A358")
(67219 . "LINEAR A SIGN A359")
(67220 . "LINEAR A SIGN A360")
(67221 . "LINEAR A SIGN A361")
(67222 . "LINEAR A SIGN A362")
(67223 . "LINEAR A SIGN A363")
(67224 . "LINEAR A SIGN A364")
(67225 . "LINEAR A SIGN A365")
(67226 . "LINEAR A SIGN A366")
(67227 . "LINEAR A SIGN A367")
(67228 . "LINEAR A SIGN A368")
(67229 . "LINEAR A SIGN A369")
(67230 . "LINEAR A SIGN A370")
(67231 . "LINEAR A SIGN A371")
(67232 . "LINEAR A SIGN A400-VAS")
(67233 . "LINEAR A SIGN A401-VAS")
(67234 . "LINEAR A SIGN A402-VAS")
(67235 . "LINEAR A SIGN A403-VAS")
(67236 . "LINEAR A SIGN A404-VAS")
(67237 . "LINEAR A SIGN A405-VAS")
(67238 . "LINEAR A SIGN A406-VAS")
(67239 . "LINEAR A SIGN A407-VAS")
(67240 . "LINEAR A SIGN A408-VAS")
(67241 . "LINEAR A SIGN A409-VAS")
(67242 . "LINEAR A SIGN A410-VAS")
(67243 . "LINEAR A SIGN A411-VAS")
(67244 . "LINEAR A SIGN A412-VAS")
(67245 . "LINEAR A SIGN A413-VAS")
(67246 . "LINEAR A SIGN A414-VAS")
(67247 . "LINEAR A SIGN A415-VAS")
(67248 . "LINEAR A SIGN A416-VAS")
(67249 . "LINEAR A SIGN A417-VAS")
(67250 . "LINEAR A SIGN A418-VAS")
(67251 . "LINEAR A SIGN A501")
(67252 . "LINEAR A SIGN A502")
(67253 . "LINEAR A SIGN A503")
(67254 . "LINEAR A SIGN A504")
(67255 . "LINEAR A SIGN A505")
(67256 . "LINEAR A SIGN A506")
(67257 . "LINEAR A SIGN A508")
(67258 . "LINEAR A SIGN A509")
(67259 . "LINEAR A SIGN A510")
(67260 . "LINEAR A SIGN A511")
(67261 . "LINEAR A SIGN A512")
(67262 . "LINEAR A SIGN A513")
(67263 . "LINEAR A SIGN A515")
(67264 . "LINEAR A SIGN A516")
(67265 . "LINEAR A SIGN A520")
(67266 . "LINEAR A SIGN A521")
(67267 . "LINEAR A SIGN A523")
(67268 . "LINEAR A SIGN A524")
(67269 . "LINEAR A SIGN A525")
(67270 . "LINEAR A SIGN A526")
(67271 . "LINEAR A SIGN A527")
(67272 . "LINEAR A SIGN A528")
(67273 . "LINEAR A SIGN A529")
(67274 . "LINEAR A SIGN A530")
(67275 . "LINEAR A SIGN A531")
(67276 . "LINEAR A SIGN A532")
(67277 . "LINEAR A SIGN A534")
(67278 . "LINEAR A SIGN A535")
(67279 . "LINEAR A SIGN A536")
(67280 . "LINEAR A SIGN A537")
(67281 . "LINEAR A SIGN A538")
(67282 . "LINEAR A SIGN A539")
(67283 . "LINEAR A SIGN A540")
(67284 . "LINEAR A SIGN A541")
(67285 . "LINEAR A SIGN A542")
(67286 . "LINEAR A SIGN A545")
(67287 . "LINEAR A SIGN A547")
(67288 . "LINEAR A SIGN A548")
(67289 . "LINEAR A SIGN A549")
(67290 . "LINEAR A SIGN A550")
(67291 . "LINEAR A SIGN A551")
(67292 . "LINEAR A SIGN A552")
(67293 . "LINEAR A SIGN A553")
(67294 . "LINEAR A SIGN A554")
(67295 . "LINEAR A SIGN A555")
(67296 . "LINEAR A SIGN A556")
(67297 . "LINEAR A SIGN A557")
(67298 . "LINEAR A SIGN A559")
(67299 . "LINEAR A SIGN A563")
(67300 . "LINEAR A SIGN A564")
(67301 . "LINEAR A SIGN A565")
(67302 . "LINEAR A SIGN A566")
(67303 . "LINEAR A SIGN A568")
(67304 . "LINEAR A SIGN A569")
(67305 . "LINEAR A SIGN A570")
(67306 . "LINEAR A SIGN A571")
(67307 . "LINEAR A SIGN A572")
(67308 . "LINEAR A SIGN A573")
(67309 . "LINEAR A SIGN A574")
(67310 . "LINEAR A SIGN A575")
(67311 . "LINEAR A SIGN A576")
(67312 . "LINEAR A SIGN A577")
(67313 . "LINEAR A SIGN A578")
(67314 . "LINEAR A SIGN A579")
(67315 . "LINEAR A SIGN A580")
(67316 . "LINEAR A SIGN A581")
(67317 . "LINEAR A SIGN A582")
(67318 . "LINEAR A SIGN A583")
(67319 . "LINEAR A SIGN A584")
(67320 . "LINEAR A SIGN A585")
(67321 . "LINEAR A SIGN A586")
(67322 . "LINEAR A SIGN A587")
(67323 . "LINEAR A SIGN A588")
(67324 . "LINEAR A SIGN A589")
(67325 . "LINEAR A SIGN A591")
(67326 . "LINEAR A SIGN A592")
(67327 . "LINEAR A SIGN A594")
(67328 . "LINEAR A SIGN A595")
(67329 . "LINEAR A SIGN A596")
(67330 . "LINEAR A SIGN A598")
(67331 . "LINEAR A SIGN A600")
(67332 . "LINEAR A SIGN A601")
(67333 . "LINEAR A SIGN A602")
(67334 . "LINEAR A SIGN A603")
(67335 . "LINEAR A SIGN A604")
(67336 . "LINEAR A SIGN A606")
(67337 . "LINEAR A SIGN A608")
(67338 . "LINEAR A SIGN A609")
(67339 . "LINEAR A SIGN A610")
(67340 . "LINEAR A SIGN A611")
(67341 . "LINEAR A SIGN A612")
(67342 . "LINEAR A SIGN A613")
(67343 . "LINEAR A SIGN A614")
(67344 . "LINEAR A SIGN A615")
(67345 . "LINEAR A SIGN A616")
(67346 . "LINEAR A SIGN A617")
(67347 . "LINEAR A SIGN A618")
(67348 . "LINEAR A SIGN A619")
(67349 . "LINEAR A SIGN A620")
(67350 . "LINEAR A SIGN A621")
(67351 . "LINEAR A SIGN A622")
(67352 . "LINEAR A SIGN A623")
(67353 . "LINEAR A SIGN A624")
(67354 . "LINEAR A SIGN A626")
(67355 . "LINEAR A SIGN A627")
(67356 . "LINEAR A SIGN A628")
(67357 . "LINEAR A SIGN A629")
(67358 . "LINEAR A SIGN A634")
(67359 . "LINEAR A SIGN A637")
(67360 . "LINEAR A SIGN A638")
(67361 . "LINEAR A SIGN A640")
(67362 . "LINEAR A SIGN A642")
(67363 . "LINEAR A SIGN A643")
(67364 . "LINEAR A SIGN A644")
(67365 . "LINEAR A SIGN A645")
(67366 . "LINEAR A SIGN A646")
(67367 . "LINEAR A SIGN A648")
(67368 . "LINEAR A SIGN A649")
(67369 . "LINEAR A SIGN A651")
(67370 . "LINEAR A SIGN A652")
(67371 . "LINEAR A SIGN A653")
(67372 . "LINEAR A SIGN A654")
(67373 . "LINEAR A SIGN A655")
(67374 . "LINEAR A SIGN A656")
(67375 . "LINEAR A SIGN A657")
(67376 . "LINEAR A SIGN A658")
(67377 . "LINEAR A SIGN A659")
(67378 . "LINEAR A SIGN A660")
(67379 . "LINEAR A SIGN A661")
(67380 . "LINEAR A SIGN A662")
(67381 . "LINEAR A SIGN A663")
(67382 . "LINEAR A SIGN A664")
((67383 . 67392) . #f)
(67392 . "LINEAR A SIGN A701 A")
(67393 . "LINEAR A SIGN A702 B")
(67394 . "LINEAR A SIGN A703 D")
(67395 . "LINEAR A SIGN A704 E")
(67396 . "LINEAR A SIGN A705 F")
(67397 . "LINEAR A SIGN A706 H")
(67398 . "LINEAR A SIGN A707 J")
(67399 . "LINEAR A SIGN A708 K")
(67400 . "LINEAR A SIGN A709 L")
(67401 . "LINEAR A SIGN A709-2 L2")
(67402 . "LINEAR A SIGN A709-3 L3")
(67403 . "LINEAR A SIGN A709-4 L4")
(67404 . "LINEAR A SIGN A709-6 L6")
(67405 . "LINEAR A SIGN A710 W")
(67406 . "LINEAR A SIGN A711 X")
(67407 . "LINEAR A SIGN A712 Y")
(67408 . "LINEAR A SIGN A713 OMEGA")
(67409 . "LINEAR A SIGN A714 ABB")
(67410 . "LINEAR A SIGN A715 BB")
(67411 . "LINEAR A SIGN A717 DD")
(67412 . "LINEAR A SIGN A726 EYYY")
(67413 . "LINEAR A SIGN A732 JE")
((67414 . 67424) . #f)
(67424 . "LINEAR A SIGN A800")
(67425 . "LINEAR A SIGN A801")
(67426 . "LINEAR A SIGN A802")
(67427 . "LINEAR A SIGN A803")
(67428 . "LINEAR A SIGN A804")
(67429 . "LINEAR A SIGN A805")
(67430 . "LINEAR A SIGN A806")
(67431 . "LINEAR A SIGN A807")
((67432 . 67584) . #f)
(67584 . "CYPRIOT SYLLABLE A")
(67585 . "CYPRIOT SYLLABLE E")
(67586 . "CYPRIOT SYLLABLE I")
(67587 . "CYPRIOT SYLLABLE O")
(67588 . "CYPRIOT SYLLABLE U")
(67589 . "CYPRIOT SYLLABLE JA")
((67590 . 67592) . #f)
(67592 . "CYPRIOT SYLLABLE JO")
(67593 . #f)
(67594 . "CYPRIOT SYLLABLE KA")
(67595 . "CYPRIOT SYLLABLE KE")
(67596 . "CYPRIOT SYLLABLE KI")
(67597 . "CYPRIOT SYLLABLE KO")
(67598 . "CYPRIOT SYLLABLE KU")
(67599 . "CYPRIOT SYLLABLE LA")
(67600 . "CYPRIOT SYLLABLE LE")
(67601 . "CYPRIOT SYLLABLE LI")
(67602 . "CYPRIOT SYLLABLE LO")
(67603 . "CYPRIOT SYLLABLE LU")
(67604 . "CYPRIOT SYLLABLE MA")
(67605 . "CYPRIOT SYLLABLE ME")
(67606 . "CYPRIOT SYLLABLE MI")
(67607 . "CYPRIOT SYLLABLE MO")
(67608 . "CYPRIOT SYLLABLE MU")
(67609 . "CYPRIOT SYLLABLE NA")
(67610 . "CYPRIOT SYLLABLE NE")
(67611 . "CYPRIOT SYLLABLE NI")
(67612 . "CYPRIOT SYLLABLE NO")
(67613 . "CYPRIOT SYLLABLE NU")
(67614 . "CYPRIOT SYLLABLE PA")
(67615 . "CYPRIOT SYLLABLE PE")
(67616 . "CYPRIOT SYLLABLE PI")
(67617 . "CYPRIOT SYLLABLE PO")
(67618 . "CYPRIOT SYLLABLE PU")
(67619 . "CYPRIOT SYLLABLE RA")
(67620 . "CYPRIOT SYLLABLE RE")
(67621 . "CYPRIOT SYLLABLE RI")
(67622 . "CYPRIOT SYLLABLE RO")
(67623 . "CYPRIOT SYLLABLE RU")
(67624 . "CYPRIOT SYLLABLE SA")
(67625 . "CYPRIOT SYLLABLE SE")
(67626 . "CYPRIOT SYLLABLE SI")
(67627 . "CYPRIOT SYLLABLE SO")
(67628 . "CYPRIOT SYLLABLE SU")
(67629 . "CYPRIOT SYLLABLE TA")
(67630 . "CYPRIOT SYLLABLE TE")
(67631 . "CYPRIOT SYLLABLE TI")
(67632 . "CYPRIOT SYLLABLE TO")
(67633 . "CYPRIOT SYLLABLE TU")
(67634 . "CYPRIOT SYLLABLE WA")
(67635 . "CYPRIOT SYLLABLE WE")
(67636 . "CYPRIOT SYLLABLE WI")
(67637 . "CYPRIOT SYLLABLE WO")
(67638 . #f)
(67639 . "CYPRIOT SYLLABLE XA")
(67640 . "CYPRIOT SYLLABLE XE")
((67641 . 67644) . #f)
(67644 . "CYPRIOT SYLLABLE ZA")
((67645 . 67647) . #f)
(67647 . "CYPRIOT SYLLABLE ZO")
(67648 . "IMPERIAL ARAMAIC LETTER ALEPH")
(67649 . "IMPERIAL ARAMAIC LETTER BETH")
(67650 . "IMPERIAL ARAMAIC LETTER GIMEL")
(67651 . "IMPERIAL ARAMAIC LETTER DALETH")
(67652 . "IMPERIAL ARAMAIC LETTER HE")
(67653 . "IMPERIAL ARAMAIC LETTER WAW")
(67654 . "IMPERIAL ARAMAIC LETTER ZAYIN")
(67655 . "IMPERIAL ARAMAIC LETTER HETH")
(67656 . "IMPERIAL ARAMAIC LETTER TETH")
(67657 . "IMPERIAL ARAMAIC LETTER YODH")
(67658 . "IMPERIAL ARAMAIC LETTER KAPH")
(67659 . "IMPERIAL ARAMAIC LETTER LAMEDH")
(67660 . "IMPERIAL ARAMAIC LETTER MEM")
(67661 . "IMPERIAL ARAMAIC LETTER NUN")
(67662 . "IMPERIAL ARAMAIC LETTER SAMEKH")
(67663 . "IMPERIAL ARAMAIC LETTER AYIN")
(67664 . "IMPERIAL ARAMAIC LETTER PE")
(67665 . "IMPERIAL ARAMAIC LETTER SADHE")
(67666 . "IMPERIAL ARAMAIC LETTER QOPH")
(67667 . "IMPERIAL ARAMAIC LETTER RESH")
(67668 . "IMPERIAL ARAMAIC LETTER SHIN")
(67669 . "IMPERIAL ARAMAIC LETTER TAW")
(67670 . #f)
(67671 . "IMPERIAL ARAMAIC SECTION SIGN")
(67672 . "IMPERIAL ARAMAIC NUMBER ONE")
(67673 . "IMPERIAL ARAMAIC NUMBER TWO")
(67674 . "IMPERIAL ARAMAIC NUMBER THREE")
(67675 . "IMPERIAL ARAMAIC NUMBER TEN")
(67676 . "IMPERIAL ARAMAIC NUMBER TWENTY")
(67677 . "IMPERIAL ARAMAIC NUMBER ONE HUNDRED")
(67678 . "IMPERIAL ARAMAIC NUMBER ONE THOUSAND")
(67679 . "IMPERIAL ARAMAIC NUMBER TEN THOUSAND")
(67680 . "PALMYRENE LETTER ALEPH")
(67681 . "PALMYRENE LETTER BETH")
(67682 . "PALMYRENE LETTER GIMEL")
(67683 . "PALMYRENE LETTER DALETH")
(67684 . "PALMYRENE LETTER HE")
(67685 . "PALMYRENE LETTER WAW")
(67686 . "PALMYRENE LETTER ZAYIN")
(67687 . "PALMYRENE LETTER HETH")
(67688 . "PALMYRENE LETTER TETH")
(67689 . "PALMYRENE LETTER YODH")
(67690 . "PALMYRENE LETTER KAPH")
(67691 . "PALMYRENE LETTER LAMEDH")
(67692 . "PALMYRENE LETTER MEM")
(67693 . "PALMYRENE LETTER FINAL NUN")
(67694 . "PALMYRENE LETTER NUN")
(67695 . "PALMYRENE LETTER SAMEKH")
(67696 . "PALMYRENE LETTER AYIN")
(67697 . "PALMYRENE LETTER PE")
(67698 . "PALMYRENE LETTER SADHE")
(67699 . "PALMYRENE LETTER QOPH")
(67700 . "PALMYRENE LETTER RESH")
(67701 . "PALMYRENE LETTER SHIN")
(67702 . "PALMYRENE LETTER TAW")
(67703 . "PALMYRENE LEFT-POINTING FLEURON")
(67704 . "PALMYRENE RIGHT-POINTING FLEURON")
(67705 . "PALMYRENE NUMBER ONE")
(67706 . "PALMYRENE NUMBER TWO")
(67707 . "PALMYRENE NUMBER THREE")
(67708 . "PALMYRENE NUMBER FOUR")
(67709 . "PALMYRENE NUMBER FIVE")
(67710 . "PALMYRENE NUMBER TEN")
(67711 . "PALMYRENE NUMBER TWENTY")
(67712 . "NABATAEAN LETTER FINAL ALEPH")
(67713 . "NABATAEAN LETTER ALEPH")
(67714 . "NABATAEAN LETTER FINAL BETH")
(67715 . "NABATAEAN LETTER BETH")
(67716 . "NABATAEAN LETTER GIMEL")
(67717 . "NABATAEAN LETTER DALETH")
(67718 . "NABATAEAN LETTER FINAL HE")
(67719 . "NABATAEAN LETTER HE")
(67720 . "NABATAEAN LETTER WAW")
(67721 . "NABATAEAN LETTER ZAYIN")
(67722 . "NABATAEAN LETTER HETH")
(67723 . "NABATAEAN LETTER TETH")
(67724 . "NABATAEAN LETTER FINAL YODH")
(67725 . "NABATAEAN LETTER YODH")
(67726 . "NABATAEAN LETTER FINAL KAPH")
(67727 . "NABATAEAN LETTER KAPH")
(67728 . "NABATAEAN LETTER FINAL LAMEDH")
(67729 . "NABATAEAN LETTER LAMEDH")
(67730 . "NABATAEAN LETTER FINAL MEM")
(67731 . "NABATAEAN LETTER MEM")
(67732 . "NABATAEAN LETTER FINAL NUN")
(67733 . "NABATAEAN LETTER NUN")
(67734 . "NABATAEAN LETTER SAMEKH")
(67735 . "NABATAEAN LETTER AYIN")
(67736 . "NABATAEAN LETTER PE")
(67737 . "NABATAEAN LETTER SADHE")
(67738 . "NABATAEAN LETTER QOPH")
(67739 . "NABATAEAN LETTER RESH")
(67740 . "NABATAEAN LETTER FINAL SHIN")
(67741 . "NABATAEAN LETTER SHIN")
(67742 . "NABATAEAN LETTER TAW")
((67743 . 67751) . #f)
(67751 . "NABATAEAN NUMBER ONE")
(67752 . "NABATAEAN NUMBER TWO")
(67753 . "NABATAEAN NUMBER THREE")
(67754 . "NABATAEAN NUMBER FOUR")
(67755 . "NABATAEAN CRUCIFORM NUMBER FOUR")
(67756 . "NABATAEAN NUMBER FIVE")
(67757 . "NABATAEAN NUMBER TEN")
(67758 . "NABATAEAN NUMBER TWENTY")
(67759 . "NABATAEAN NUMBER ONE HUNDRED")
((67760 . 67808) . #f)
(67808 . "HATRAN LETTER ALEPH")
(67809 . "HATRAN LETTER BETH")
(67810 . "HATRAN LETTER GIMEL")
(67811 . "HATRAN LETTER DALETH-RESH")
(67812 . "HATRAN LETTER HE")
(67813 . "HATRAN LETTER WAW")
(67814 . "HATRAN LETTER ZAYN")
(67815 . "HATRAN LETTER HETH")
(67816 . "HATRAN LETTER TETH")
(67817 . "HATRAN LETTER YODH")
(67818 . "HATRAN LETTER KAPH")
(67819 . "HATRAN LETTER LAMEDH")
(67820 . "HATRAN LETTER MEM")
(67821 . "HATRAN LETTER NUN")
(67822 . "HATRAN LETTER SAMEKH")
(67823 . "HATRAN LETTER AYN")
(67824 . "HATRAN LETTER PE")
(67825 . "HATRAN LETTER SADHE")
(67826 . "HATRAN LETTER QOPH")
(67827 . #f)
(67828 . "HATRAN LETTER SHIN")
(67829 . "HATRAN LETTER TAW")
((67830 . 67835) . #f)
(67835 . "HATRAN NUMBER ONE")
(67836 . "HATRAN NUMBER FIVE")
(67837 . "HATRAN NUMBER TEN")
(67838 . "HATRAN NUMBER TWENTY")
(67839 . "HATRAN NUMBER ONE HUNDRED")
(67840 . "PHOENICIAN LETTER ALF")
(67841 . "PHOENICIAN LETTER BET")
(67842 . "PHOENICIAN LETTER GAML")
(67843 . "PHOENICIAN LETTER DELT")
(67844 . "PHOENICIAN LETTER HE")
(67845 . "PHOENICIAN LETTER WAU")
(67846 . "PHOENICIAN LETTER ZAI")
(67847 . "PHOENICIAN LETTER HET")
(67848 . "PHOENICIAN LETTER TET")
(67849 . "PHOENICIAN LETTER YOD")
(67850 . "PHOENICIAN LETTER KAF")
(67851 . "PHOENICIAN LETTER LAMD")
(67852 . "PHOENICIAN LETTER MEM")
(67853 . "PHOENICIAN LETTER NUN")
(67854 . "PHOENICIAN LETTER SEMK")
(67855 . "PHOENICIAN LETTER AIN")
(67856 . "PHOENICIAN LETTER PE")
(67857 . "PHOENICIAN LETTER SADE")
(67858 . "PHOENICIAN LETTER QOF")
(67859 . "PHOENICIAN LETTER ROSH")
(67860 . "PHOENICIAN LETTER SHIN")
(67861 . "PHOENICIAN LETTER TAU")
(67862 . "PHOENICIAN NUMBER ONE")
(67863 . "PHOENICIAN NUMBER TEN")
(67864 . "PHOENICIAN NUMBER TWENTY")
(67865 . "PHOENICIAN NUMBER ONE HUNDRED")
(67866 . "PHOENICIAN NUMBER TWO")
(67867 . "PHOENICIAN NUMBER THREE")
((67868 . 67871) . #f)
(67871 . "PHOENICIAN WORD SEPARATOR")
(67872 . "LYDIAN LETTER A")
(67873 . "LYDIAN LETTER B")
(67874 . "LYDIAN LETTER G")
(67875 . "LYDIAN LETTER D")
(67876 . "LYDIAN LETTER E")
(67877 . "LYDIAN LETTER V")
(67878 . "LYDIAN LETTER I")
(67879 . "LYDIAN LETTER Y")
(67880 . "LYDIAN LETTER K")
(67881 . "LYDIAN LETTER L")
(67882 . "LYDIAN LETTER M")
(67883 . "LYDIAN LETTER N")
(67884 . "LYDIAN LETTER O")
(67885 . "LYDIAN LETTER R")
(67886 . "LYDIAN LETTER SS")
(67887 . "LYDIAN LETTER T")
(67888 . "LYDIAN LETTER U")
(67889 . "LYDIAN LETTER F")
(67890 . "LYDIAN LETTER Q")
(67891 . "LYDIAN LETTER S")
(67892 . "LYDIAN LETTER TT")
(67893 . "LYDIAN LETTER AN")
(67894 . "LYDIAN LETTER EN")
(67895 . "LYDIAN LETTER LY")
(67896 . "LYDIAN LETTER NN")
(67897 . "LYDIAN LETTER C")
((67898 . 67903) . #f)
(67903 . "LYDIAN TRIANGULAR MARK")
((67904 . 67968) . #f)
(67968 . "MEROITIC HIEROGLYPHIC LETTER A")
(67969 . "MEROITIC HIEROGLYPHIC LETTER E")
(67970 . "MEROITIC HIEROGLYPHIC LETTER I")
(67971 . "MEROITIC HIEROGLYPHIC LETTER O")
(67972 . "MEROITIC HIEROGLYPHIC LETTER YA")
(67973 . "MEROITIC HIEROGLYPHIC LETTER WA")
(67974 . "MEROITIC HIEROGLYPHIC LETTER BA")
(67975 . "MEROITIC HIEROGLYPHIC LETTER BA-2")
(67976 . "MEROITIC HIEROGLYPHIC LETTER PA")
(67977 . "MEROITIC HIEROGLYPHIC LETTER MA")
(67978 . "MEROITIC HIEROGLYPHIC LETTER NA")
(67979 . "MEROITIC HIEROGLYPHIC LETTER NA-2")
(67980 . "MEROITIC HIEROGLYPHIC LETTER NE")
(67981 . "MEROITIC HIEROGLYPHIC LETTER NE-2")
(67982 . "MEROITIC HIEROGLYPHIC LETTER RA")
(67983 . "MEROITIC HIEROGLYPHIC LETTER RA-2")
(67984 . "MEROITIC HIEROGLYPHIC LETTER LA")
(67985 . "MEROITIC HIEROGLYPHIC LETTER KHA")
(67986 . "MEROITIC HIEROGLYPHIC LETTER HHA")
(67987 . "MEROITIC HIEROGLYPHIC LETTER SA")
(67988 . "MEROITIC HIEROGLYPHIC LETTER SA-2")
(67989 . "MEROITIC HIEROGLYPHIC LETTER SE")
(67990 . "MEROITIC HIEROGLYPHIC LETTER KA")
(67991 . "MEROITIC HIEROGLYPHIC LETTER QA")
(67992 . "MEROITIC HIEROGLYPHIC LETTER TA")
(67993 . "MEROITIC HIEROGLYPHIC LETTER TA-2")
(67994 . "MEROITIC HIEROGLYPHIC LETTER TE")
(67995 . "MEROITIC HIEROGLYPHIC LETTER TE-2")
(67996 . "MEROITIC HIEROGLYPHIC LETTER TO")
(67997 . "MEROITIC HIEROGLYPHIC LETTER DA")
(67998 . "MEROITIC HIEROGLYPHIC SYMBOL VIDJ")
(67999 . "MEROITIC HIEROGLYPHIC SYMBOL VIDJ-2")
(68000 . "MEROITIC CURSIVE LETTER A")
(68001 . "MEROITIC CURSIVE LETTER E")
(68002 . "MEROITIC CURSIVE LETTER I")
(68003 . "MEROITIC CURSIVE LETTER O")
(68004 . "MEROITIC CURSIVE LETTER YA")
(68005 . "MEROITIC CURSIVE LETTER WA")
(68006 . "MEROITIC CURSIVE LETTER BA")
(68007 . "MEROITIC CURSIVE LETTER PA")
(68008 . "MEROITIC CURSIVE LETTER MA")
(68009 . "MEROITIC CURSIVE LETTER NA")
(68010 . "MEROITIC CURSIVE LETTER NE")
(68011 . "MEROITIC CURSIVE LETTER RA")
(68012 . "MEROITIC CURSIVE LETTER LA")
(68013 . "MEROITIC CURSIVE LETTER KHA")
(68014 . "MEROITIC CURSIVE LETTER HHA")
(68015 . "MEROITIC CURSIVE LETTER SA")
(68016 . "MEROITIC CURSIVE LETTER ARCHAIC SA")
(68017 . "MEROITIC CURSIVE LETTER SE")
(68018 . "MEROITIC CURSIVE LETTER KA")
(68019 . "MEROITIC CURSIVE LETTER QA")
(68020 . "MEROITIC CURSIVE LETTER TA")
(68021 . "MEROITIC CURSIVE LETTER TE")
(68022 . "MEROITIC CURSIVE LETTER TO")
(68023 . "MEROITIC CURSIVE LETTER DA")
((68024 . 68028) . #f)
(68028 . "MEROITIC CURSIVE FRACTION ELEVEN TWELFTHS")
(68029 . "MEROITIC CURSIVE FRACTION ONE HALF")
(68030 . "MEROITIC CURSIVE LOGOGRAM RMT")
(68031 . "MEROITIC CURSIVE LOGOGRAM IMN")
(68032 . "MEROITIC CURSIVE NUMBER ONE")
(68033 . "MEROITIC CURSIVE NUMBER TWO")
(68034 . "MEROITIC CURSIVE NUMBER THREE")
(68035 . "MEROITIC CURSIVE NUMBER FOUR")
(68036 . "MEROITIC CURSIVE NUMBER FIVE")
(68037 . "MEROITIC CURSIVE NUMBER SIX")
(68038 . "MEROITIC CURSIVE NUMBER SEVEN")
(68039 . "MEROITIC CURSIVE NUMBER EIGHT")
(68040 . "MEROITIC CURSIVE NUMBER NINE")
(68041 . "MEROITIC CURSIVE NUMBER TEN")
(68042 . "MEROITIC CURSIVE NUMBER TWENTY")
(68043 . "MEROITIC CURSIVE NUMBER THIRTY")
(68044 . "MEROITIC CURSIVE NUMBER FORTY")
(68045 . "MEROITIC CURSIVE NUMBER FIFTY")
(68046 . "MEROITIC CURSIVE NUMBER SIXTY")
(68047 . "MEROITIC CURSIVE NUMBER SEVENTY")
((68048 . 68050) . #f)
(68050 . "MEROITIC CURSIVE NUMBER ONE HUNDRED")
(68051 . "MEROITIC CURSIVE NUMBER TWO HUNDRED")
(68052 . "MEROITIC CURSIVE NUMBER THREE HUNDRED")
(68053 . "MEROITIC CURSIVE NUMBER FOUR HUNDRED")
(68054 . "MEROITIC CURSIVE NUMBER FIVE HUNDRED")
(68055 . "MEROITIC CURSIVE NUMBER SIX HUNDRED")
(68056 . "MEROITIC CURSIVE NUMBER SEVEN HUNDRED")
(68057 . "MEROITIC CURSIVE NUMBER EIGHT HUNDRED")
(68058 . "MEROITIC CURSIVE NUMBER NINE HUNDRED")
(68059 . "MEROITIC CURSIVE NUMBER ONE THOUSAND")
(68060 . "MEROITIC CURSIVE NUMBER TWO THOUSAND")
(68061 . "MEROITIC CURSIVE NUMBER THREE THOUSAND")
(68062 . "MEROITIC CURSIVE NUMBER FOUR THOUSAND")
(68063 . "MEROITIC CURSIVE NUMBER FIVE THOUSAND")
(68064 . "MEROITIC CURSIVE NUMBER SIX THOUSAND")
(68065 . "MEROITIC CURSIVE NUMBER SEVEN THOUSAND")
(68066 . "MEROITIC CURSIVE NUMBER EIGHT THOUSAND")
(68067 . "MEROITIC CURSIVE NUMBER NINE THOUSAND")
(68068 . "MEROITIC CURSIVE NUMBER TEN THOUSAND")
(68069 . "MEROITIC CURSIVE NUMBER TWENTY THOUSAND")
(68070 . "MEROITIC CURSIVE NUMBER THIRTY THOUSAND")
(68071 . "MEROITIC CURSIVE NUMBER FORTY THOUSAND")
(68072 . "MEROITIC CURSIVE NUMBER FIFTY THOUSAND")
(68073 . "MEROITIC CURSIVE NUMBER SIXTY THOUSAND")
(68074 . "MEROITIC CURSIVE NUMBER SEVENTY THOUSAND")
(68075 . "MEROITIC CURSIVE NUMBER EIGHTY THOUSAND")
(68076 . "MEROITIC CURSIVE NUMBER NINETY THOUSAND")
(68077 . "MEROITIC CURSIVE NUMBER ONE HUNDRED THOUSAND")
(68078 . "MEROITIC CURSIVE NUMBER TWO HUNDRED THOUSAND")
(68079 . "MEROITIC CURSIVE NUMBER THREE HUNDRED THOUSAND")
(68080 . "MEROITIC CURSIVE NUMBER FOUR HUNDRED THOUSAND")
(68081 . "MEROITIC CURSIVE NUMBER FIVE HUNDRED THOUSAND")
(68082 . "MEROITIC CURSIVE NUMBER SIX HUNDRED THOUSAND")
(68083 . "MEROITIC CURSIVE NUMBER SEVEN HUNDRED THOUSAND")
(68084 . "MEROITIC CURSIVE NUMBER EIGHT HUNDRED THOUSAND")
(68085 . "MEROITIC CURSIVE NUMBER NINE HUNDRED THOUSAND")
(68086 . "MEROITIC CURSIVE FRACTION ONE TWELFTH")
(68087 . "MEROITIC CURSIVE FRACTION TWO TWELFTHS")
(68088 . "MEROITIC CURSIVE FRACTION THREE TWELFTHS")
(68089 . "MEROITIC CURSIVE FRACTION FOUR TWELFTHS")
(68090 . "MEROITIC CURSIVE FRACTION FIVE TWELFTHS")
(68091 . "MEROITIC CURSIVE FRACTION SIX TWELFTHS")
(68092 . "MEROITIC CURSIVE FRACTION SEVEN TWELFTHS")
(68093 . "MEROITIC CURSIVE FRACTION EIGHT TWELFTHS")
(68094 . "MEROITIC CURSIVE FRACTION NINE TWELFTHS")
(68095 . "MEROITIC CURSIVE FRACTION TEN TWELFTHS")
(68096 . "KHAROSHTHI LETTER A")
(68097 . "KHAROSHTHI VOWEL SIGN I")
(68098 . "KHAROSHTHI VOWEL SIGN U")
(68099 . "KHAROSHTHI VOWEL SIGN VOCALIC R")
(68100 . #f)
(68101 . "KHAROSHTHI VOWEL SIGN E")
(68102 . "KHAROSHTHI VOWEL SIGN O")
((68103 . 68108) . #f)
(68108 . "KHAROSHTHI VOWEL LENGTH MARK")
(68109 . "KHAROSHTHI SIGN DOUBLE RING BELOW")
(68110 . "KHAROSHTHI SIGN ANUSVARA")
(68111 . "KHAROSHTHI SIGN VISARGA")
(68112 . "KHAROSHTHI LETTER KA")
(68113 . "KHAROSHTHI LETTER KHA")
(68114 . "KHAROSHTHI LETTER GA")
(68115 . "KHAROSHTHI LETTER GHA")
(68116 . #f)
(68117 . "KHAROSHTHI LETTER CA")
(68118 . "KHAROSHTHI LETTER CHA")
(68119 . "KHAROSHTHI LETTER JA")
(68120 . #f)
(68121 . "KHAROSHTHI LETTER NYA")
(68122 . "KHAROSHTHI LETTER TTA")
(68123 . "KHAROSHTHI LETTER TTHA")
(68124 . "KHAROSHTHI LETTER DDA")
(68125 . "KHAROSHTHI LETTER DDHA")
(68126 . "KHAROSHTHI LETTER NNA")
(68127 . "KHAROSHTHI LETTER TA")
(68128 . "KHAROSHTHI LETTER THA")
(68129 . "KHAROSHTHI LETTER DA")
(68130 . "KHAROSHTHI LETTER DHA")
(68131 . "KHAROSHTHI LETTER NA")
(68132 . "KHAROSHTHI LETTER PA")
(68133 . "KHAROSHTHI LETTER PHA")
(68134 . "KHAROSHTHI LETTER BA")
(68135 . "KHAROSHTHI LETTER BHA")
(68136 . "KHAROSHTHI LETTER MA")
(68137 . "KHAROSHTHI LETTER YA")
(68138 . "KHAROSHTHI LETTER RA")
(68139 . "KHAROSHTHI LETTER LA")
(68140 . "KHAROSHTHI LETTER VA")
(68141 . "KHAROSHTHI LETTER SHA")
(68142 . "KHAROSHTHI LETTER SSA")
(68143 . "KHAROSHTHI LETTER SA")
(68144 . "KHAROSHTHI LETTER ZA")
(68145 . "KHAROSHTHI LETTER HA")
(68146 . "KHAROSHTHI LETTER KKA")
(68147 . "KHAROSHTHI LETTER TTTHA")
((68148 . 68152) . #f)
(68152 . "KHAROSHTHI SIGN BAR ABOVE")
(68153 . "KHAROSHTHI SIGN CAUDA")
(68154 . "KHAROSHTHI SIGN DOT BELOW")
((68155 . 68159) . #f)
(68159 . "KHAROSHTHI VIRAMA")
(68160 . "KHAROSHTHI DIGIT ONE")
(68161 . "KHAROSHTHI DIGIT TWO")
(68162 . "KHAROSHTHI DIGIT THREE")
(68163 . "KHAROSHTHI DIGIT FOUR")
(68164 . "KHAROSHTHI NUMBER TEN")
(68165 . "KHAROSHTHI NUMBER TWENTY")
(68166 . "KHAROSHTHI NUMBER ONE HUNDRED")
(68167 . "KHAROSHTHI NUMBER ONE THOUSAND")
((68168 . 68176) . #f)
(68176 . "KHAROSHTHI PUNCTUATION DOT")
(68177 . "KHAROSHTHI PUNCTUATION SMALL CIRCLE")
(68178 . "KHAROSHTHI PUNCTUATION CIRCLE")
(68179 . "KHAROSHTHI PUNCTUATION CRESCENT BAR")
(68180 . "KHAROSHTHI PUNCTUATION MANGALAM")
(68181 . "KHAROSHTHI PUNCTUATION LOTUS")
(68182 . "KHAROSHTHI PUNCTUATION DANDA")
(68183 . "KHAROSHTHI PUNCTUATION DOUBLE DANDA")
(68184 . "KHAROSHTHI PUNCTUATION LINES")
((68185 . 68192) . #f)
(68192 . "OLD SOUTH ARABIAN LETTER HE")
(68193 . "OLD SOUTH ARABIAN LETTER LAMEDH")
(68194 . "OLD SOUTH ARABIAN LETTER HETH")
(68195 . "OLD SOUTH ARABIAN LETTER MEM")
(68196 . "OLD SOUTH ARABIAN LETTER QOPH")
(68197 . "OLD SOUTH ARABIAN LETTER WAW")
(68198 . "OLD SOUTH ARABIAN LETTER SHIN")
(68199 . "OLD SOUTH ARABIAN LETTER RESH")
(68200 . "OLD SOUTH ARABIAN LETTER BETH")
(68201 . "OLD SOUTH ARABIAN LETTER TAW")
(68202 . "OLD SOUTH ARABIAN LETTER SAT")
(68203 . "OLD SOUTH ARABIAN LETTER KAPH")
(68204 . "OLD SOUTH ARABIAN LETTER NUN")
(68205 . "OLD SOUTH ARABIAN LETTER KHETH")
(68206 . "OLD SOUTH ARABIAN LETTER SADHE")
(68207 . "OLD SOUTH ARABIAN LETTER SAMEKH")
(68208 . "OLD SOUTH ARABIAN LETTER FE")
(68209 . "OLD SOUTH ARABIAN LETTER ALEF")
(68210 . "OLD SOUTH ARABIAN LETTER AYN")
(68211 . "OLD SOUTH ARABIAN LETTER DHADHE")
(68212 . "OLD SOUTH ARABIAN LETTER GIMEL")
(68213 . "OLD SOUTH ARABIAN LETTER DALETH")
(68214 . "OLD SOUTH ARABIAN LETTER GHAYN")
(68215 . "OLD SOUTH ARABIAN LETTER TETH")
(68216 . "OLD SOUTH ARABIAN LETTER ZAYN")
(68217 . "OLD SOUTH ARABIAN LETTER DHALETH")
(68218 . "OLD SOUTH ARABIAN LETTER YODH")
(68219 . "OLD SOUTH ARABIAN LETTER THAW")
(68220 . "OLD SOUTH ARABIAN LETTER THETH")
(68221 . "OLD SOUTH ARABIAN NUMBER ONE")
(68222 . "OLD SOUTH ARABIAN NUMBER FIFTY")
(68223 . "OLD SOUTH ARABIAN NUMERIC INDICATOR")
(68224 . "OLD NORTH ARABIAN LETTER HEH")
(68225 . "OLD NORTH ARABIAN LETTER LAM")
(68226 . "OLD NORTH ARABIAN LETTER HAH")
(68227 . "OLD NORTH ARABIAN LETTER MEEM")
(68228 . "OLD NORTH ARABIAN LETTER QAF")
(68229 . "OLD NORTH ARABIAN LETTER WAW")
(68230 . "OLD NORTH ARABIAN LETTER ES-2")
(68231 . "OLD NORTH ARABIAN LETTER REH")
(68232 . "OLD NORTH ARABIAN LETTER BEH")
(68233 . "OLD NORTH ARABIAN LETTER TEH")
(68234 . "OLD NORTH ARABIAN LETTER ES-1")
(68235 . "OLD NORTH ARABIAN LETTER KAF")
(68236 . "OLD NORTH ARABIAN LETTER NOON")
(68237 . "OLD NORTH ARABIAN LETTER KHAH")
(68238 . "OLD NORTH ARABIAN LETTER SAD")
(68239 . "OLD NORTH ARABIAN LETTER ES-3")
(68240 . "OLD NORTH ARABIAN LETTER FEH")
(68241 . "OLD NORTH ARABIAN LETTER ALEF")
(68242 . "OLD NORTH ARABIAN LETTER AIN")
(68243 . "OLD NORTH ARABIAN LETTER DAD")
(68244 . "OLD NORTH ARABIAN LETTER GEEM")
(68245 . "OLD NORTH ARABIAN LETTER DAL")
(68246 . "OLD NORTH ARABIAN LETTER GHAIN")
(68247 . "OLD NORTH ARABIAN LETTER TAH")
(68248 . "OLD NORTH ARABIAN LETTER ZAIN")
(68249 . "OLD NORTH ARABIAN LETTER THAL")
(68250 . "OLD NORTH ARABIAN LETTER YEH")
(68251 . "OLD NORTH ARABIAN LETTER THEH")
(68252 . "OLD NORTH ARABIAN LETTER ZAH")
(68253 . "OLD NORTH ARABIAN NUMBER ONE")
(68254 . "OLD NORTH ARABIAN NUMBER TEN")
(68255 . "OLD NORTH ARABIAN NUMBER TWENTY")
((68256 . 68288) . #f)
(68288 . "MANICHAEAN LETTER ALEPH")
(68289 . "MANICHAEAN LETTER BETH")
(68290 . "MANICHAEAN LETTER BHETH")
(68291 . "MANICHAEAN LETTER GIMEL")
(68292 . "MANICHAEAN LETTER GHIMEL")
(68293 . "MANICHAEAN LETTER DALETH")
(68294 . "MANICHAEAN LETTER HE")
(68295 . "MANICHAEAN LETTER WAW")
(68296 . "MANICHAEAN SIGN UD")
(68297 . "MANICHAEAN LETTER ZAYIN")
(68298 . "MANICHAEAN LETTER ZHAYIN")
(68299 . "MANICHAEAN LETTER JAYIN")
(68300 . "MANICHAEAN LETTER JHAYIN")
(68301 . "MANICHAEAN LETTER HETH")
(68302 . "MANICHAEAN LETTER TETH")
(68303 . "MANICHAEAN LETTER YODH")
(68304 . "MANICHAEAN LETTER KAPH")
(68305 . "MANICHAEAN LETTER XAPH")
(68306 . "MANICHAEAN LETTER KHAPH")
(68307 . "MANICHAEAN LETTER LAMEDH")
(68308 . "MANICHAEAN LETTER DHAMEDH")
(68309 . "MANICHAEAN LETTER THAMEDH")
(68310 . "MANICHAEAN LETTER MEM")
(68311 . "MANICHAEAN LETTER NUN")
(68312 . "MANICHAEAN LETTER SAMEKH")
(68313 . "MANICHAEAN LETTER AYIN")
(68314 . "MANICHAEAN LETTER AAYIN")
(68315 . "MANICHAEAN LETTER PE")
(68316 . "MANICHAEAN LETTER FE")
(68317 . "MANICHAEAN LETTER SADHE")
(68318 . "MANICHAEAN LETTER QOPH")
(68319 . "MANICHAEAN LETTER XOPH")
(68320 . "MANICHAEAN LETTER QHOPH")
(68321 . "MANICHAEAN LETTER RESH")
(68322 . "MANICHAEAN LETTER SHIN")
(68323 . "MANICHAEAN LETTER SSHIN")
(68324 . "MANICHAEAN LETTER TAW")
(68325 . "MANICHAEAN ABBREVIATION MARK ABOVE")
(68326 . "MANICHAEAN ABBREVIATION MARK BELOW")
((68327 . 68331) . #f)
(68331 . "MANICHAEAN NUMBER ONE")
(68332 . "MANICHAEAN NUMBER FIVE")
(68333 . "MANICHAEAN NUMBER TEN")
(68334 . "MANICHAEAN NUMBER TWENTY")
(68335 . "MANICHAEAN NUMBER ONE HUNDRED")
(68336 . "MANICHAEAN PUNCTUATION STAR")
(68337 . "MANICHAEAN PUNCTUATION FLEURON")
(68338 . "MANICHAEAN PUNCTUATION DOUBLE DOT WITHIN DOT")
(68339 . "MANICHAEAN PUNCTUATION DOT WITHIN DOT")
(68340 . "MANICHAEAN PUNCTUATION DOT")
(68341 . "MANICHAEAN PUNCTUATION TWO DOTS")
(68342 . "MANICHAEAN PUNCTUATION LINE FILLER")
((68343 . 68352) . #f)
(68352 . "AVESTAN LETTER A")
(68353 . "AVESTAN LETTER AA")
(68354 . "AVESTAN LETTER AO")
(68355 . "AVESTAN LETTER AAO")
(68356 . "AVESTAN LETTER AN")
(68357 . "AVESTAN LETTER AAN")
(68358 . "AVESTAN LETTER AE")
(68359 . "AVESTAN LETTER AEE")
(68360 . "AVESTAN LETTER E")
(68361 . "AVESTAN LETTER EE")
(68362 . "AVESTAN LETTER O")
(68363 . "AVESTAN LETTER OO")
(68364 . "AVESTAN LETTER I")
(68365 . "AVESTAN LETTER II")
(68366 . "AVESTAN LETTER U")
(68367 . "AVESTAN LETTER UU")
(68368 . "AVESTAN LETTER KE")
(68369 . "AVESTAN LETTER XE")
(68370 . "AVESTAN LETTER XYE")
(68371 . "AVESTAN LETTER XVE")
(68372 . "AVESTAN LETTER GE")
(68373 . "AVESTAN LETTER GGE")
(68374 . "AVESTAN LETTER GHE")
(68375 . "AVESTAN LETTER CE")
(68376 . "AVESTAN LETTER JE")
(68377 . "AVESTAN LETTER TE")
(68378 . "AVESTAN LETTER THE")
(68379 . "AVESTAN LETTER DE")
(68380 . "AVESTAN LETTER DHE")
(68381 . "AVESTAN LETTER TTE")
(68382 . "AVESTAN LETTER PE")
(68383 . "AVESTAN LETTER FE")
(68384 . "AVESTAN LETTER BE")
(68385 . "AVESTAN LETTER BHE")
(68386 . "AVESTAN LETTER NGE")
(68387 . "AVESTAN LETTER NGYE")
(68388 . "AVESTAN LETTER NGVE")
(68389 . "AVESTAN LETTER NE")
(68390 . "AVESTAN LETTER NYE")
(68391 . "AVESTAN LETTER NNE")
(68392 . "AVESTAN LETTER ME")
(68393 . "AVESTAN LETTER HME")
(68394 . "AVESTAN LETTER YYE")
(68395 . "AVESTAN LETTER YE")
(68396 . "AVESTAN LETTER VE")
(68397 . "AVESTAN LETTER RE")
(68398 . "AVESTAN LETTER LE")
(68399 . "AVESTAN LETTER SE")
(68400 . "AVESTAN LETTER ZE")
(68401 . "AVESTAN LETTER SHE")
(68402 . "AVESTAN LETTER ZHE")
(68403 . "AVESTAN LETTER SHYE")
(68404 . "AVESTAN LETTER SSHE")
(68405 . "AVESTAN LETTER HE")
((68406 . 68409) . #f)
(68409 . "AVESTAN ABBREVIATION MARK")
(68410 . "TINY TWO DOTS OVER ONE DOT PUNCTUATION")
(68411 . "SMALL TWO DOTS OVER ONE DOT PUNCTUATION")
(68412 . "LARGE TWO DOTS OVER ONE DOT PUNCTUATION")
(68413 . "LARGE ONE DOT OVER TWO DOTS PUNCTUATION")
(68414 . "LARGE TWO RINGS OVER ONE RING PUNCTUATION")
(68415 . "LARGE ONE RING OVER TWO RINGS PUNCTUATION")
(68416 . "INSCRIPTIONAL PARTHIAN LETTER ALEPH")
(68417 . "INSCRIPTIONAL PARTHIAN LETTER BETH")
(68418 . "INSCRIPTIONAL PARTHIAN LETTER GIMEL")
(68419 . "INSCRIPTIONAL PARTHIAN LETTER DALETH")
(68420 . "INSCRIPTIONAL PARTHIAN LETTER HE")
(68421 . "INSCRIPTIONAL PARTHIAN LETTER WAW")
(68422 . "INSCRIPTIONAL PARTHIAN LETTER ZAYIN")
(68423 . "INSCRIPTIONAL PARTHIAN LETTER HETH")
(68424 . "INSCRIPTIONAL PARTHIAN LETTER TETH")
(68425 . "INSCRIPTIONAL PARTHIAN LETTER YODH")
(68426 . "INSCRIPTIONAL PARTHIAN LETTER KAPH")
(68427 . "INSCRIPTIONAL PARTHIAN LETTER LAMEDH")
(68428 . "INSCRIPTIONAL PARTHIAN LETTER MEM")
(68429 . "INSCRIPTIONAL PARTHIAN LETTER NUN")
(68430 . "INSCRIPTIONAL PARTHIAN LETTER SAMEKH")
(68431 . "INSCRIPTIONAL PARTHIAN LETTER AYIN")
(68432 . "INSCRIPTIONAL PARTHIAN LETTER PE")
(68433 . "INSCRIPTIONAL PARTHIAN LETTER SADHE")
(68434 . "INSCRIPTIONAL PARTHIAN LETTER QOPH")
(68435 . "INSCRIPTIONAL PARTHIAN LETTER RESH")
(68436 . "INSCRIPTIONAL PARTHIAN LETTER SHIN")
(68437 . "INSCRIPTIONAL PARTHIAN LETTER TAW")
((68438 . 68440) . #f)
(68440 . "INSCRIPTIONAL PARTHIAN NUMBER ONE")
(68441 . "INSCRIPTIONAL PARTHIAN NUMBER TWO")
(68442 . "INSCRIPTIONAL PARTHIAN NUMBER THREE")
(68443 . "INSCRIPTIONAL PARTHIAN NUMBER FOUR")
(68444 . "INSCRIPTIONAL PARTHIAN NUMBER TEN")
(68445 . "INSCRIPTIONAL PARTHIAN NUMBER TWENTY")
(68446 . "INSCRIPTIONAL PARTHIAN NUMBER ONE HUNDRED")
(68447 . "INSCRIPTIONAL PARTHIAN NUMBER ONE THOUSAND")
(68448 . "INSCRIPTIONAL PAHLAVI LETTER ALEPH")
(68449 . "INSCRIPTIONAL PAHLAVI LETTER BETH")
(68450 . "INSCRIPTIONAL PAHLAVI LETTER GIMEL")
(68451 . "INSCRIPTIONAL PAHLAVI LETTER DALETH")
(68452 . "INSCRIPTIONAL PAHLAVI LETTER HE")
(68453 . "INSCRIPTIONAL PAHLAVI LETTER WAW-AYIN-RESH")
(68454 . "INSCRIPTIONAL PAHLAVI LETTER ZAYIN")
(68455 . "INSCRIPTIONAL PAHLAVI LETTER HETH")
(68456 . "INSCRIPTIONAL PAHLAVI LETTER TETH")
(68457 . "INSCRIPTIONAL PAHLAVI LETTER YODH")
(68458 . "INSCRIPTIONAL PAHLAVI LETTER KAPH")
(68459 . "INSCRIPTIONAL PAHLAVI LETTER LAMEDH")
(68460 . "INSCRIPTIONAL PAHLAVI LETTER MEM-QOPH")
(68461 . "INSCRIPTIONAL PAHLAVI LETTER NUN")
(68462 . "INSCRIPTIONAL PAHLAVI LETTER SAMEKH")
(68463 . "INSCRIPTIONAL PAHLAVI LETTER PE")
(68464 . "INSCRIPTIONAL PAHLAVI LETTER SADHE")
(68465 . "INSCRIPTIONAL PAHLAVI LETTER SHIN")
(68466 . "INSCRIPTIONAL PAHLAVI LETTER TAW")
((68467 . 68472) . #f)
(68472 . "INSCRIPTIONAL PAHLAVI NUMBER ONE")
(68473 . "INSCRIPTIONAL PAHLAVI NUMBER TWO")
(68474 . "INSCRIPTIONAL PAHLAVI NUMBER THREE")
(68475 . "INSCRIPTIONAL PAHLAVI NUMBER FOUR")
(68476 . "INSCRIPTIONAL PAHLAVI NUMBER TEN")
(68477 . "INSCRIPTIONAL PAHLAVI NUMBER TWENTY")
(68478 . "INSCRIPTIONAL PAHLAVI NUMBER ONE HUNDRED")
(68479 . "INSCRIPTIONAL PAHLAVI NUMBER ONE THOUSAND")
(68480 . "PSALTER PAHLAVI LETTER ALEPH")
(68481 . "PSALTER PAHLAVI LETTER BETH")
(68482 . "PSALTER PAHLAVI LETTER GIMEL")
(68483 . "PSALTER PAHLAVI LETTER DALETH")
(68484 . "PSALTER PAHLAVI LETTER HE")
(68485 . "PSALTER PAHLAVI LETTER WAW-AYIN-RESH")
(68486 . "PSALTER PAHLAVI LETTER ZAYIN")
(68487 . "PSALTER PAHLAVI LETTER HETH")
(68488 . "PSALTER PAHLAVI LETTER YODH")
(68489 . "PSALTER PAHLAVI LETTER KAPH")
(68490 . "PSALTER PAHLAVI LETTER LAMEDH")
(68491 . "PSALTER PAHLAVI LETTER MEM-QOPH")
(68492 . "PSALTER PAHLAVI LETTER NUN")
(68493 . "PSALTER PAHLAVI LETTER SAMEKH")
(68494 . "PSALTER PAHLAVI LETTER PE")
(68495 . "PSALTER PAHLAVI LETTER SADHE")
(68496 . "PSALTER PAHLAVI LETTER SHIN")
(68497 . "PSALTER PAHLAVI LETTER TAW")
((68498 . 68505) . #f)
(68505 . "PSALTER PAHLAVI SECTION MARK")
(68506 . "PSALTER PAHLAVI TURNED SECTION MARK")
(68507 . "PSALTER PAHLAVI FOUR DOTS WITH CROSS")
(68508 . "PSALTER PAHLAVI FOUR DOTS WITH DOT")
((68509 . 68521) . #f)
(68521 . "PSALTER PAHLAVI NUMBER ONE")
(68522 . "PSALTER PAHLAVI NUMBER TWO")
(68523 . "PSALTER PAHLAVI NUMBER THREE")
(68524 . "PSALTER PAHLAVI NUMBER FOUR")
(68525 . "PSALTER PAHLAVI NUMBER TEN")
(68526 . "PSALTER PAHLAVI NUMBER TWENTY")
(68527 . "PSALTER PAHLAVI NUMBER ONE HUNDRED")
((68528 . 68608) . #f)
(68608 . "OLD TURKIC LETTER ORKHON A")
(68609 . "OLD TURKIC LETTER YENISEI A")
(68610 . "OLD TURKIC LETTER YENISEI AE")
(68611 . "OLD TURKIC LETTER ORKHON I")
(68612 . "OLD TURKIC LETTER YENISEI I")
(68613 . "OLD TURKIC LETTER YENISEI E")
(68614 . "OLD TURKIC LETTER ORKHON O")
(68615 . "OLD TURKIC LETTER ORKHON OE")
(68616 . "OLD TURKIC LETTER YENISEI OE")
(68617 . "OLD TURKIC LETTER ORKHON AB")
(68618 . "OLD TURKIC LETTER YENISEI AB")
(68619 . "OLD TURKIC LETTER ORKHON AEB")
(68620 . "OLD TURKIC LETTER YENISEI AEB")
(68621 . "OLD TURKIC LETTER ORKHON AG")
(68622 . "OLD TURKIC LETTER YENISEI AG")
(68623 . "OLD TURKIC LETTER ORKHON AEG")
(68624 . "OLD TURKIC LETTER YENISEI AEG")
(68625 . "OLD TURKIC LETTER ORKHON AD")
(68626 . "OLD TURKIC LETTER YENISEI AD")
(68627 . "OLD TURKIC LETTER ORKHON AED")
(68628 . "OLD TURKIC LETTER ORKHON EZ")
(68629 . "OLD TURKIC LETTER YENISEI EZ")
(68630 . "OLD TURKIC LETTER ORKHON AY")
(68631 . "OLD TURKIC LETTER YENISEI AY")
(68632 . "OLD TURKIC LETTER ORKHON AEY")
(68633 . "OLD TURKIC LETTER YENISEI AEY")
(68634 . "OLD TURKIC LETTER ORKHON AEK")
(68635 . "OLD TURKIC LETTER YENISEI AEK")
(68636 . "OLD TURKIC LETTER ORKHON OEK")
(68637 . "OLD TURKIC LETTER YENISEI OEK")
(68638 . "OLD TURKIC LETTER ORKHON AL")
(68639 . "OLD TURKIC LETTER YENISEI AL")
(68640 . "OLD TURKIC LETTER ORKHON AEL")
(68641 . "OLD TURKIC LETTER ORKHON ELT")
(68642 . "OLD TURKIC LETTER ORKHON EM")
(68643 . "OLD TURKIC LETTER ORKHON AN")
(68644 . "OLD TURKIC LETTER ORKHON AEN")
(68645 . "OLD TURKIC LETTER YENISEI AEN")
(68646 . "OLD TURKIC LETTER ORKHON ENT")
(68647 . "OLD TURKIC LETTER YENISEI ENT")
(68648 . "OLD TURKIC LETTER ORKHON ENC")
(68649 . "OLD TURKIC LETTER YENISEI ENC")
(68650 . "OLD TURKIC LETTER ORKHON ENY")
(68651 . "OLD TURKIC LETTER YENISEI ENY")
(68652 . "OLD TURKIC LETTER YENISEI ANG")
(68653 . "OLD TURKIC LETTER ORKHON ENG")
(68654 . "OLD TURKIC LETTER YENISEI AENG")
(68655 . "OLD TURKIC LETTER ORKHON EP")
(68656 . "OLD TURKIC LETTER ORKHON OP")
(68657 . "OLD TURKIC LETTER ORKHON IC")
(68658 . "OLD TURKIC LETTER ORKHON EC")
(68659 . "OLD TURKIC LETTER YENISEI EC")
(68660 . "OLD TURKIC LETTER ORKHON AQ")
(68661 . "OLD TURKIC LETTER YENISEI AQ")
(68662 . "OLD TURKIC LETTER ORKHON IQ")
(68663 . "OLD TURKIC LETTER YENISEI IQ")
(68664 . "OLD TURKIC LETTER ORKHON OQ")
(68665 . "OLD TURKIC LETTER YENISEI OQ")
(68666 . "OLD TURKIC LETTER ORKHON AR")
(68667 . "OLD TURKIC LETTER YENISEI AR")
(68668 . "OLD TURKIC LETTER ORKHON AER")
(68669 . "OLD TURKIC LETTER ORKHON AS")
(68670 . "OLD TURKIC LETTER ORKHON AES")
(68671 . "OLD TURKIC LETTER ORKHON ASH")
(68672 . "OLD TURKIC LETTER YENISEI ASH")
(68673 . "OLD TURKIC LETTER ORKHON ESH")
(68674 . "OLD TURKIC LETTER YENISEI ESH")
(68675 . "OLD TURKIC LETTER ORKHON AT")
(68676 . "OLD TURKIC LETTER YENISEI AT")
(68677 . "OLD TURKIC LETTER ORKHON AET")
(68678 . "OLD TURKIC LETTER YENISEI AET")
(68679 . "OLD TURKIC LETTER ORKHON OT")
(68680 . "OLD TURKIC LETTER ORKHON BASH")
((68681 . 68736) . #f)
(68736 . "OLD HUNGARIAN CAPITAL LETTER A")
(68737 . "OLD HUNGARIAN CAPITAL LETTER AA")
(68738 . "OLD HUNGARIAN CAPITAL LETTER EB")
(68739 . "OLD HUNGARIAN CAPITAL LETTER AMB")
(68740 . "OLD HUNGARIAN CAPITAL LETTER EC")
(68741 . "OLD HUNGARIAN CAPITAL LETTER ENC")
(68742 . "OLD HUNGARIAN CAPITAL LETTER ECS")
(68743 . "OLD HUNGARIAN CAPITAL LETTER ED")
(68744 . "OLD HUNGARIAN CAPITAL LETTER AND")
(68745 . "OLD HUNGARIAN CAPITAL LETTER E")
(68746 . "OLD HUNGARIAN CAPITAL LETTER CLOSE E")
(68747 . "OLD HUNGARIAN CAPITAL LETTER EE")
(68748 . "OLD HUNGARIAN CAPITAL LETTER EF")
(68749 . "OLD HUNGARIAN CAPITAL LETTER EG")
(68750 . "OLD HUNGARIAN CAPITAL LETTER EGY")
(68751 . "OLD HUNGARIAN CAPITAL LETTER EH")
(68752 . "OLD HUNGARIAN CAPITAL LETTER I")
(68753 . "OLD HUNGARIAN CAPITAL LETTER II")
(68754 . "OLD HUNGARIAN CAPITAL LETTER EJ")
(68755 . "OLD HUNGARIAN CAPITAL LETTER EK")
(68756 . "OLD HUNGARIAN CAPITAL LETTER AK")
(68757 . "OLD HUNGARIAN CAPITAL LETTER UNK")
(68758 . "OLD HUNGARIAN CAPITAL LETTER EL")
(68759 . "OLD HUNGARIAN CAPITAL LETTER ELY")
(68760 . "OLD HUNGARIAN CAPITAL LETTER EM")
(68761 . "OLD HUNGARIAN CAPITAL LETTER EN")
(68762 . "OLD HUNGARIAN CAPITAL LETTER ENY")
(68763 . "OLD HUNGARIAN CAPITAL LETTER O")
(68764 . "OLD HUNGARIAN CAPITAL LETTER OO")
(68765 . "OLD HUNGARIAN CAPITAL LETTER NIKOLSBURG OE")
(68766 . "OLD HUNGARIAN CAPITAL LETTER RUDIMENTA OE")
(68767 . "OLD HUNGARIAN CAPITAL LETTER OEE")
(68768 . "OLD HUNGARIAN CAPITAL LETTER EP")
(68769 . "OLD HUNGARIAN CAPITAL LETTER EMP")
(68770 . "OLD HUNGARIAN CAPITAL LETTER ER")
(68771 . "OLD HUNGARIAN CAPITAL LETTER SHORT ER")
(68772 . "OLD HUNGARIAN CAPITAL LETTER ES")
(68773 . "OLD HUNGARIAN CAPITAL LETTER ESZ")
(68774 . "OLD HUNGARIAN CAPITAL LETTER ET")
(68775 . "OLD HUNGARIAN CAPITAL LETTER ENT")
(68776 . "OLD HUNGARIAN CAPITAL LETTER ETY")
(68777 . "OLD HUNGARIAN CAPITAL LETTER ECH")
(68778 . "OLD HUNGARIAN CAPITAL LETTER U")
(68779 . "OLD HUNGARIAN CAPITAL LETTER UU")
(68780 . "OLD HUNGARIAN CAPITAL LETTER NIKOLSBURG UE")
(68781 . "OLD HUNGARIAN CAPITAL LETTER RUDIMENTA UE")
(68782 . "OLD HUNGARIAN CAPITAL LETTER EV")
(68783 . "OLD HUNGARIAN CAPITAL LETTER EZ")
(68784 . "OLD HUNGARIAN CAPITAL LETTER EZS")
(68785 . "OLD HUNGARIAN CAPITAL LETTER ENT-SHAPED SIGN")
(68786 . "OLD HUNGARIAN CAPITAL LETTER US")
((68787 . 68800) . #f)
(68800 . "OLD HUNGARIAN SMALL LETTER A")
(68801 . "OLD HUNGARIAN SMALL LETTER AA")
(68802 . "OLD HUNGARIAN SMALL LETTER EB")
(68803 . "OLD HUNGARIAN SMALL LETTER AMB")
(68804 . "OLD HUNGARIAN SMALL LETTER EC")
(68805 . "OLD HUNGARIAN SMALL LETTER ENC")
(68806 . "OLD HUNGARIAN SMALL LETTER ECS")
(68807 . "OLD HUNGARIAN SMALL LETTER ED")
(68808 . "OLD HUNGARIAN SMALL LETTER AND")
(68809 . "OLD HUNGARIAN SMALL LETTER E")
(68810 . "OLD HUNGARIAN SMALL LETTER CLOSE E")
(68811 . "OLD HUNGARIAN SMALL LETTER EE")
(68812 . "OLD HUNGARIAN SMALL LETTER EF")
(68813 . "OLD HUNGARIAN SMALL LETTER EG")
(68814 . "OLD HUNGARIAN SMALL LETTER EGY")
(68815 . "OLD HUNGARIAN SMALL LETTER EH")
(68816 . "OLD HUNGARIAN SMALL LETTER I")
(68817 . "OLD HUNGARIAN SMALL LETTER II")
(68818 . "OLD HUNGARIAN SMALL LETTER EJ")
(68819 . "OLD HUNGARIAN SMALL LETTER EK")
(68820 . "OLD HUNGARIAN SMALL LETTER AK")
(68821 . "OLD HUNGARIAN SMALL LETTER UNK")
(68822 . "OLD HUNGARIAN SMALL LETTER EL")
(68823 . "OLD HUNGARIAN SMALL LETTER ELY")
(68824 . "OLD HUNGARIAN SMALL LETTER EM")
(68825 . "OLD HUNGARIAN SMALL LETTER EN")
(68826 . "OLD HUNGARIAN SMALL LETTER ENY")
(68827 . "OLD HUNGARIAN SMALL LETTER O")
(68828 . "OLD HUNGARIAN SMALL LETTER OO")
(68829 . "OLD HUNGARIAN SMALL LETTER NIKOLSBURG OE")
(68830 . "OLD HUNGARIAN SMALL LETTER RUDIMENTA OE")
(68831 . "OLD HUNGARIAN SMALL LETTER OEE")
(68832 . "OLD HUNGARIAN SMALL LETTER EP")
(68833 . "OLD HUNGARIAN SMALL LETTER EMP")
(68834 . "OLD HUNGARIAN SMALL LETTER ER")
(68835 . "OLD HUNGARIAN SMALL LETTER SHORT ER")
(68836 . "OLD HUNGARIAN SMALL LETTER ES")
(68837 . "OLD HUNGARIAN SMALL LETTER ESZ")
(68838 . "OLD HUNGARIAN SMALL LETTER ET")
(68839 . "OLD HUNGARIAN SMALL LETTER ENT")
(68840 . "OLD HUNGARIAN SMALL LETTER ETY")
(68841 . "OLD HUNGARIAN SMALL LETTER ECH")
(68842 . "OLD HUNGARIAN SMALL LETTER U")
(68843 . "OLD HUNGARIAN SMALL LETTER UU")
(68844 . "OLD HUNGARIAN SMALL LETTER NIKOLSBURG UE")
(68845 . "OLD HUNGARIAN SMALL LETTER RUDIMENTA UE")
(68846 . "OLD HUNGARIAN SMALL LETTER EV")
(68847 . "OLD HUNGARIAN SMALL LETTER EZ")
(68848 . "OLD HUNGARIAN SMALL LETTER EZS")
(68849 . "OLD HUNGARIAN SMALL LETTER ENT-SHAPED SIGN")
(68850 . "OLD HUNGARIAN SMALL LETTER US")
((68851 . 68858) . #f)
(68858 . "OLD HUNGARIAN NUMBER ONE")
(68859 . "OLD HUNGARIAN NUMBER FIVE")
(68860 . "OLD HUNGARIAN NUMBER TEN")
(68861 . "OLD HUNGARIAN NUMBER FIFTY")
(68862 . "OLD HUNGARIAN NUMBER ONE HUNDRED")
(68863 . "OLD HUNGARIAN NUMBER ONE THOUSAND")
((68864 . 69216) . #f)
(69216 . "RUMI DIGIT ONE")
(69217 . "RUMI DIGIT TWO")
(69218 . "RUMI DIGIT THREE")
(69219 . "RUMI DIGIT FOUR")
(69220 . "RUMI DIGIT FIVE")
(69221 . "RUMI DIGIT SIX")
(69222 . "RUMI DIGIT SEVEN")
(69223 . "RUMI DIGIT EIGHT")
(69224 . "RUMI DIGIT NINE")
(69225 . "RUMI NUMBER TEN")
(69226 . "RUMI NUMBER TWENTY")
(69227 . "RUMI NUMBER THIRTY")
(69228 . "RUMI NUMBER FORTY")
(69229 . "RUMI NUMBER FIFTY")
(69230 . "RUMI NUMBER SIXTY")
(69231 . "RUMI NUMBER SEVENTY")
(69232 . "RUMI NUMBER EIGHTY")
(69233 . "RUMI NUMBER NINETY")
(69234 . "RUMI NUMBER ONE HUNDRED")
(69235 . "RUMI NUMBER TWO HUNDRED")
(69236 . "RUMI NUMBER THREE HUNDRED")
(69237 . "RUMI NUMBER FOUR HUNDRED")
(69238 . "RUMI NUMBER FIVE HUNDRED")
(69239 . "RUMI NUMBER SIX HUNDRED")
(69240 . "RUMI NUMBER SEVEN HUNDRED")
(69241 . "RUMI NUMBER EIGHT HUNDRED")
(69242 . "RUMI NUMBER NINE HUNDRED")
(69243 . "RUMI FRACTION ONE HALF")
(69244 . "RUMI FRACTION ONE QUARTER")
(69245 . "RUMI FRACTION ONE THIRD")
(69246 . "RUMI FRACTION TWO THIRDS")
((69247 . 69632) . #f)
(69632 . "BRAHMI SIGN CANDRABINDU")
(69633 . "BRAHMI SIGN ANUSVARA")
(69634 . "BRAHMI SIGN VISARGA")
(69635 . "BRAHMI SIGN JIHVAMULIYA")
(69636 . "BRAHMI SIGN UPADHMANIYA")
(69637 . "BRAHMI LETTER A")
(69638 . "BRAHMI LETTER AA")
(69639 . "BRAHMI LETTER I")
(69640 . "BRAHMI LETTER II")
(69641 . "BRAHMI LETTER U")
(69642 . "BRAHMI LETTER UU")
(69643 . "BRAHMI LETTER VOCALIC R")
(69644 . "BRAHMI LETTER VOCALIC RR")
(69645 . "BRAHMI LETTER VOCALIC L")
(69646 . "BRAHMI LETTER VOCALIC LL")
(69647 . "BRAHMI LETTER E")
(69648 . "BRAHMI LETTER AI")
(69649 . "BRAHMI LETTER O")
(69650 . "BRAHMI LETTER AU")
(69651 . "BRAHMI LETTER KA")
(69652 . "BRAHMI LETTER KHA")
(69653 . "BRAHMI LETTER GA")
(69654 . "BRAHMI LETTER GHA")
(69655 . "BRAHMI LETTER NGA")
(69656 . "BRAHMI LETTER CA")
(69657 . "BRAHMI LETTER CHA")
(69658 . "BRAHMI LETTER JA")
(69659 . "BRAHMI LETTER JHA")
(69660 . "BRAHMI LETTER NYA")
(69661 . "BRAHMI LETTER TTA")
(69662 . "BRAHMI LETTER TTHA")
(69663 . "BRAHMI LETTER DDA")
(69664 . "BRAHMI LETTER DDHA")
(69665 . "BRAHMI LETTER NNA")
(69666 . "BRAHMI LETTER TA")
(69667 . "BRAHMI LETTER THA")
(69668 . "BRAHMI LETTER DA")
(69669 . "BRAHMI LETTER DHA")
(69670 . "BRAHMI LETTER NA")
(69671 . "BRAHMI LETTER PA")
(69672 . "BRAHMI LETTER PHA")
(69673 . "BRAHMI LETTER BA")
(69674 . "BRAHMI LETTER BHA")
(69675 . "BRAHMI LETTER MA")
(69676 . "BRAHMI LETTER YA")
(69677 . "BRAHMI LETTER RA")
(69678 . "BRAHMI LETTER LA")
(69679 . "BRAHMI LETTER VA")
(69680 . "BRAHMI LETTER SHA")
(69681 . "BRAHMI LETTER SSA")
(69682 . "BRAHMI LETTER SA")
(69683 . "BRAHMI LETTER HA")
(69684 . "BRAHMI LETTER LLA")
(69685 . "BRAHMI LETTER OLD TAMIL LLLA")
(69686 . "BRAHMI LETTER OLD TAMIL RRA")
(69687 . "BRAHMI LETTER OLD TAMIL NNNA")
(69688 . "BRAHMI VOWEL SIGN AA")
(69689 . "BRAHMI VOWEL SIGN BHATTIPROLU AA")
(69690 . "BRAHMI VOWEL SIGN I")
(69691 . "BRAHMI VOWEL SIGN II")
(69692 . "BRAHMI VOWEL SIGN U")
(69693 . "BRAHMI VOWEL SIGN UU")
(69694 . "BRAHMI VOWEL SIGN VOCALIC R")
(69695 . "BRAHMI VOWEL SIGN VOCALIC RR")
(69696 . "BRAHMI VOWEL SIGN VOCALIC L")
(69697 . "BRAHMI VOWEL SIGN VOCALIC LL")
(69698 . "BRAHMI VOWEL SIGN E")
(69699 . "BRAHMI VOWEL SIGN AI")
(69700 . "BRAHMI VOWEL SIGN O")
(69701 . "BRAHMI VOWEL SIGN AU")
(69702 . "BRAHMI VIRAMA")
(69703 . "BRAHMI DANDA")
(69704 . "BRAHMI DOUBLE DANDA")
(69705 . "BRAHMI PUNCTUATION DOT")
(69706 . "BRAHMI PUNCTUATION DOUBLE DOT")
(69707 . "BRAHMI PUNCTUATION LINE")
(69708 . "BRAHMI PUNCTUATION CRESCENT BAR")
(69709 . "BRAHMI PUNCTUATION LOTUS")
((69710 . 69714) . #f)
(69714 . "BRAHMI NUMBER ONE")
(69715 . "BRAHMI NUMBER TWO")
(69716 . "BRAHMI NUMBER THREE")
(69717 . "BRAHMI NUMBER FOUR")
(69718 . "BRAHMI NUMBER FIVE")
(69719 . "BRAHMI NUMBER SIX")
(69720 . "BRAHMI NUMBER SEVEN")
(69721 . "BRAHMI NUMBER EIGHT")
(69722 . "BRAHMI NUMBER NINE")
(69723 . "BRAHMI NUMBER TEN")
(69724 . "BRAHMI NUMBER TWENTY")
(69725 . "BRAHMI NUMBER THIRTY")
(69726 . "BRAHMI NUMBER FORTY")
(69727 . "BRAHMI NUMBER FIFTY")
(69728 . "BRAHMI NUMBER SIXTY")
(69729 . "BRAHMI NUMBER SEVENTY")
(69730 . "BRAHMI NUMBER EIGHTY")
(69731 . "BRAHMI NUMBER NINETY")
(69732 . "BRAHMI NUMBER ONE HUNDRED")
(69733 . "BRAHMI NUMBER ONE THOUSAND")
(69734 . "BRAHMI DIGIT ZERO")
(69735 . "BRAHMI DIGIT ONE")
(69736 . "BRAHMI DIGIT TWO")
(69737 . "BRAHMI DIGIT THREE")
(69738 . "BRAHMI DIGIT FOUR")
(69739 . "BRAHMI DIGIT FIVE")
(69740 . "BRAHMI DIGIT SIX")
(69741 . "BRAHMI DIGIT SEVEN")
(69742 . "BRAHMI DIGIT EIGHT")
(69743 . "BRAHMI DIGIT NINE")
((69744 . 69759) . #f)
(69759 . "BRAHMI NUMBER JOINER")
(69760 . "KAITHI SIGN CANDRABINDU")
(69761 . "KAITHI SIGN ANUSVARA")
(69762 . "KAITHI SIGN VISARGA")
(69763 . "KAITHI LETTER A")
(69764 . "KAITHI LETTER AA")
(69765 . "KAITHI LETTER I")
(69766 . "KAITHI LETTER II")
(69767 . "KAITHI LETTER U")
(69768 . "KAITHI LETTER UU")
(69769 . "KAITHI LETTER E")
(69770 . "KAITHI LETTER AI")
(69771 . "KAITHI LETTER O")
(69772 . "KAITHI LETTER AU")
(69773 . "KAITHI LETTER KA")
(69774 . "KAITHI LETTER KHA")
(69775 . "KAITHI LETTER GA")
(69776 . "KAITHI LETTER GHA")
(69777 . "KAITHI LETTER NGA")
(69778 . "KAITHI LETTER CA")
(69779 . "KAITHI LETTER CHA")
(69780 . "KAITHI LETTER JA")
(69781 . "KAITHI LETTER JHA")
(69782 . "KAITHI LETTER NYA")
(69783 . "KAITHI LETTER TTA")
(69784 . "KAITHI LETTER TTHA")
(69785 . "KAITHI LETTER DDA")
(69786 . "KAITHI LETTER DDDHA")
(69787 . "KAITHI LETTER DDHA")
(69788 . "KAITHI LETTER RHA")
(69789 . "KAITHI LETTER NNA")
(69790 . "KAITHI LETTER TA")
(69791 . "KAITHI LETTER THA")
(69792 . "KAITHI LETTER DA")
(69793 . "KAITHI LETTER DHA")
(69794 . "KAITHI LETTER NA")
(69795 . "KAITHI LETTER PA")
(69796 . "KAITHI LETTER PHA")
(69797 . "KAITHI LETTER BA")
(69798 . "KAITHI LETTER BHA")
(69799 . "KAITHI LETTER MA")
(69800 . "KAITHI LETTER YA")
(69801 . "KAITHI LETTER RA")
(69802 . "KAITHI LETTER LA")
(69803 . "KAITHI LETTER VA")
(69804 . "KAITHI LETTER SHA")
(69805 . "KAITHI LETTER SSA")
(69806 . "KAITHI LETTER SA")
(69807 . "KAITHI LETTER HA")
(69808 . "KAITHI VOWEL SIGN AA")
(69809 . "KAITHI VOWEL SIGN I")
(69810 . "KAITHI VOWEL SIGN II")
(69811 . "KAITHI VOWEL SIGN U")
(69812 . "KAITHI VOWEL SIGN UU")
(69813 . "KAITHI VOWEL SIGN E")
(69814 . "KAITHI VOWEL SIGN AI")
(69815 . "KAITHI VOWEL SIGN O")
(69816 . "KAITHI VOWEL SIGN AU")
(69817 . "KAITHI SIGN VIRAMA")
(69818 . "KAITHI SIGN NUKTA")
(69819 . "KAITHI ABBREVIATION SIGN")
(69820 . "KAITHI ENUMERATION SIGN")
(69821 . "KAITHI NUMBER SIGN")
(69822 . "KAITHI SECTION MARK")
(69823 . "KAITHI DOUBLE SECTION MARK")
(69824 . "KAITHI DANDA")
(69825 . "KAITHI DOUBLE DANDA")
((69826 . 69840) . #f)
(69840 . "SORA SOMPENG LETTER SAH")
(69841 . "SORA SOMPENG LETTER TAH")
(69842 . "SORA SOMPENG LETTER BAH")
(69843 . "SORA SOMPENG LETTER CAH")
(69844 . "SORA SOMPENG LETTER DAH")
(69845 . "SORA SOMPENG LETTER GAH")
(69846 . "SORA SOMPENG LETTER MAH")
(69847 . "SORA SOMPENG LETTER NGAH")
(69848 . "SORA SOMPENG LETTER LAH")
(69849 . "SORA SOMPENG LETTER NAH")
(69850 . "SORA SOMPENG LETTER VAH")
(69851 . "SORA SOMPENG LETTER PAH")
(69852 . "SORA SOMPENG LETTER YAH")
(69853 . "SORA SOMPENG LETTER RAH")
(69854 . "SORA SOMPENG LETTER HAH")
(69855 . "SORA SOMPENG LETTER KAH")
(69856 . "SORA SOMPENG LETTER JAH")
(69857 . "SORA SOMPENG LETTER NYAH")
(69858 . "SORA SOMPENG LETTER AH")
(69859 . "SORA SOMPENG LETTER EEH")
(69860 . "SORA SOMPENG LETTER IH")
(69861 . "SORA SOMPENG LETTER UH")
(69862 . "SORA SOMPENG LETTER OH")
(69863 . "SORA SOMPENG LETTER EH")
(69864 . "SORA SOMPENG LETTER MAE")
((69865 . 69872) . #f)
(69872 . "SORA SOMPENG DIGIT ZERO")
(69873 . "SORA SOMPENG DIGIT ONE")
(69874 . "SORA SOMPENG DIGIT TWO")
(69875 . "SORA SOMPENG DIGIT THREE")
(69876 . "SORA SOMPENG DIGIT FOUR")
(69877 . "SORA SOMPENG DIGIT FIVE")
(69878 . "SORA SOMPENG DIGIT SIX")
(69879 . "SORA SOMPENG DIGIT SEVEN")
(69880 . "SORA SOMPENG DIGIT EIGHT")
(69881 . "SORA SOMPENG DIGIT NINE")
((69882 . 69888) . #f)
(69888 . "CHAKMA SIGN CANDRABINDU")
(69889 . "CHAKMA SIGN ANUSVARA")
(69890 . "CHAKMA SIGN VISARGA")
(69891 . "CHAKMA LETTER AA")
(69892 . "CHAKMA LETTER I")
(69893 . "CHAKMA LETTER U")
(69894 . "CHAKMA LETTER E")
(69895 . "CHAKMA LETTER KAA")
(69896 . "CHAKMA LETTER KHAA")
(69897 . "CHAKMA LETTER GAA")
(69898 . "CHAKMA LETTER GHAA")
(69899 . "CHAKMA LETTER NGAA")
(69900 . "CHAKMA LETTER CAA")
(69901 . "CHAKMA LETTER CHAA")
(69902 . "CHAKMA LETTER JAA")
(69903 . "CHAKMA LETTER JHAA")
(69904 . "CHAKMA LETTER NYAA")
(69905 . "CHAKMA LETTER TTAA")
(69906 . "CHAKMA LETTER TTHAA")
(69907 . "CHAKMA LETTER DDAA")
(69908 . "CHAKMA LETTER DDHAA")
(69909 . "CHAKMA LETTER NNAA")
(69910 . "CHAKMA LETTER TAA")
(69911 . "CHAKMA LETTER THAA")
(69912 . "CHAKMA LETTER DAA")
(69913 . "CHAKMA LETTER DHAA")
(69914 . "CHAKMA LETTER NAA")
(69915 . "CHAKMA LETTER PAA")
(69916 . "CHAKMA LETTER PHAA")
(69917 . "CHAKMA LETTER BAA")
(69918 . "CHAKMA LETTER BHAA")
(69919 . "CHAKMA LETTER MAA")
(69920 . "CHAKMA LETTER YYAA")
(69921 . "CHAKMA LETTER YAA")
(69922 . "CHAKMA LETTER RAA")
(69923 . "CHAKMA LETTER LAA")
(69924 . "CHAKMA LETTER WAA")
(69925 . "CHAKMA LETTER SAA")
(69926 . "CHAKMA LETTER HAA")
(69927 . "CHAKMA VOWEL SIGN A")
(69928 . "CHAKMA VOWEL SIGN I")
(69929 . "CHAKMA VOWEL SIGN II")
(69930 . "CHAKMA VOWEL SIGN U")
(69931 . "CHAKMA VOWEL SIGN UU")
(69932 . "CHAKMA VOWEL SIGN E")
(69933 . "CHAKMA VOWEL SIGN AI")
(69934 . "CHAKMA VOWEL SIGN O")
(69935 . "CHAKMA VOWEL SIGN AU")
(69936 . "CHAKMA VOWEL SIGN OI")
(69937 . "CHAKMA O MARK")
(69938 . "CHAKMA AU MARK")
(69939 . "CHAKMA VIRAMA")
(69940 . "CHAKMA MAAYYAA")
(69941 . #f)
(69942 . "CHAKMA DIGIT ZERO")
(69943 . "CHAKMA DIGIT ONE")
(69944 . "CHAKMA DIGIT TWO")
(69945 . "CHAKMA DIGIT THREE")
(69946 . "CHAKMA DIGIT FOUR")
(69947 . "CHAKMA DIGIT FIVE")
(69948 . "CHAKMA DIGIT SIX")
(69949 . "CHAKMA DIGIT SEVEN")
(69950 . "CHAKMA DIGIT EIGHT")
(69951 . "CHAKMA DIGIT NINE")
(69952 . "CHAKMA SECTION MARK")
(69953 . "CHAKMA DANDA")
(69954 . "CHAKMA DOUBLE DANDA")
(69955 . "CHAKMA QUESTION MARK")
((69956 . 69968) . #f)
(69968 . "MAHAJANI LETTER A")
(69969 . "MAHAJANI LETTER I")
(69970 . "MAHAJANI LETTER U")
(69971 . "MAHAJANI LETTER E")
(69972 . "MAHAJANI LETTER O")
(69973 . "MAHAJANI LETTER KA")
(69974 . "MAHAJANI LETTER KHA")
(69975 . "MAHAJANI LETTER GA")
(69976 . "MAHAJANI LETTER GHA")
(69977 . "MAHAJANI LETTER CA")
(69978 . "MAHAJANI LETTER CHA")
(69979 . "MAHAJANI LETTER JA")
(69980 . "MAHAJANI LETTER JHA")
(69981 . "MAHAJANI LETTER NYA")
(69982 . "MAHAJANI LETTER TTA")
(69983 . "MAHAJANI LETTER TTHA")
(69984 . "MAHAJANI LETTER DDA")
(69985 . "MAHAJANI LETTER DDHA")
(69986 . "MAHAJANI LETTER NNA")
(69987 . "MAHAJANI LETTER TA")
(69988 . "MAHAJANI LETTER THA")
(69989 . "MAHAJANI LETTER DA")
(69990 . "MAHAJANI LETTER DHA")
(69991 . "MAHAJANI LETTER NA")
(69992 . "MAHAJANI LETTER PA")
(69993 . "MAHAJANI LETTER PHA")
(69994 . "MAHAJANI LETTER BA")
(69995 . "MAHAJANI LETTER BHA")
(69996 . "MAHAJANI LETTER MA")
(69997 . "MAHAJANI LETTER RA")
(69998 . "MAHAJANI LETTER LA")
(69999 . "MAHAJANI LETTER VA")
(70000 . "MAHAJANI LETTER SA")
(70001 . "MAHAJANI LETTER HA")
(70002 . "MAHAJANI LETTER RRA")
(70003 . "MAHAJANI SIGN NUKTA")
(70004 . "MAHAJANI ABBREVIATION SIGN")
(70005 . "MAHAJANI SECTION MARK")
(70006 . "MAHAJANI LIGATURE SHRI")
((70007 . 70016) . #f)
(70016 . "SHARADA SIGN CANDRABINDU")
(70017 . "SHARADA SIGN ANUSVARA")
(70018 . "SHARADA SIGN VISARGA")
(70019 . "SHARADA LETTER A")
(70020 . "SHARADA LETTER AA")
(70021 . "SHARADA LETTER I")
(70022 . "SHARADA LETTER II")
(70023 . "SHARADA LETTER U")
(70024 . "SHARADA LETTER UU")
(70025 . "SHARADA LETTER VOCALIC R")
(70026 . "SHARADA LETTER VOCALIC RR")
(70027 . "SHARADA LETTER VOCALIC L")
(70028 . "SHARADA LETTER VOCALIC LL")
(70029 . "SHARADA LETTER E")
(70030 . "SHARADA LETTER AI")
(70031 . "SHARADA LETTER O")
(70032 . "SHARADA LETTER AU")
(70033 . "SHARADA LETTER KA")
(70034 . "SHARADA LETTER KHA")
(70035 . "SHARADA LETTER GA")
(70036 . "SHARADA LETTER GHA")
(70037 . "SHARADA LETTER NGA")
(70038 . "SHARADA LETTER CA")
(70039 . "SHARADA LETTER CHA")
(70040 . "SHARADA LETTER JA")
(70041 . "SHARADA LETTER JHA")
(70042 . "SHARADA LETTER NYA")
(70043 . "SHARADA LETTER TTA")
(70044 . "SHARADA LETTER TTHA")
(70045 . "SHARADA LETTER DDA")
(70046 . "SHARADA LETTER DDHA")
(70047 . "SHARADA LETTER NNA")
(70048 . "SHARADA LETTER TA")
(70049 . "SHARADA LETTER THA")
(70050 . "SHARADA LETTER DA")
(70051 . "SHARADA LETTER DHA")
(70052 . "SHARADA LETTER NA")
(70053 . "SHARADA LETTER PA")
(70054 . "SHARADA LETTER PHA")
(70055 . "SHARADA LETTER BA")
(70056 . "SHARADA LETTER BHA")
(70057 . "SHARADA LETTER MA")
(70058 . "SHARADA LETTER YA")
(70059 . "SHARADA LETTER RA")
(70060 . "SHARADA LETTER LA")
(70061 . "SHARADA LETTER LLA")
(70062 . "SHARADA LETTER VA")
(70063 . "SHARADA LETTER SHA")
(70064 . "SHARADA LETTER SSA")
(70065 . "SHARADA LETTER SA")
(70066 . "SHARADA LETTER HA")
(70067 . "SHARADA VOWEL SIGN AA")
(70068 . "SHARADA VOWEL SIGN I")
(70069 . "SHARADA VOWEL SIGN II")
(70070 . "SHARADA VOWEL SIGN U")
(70071 . "SHARADA VOWEL SIGN UU")
(70072 . "SHARADA VOWEL SIGN VOCALIC R")
(70073 . "SHARADA VOWEL SIGN VOCALIC RR")
(70074 . "SHARADA VOWEL SIGN VOCALIC L")
(70075 . "SHARADA VOWEL SIGN VOCALIC LL")
(70076 . "SHARADA VOWEL SIGN E")
(70077 . "SHARADA VOWEL SIGN AI")
(70078 . "SHARADA VOWEL SIGN O")
(70079 . "SHARADA VOWEL SIGN AU")
(70080 . "SHARADA SIGN VIRAMA")
(70081 . "SHARADA SIGN AVAGRAHA")
(70082 . "SHARADA SIGN JIHVAMULIYA")
(70083 . "SHARADA SIGN UPADHMANIYA")
(70084 . "SHARADA OM")
(70085 . "SHARADA DANDA")
(70086 . "SHARADA DOUBLE DANDA")
(70087 . "SHARADA ABBREVIATION SIGN")
(70088 . "SHARADA SEPARATOR")
(70089 . "SHARADA SANDHI MARK")
(70090 . "SHARADA SIGN NUKTA")
(70091 . "SHARADA VOWEL MODIFIER MARK")
(70092 . "SHARADA EXTRA SHORT VOWEL MARK")
(70093 . "SHARADA SUTRA MARK")
((70094 . 70096) . #f)
(70096 . "SHARADA DIGIT ZERO")
(70097 . "SHARADA DIGIT ONE")
(70098 . "SHARADA DIGIT TWO")
(70099 . "SHARADA DIGIT THREE")
(70100 . "SHARADA DIGIT FOUR")
(70101 . "SHARADA DIGIT FIVE")
(70102 . "SHARADA DIGIT SIX")
(70103 . "SHARADA DIGIT SEVEN")
(70104 . "SHARADA DIGIT EIGHT")
(70105 . "SHARADA DIGIT NINE")
(70106 . "SHARADA EKAM")
(70107 . "SHARADA SIGN SIDDHAM")
(70108 . "SHARADA HEADSTROKE")
(70109 . "SHARADA CONTINUATION SIGN")
(70110 . "SHARADA SECTION MARK-1")
(70111 . "SHARADA SECTION MARK-2")
(70112 . #f)
(70113 . "SINHALA ARCHAIC DIGIT ONE")
(70114 . "SINHALA ARCHAIC DIGIT TWO")
(70115 . "SINHALA ARCHAIC DIGIT THREE")
(70116 . "SINHALA ARCHAIC DIGIT FOUR")
(70117 . "SINHALA ARCHAIC DIGIT FIVE")
(70118 . "SINHALA ARCHAIC DIGIT SIX")
(70119 . "SINHALA ARCHAIC DIGIT SEVEN")
(70120 . "SINHALA ARCHAIC DIGIT EIGHT")
(70121 . "SINHALA ARCHAIC DIGIT NINE")
(70122 . "SINHALA ARCHAIC NUMBER TEN")
(70123 . "SINHALA ARCHAIC NUMBER TWENTY")
(70124 . "SINHALA ARCHAIC NUMBER THIRTY")
(70125 . "SINHALA ARCHAIC NUMBER FORTY")
(70126 . "SINHALA ARCHAIC NUMBER FIFTY")
(70127 . "SINHALA ARCHAIC NUMBER SIXTY")
(70128 . "SINHALA ARCHAIC NUMBER SEVENTY")
(70129 . "SINHALA ARCHAIC NUMBER EIGHTY")
(70130 . "SINHALA ARCHAIC NUMBER NINETY")
(70131 . "SINHALA ARCHAIC NUMBER ONE HUNDRED")
(70132 . "SINHALA ARCHAIC NUMBER ONE THOUSAND")
((70133 . 70144) . #f)
(70144 . "KHOJKI LETTER A")
(70145 . "KHOJKI LETTER AA")
(70146 . "KHOJKI LETTER I")
(70147 . "KHOJKI LETTER U")
(70148 . "KHOJKI LETTER E")
(70149 . "KHOJKI LETTER AI")
(70150 . "KHOJKI LETTER O")
(70151 . "KHOJKI LETTER AU")
(70152 . "KHOJKI LETTER KA")
(70153 . "KHOJKI LETTER KHA")
(70154 . "KHOJKI LETTER GA")
(70155 . "KHOJKI LETTER GGA")
(70156 . "KHOJKI LETTER GHA")
(70157 . "KHOJKI LETTER NGA")
(70158 . "KHOJKI LETTER CA")
(70159 . "KHOJKI LETTER CHA")
(70160 . "KHOJKI LETTER JA")
(70161 . "KHOJKI LETTER JJA")
(70162 . #f)
(70163 . "KHOJKI LETTER NYA")
(70164 . "KHOJKI LETTER TTA")
(70165 . "KHOJKI LETTER TTHA")
(70166 . "KHOJKI LETTER DDA")
(70167 . "KHOJKI LETTER DDHA")
(70168 . "KHOJKI LETTER NNA")
(70169 . "KHOJKI LETTER TA")
(70170 . "KHOJKI LETTER THA")
(70171 . "KHOJKI LETTER DA")
(70172 . "KHOJKI LETTER DDDA")
(70173 . "KHOJKI LETTER DHA")
(70174 . "KHOJKI LETTER NA")
(70175 . "KHOJKI LETTER PA")
(70176 . "KHOJKI LETTER PHA")
(70177 . "KHOJKI LETTER BA")
(70178 . "KHOJKI LETTER BBA")
(70179 . "KHOJKI LETTER BHA")
(70180 . "KHOJKI LETTER MA")
(70181 . "KHOJKI LETTER YA")
(70182 . "KHOJKI LETTER RA")
(70183 . "KHOJKI LETTER LA")
(70184 . "KHOJKI LETTER VA")
(70185 . "KHOJKI LETTER SA")
(70186 . "KHOJKI LETTER HA")
(70187 . "KHOJKI LETTER LLA")
(70188 . "KHOJKI VOWEL SIGN AA")
(70189 . "KHOJKI VOWEL SIGN I")
(70190 . "KHOJKI VOWEL SIGN II")
(70191 . "KHOJKI VOWEL SIGN U")
(70192 . "KHOJKI VOWEL SIGN E")
(70193 . "KHOJKI VOWEL SIGN AI")
(70194 . "KHOJKI VOWEL SIGN O")
(70195 . "KHOJKI VOWEL SIGN AU")
(70196 . "KHOJKI SIGN ANUSVARA")
(70197 . "KHOJKI SIGN VIRAMA")
(70198 . "KHOJKI SIGN NUKTA")
(70199 . "KHOJKI SIGN SHADDA")
(70200 . "KHOJKI DANDA")
(70201 . "KHOJKI DOUBLE DANDA")
(70202 . "KHOJKI WORD SEPARATOR")
(70203 . "KHOJKI SECTION MARK")
(70204 . "KHOJKI DOUBLE SECTION MARK")
(70205 . "KHOJKI ABBREVIATION SIGN")
(70206 . "KHOJKI SIGN SUKUN")
((70207 . 70272) . #f)
(70272 . "MULTANI LETTER A")
(70273 . "MULTANI LETTER I")
(70274 . "MULTANI LETTER U")
(70275 . "MULTANI LETTER E")
(70276 . "MULTANI LETTER KA")
(70277 . "MULTANI LETTER KHA")
(70278 . "MULTANI LETTER GA")
(70279 . #f)
(70280 . "MULTANI LETTER GHA")
(70281 . #f)
(70282 . "MULTANI LETTER CA")
(70283 . "MULTANI LETTER CHA")
(70284 . "MULTANI LETTER JA")
(70285 . "MULTANI LETTER JJA")
(70286 . #f)
(70287 . "MULTANI LETTER NYA")
(70288 . "MULTANI LETTER TTA")
(70289 . "MULTANI LETTER TTHA")
(70290 . "MULTANI LETTER DDA")
(70291 . "MULTANI LETTER DDDA")
(70292 . "MULTANI LETTER DDHA")
(70293 . "MULTANI LETTER NNA")
(70294 . "MULTANI LETTER TA")
(70295 . "MULTANI LETTER THA")
(70296 . "MULTANI LETTER DA")
(70297 . "MULTANI LETTER DHA")
(70298 . "MULTANI LETTER NA")
(70299 . "MULTANI LETTER PA")
(70300 . "MULTANI LETTER PHA")
(70301 . "MULTANI LETTER BA")
(70302 . #f)
(70303 . "MULTANI LETTER BHA")
(70304 . "MULTANI LETTER MA")
(70305 . "MULTANI LETTER YA")
(70306 . "MULTANI LETTER RA")
(70307 . "MULTANI LETTER LA")
(70308 . "MULTANI LETTER VA")
(70309 . "MULTANI LETTER SA")
(70310 . "MULTANI LETTER HA")
(70311 . "MULTANI LETTER RRA")
(70312 . "MULTANI LETTER RHA")
(70313 . "MULTANI SECTION MARK")
((70314 . 70320) . #f)
(70320 . "KHUDAWADI LETTER A")
(70321 . "KHUDAWADI LETTER AA")
(70322 . "KHUDAWADI LETTER I")
(70323 . "KHUDAWADI LETTER II")
(70324 . "KHUDAWADI LETTER U")
(70325 . "KHUDAWADI LETTER UU")
(70326 . "KHUDAWADI LETTER E")
(70327 . "KHUDAWADI LETTER AI")
(70328 . "KHUDAWADI LETTER O")
(70329 . "KHUDAWADI LETTER AU")
(70330 . "KHUDAWADI LETTER KA")
(70331 . "KHUDAWADI LETTER KHA")
(70332 . "KHUDAWADI LETTER GA")
(70333 . "KHUDAWADI LETTER GGA")
(70334 . "KHUDAWADI LETTER GHA")
(70335 . "KHUDAWADI LETTER NGA")
(70336 . "KHUDAWADI LETTER CA")
(70337 . "KHUDAWADI LETTER CHA")
(70338 . "KHUDAWADI LETTER JA")
(70339 . "KHUDAWADI LETTER JJA")
(70340 . "KHUDAWADI LETTER JHA")
(70341 . "KHUDAWADI LETTER NYA")
(70342 . "KHUDAWADI LETTER TTA")
(70343 . "KHUDAWADI LETTER TTHA")
(70344 . "KHUDAWADI LETTER DDA")
(70345 . "KHUDAWADI LETTER DDDA")
(70346 . "KHUDAWADI LETTER RRA")
(70347 . "KHUDAWADI LETTER DDHA")
(70348 . "KHUDAWADI LETTER NNA")
(70349 . "KHUDAWADI LETTER TA")
(70350 . "KHUDAWADI LETTER THA")
(70351 . "KHUDAWADI LETTER DA")
(70352 . "KHUDAWADI LETTER DHA")
(70353 . "KHUDAWADI LETTER NA")
(70354 . "KHUDAWADI LETTER PA")
(70355 . "KHUDAWADI LETTER PHA")
(70356 . "KHUDAWADI LETTER BA")
(70357 . "KHUDAWADI LETTER BBA")
(70358 . "KHUDAWADI LETTER BHA")
(70359 . "KHUDAWADI LETTER MA")
(70360 . "KHUDAWADI LETTER YA")
(70361 . "KHUDAWADI LETTER RA")
(70362 . "KHUDAWADI LETTER LA")
(70363 . "KHUDAWADI LETTER VA")
(70364 . "KHUDAWADI LETTER SHA")
(70365 . "KHUDAWADI LETTER SA")
(70366 . "KHUDAWADI LETTER HA")
(70367 . "KHUDAWADI SIGN ANUSVARA")
(70368 . "KHUDAWADI VOWEL SIGN AA")
(70369 . "KHUDAWADI VOWEL SIGN I")
(70370 . "KHUDAWADI VOWEL SIGN II")
(70371 . "KHUDAWADI VOWEL SIGN U")
(70372 . "KHUDAWADI VOWEL SIGN UU")
(70373 . "KHUDAWADI VOWEL SIGN E")
(70374 . "KHUDAWADI VOWEL SIGN AI")
(70375 . "KHUDAWADI VOWEL SIGN O")
(70376 . "KHUDAWADI VOWEL SIGN AU")
(70377 . "KHUDAWADI SIGN NUKTA")
(70378 . "KHUDAWADI SIGN VIRAMA")
((70379 . 70384) . #f)
(70384 . "KHUDAWADI DIGIT ZERO")
(70385 . "KHUDAWADI DIGIT ONE")
(70386 . "KHUDAWADI DIGIT TWO")
(70387 . "KHUDAWADI DIGIT THREE")
(70388 . "KHUDAWADI DIGIT FOUR")
(70389 . "KHUDAWADI DIGIT FIVE")
(70390 . "KHUDAWADI DIGIT SIX")
(70391 . "KHUDAWADI DIGIT SEVEN")
(70392 . "KHUDAWADI DIGIT EIGHT")
(70393 . "KHUDAWADI DIGIT NINE")
((70394 . 70400) . #f)
(70400 . "GRANTHA SIGN COMBINING ANUSVARA ABOVE")
(70401 . "GRANTHA SIGN CANDRABINDU")
(70402 . "GRANTHA SIGN ANUSVARA")
(70403 . "GRANTHA SIGN VISARGA")
(70404 . #f)
(70405 . "GRANTHA LETTER A")
(70406 . "GRANTHA LETTER AA")
(70407 . "GRANTHA LETTER I")
(70408 . "GRANTHA LETTER II")
(70409 . "GRANTHA LETTER U")
(70410 . "GRANTHA LETTER UU")
(70411 . "GRANTHA LETTER VOCALIC R")
(70412 . "GRANTHA LETTER VOCALIC L")
((70413 . 70415) . #f)
(70415 . "GRANTHA LETTER EE")
(70416 . "GRANTHA LETTER AI")
((70417 . 70419) . #f)
(70419 . "GRANTHA LETTER OO")
(70420 . "GRANTHA LETTER AU")
(70421 . "GRANTHA LETTER KA")
(70422 . "GRANTHA LETTER KHA")
(70423 . "GRANTHA LETTER GA")
(70424 . "GRANTHA LETTER GHA")
(70425 . "GRANTHA LETTER NGA")
(70426 . "GRANTHA LETTER CA")
(70427 . "GRANTHA LETTER CHA")
(70428 . "GRANTHA LETTER JA")
(70429 . "GRANTHA LETTER JHA")
(70430 . "GRANTHA LETTER NYA")
(70431 . "GRANTHA LETTER TTA")
(70432 . "GRANTHA LETTER TTHA")
(70433 . "GRANTHA LETTER DDA")
(70434 . "GRANTHA LETTER DDHA")
(70435 . "GRANTHA LETTER NNA")
(70436 . "GRANTHA LETTER TA")
(70437 . "GRANTHA LETTER THA")
(70438 . "GRANTHA LETTER DA")
(70439 . "GRANTHA LETTER DHA")
(70440 . "GRANTHA LETTER NA")
(70441 . #f)
(70442 . "GRANTHA LETTER PA")
(70443 . "GRANTHA LETTER PHA")
(70444 . "GRANTHA LETTER BA")
(70445 . "GRANTHA LETTER BHA")
(70446 . "GRANTHA LETTER MA")
(70447 . "GRANTHA LETTER YA")
(70448 . "GRANTHA LETTER RA")
(70449 . #f)
(70450 . "GRANTHA LETTER LA")
(70451 . "GRANTHA LETTER LLA")
(70452 . #f)
(70453 . "GRANTHA LETTER VA")
(70454 . "GRANTHA LETTER SHA")
(70455 . "GRANTHA LETTER SSA")
(70456 . "GRANTHA LETTER SA")
(70457 . "GRANTHA LETTER HA")
((70458 . 70460) . #f)
(70460 . "GRANTHA SIGN NUKTA")
(70461 . "GRANTHA SIGN AVAGRAHA")
(70462 . "GRANTHA VOWEL SIGN AA")
(70463 . "GRANTHA VOWEL SIGN I")
(70464 . "GRANTHA VOWEL SIGN II")
(70465 . "GRANTHA VOWEL SIGN U")
(70466 . "GRANTHA VOWEL SIGN UU")
(70467 . "GRANTHA VOWEL SIGN VOCALIC R")
(70468 . "GRANTHA VOWEL SIGN VOCALIC RR")
((70469 . 70471) . #f)
(70471 . "GRANTHA VOWEL SIGN EE")
(70472 . "GRANTHA VOWEL SIGN AI")
((70473 . 70475) . #f)
(70475 . "GRANTHA VOWEL SIGN OO")
(70476 . "GRANTHA VOWEL SIGN AU")
(70477 . "GRANTHA SIGN VIRAMA")
((70478 . 70480) . #f)
(70480 . "GRANTHA OM")
((70481 . 70487) . #f)
(70487 . "GRANTHA AU LENGTH MARK")
((70488 . 70493) . #f)
(70493 . "GRANTHA SIGN PLUTA")
(70494 . "GRANTHA LETTER VEDIC ANUSVARA")
(70495 . "GRANTHA LETTER VEDIC DOUBLE ANUSVARA")
(70496 . "GRANTHA LETTER VOCALIC RR")
(70497 . "GRANTHA LETTER VOCALIC LL")
(70498 . "GRANTHA VOWEL SIGN VOCALIC L")
(70499 . "GRANTHA VOWEL SIGN VOCALIC LL")
((70500 . 70502) . #f)
(70502 . "COMBINING GRANTHA DIGIT ZERO")
(70503 . "COMBINING GRANTHA DIGIT ONE")
(70504 . "COMBINING GRANTHA DIGIT TWO")
(70505 . "COMBINING GRANTHA DIGIT THREE")
(70506 . "COMBINING GRANTHA DIGIT FOUR")
(70507 . "COMBINING GRANTHA DIGIT FIVE")
(70508 . "COMBINING GRANTHA DIGIT SIX")
((70509 . 70512) . #f)
(70512 . "COMBINING GRANTHA LETTER A")
(70513 . "COMBINING GRANTHA LETTER KA")
(70514 . "COMBINING GRANTHA LETTER NA")
(70515 . "COMBINING GRANTHA LETTER VI")
(70516 . "COMBINING GRANTHA LETTER PA")
((70517 . 70656) . #f)
(70656 . "NEWA LETTER A")
(70657 . "NEWA LETTER AA")
(70658 . "NEWA LETTER I")
(70659 . "NEWA LETTER II")
(70660 . "NEWA LETTER U")
(70661 . "NEWA LETTER UU")
(70662 . "NEWA LETTER VOCALIC R")
(70663 . "NEWA LETTER VOCALIC RR")
(70664 . "NEWA LETTER VOCALIC L")
(70665 . "NEWA LETTER VOCALIC LL")
(70666 . "NEWA LETTER E")
(70667 . "NEWA LETTER AI")
(70668 . "NEWA LETTER O")
(70669 . "NEWA LETTER AU")
(70670 . "NEWA LETTER KA")
(70671 . "NEWA LETTER KHA")
(70672 . "NEWA LETTER GA")
(70673 . "NEWA LETTER GHA")
(70674 . "NEWA LETTER NGA")
(70675 . "NEWA LETTER NGHA")
(70676 . "NEWA LETTER CA")
(70677 . "NEWA LETTER CHA")
(70678 . "NEWA LETTER JA")
(70679 . "NEWA LETTER JHA")
(70680 . "NEWA LETTER NYA")
(70681 . "NEWA LETTER NYHA")
(70682 . "NEWA LETTER TTA")
(70683 . "NEWA LETTER TTHA")
(70684 . "NEWA LETTER DDA")
(70685 . "NEWA LETTER DDHA")
(70686 . "NEWA LETTER NNA")
(70687 . "NEWA LETTER TA")
(70688 . "NEWA LETTER THA")
(70689 . "NEWA LETTER DA")
(70690 . "NEWA LETTER DHA")
(70691 . "NEWA LETTER NA")
(70692 . "NEWA LETTER NHA")
(70693 . "NEWA LETTER PA")
(70694 . "NEWA LETTER PHA")
(70695 . "NEWA LETTER BA")
(70696 . "NEWA LETTER BHA")
(70697 . "NEWA LETTER MA")
(70698 . "NEWA LETTER MHA")
(70699 . "NEWA LETTER YA")
(70700 . "NEWA LETTER RA")
(70701 . "NEWA LETTER RHA")
(70702 . "NEWA LETTER LA")
(70703 . "NEWA LETTER LHA")
(70704 . "NEWA LETTER WA")
(70705 . "NEWA LETTER SHA")
(70706 . "NEWA LETTER SSA")
(70707 . "NEWA LETTER SA")
(70708 . "NEWA LETTER HA")
(70709 . "NEWA VOWEL SIGN AA")
(70710 . "NEWA VOWEL SIGN I")
(70711 . "NEWA VOWEL SIGN II")
(70712 . "NEWA VOWEL SIGN U")
(70713 . "NEWA VOWEL SIGN UU")
(70714 . "NEWA VOWEL SIGN VOCALIC R")
(70715 . "NEWA VOWEL SIGN VOCALIC RR")
(70716 . "NEWA VOWEL SIGN VOCALIC L")
(70717 . "NEWA VOWEL SIGN VOCALIC LL")
(70718 . "NEWA VOWEL SIGN E")
(70719 . "NEWA VOWEL SIGN AI")
(70720 . "NEWA VOWEL SIGN O")
(70721 . "NEWA VOWEL SIGN AU")
(70722 . "NEWA SIGN VIRAMA")
(70723 . "NEWA SIGN CANDRABINDU")
(70724 . "NEWA SIGN ANUSVARA")
(70725 . "NEWA SIGN VISARGA")
(70726 . "NEWA SIGN NUKTA")
(70727 . "NEWA SIGN AVAGRAHA")
(70728 . "NEWA SIGN FINAL ANUSVARA")
(70729 . "NEWA OM")
(70730 . "NEWA SIDDHI")
(70731 . "NEWA DANDA")
(70732 . "NEWA DOUBLE DANDA")
(70733 . "NEWA COMMA")
(70734 . "NEWA GAP FILLER")
(70735 . "NEWA ABBREVIATION SIGN")
(70736 . "NEWA DIGIT ZERO")
(70737 . "NEWA DIGIT ONE")
(70738 . "NEWA DIGIT TWO")
(70739 . "NEWA DIGIT THREE")
(70740 . "NEWA DIGIT FOUR")
(70741 . "NEWA DIGIT FIVE")
(70742 . "NEWA DIGIT SIX")
(70743 . "NEWA DIGIT SEVEN")
(70744 . "NEWA DIGIT EIGHT")
(70745 . "NEWA DIGIT NINE")
(70746 . #f)
(70747 . "NEWA PLACEHOLDER MARK")
(70748 . #f)
(70749 . "NEWA INSERTION SIGN")
((70750 . 70784) . #f)
(70784 . "TIRHUTA ANJI")
(70785 . "TIRHUTA LETTER A")
(70786 . "TIRHUTA LETTER AA")
(70787 . "TIRHUTA LETTER I")
(70788 . "TIRHUTA LETTER II")
(70789 . "TIRHUTA LETTER U")
(70790 . "TIRHUTA LETTER UU")
(70791 . "TIRHUTA LETTER VOCALIC R")
(70792 . "TIRHUTA LETTER VOCALIC RR")
(70793 . "TIRHUTA LETTER VOCALIC L")
(70794 . "TIRHUTA LETTER VOCALIC LL")
(70795 . "TIRHUTA LETTER E")
(70796 . "TIRHUTA LETTER AI")
(70797 . "TIRHUTA LETTER O")
(70798 . "TIRHUTA LETTER AU")
(70799 . "TIRHUTA LETTER KA")
(70800 . "TIRHUTA LETTER KHA")
(70801 . "TIRHUTA LETTER GA")
(70802 . "TIRHUTA LETTER GHA")
(70803 . "TIRHUTA LETTER NGA")
(70804 . "TIRHUTA LETTER CA")
(70805 . "TIRHUTA LETTER CHA")
(70806 . "TIRHUTA LETTER JA")
(70807 . "TIRHUTA LETTER JHA")
(70808 . "TIRHUTA LETTER NYA")
(70809 . "TIRHUTA LETTER TTA")
(70810 . "TIRHUTA LETTER TTHA")
(70811 . "TIRHUTA LETTER DDA")
(70812 . "TIRHUTA LETTER DDHA")
(70813 . "TIRHUTA LETTER NNA")
(70814 . "TIRHUTA LETTER TA")
(70815 . "TIRHUTA LETTER THA")
(70816 . "TIRHUTA LETTER DA")
(70817 . "TIRHUTA LETTER DHA")
(70818 . "TIRHUTA LETTER NA")
(70819 . "TIRHUTA LETTER PA")
(70820 . "TIRHUTA LETTER PHA")
(70821 . "TIRHUTA LETTER BA")
(70822 . "TIRHUTA LETTER BHA")
(70823 . "TIRHUTA LETTER MA")
(70824 . "TIRHUTA LETTER YA")
(70825 . "TIRHUTA LETTER RA")
(70826 . "TIRHUTA LETTER LA")
(70827 . "TIRHUTA LETTER VA")
(70828 . "TIRHUTA LETTER SHA")
(70829 . "TIRHUTA LETTER SSA")
(70830 . "TIRHUTA LETTER SA")
(70831 . "TIRHUTA LETTER HA")
(70832 . "TIRHUTA VOWEL SIGN AA")
(70833 . "TIRHUTA VOWEL SIGN I")
(70834 . "TIRHUTA VOWEL SIGN II")
(70835 . "TIRHUTA VOWEL SIGN U")
(70836 . "TIRHUTA VOWEL SIGN UU")
(70837 . "TIRHUTA VOWEL SIGN VOCALIC R")
(70838 . "TIRHUTA VOWEL SIGN VOCALIC RR")
(70839 . "TIRHUTA VOWEL SIGN VOCALIC L")
(70840 . "TIRHUTA VOWEL SIGN VOCALIC LL")
(70841 . "TIRHUTA VOWEL SIGN E")
(70842 . "TIRHUTA VOWEL SIGN SHORT E")
(70843 . "TIRHUTA VOWEL SIGN AI")
(70844 . "TIRHUTA VOWEL SIGN O")
(70845 . "TIRHUTA VOWEL SIGN SHORT O")
(70846 . "TIRHUTA VOWEL SIGN AU")
(70847 . "TIRHUTA SIGN CANDRABINDU")
(70848 . "TIRHUTA SIGN ANUSVARA")
(70849 . "TIRHUTA SIGN VISARGA")
(70850 . "TIRHUTA SIGN VIRAMA")
(70851 . "TIRHUTA SIGN NUKTA")
(70852 . "TIRHUTA SIGN AVAGRAHA")
(70853 . "TIRHUTA GVANG")
(70854 . "TIRHUTA ABBREVIATION SIGN")
(70855 . "TIRHUTA OM")
((70856 . 70864) . #f)
(70864 . "TIRHUTA DIGIT ZERO")
(70865 . "TIRHUTA DIGIT ONE")
(70866 . "TIRHUTA DIGIT TWO")
(70867 . "TIRHUTA DIGIT THREE")
(70868 . "TIRHUTA DIGIT FOUR")
(70869 . "TIRHUTA DIGIT FIVE")
(70870 . "TIRHUTA DIGIT SIX")
(70871 . "TIRHUTA DIGIT SEVEN")
(70872 . "TIRHUTA DIGIT EIGHT")
(70873 . "TIRHUTA DIGIT NINE")
((70874 . 71040) . #f)
(71040 . "SIDDHAM LETTER A")
(71041 . "SIDDHAM LETTER AA")
(71042 . "SIDDHAM LETTER I")
(71043 . "SIDDHAM LETTER II")
(71044 . "SIDDHAM LETTER U")
(71045 . "SIDDHAM LETTER UU")
(71046 . "SIDDHAM LETTER VOCALIC R")
(71047 . "SIDDHAM LETTER VOCALIC RR")
(71048 . "SIDDHAM LETTER VOCALIC L")
(71049 . "SIDDHAM LETTER VOCALIC LL")
(71050 . "SIDDHAM LETTER E")
(71051 . "SIDDHAM LETTER AI")
(71052 . "SIDDHAM LETTER O")
(71053 . "SIDDHAM LETTER AU")
(71054 . "SIDDHAM LETTER KA")
(71055 . "SIDDHAM LETTER KHA")
(71056 . "SIDDHAM LETTER GA")
(71057 . "SIDDHAM LETTER GHA")
(71058 . "SIDDHAM LETTER NGA")
(71059 . "SIDDHAM LETTER CA")
(71060 . "SIDDHAM LETTER CHA")
(71061 . "SIDDHAM LETTER JA")
(71062 . "SIDDHAM LETTER JHA")
(71063 . "SIDDHAM LETTER NYA")
(71064 . "SIDDHAM LETTER TTA")
(71065 . "SIDDHAM LETTER TTHA")
(71066 . "SIDDHAM LETTER DDA")
(71067 . "SIDDHAM LETTER DDHA")
(71068 . "SIDDHAM LETTER NNA")
(71069 . "SIDDHAM LETTER TA")
(71070 . "SIDDHAM LETTER THA")
(71071 . "SIDDHAM LETTER DA")
(71072 . "SIDDHAM LETTER DHA")
(71073 . "SIDDHAM LETTER NA")
(71074 . "SIDDHAM LETTER PA")
(71075 . "SIDDHAM LETTER PHA")
(71076 . "SIDDHAM LETTER BA")
(71077 . "SIDDHAM LETTER BHA")
(71078 . "SIDDHAM LETTER MA")
(71079 . "SIDDHAM LETTER YA")
(71080 . "SIDDHAM LETTER RA")
(71081 . "SIDDHAM LETTER LA")
(71082 . "SIDDHAM LETTER VA")
(71083 . "SIDDHAM LETTER SHA")
(71084 . "SIDDHAM LETTER SSA")
(71085 . "SIDDHAM LETTER SA")
(71086 . "SIDDHAM LETTER HA")
(71087 . "SIDDHAM VOWEL SIGN AA")
(71088 . "SIDDHAM VOWEL SIGN I")
(71089 . "SIDDHAM VOWEL SIGN II")
(71090 . "SIDDHAM VOWEL SIGN U")
(71091 . "SIDDHAM VOWEL SIGN UU")
(71092 . "SIDDHAM VOWEL SIGN VOCALIC R")
(71093 . "SIDDHAM VOWEL SIGN VOCALIC RR")
((71094 . 71096) . #f)
(71096 . "SIDDHAM VOWEL SIGN E")
(71097 . "SIDDHAM VOWEL SIGN AI")
(71098 . "SIDDHAM VOWEL SIGN O")
(71099 . "SIDDHAM VOWEL SIGN AU")
(71100 . "SIDDHAM SIGN CANDRABINDU")
(71101 . "SIDDHAM SIGN ANUSVARA")
(71102 . "SIDDHAM SIGN VISARGA")
(71103 . "SIDDHAM SIGN VIRAMA")
(71104 . "SIDDHAM SIGN NUKTA")
(71105 . "SIDDHAM SIGN SIDDHAM")
(71106 . "SIDDHAM DANDA")
(71107 . "SIDDHAM DOUBLE DANDA")
(71108 . "SIDDHAM SEPARATOR DOT")
(71109 . "SIDDHAM SEPARATOR BAR")
(71110 . "SIDDHAM REPETITION MARK-1")
(71111 . "SIDDHAM REPETITION MARK-2")
(71112 . "SIDDHAM REPETITION MARK-3")
(71113 . "SIDDHAM END OF TEXT MARK")
(71114 . "SIDDHAM SECTION MARK WITH TRIDENT AND U-SHAPED ORNAMENTS")
(71115 . "SIDDHAM SECTION MARK WITH TRIDENT AND DOTTED CRESCENTS")
(71116 . "SIDDHAM SECTION MARK WITH RAYS AND DOTTED CRESCENTS")
(71117 . "SIDDHAM SECTION MARK WITH RAYS AND DOTTED DOUBLE CRESCENTS")
(71118 . "SIDDHAM SECTION MARK WITH RAYS AND DOTTED TRIPLE CRESCENTS")
(71119 . "SIDDHAM SECTION MARK DOUBLE RING")
(71120 . "SIDDHAM SECTION MARK DOUBLE RING WITH RAYS")
(71121 . "SIDDHAM SECTION MARK WITH DOUBLE CRESCENTS")
(71122 . "SIDDHAM SECTION MARK WITH TRIPLE CRESCENTS")
(71123 . "SIDDHAM SECTION MARK WITH QUADRUPLE CRESCENTS")
(71124 . "SIDDHAM SECTION MARK WITH SEPTUPLE CRESCENTS")
(71125 . "SIDDHAM SECTION MARK WITH CIRCLES AND RAYS")
(71126 . "SIDDHAM SECTION MARK WITH CIRCLES AND TWO ENCLOSURES")
(71127 . "SIDDHAM SECTION MARK WITH CIRCLES AND FOUR ENCLOSURES")
(71128 . "SIDDHAM LETTER THREE-CIRCLE ALTERNATE I")
(71129 . "SIDDHAM LETTER TWO-CIRCLE ALTERNATE I")
(71130 . "SIDDHAM LETTER TWO-CIRCLE ALTERNATE II")
(71131 . "SIDDHAM LETTER ALTERNATE U")
(71132 . "SIDDHAM VOWEL SIGN ALTERNATE U")
(71133 . "SIDDHAM VOWEL SIGN ALTERNATE UU")
((71134 . 71168) . #f)
(71168 . "MODI LETTER A")
(71169 . "MODI LETTER AA")
(71170 . "MODI LETTER I")
(71171 . "MODI LETTER II")
(71172 . "MODI LETTER U")
(71173 . "MODI LETTER UU")
(71174 . "MODI LETTER VOCALIC R")
(71175 . "MODI LETTER VOCALIC RR")
(71176 . "MODI LETTER VOCALIC L")
(71177 . "MODI LETTER VOCALIC LL")
(71178 . "MODI LETTER E")
(71179 . "MODI LETTER AI")
(71180 . "MODI LETTER O")
(71181 . "MODI LETTER AU")
(71182 . "MODI LETTER KA")
(71183 . "MODI LETTER KHA")
(71184 . "MODI LETTER GA")
(71185 . "MODI LETTER GHA")
(71186 . "MODI LETTER NGA")
(71187 . "MODI LETTER CA")
(71188 . "MODI LETTER CHA")
(71189 . "MODI LETTER JA")
(71190 . "MODI LETTER JHA")
(71191 . "MODI LETTER NYA")
(71192 . "MODI LETTER TTA")
(71193 . "MODI LETTER TTHA")
(71194 . "MODI LETTER DDA")
(71195 . "MODI LETTER DDHA")
(71196 . "MODI LETTER NNA")
(71197 . "MODI LETTER TA")
(71198 . "MODI LETTER THA")
(71199 . "MODI LETTER DA")
(71200 . "MODI LETTER DHA")
(71201 . "MODI LETTER NA")
(71202 . "MODI LETTER PA")
(71203 . "MODI LETTER PHA")
(71204 . "MODI LETTER BA")
(71205 . "MODI LETTER BHA")
(71206 . "MODI LETTER MA")
(71207 . "MODI LETTER YA")
(71208 . "MODI LETTER RA")
(71209 . "MODI LETTER LA")
(71210 . "MODI LETTER VA")
(71211 . "MODI LETTER SHA")
(71212 . "MODI LETTER SSA")
(71213 . "MODI LETTER SA")
(71214 . "MODI LETTER HA")
(71215 . "MODI LETTER LLA")
(71216 . "MODI VOWEL SIGN AA")
(71217 . "MODI VOWEL SIGN I")
(71218 . "MODI VOWEL SIGN II")
(71219 . "MODI VOWEL SIGN U")
(71220 . "MODI VOWEL SIGN UU")
(71221 . "MODI VOWEL SIGN VOCALIC R")
(71222 . "MODI VOWEL SIGN VOCALIC RR")
(71223 . "MODI VOWEL SIGN VOCALIC L")
(71224 . "MODI VOWEL SIGN VOCALIC LL")
(71225 . "MODI VOWEL SIGN E")
(71226 . "MODI VOWEL SIGN AI")
(71227 . "MODI VOWEL SIGN O")
(71228 . "MODI VOWEL SIGN AU")
(71229 . "MODI SIGN ANUSVARA")
(71230 . "MODI SIGN VISARGA")
(71231 . "MODI SIGN VIRAMA")
(71232 . "MODI SIGN ARDHACANDRA")
(71233 . "MODI DANDA")
(71234 . "MODI DOUBLE DANDA")
(71235 . "MODI ABBREVIATION SIGN")
(71236 . "MODI SIGN HUVA")
((71237 . 71248) . #f)
(71248 . "MODI DIGIT ZERO")
(71249 . "MODI DIGIT ONE")
(71250 . "MODI DIGIT TWO")
(71251 . "MODI DIGIT THREE")
(71252 . "MODI DIGIT FOUR")
(71253 . "MODI DIGIT FIVE")
(71254 . "MODI DIGIT SIX")
(71255 . "MODI DIGIT SEVEN")
(71256 . "MODI DIGIT EIGHT")
(71257 . "MODI DIGIT NINE")
((71258 . 71264) . #f)
(71264 . "MONGOLIAN BIRGA WITH ORNAMENT")
(71265 . "MONGOLIAN ROTATED BIRGA")
(71266 . "MONGOLIAN DOUBLE BIRGA WITH ORNAMENT")
(71267 . "MONGOLIAN TRIPLE BIRGA WITH ORNAMENT")
(71268 . "MONGOLIAN BIRGA WITH DOUBLE ORNAMENT")
(71269 . "MONGOLIAN ROTATED BIRGA WITH ORNAMENT")
(71270 . "MONGOLIAN ROTATED BIRGA WITH DOUBLE ORNAMENT")
(71271 . "MONGOLIAN INVERTED BIRGA")
(71272 . "MONGOLIAN INVERTED BIRGA WITH DOUBLE ORNAMENT")
(71273 . "MONGOLIAN SWIRL BIRGA")
(71274 . "MONGOLIAN SWIRL BIRGA WITH ORNAMENT")
(71275 . "MONGOLIAN SWIRL BIRGA WITH DOUBLE ORNAMENT")
(71276 . "MONGOLIAN TURNED SWIRL BIRGA WITH DOUBLE ORNAMENT")
((71277 . 71296) . #f)
(71296 . "TAKRI LETTER A")
(71297 . "TAKRI LETTER AA")
(71298 . "TAKRI LETTER I")
(71299 . "TAKRI LETTER II")
(71300 . "TAKRI LETTER U")
(71301 . "TAKRI LETTER UU")
(71302 . "TAKRI LETTER E")
(71303 . "TAKRI LETTER AI")
(71304 . "TAKRI LETTER O")
(71305 . "TAKRI LETTER AU")
(71306 . "TAKRI LETTER KA")
(71307 . "TAKRI LETTER KHA")
(71308 . "TAKRI LETTER GA")
(71309 . "TAKRI LETTER GHA")
(71310 . "TAKRI LETTER NGA")
(71311 . "TAKRI LETTER CA")
(71312 . "TAKRI LETTER CHA")
(71313 . "TAKRI LETTER JA")
(71314 . "TAKRI LETTER JHA")
(71315 . "TAKRI LETTER NYA")
(71316 . "TAKRI LETTER TTA")
(71317 . "TAKRI LETTER TTHA")
(71318 . "TAKRI LETTER DDA")
(71319 . "TAKRI LETTER DDHA")
(71320 . "TAKRI LETTER NNA")
(71321 . "TAKRI LETTER TA")
(71322 . "TAKRI LETTER THA")
(71323 . "TAKRI LETTER DA")
(71324 . "TAKRI LETTER DHA")
(71325 . "TAKRI LETTER NA")
(71326 . "TAKRI LETTER PA")
(71327 . "TAKRI LETTER PHA")
(71328 . "TAKRI LETTER BA")
(71329 . "TAKRI LETTER BHA")
(71330 . "TAKRI LETTER MA")
(71331 . "TAKRI LETTER YA")
(71332 . "TAKRI LETTER RA")
(71333 . "TAKRI LETTER LA")
(71334 . "TAKRI LETTER VA")
(71335 . "TAKRI LETTER SHA")
(71336 . "TAKRI LETTER SA")
(71337 . "TAKRI LETTER HA")
(71338 . "TAKRI LETTER RRA")
(71339 . "TAKRI SIGN ANUSVARA")
(71340 . "TAKRI SIGN VISARGA")
(71341 . "TAKRI VOWEL SIGN AA")
(71342 . "TAKRI VOWEL SIGN I")
(71343 . "TAKRI VOWEL SIGN II")
(71344 . "TAKRI VOWEL SIGN U")
(71345 . "TAKRI VOWEL SIGN UU")
(71346 . "TAKRI VOWEL SIGN E")
(71347 . "TAKRI VOWEL SIGN AI")
(71348 . "TAKRI VOWEL SIGN O")
(71349 . "TAKRI VOWEL SIGN AU")
(71350 . "TAKRI SIGN VIRAMA")
(71351 . "TAKRI SIGN NUKTA")
((71352 . 71360) . #f)
(71360 . "TAKRI DIGIT ZERO")
(71361 . "TAKRI DIGIT ONE")
(71362 . "TAKRI DIGIT TWO")
(71363 . "TAKRI DIGIT THREE")
(71364 . "TAKRI DIGIT FOUR")
(71365 . "TAKRI DIGIT FIVE")
(71366 . "TAKRI DIGIT SIX")
(71367 . "TAKRI DIGIT SEVEN")
(71368 . "TAKRI DIGIT EIGHT")
(71369 . "TAKRI DIGIT NINE")
((71370 . 71424) . #f)
(71424 . "AHOM LETTER KA")
(71425 . "AHOM LETTER KHA")
(71426 . "AHOM LETTER NGA")
(71427 . "AHOM LETTER NA")
(71428 . "AHOM LETTER TA")
(71429 . "AHOM LETTER ALTERNATE TA")
(71430 . "AHOM LETTER PA")
(71431 . "AHOM LETTER PHA")
(71432 . "AHOM LETTER BA")
(71433 . "AHOM LETTER MA")
(71434 . "AHOM LETTER JA")
(71435 . "AHOM LETTER CHA")
(71436 . "AHOM LETTER THA")
(71437 . "AHOM LETTER RA")
(71438 . "AHOM LETTER LA")
(71439 . "AHOM LETTER SA")
(71440 . "AHOM LETTER NYA")
(71441 . "AHOM LETTER HA")
(71442 . "AHOM LETTER A")
(71443 . "AHOM LETTER DA")
(71444 . "AHOM LETTER DHA")
(71445 . "AHOM LETTER GA")
(71446 . "AHOM LETTER ALTERNATE GA")
(71447 . "AHOM LETTER GHA")
(71448 . "AHOM LETTER BHA")
(71449 . "AHOM LETTER JHA")
((71450 . 71453) . #f)
(71453 . "AHOM CONSONANT SIGN MEDIAL LA")
(71454 . "AHOM CONSONANT SIGN MEDIAL RA")
(71455 . "AHOM CONSONANT SIGN MEDIAL LIGATING RA")
(71456 . "AHOM VOWEL SIGN A")
(71457 . "AHOM VOWEL SIGN AA")
(71458 . "AHOM VOWEL SIGN I")
(71459 . "AHOM VOWEL SIGN II")
(71460 . "AHOM VOWEL SIGN U")
(71461 . "AHOM VOWEL SIGN UU")
(71462 . "AHOM VOWEL SIGN E")
(71463 . "AHOM VOWEL SIGN AW")
(71464 . "AHOM VOWEL SIGN O")
(71465 . "AHOM VOWEL SIGN AI")
(71466 . "AHOM VOWEL SIGN AM")
(71467 . "AHOM SIGN KILLER")
((71468 . 71472) . #f)
(71472 . "AHOM DIGIT ZERO")
(71473 . "AHOM DIGIT ONE")
(71474 . "AHOM DIGIT TWO")
(71475 . "AHOM DIGIT THREE")
(71476 . "AHOM DIGIT FOUR")
(71477 . "AHOM DIGIT FIVE")
(71478 . "AHOM DIGIT SIX")
(71479 . "AHOM DIGIT SEVEN")
(71480 . "AHOM DIGIT EIGHT")
(71481 . "AHOM DIGIT NINE")
(71482 . "AHOM NUMBER TEN")
(71483 . "AHOM NUMBER TWENTY")
(71484 . "AHOM SIGN SMALL SECTION")
(71485 . "AHOM SIGN SECTION")
(71486 . "AHOM SIGN RULAI")
(71487 . "AHOM SYMBOL VI")
((71488 . 71840) . #f)
(71840 . "WARANG CITI CAPITAL LETTER NGAA")
(71841 . "WARANG CITI CAPITAL LETTER A")
(71842 . "WARANG CITI CAPITAL LETTER WI")
(71843 . "WARANG CITI CAPITAL LETTER YU")
(71844 . "WARANG CITI CAPITAL LETTER YA")
(71845 . "WARANG CITI CAPITAL LETTER YO")
(71846 . "WARANG CITI CAPITAL LETTER II")
(71847 . "WARANG CITI CAPITAL LETTER UU")
(71848 . "WARANG CITI CAPITAL LETTER E")
(71849 . "WARANG CITI CAPITAL LETTER O")
(71850 . "WARANG CITI CAPITAL LETTER ANG")
(71851 . "WARANG CITI CAPITAL LETTER GA")
(71852 . "WARANG CITI CAPITAL LETTER KO")
(71853 . "WARANG CITI CAPITAL LETTER ENY")
(71854 . "WARANG CITI CAPITAL LETTER YUJ")
(71855 . "WARANG CITI CAPITAL LETTER UC")
(71856 . "WARANG CITI CAPITAL LETTER ENN")
(71857 . "WARANG CITI CAPITAL LETTER ODD")
(71858 . "WARANG CITI CAPITAL LETTER TTE")
(71859 . "WARANG CITI CAPITAL LETTER NUNG")
(71860 . "WARANG CITI CAPITAL LETTER DA")
(71861 . "WARANG CITI CAPITAL LETTER AT")
(71862 . "WARANG CITI CAPITAL LETTER AM")
(71863 . "WARANG CITI CAPITAL LETTER BU")
(71864 . "WARANG CITI CAPITAL LETTER PU")
(71865 . "WARANG CITI CAPITAL LETTER HIYO")
(71866 . "WARANG CITI CAPITAL LETTER HOLO")
(71867 . "WARANG CITI CAPITAL LETTER HORR")
(71868 . "WARANG CITI CAPITAL LETTER HAR")
(71869 . "WARANG CITI CAPITAL LETTER SSUU")
(71870 . "WARANG CITI CAPITAL LETTER SII")
(71871 . "WARANG CITI CAPITAL LETTER VIYO")
(71872 . "WARANG CITI SMALL LETTER NGAA")
(71873 . "WARANG CITI SMALL LETTER A")
(71874 . "WARANG CITI SMALL LETTER WI")
(71875 . "WARANG CITI SMALL LETTER YU")
(71876 . "WARANG CITI SMALL LETTER YA")
(71877 . "WARANG CITI SMALL LETTER YO")
(71878 . "WARANG CITI SMALL LETTER II")
(71879 . "WARANG CITI SMALL LETTER UU")
(71880 . "WARANG CITI SMALL LETTER E")
(71881 . "WARANG CITI SMALL LETTER O")
(71882 . "WARANG CITI SMALL LETTER ANG")
(71883 . "WARANG CITI SMALL LETTER GA")
(71884 . "WARANG CITI SMALL LETTER KO")
(71885 . "WARANG CITI SMALL LETTER ENY")
(71886 . "WARANG CITI SMALL LETTER YUJ")
(71887 . "WARANG CITI SMALL LETTER UC")
(71888 . "WARANG CITI SMALL LETTER ENN")
(71889 . "WARANG CITI SMALL LETTER ODD")
(71890 . "WARANG CITI SMALL LETTER TTE")
(71891 . "WARANG CITI SMALL LETTER NUNG")
(71892 . "WARANG CITI SMALL LETTER DA")
(71893 . "WARANG CITI SMALL LETTER AT")
(71894 . "WARANG CITI SMALL LETTER AM")
(71895 . "WARANG CITI SMALL LETTER BU")
(71896 . "WARANG CITI SMALL LETTER PU")
(71897 . "WARANG CITI SMALL LETTER HIYO")
(71898 . "WARANG CITI SMALL LETTER HOLO")
(71899 . "WARANG CITI SMALL LETTER HORR")
(71900 . "WARANG CITI SMALL LETTER HAR")
(71901 . "WARANG CITI SMALL LETTER SSUU")
(71902 . "WARANG CITI SMALL LETTER SII")
(71903 . "WARANG CITI SMALL LETTER VIYO")
(71904 . "WARANG CITI DIGIT ZERO")
(71905 . "WARANG CITI DIGIT ONE")
(71906 . "WARANG CITI DIGIT TWO")
(71907 . "WARANG CITI DIGIT THREE")
(71908 . "WARANG CITI DIGIT FOUR")
(71909 . "WARANG CITI DIGIT FIVE")
(71910 . "WARANG CITI DIGIT SIX")
(71911 . "WARANG CITI DIGIT SEVEN")
(71912 . "WARANG CITI DIGIT EIGHT")
(71913 . "WARANG CITI DIGIT NINE")
(71914 . "WARANG CITI NUMBER TEN")
(71915 . "WARANG CITI NUMBER TWENTY")
(71916 . "WARANG CITI NUMBER THIRTY")
(71917 . "WARANG CITI NUMBER FORTY")
(71918 . "WARANG CITI NUMBER FIFTY")
(71919 . "WARANG CITI NUMBER SIXTY")
(71920 . "WARANG CITI NUMBER SEVENTY")
(71921 . "WARANG CITI NUMBER EIGHTY")
(71922 . "WARANG CITI NUMBER NINETY")
((71923 . 71935) . #f)
(71935 . "WARANG CITI OM")
((71936 . 72384) . #f)
(72384 . "PAU CIN HAU LETTER PA")
(72385 . "PAU CIN HAU LETTER KA")
(72386 . "PAU CIN HAU LETTER LA")
(72387 . "PAU CIN HAU LETTER MA")
(72388 . "PAU CIN HAU LETTER DA")
(72389 . "PAU CIN HAU LETTER ZA")
(72390 . "PAU CIN HAU LETTER VA")
(72391 . "PAU CIN HAU LETTER NGA")
(72392 . "PAU CIN HAU LETTER HA")
(72393 . "PAU CIN HAU LETTER GA")
(72394 . "PAU CIN HAU LETTER KHA")
(72395 . "PAU CIN HAU LETTER SA")
(72396 . "PAU CIN HAU LETTER BA")
(72397 . "PAU CIN HAU LETTER CA")
(72398 . "PAU CIN HAU LETTER TA")
(72399 . "PAU CIN HAU LETTER THA")
(72400 . "PAU CIN HAU LETTER NA")
(72401 . "PAU CIN HAU LETTER PHA")
(72402 . "PAU CIN HAU LETTER RA")
(72403 . "PAU CIN HAU LETTER FA")
(72404 . "PAU CIN HAU LETTER CHA")
(72405 . "PAU CIN HAU LETTER A")
(72406 . "PAU CIN HAU LETTER E")
(72407 . "PAU CIN HAU LETTER I")
(72408 . "PAU CIN HAU LETTER O")
(72409 . "PAU CIN HAU LETTER U")
(72410 . "PAU CIN HAU LETTER UA")
(72411 . "PAU CIN HAU LETTER IA")
(72412 . "PAU CIN HAU LETTER FINAL P")
(72413 . "PAU CIN HAU LETTER FINAL K")
(72414 . "PAU CIN HAU LETTER FINAL T")
(72415 . "PAU CIN HAU LETTER FINAL M")
(72416 . "PAU CIN HAU LETTER FINAL N")
(72417 . "PAU CIN HAU LETTER FINAL L")
(72418 . "PAU CIN HAU LETTER FINAL W")
(72419 . "PAU CIN HAU LETTER FINAL NG")
(72420 . "PAU CIN HAU LETTER FINAL Y")
(72421 . "PAU CIN HAU RISING TONE LONG")
(72422 . "PAU CIN HAU RISING TONE")
(72423 . "PAU CIN HAU SANDHI GLOTTAL STOP")
(72424 . "PAU CIN HAU RISING TONE LONG FINAL")
(72425 . "PAU CIN HAU RISING TONE FINAL")
(72426 . "PAU CIN HAU SANDHI GLOTTAL STOP FINAL")
(72427 . "PAU CIN HAU SANDHI TONE LONG")
(72428 . "PAU CIN HAU SANDHI TONE")
(72429 . "PAU CIN HAU SANDHI TONE LONG FINAL")
(72430 . "PAU CIN HAU SANDHI TONE FINAL")
(72431 . "PAU CIN HAU MID-LEVEL TONE")
(72432 . "PAU CIN HAU GLOTTAL STOP VARIANT")
(72433 . "PAU CIN HAU MID-LEVEL TONE LONG FINAL")
(72434 . "PAU CIN HAU MID-LEVEL TONE FINAL")
(72435 . "PAU CIN HAU LOW-FALLING TONE LONG")
(72436 . "PAU CIN HAU LOW-FALLING TONE")
(72437 . "PAU CIN HAU GLOTTAL STOP")
(72438 . "PAU CIN HAU LOW-FALLING TONE LONG FINAL")
(72439 . "PAU CIN HAU LOW-FALLING TONE FINAL")
(72440 . "PAU CIN HAU GLOTTAL STOP FINAL")
((72441 . 72704) . #f)
(72704 . "BHAIKSUKI LETTER A")
(72705 . "BHAIKSUKI LETTER AA")
(72706 . "BHAIKSUKI LETTER I")
(72707 . "BHAIKSUKI LETTER II")
(72708 . "BHAIKSUKI LETTER U")
(72709 . "BHAIKSUKI LETTER UU")
(72710 . "BHAIKSUKI LETTER VOCALIC R")
(72711 . "BHAIKSUKI LETTER VOCALIC RR")
(72712 . "BHAIKSUKI LETTER VOCALIC L")
(72713 . #f)
(72714 . "BHAIKSUKI LETTER E")
(72715 . "BHAIKSUKI LETTER AI")
(72716 . "BHAIKSUKI LETTER O")
(72717 . "BHAIKSUKI LETTER AU")
(72718 . "BHAIKSUKI LETTER KA")
(72719 . "BHAIKSUKI LETTER KHA")
(72720 . "BHAIKSUKI LETTER GA")
(72721 . "BHAIKSUKI LETTER GHA")
(72722 . "BHAIKSUKI LETTER NGA")
(72723 . "BHAIKSUKI LETTER CA")
(72724 . "BHAIKSUKI LETTER CHA")
(72725 . "BHAIKSUKI LETTER JA")
(72726 . "BHAIKSUKI LETTER JHA")
(72727 . "BHAIKSUKI LETTER NYA")
(72728 . "BHAIKSUKI LETTER TTA")
(72729 . "BHAIKSUKI LETTER TTHA")
(72730 . "BHAIKSUKI LETTER DDA")
(72731 . "BHAIKSUKI LETTER DDHA")
(72732 . "BHAIKSUKI LETTER NNA")
(72733 . "BHAIKSUKI LETTER TA")
(72734 . "BHAIKSUKI LETTER THA")
(72735 . "BHAIKSUKI LETTER DA")
(72736 . "BHAIKSUKI LETTER DHA")
(72737 . "BHAIKSUKI LETTER NA")
(72738 . "BHAIKSUKI LETTER PA")
(72739 . "BHAIKSUKI LETTER PHA")
(72740 . "BHAIKSUKI LETTER BA")
(72741 . "BHAIKSUKI LETTER BHA")
(72742 . "BHAIKSUKI LETTER MA")
(72743 . "BHAIKSUKI LETTER YA")
(72744 . "BHAIKSUKI LETTER RA")
(72745 . "BHAIKSUKI LETTER LA")
(72746 . "BHAIKSUKI LETTER VA")
(72747 . "BHAIKSUKI LETTER SHA")
(72748 . "BHAIKSUKI LETTER SSA")
(72749 . "BHAIKSUKI LETTER SA")
(72750 . "BHAIKSUKI LETTER HA")
(72751 . "BHAIKSUKI VOWEL SIGN AA")
(72752 . "BHAIKSUKI VOWEL SIGN I")
(72753 . "BHAIKSUKI VOWEL SIGN II")
(72754 . "BHAIKSUKI VOWEL SIGN U")
(72755 . "BHAIKSUKI VOWEL SIGN UU")
(72756 . "BHAIKSUKI VOWEL SIGN VOCALIC R")
(72757 . "BHAIKSUKI VOWEL SIGN VOCALIC RR")
(72758 . "BHAIKSUKI VOWEL SIGN VOCALIC L")
(72759 . #f)
(72760 . "BHAIKSUKI VOWEL SIGN E")
(72761 . "BHAIKSUKI VOWEL SIGN AI")
(72762 . "BHAIKSUKI VOWEL SIGN O")
(72763 . "BHAIKSUKI VOWEL SIGN AU")
(72764 . "BHAIKSUKI SIGN CANDRABINDU")
(72765 . "BHAIKSUKI SIGN ANUSVARA")
(72766 . "BHAIKSUKI SIGN VISARGA")
(72767 . "BHAIKSUKI SIGN VIRAMA")
(72768 . "BHAIKSUKI SIGN AVAGRAHA")
(72769 . "BHAIKSUKI DANDA")
(72770 . "BHAIKSUKI DOUBLE DANDA")
(72771 . "BHAIKSUKI WORD SEPARATOR")
(72772 . "BHAIKSUKI GAP FILLER-1")
(72773 . "BHAIKSUKI GAP FILLER-2")
((72774 . 72784) . #f)
(72784 . "BHAIKSUKI DIGIT ZERO")
(72785 . "BHAIKSUKI DIGIT ONE")
(72786 . "BHAIKSUKI DIGIT TWO")
(72787 . "BHAIKSUKI DIGIT THREE")
(72788 . "BHAIKSUKI DIGIT FOUR")
(72789 . "BHAIKSUKI DIGIT FIVE")
(72790 . "BHAIKSUKI DIGIT SIX")
(72791 . "BHAIKSUKI DIGIT SEVEN")
(72792 . "BHAIKSUKI DIGIT EIGHT")
(72793 . "BHAIKSUKI DIGIT NINE")
(72794 . "BHAIKSUKI NUMBER ONE")
(72795 . "BHAIKSUKI NUMBER TWO")
(72796 . "BHAIKSUKI NUMBER THREE")
(72797 . "BHAIKSUKI NUMBER FOUR")
(72798 . "BHAIKSUKI NUMBER FIVE")
(72799 . "BHAIKSUKI NUMBER SIX")
(72800 . "BHAIKSUKI NUMBER SEVEN")
(72801 . "BHAIKSUKI NUMBER EIGHT")
(72802 . "BHAIKSUKI NUMBER NINE")
(72803 . "BHAIKSUKI NUMBER TEN")
(72804 . "BHAIKSUKI NUMBER TWENTY")
(72805 . "BHAIKSUKI NUMBER THIRTY")
(72806 . "BHAIKSUKI NUMBER FORTY")
(72807 . "BHAIKSUKI NUMBER FIFTY")
(72808 . "BHAIKSUKI NUMBER SIXTY")
(72809 . "BHAIKSUKI NUMBER SEVENTY")
(72810 . "BHAIKSUKI NUMBER EIGHTY")
(72811 . "BHAIKSUKI NUMBER NINETY")
(72812 . "BHAIKSUKI HUNDREDS UNIT MARK")
((72813 . 72816) . #f)
(72816 . "MARCHEN HEAD MARK")
(72817 . "MARCHEN MARK SHAD")
(72818 . "MARCHEN LETTER KA")
(72819 . "MARCHEN LETTER KHA")
(72820 . "MARCHEN LETTER GA")
(72821 . "MARCHEN LETTER NGA")
(72822 . "MARCHEN LETTER CA")
(72823 . "MARCHEN LETTER CHA")
(72824 . "MARCHEN LETTER JA")
(72825 . "MARCHEN LETTER NYA")
(72826 . "MARCHEN LETTER TA")
(72827 . "MARCHEN LETTER THA")
(72828 . "MARCHEN LETTER DA")
(72829 . "MARCHEN LETTER NA")
(72830 . "MARCHEN LETTER PA")
(72831 . "MARCHEN LETTER PHA")
(72832 . "MARCHEN LETTER BA")
(72833 . "MARCHEN LETTER MA")
(72834 . "MARCHEN LETTER TSA")
(72835 . "MARCHEN LETTER TSHA")
(72836 . "MARCHEN LETTER DZA")
(72837 . "MARCHEN LETTER WA")
(72838 . "MARCHEN LETTER ZHA")
(72839 . "MARCHEN LETTER ZA")
(72840 . "MARCHEN LETTER -A")
(72841 . "MARCHEN LETTER YA")
(72842 . "MARCHEN LETTER RA")
(72843 . "MARCHEN LETTER LA")
(72844 . "MARCHEN LETTER SHA")
(72845 . "MARCHEN LETTER SA")
(72846 . "MARCHEN LETTER HA")
(72847 . "MARCHEN LETTER A")
((72848 . 72850) . #f)
(72850 . "MARCHEN SUBJOINED LETTER KA")
(72851 . "MARCHEN SUBJOINED LETTER KHA")
(72852 . "MARCHEN SUBJOINED LETTER GA")
(72853 . "MARCHEN SUBJOINED LETTER NGA")
(72854 . "MARCHEN SUBJOINED LETTER CA")
(72855 . "MARCHEN SUBJOINED LETTER CHA")
(72856 . "MARCHEN SUBJOINED LETTER JA")
(72857 . "MARCHEN SUBJOINED LETTER NYA")
(72858 . "MARCHEN SUBJOINED LETTER TA")
(72859 . "MARCHEN SUBJOINED LETTER THA")
(72860 . "MARCHEN SUBJOINED LETTER DA")
(72861 . "MARCHEN SUBJOINED LETTER NA")
(72862 . "MARCHEN SUBJOINED LETTER PA")
(72863 . "MARCHEN SUBJOINED LETTER PHA")
(72864 . "MARCHEN SUBJOINED LETTER BA")
(72865 . "MARCHEN SUBJOINED LETTER MA")
(72866 . "MARCHEN SUBJOINED LETTER TSA")
(72867 . "MARCHEN SUBJOINED LETTER TSHA")
(72868 . "MARCHEN SUBJOINED LETTER DZA")
(72869 . "MARCHEN SUBJOINED LETTER WA")
(72870 . "MARCHEN SUBJOINED LETTER ZHA")
(72871 . "MARCHEN SUBJOINED LETTER ZA")
(72872 . #f)
(72873 . "MARCHEN SUBJOINED LETTER YA")
(72874 . "MARCHEN SUBJOINED LETTER RA")
(72875 . "MARCHEN SUBJOINED LETTER LA")
(72876 . "MARCHEN SUBJOINED LETTER SHA")
(72877 . "MARCHEN SUBJOINED LETTER SA")
(72878 . "MARCHEN SUBJOINED LETTER HA")
(72879 . "MARCHEN SUBJOINED LETTER A")
(72880 . "MARCHEN VOWEL SIGN AA")
(72881 . "MARCHEN VOWEL SIGN I")
(72882 . "MARCHEN VOWEL SIGN U")
(72883 . "MARCHEN VOWEL SIGN E")
(72884 . "MARCHEN VOWEL SIGN O")
(72885 . "MARCHEN SIGN ANUSVARA")
(72886 . "MARCHEN SIGN CANDRABINDU")
((72887 . 73728) . #f)
(73728 . "CUNEIFORM SIGN A")
(73729 . "CUNEIFORM SIGN A TIMES A")
(73730 . "CUNEIFORM SIGN A TIMES BAD")
(73731 . "CUNEIFORM SIGN A TIMES GAN2 TENU")
(73732 . "CUNEIFORM SIGN A TIMES HA")
(73733 . "CUNEIFORM SIGN A TIMES IGI")
(73734 . "CUNEIFORM SIGN A TIMES LAGAR GUNU")
(73735 . "CUNEIFORM SIGN A TIMES MUSH")
(73736 . "CUNEIFORM SIGN A TIMES SAG")
(73737 . "CUNEIFORM SIGN A2")
(73738 . "CUNEIFORM SIGN AB")
(73739 . "CUNEIFORM SIGN AB TIMES ASH2")
(73740 . "CUNEIFORM SIGN AB TIMES DUN3 GUNU")
(73741 . "CUNEIFORM SIGN AB TIMES GAL")
(73742 . "CUNEIFORM SIGN AB TIMES GAN2 TENU")
(73743 . "CUNEIFORM SIGN AB TIMES HA")
(73744 . "CUNEIFORM SIGN AB TIMES IGI GUNU")
(73745 . "CUNEIFORM SIGN AB TIMES IMIN")
(73746 . "CUNEIFORM SIGN AB TIMES LAGAB")
(73747 . "CUNEIFORM SIGN AB TIMES SHESH")
(73748 . "CUNEIFORM SIGN AB TIMES U PLUS U PLUS U")
(73749 . "CUNEIFORM SIGN AB GUNU")
(73750 . "CUNEIFORM SIGN AB2")
(73751 . "CUNEIFORM SIGN AB2 TIMES BALAG")
(73752 . "CUNEIFORM SIGN AB2 TIMES GAN2 TENU")
(73753 . "CUNEIFORM SIGN AB2 TIMES ME PLUS EN")
(73754 . "CUNEIFORM SIGN AB2 TIMES SHA3")
(73755 . "CUNEIFORM SIGN AB2 TIMES TAK4")
(73756 . "CUNEIFORM SIGN AD")
(73757 . "CUNEIFORM SIGN AK")
(73758 . "CUNEIFORM SIGN AK TIMES ERIN2")
(73759 . "CUNEIFORM SIGN AK TIMES SHITA PLUS GISH")
(73760 . "CUNEIFORM SIGN AL")
(73761 . "CUNEIFORM SIGN AL TIMES AL")
(73762 . "CUNEIFORM SIGN AL TIMES DIM2")
(73763 . "CUNEIFORM SIGN AL TIMES GISH")
(73764 . "CUNEIFORM SIGN AL TIMES HA")
(73765 . "CUNEIFORM SIGN AL TIMES KAD3")
(73766 . "CUNEIFORM SIGN AL TIMES KI")
(73767 . "CUNEIFORM SIGN AL TIMES SHE")
(73768 . "CUNEIFORM SIGN AL TIMES USH")
(73769 . "CUNEIFORM SIGN ALAN")
(73770 . "CUNEIFORM SIGN ALEPH")
(73771 . "CUNEIFORM SIGN AMAR")
(73772 . "CUNEIFORM SIGN AMAR TIMES SHE")
(73773 . "CUNEIFORM SIGN AN")
(73774 . "CUNEIFORM SIGN AN OVER AN")
(73775 . "CUNEIFORM SIGN AN THREE TIMES")
(73776 . "CUNEIFORM SIGN AN PLUS NAGA OPPOSING AN PLUS NAGA")
(73777 . "CUNEIFORM SIGN AN PLUS NAGA SQUARED")
(73778 . "CUNEIFORM SIGN ANSHE")
(73779 . "CUNEIFORM SIGN APIN")
(73780 . "CUNEIFORM SIGN ARAD")
(73781 . "CUNEIFORM SIGN ARAD TIMES KUR")
(73782 . "CUNEIFORM SIGN ARKAB")
(73783 . "CUNEIFORM SIGN ASAL2")
(73784 . "CUNEIFORM SIGN ASH")
(73785 . "CUNEIFORM SIGN ASH ZIDA TENU")
(73786 . "CUNEIFORM SIGN ASH KABA TENU")
(73787 . "CUNEIFORM SIGN ASH OVER ASH TUG2 OVER TUG2 TUG2 OVER TUG2 PAP")
(73788 . "CUNEIFORM SIGN ASH OVER ASH OVER ASH")
(73789 . "CUNEIFORM SIGN ASH OVER ASH OVER ASH CROSSING ASH OVER ASH OVER ASH")
(73790 . "CUNEIFORM SIGN ASH2")
(73791 . "CUNEIFORM SIGN ASHGAB")
(73792 . "CUNEIFORM SIGN BA")
(73793 . "CUNEIFORM SIGN BAD")
(73794 . "CUNEIFORM SIGN BAG3")
(73795 . "CUNEIFORM SIGN BAHAR2")
(73796 . "CUNEIFORM SIGN BAL")
(73797 . "CUNEIFORM SIGN BAL OVER BAL")
(73798 . "CUNEIFORM SIGN BALAG")
(73799 . "CUNEIFORM SIGN BAR")
(73800 . "CUNEIFORM SIGN BARA2")
(73801 . "CUNEIFORM SIGN BI")
(73802 . "CUNEIFORM SIGN BI TIMES A")
(73803 . "CUNEIFORM SIGN BI TIMES GAR")
(73804 . "CUNEIFORM SIGN BI TIMES IGI GUNU")
(73805 . "CUNEIFORM SIGN BU")
(73806 . "CUNEIFORM SIGN BU OVER BU AB")
(73807 . "CUNEIFORM SIGN BU OVER BU UN")
(73808 . "CUNEIFORM SIGN BU CROSSING BU")
(73809 . "CUNEIFORM SIGN BULUG")
(73810 . "CUNEIFORM SIGN BULUG OVER BULUG")
(73811 . "CUNEIFORM SIGN BUR")
(73812 . "CUNEIFORM SIGN BUR2")
(73813 . "CUNEIFORM SIGN DA")
(73814 . "CUNEIFORM SIGN DAG")
(73815 . "CUNEIFORM SIGN DAG KISIM5 TIMES A PLUS MASH")
(73816 . "CUNEIFORM SIGN DAG KISIM5 TIMES AMAR")
(73817 . "CUNEIFORM SIGN DAG KISIM5 TIMES BALAG")
(73818 . "CUNEIFORM SIGN DAG KISIM5 TIMES BI")
(73819 . "CUNEIFORM SIGN DAG KISIM5 TIMES GA")
(73820 . "CUNEIFORM SIGN DAG KISIM5 TIMES GA PLUS MASH")
(73821 . "CUNEIFORM SIGN DAG KISIM5 TIMES GI")
(73822 . "CUNEIFORM SIGN DAG KISIM5 TIMES GIR2")
(73823 . "CUNEIFORM SIGN DAG KISIM5 TIMES GUD")
(73824 . "CUNEIFORM SIGN DAG KISIM5 TIMES HA")
(73825 . "CUNEIFORM SIGN DAG KISIM5 TIMES IR")
(73826 . "CUNEIFORM SIGN DAG KISIM5 TIMES IR PLUS LU")
(73827 . "CUNEIFORM SIGN DAG KISIM5 TIMES KAK")
(73828 . "CUNEIFORM SIGN DAG KISIM5 TIMES LA")
(73829 . "CUNEIFORM SIGN DAG KISIM5 TIMES LU")
(73830 . "CUNEIFORM SIGN DAG KISIM5 TIMES LU PLUS MASH2")
(73831 . "CUNEIFORM SIGN DAG KISIM5 TIMES LUM")
(73832 . "CUNEIFORM SIGN DAG KISIM5 TIMES NE")
(73833 . "CUNEIFORM SIGN DAG KISIM5 TIMES PAP PLUS PAP")
(73834 . "CUNEIFORM SIGN DAG KISIM5 TIMES SI")
(73835 . "CUNEIFORM SIGN DAG KISIM5 TIMES TAK4")
(73836 . "CUNEIFORM SIGN DAG KISIM5 TIMES U2 PLUS GIR2")
(73837 . "CUNEIFORM SIGN DAG KISIM5 TIMES USH")
(73838 . "CUNEIFORM SIGN DAM")
(73839 . "CUNEIFORM SIGN DAR")
(73840 . "CUNEIFORM SIGN DARA3")
(73841 . "CUNEIFORM SIGN DARA4")
(73842 . "CUNEIFORM SIGN DI")
(73843 . "CUNEIFORM SIGN DIB")
(73844 . "CUNEIFORM SIGN DIM")
(73845 . "CUNEIFORM SIGN DIM TIMES SHE")
(73846 . "CUNEIFORM SIGN DIM2")
(73847 . "CUNEIFORM SIGN DIN")
(73848 . "CUNEIFORM SIGN DIN KASKAL U GUNU DISH")
(73849 . "CUNEIFORM SIGN DISH")
(73850 . "CUNEIFORM SIGN DU")
(73851 . "CUNEIFORM SIGN DU OVER DU")
(73852 . "CUNEIFORM SIGN DU GUNU")
(73853 . "CUNEIFORM SIGN DU SHESHIG")
(73854 . "CUNEIFORM SIGN DUB")
(73855 . "CUNEIFORM SIGN DUB TIMES ESH2")
(73856 . "CUNEIFORM SIGN DUB2")
(73857 . "CUNEIFORM SIGN DUG")
(73858 . "CUNEIFORM SIGN DUGUD")
(73859 . "CUNEIFORM SIGN DUH")
(73860 . "CUNEIFORM SIGN DUN")
(73861 . "CUNEIFORM SIGN DUN3")
(73862 . "CUNEIFORM SIGN DUN3 GUNU")
(73863 . "CUNEIFORM SIGN DUN3 GUNU GUNU")
(73864 . "CUNEIFORM SIGN DUN4")
(73865 . "CUNEIFORM SIGN DUR2")
(73866 . "CUNEIFORM SIGN E")
(73867 . "CUNEIFORM SIGN E TIMES PAP")
(73868 . "CUNEIFORM SIGN E OVER E NUN OVER NUN")
(73869 . "CUNEIFORM SIGN E2")
(73870 . "CUNEIFORM SIGN E2 TIMES A PLUS HA PLUS DA")
(73871 . "CUNEIFORM SIGN E2 TIMES GAR")
(73872 . "CUNEIFORM SIGN E2 TIMES MI")
(73873 . "CUNEIFORM SIGN E2 TIMES SAL")
(73874 . "CUNEIFORM SIGN E2 TIMES SHE")
(73875 . "CUNEIFORM SIGN E2 TIMES U")
(73876 . "CUNEIFORM SIGN EDIN")
(73877 . "CUNEIFORM SIGN EGIR")
(73878 . "CUNEIFORM SIGN EL")
(73879 . "CUNEIFORM SIGN EN")
(73880 . "CUNEIFORM SIGN EN TIMES GAN2")
(73881 . "CUNEIFORM SIGN EN TIMES GAN2 TENU")
(73882 . "CUNEIFORM SIGN EN TIMES ME")
(73883 . "CUNEIFORM SIGN EN CROSSING EN")
(73884 . "CUNEIFORM SIGN EN OPPOSING EN")
(73885 . "CUNEIFORM SIGN EN SQUARED")
(73886 . "CUNEIFORM SIGN EREN")
(73887 . "CUNEIFORM SIGN ERIN2")
(73888 . "CUNEIFORM SIGN ESH2")
(73889 . "CUNEIFORM SIGN EZEN")
(73890 . "CUNEIFORM SIGN EZEN TIMES A")
(73891 . "CUNEIFORM SIGN EZEN TIMES A PLUS LAL")
(73892 . "CUNEIFORM SIGN EZEN TIMES A PLUS LAL TIMES LAL")
(73893 . "CUNEIFORM SIGN EZEN TIMES AN")
(73894 . "CUNEIFORM SIGN EZEN TIMES BAD")
(73895 . "CUNEIFORM SIGN EZEN TIMES DUN3 GUNU")
(73896 . "CUNEIFORM SIGN EZEN TIMES DUN3 GUNU GUNU")
(73897 . "CUNEIFORM SIGN EZEN TIMES HA")
(73898 . "CUNEIFORM SIGN EZEN TIMES HA GUNU")
(73899 . "CUNEIFORM SIGN EZEN TIMES IGI GUNU")
(73900 . "CUNEIFORM SIGN EZEN TIMES KASKAL")
(73901 . "CUNEIFORM SIGN EZEN TIMES KASKAL SQUARED")
(73902 . "CUNEIFORM SIGN EZEN TIMES KU3")
(73903 . "CUNEIFORM SIGN EZEN TIMES LA")
(73904 . "CUNEIFORM SIGN EZEN TIMES LAL TIMES LAL")
(73905 . "CUNEIFORM SIGN EZEN TIMES LI")
(73906 . "CUNEIFORM SIGN EZEN TIMES LU")
(73907 . "CUNEIFORM SIGN EZEN TIMES U2")
(73908 . "CUNEIFORM SIGN EZEN TIMES UD")
(73909 . "CUNEIFORM SIGN GA")
(73910 . "CUNEIFORM SIGN GA GUNU")
(73911 . "CUNEIFORM SIGN GA2")
(73912 . "CUNEIFORM SIGN GA2 TIMES A PLUS DA PLUS HA")
(73913 . "CUNEIFORM SIGN GA2 TIMES A PLUS HA")
(73914 . "CUNEIFORM SIGN GA2 TIMES A PLUS IGI")
(73915 . "CUNEIFORM SIGN GA2 TIMES AB2 TENU PLUS TAB")
(73916 . "CUNEIFORM SIGN GA2 TIMES AN")
(73917 . "CUNEIFORM SIGN GA2 TIMES ASH")
(73918 . "CUNEIFORM SIGN GA2 TIMES ASH2 PLUS GAL")
(73919 . "CUNEIFORM SIGN GA2 TIMES BAD")
(73920 . "CUNEIFORM SIGN GA2 TIMES BAR PLUS RA")
(73921 . "CUNEIFORM SIGN GA2 TIMES BUR")
(73922 . "CUNEIFORM SIGN GA2 TIMES BUR PLUS RA")
(73923 . "CUNEIFORM SIGN GA2 TIMES DA")
(73924 . "CUNEIFORM SIGN GA2 TIMES DI")
(73925 . "CUNEIFORM SIGN GA2 TIMES DIM TIMES SHE")
(73926 . "CUNEIFORM SIGN GA2 TIMES DUB")
(73927 . "CUNEIFORM SIGN GA2 TIMES EL")
(73928 . "CUNEIFORM SIGN GA2 TIMES EL PLUS LA")
(73929 . "CUNEIFORM SIGN GA2 TIMES EN")
(73930 . "CUNEIFORM SIGN GA2 TIMES EN TIMES GAN2 TENU")
(73931 . "CUNEIFORM SIGN GA2 TIMES GAN2 TENU")
(73932 . "CUNEIFORM SIGN GA2 TIMES GAR")
(73933 . "CUNEIFORM SIGN GA2 TIMES GI")
(73934 . "CUNEIFORM SIGN GA2 TIMES GI4")
(73935 . "CUNEIFORM SIGN GA2 TIMES GI4 PLUS A")
(73936 . "CUNEIFORM SIGN GA2 TIMES GIR2 PLUS SU")
(73937 . "CUNEIFORM SIGN GA2 TIMES HA PLUS LU PLUS ESH2")
(73938 . "CUNEIFORM SIGN GA2 TIMES HAL")
(73939 . "CUNEIFORM SIGN GA2 TIMES HAL PLUS LA")
(73940 . "CUNEIFORM SIGN GA2 TIMES HI PLUS LI")
(73941 . "CUNEIFORM SIGN GA2 TIMES HUB2")
(73942 . "CUNEIFORM SIGN GA2 TIMES IGI GUNU")
(73943 . "CUNEIFORM SIGN GA2 TIMES ISH PLUS HU PLUS ASH")
(73944 . "CUNEIFORM SIGN GA2 TIMES KAK")
(73945 . "CUNEIFORM SIGN GA2 TIMES KASKAL")
(73946 . "CUNEIFORM SIGN GA2 TIMES KID")
(73947 . "CUNEIFORM SIGN GA2 TIMES KID PLUS LAL")
(73948 . "CUNEIFORM SIGN GA2 TIMES KU3 PLUS AN")
(73949 . "CUNEIFORM SIGN GA2 TIMES LA")
(73950 . "CUNEIFORM SIGN GA2 TIMES ME PLUS EN")
(73951 . "CUNEIFORM SIGN GA2 TIMES MI")
(73952 . "CUNEIFORM SIGN GA2 TIMES NUN")
(73953 . "CUNEIFORM SIGN GA2 TIMES NUN OVER NUN")
(73954 . "CUNEIFORM SIGN GA2 TIMES PA")
(73955 . "CUNEIFORM SIGN GA2 TIMES SAL")
(73956 . "CUNEIFORM SIGN GA2 TIMES SAR")
(73957 . "CUNEIFORM SIGN GA2 TIMES SHE")
(73958 . "CUNEIFORM SIGN GA2 TIMES SHE PLUS TUR")
(73959 . "CUNEIFORM SIGN GA2 TIMES SHID")
(73960 . "CUNEIFORM SIGN GA2 TIMES SUM")
(73961 . "CUNEIFORM SIGN GA2 TIMES TAK4")
(73962 . "CUNEIFORM SIGN GA2 TIMES U")
(73963 . "CUNEIFORM SIGN GA2 TIMES UD")
(73964 . "CUNEIFORM SIGN GA2 TIMES UD PLUS DU")
(73965 . "CUNEIFORM SIGN GA2 OVER GA2")
(73966 . "CUNEIFORM SIGN GABA")
(73967 . "CUNEIFORM SIGN GABA CROSSING GABA")
(73968 . "CUNEIFORM SIGN GAD")
(73969 . "CUNEIFORM SIGN GAD OVER GAD GAR OVER GAR")
(73970 . "CUNEIFORM SIGN GAL")
(73971 . "CUNEIFORM SIGN GAL GAD OVER GAD GAR OVER GAR")
(73972 . "CUNEIFORM SIGN GALAM")
(73973 . "CUNEIFORM SIGN GAM")
(73974 . "CUNEIFORM SIGN GAN")
(73975 . "CUNEIFORM SIGN GAN2")
(73976 . "CUNEIFORM SIGN GAN2 TENU")
(73977 . "CUNEIFORM SIGN GAN2 OVER GAN2")
(73978 . "CUNEIFORM SIGN GAN2 CROSSING GAN2")
(73979 . "CUNEIFORM SIGN GAR")
(73980 . "CUNEIFORM SIGN GAR3")
(73981 . "CUNEIFORM SIGN GASHAN")
(73982 . "CUNEIFORM SIGN GESHTIN")
(73983 . "CUNEIFORM SIGN GESHTIN TIMES KUR")
(73984 . "CUNEIFORM SIGN GI")
(73985 . "CUNEIFORM SIGN GI TIMES E")
(73986 . "CUNEIFORM SIGN GI TIMES U")
(73987 . "CUNEIFORM SIGN GI CROSSING GI")
(73988 . "CUNEIFORM SIGN GI4")
(73989 . "CUNEIFORM SIGN GI4 OVER GI4")
(73990 . "CUNEIFORM SIGN GI4 CROSSING GI4")
(73991 . "CUNEIFORM SIGN GIDIM")
(73992 . "CUNEIFORM SIGN GIR2")
(73993 . "CUNEIFORM SIGN GIR2 GUNU")
(73994 . "CUNEIFORM SIGN GIR3")
(73995 . "CUNEIFORM SIGN GIR3 TIMES A PLUS IGI")
(73996 . "CUNEIFORM SIGN GIR3 TIMES GAN2 TENU")
(73997 . "CUNEIFORM SIGN GIR3 TIMES IGI")
(73998 . "CUNEIFORM SIGN GIR3 TIMES LU PLUS IGI")
(73999 . "CUNEIFORM SIGN GIR3 TIMES PA")
(74000 . "CUNEIFORM SIGN GISAL")
(74001 . "CUNEIFORM SIGN GISH")
(74002 . "CUNEIFORM SIGN GISH CROSSING GISH")
(74003 . "CUNEIFORM SIGN GISH TIMES BAD")
(74004 . "CUNEIFORM SIGN GISH TIMES TAK4")
(74005 . "CUNEIFORM SIGN GISH TENU")
(74006 . "CUNEIFORM SIGN GU")
(74007 . "CUNEIFORM SIGN GU CROSSING GU")
(74008 . "CUNEIFORM SIGN GU2")
(74009 . "CUNEIFORM SIGN GU2 TIMES KAK")
(74010 . "CUNEIFORM SIGN GU2 TIMES KAK TIMES IGI GUNU")
(74011 . "CUNEIFORM SIGN GU2 TIMES NUN")
(74012 . "CUNEIFORM SIGN GU2 TIMES SAL PLUS TUG2")
(74013 . "CUNEIFORM SIGN GU2 GUNU")
(74014 . "CUNEIFORM SIGN GUD")
(74015 . "CUNEIFORM SIGN GUD TIMES A PLUS KUR")
(74016 . "CUNEIFORM SIGN GUD TIMES KUR")
(74017 . "CUNEIFORM SIGN GUD OVER GUD LUGAL")
(74018 . "CUNEIFORM SIGN GUL")
(74019 . "CUNEIFORM SIGN GUM")
(74020 . "CUNEIFORM SIGN GUM TIMES SHE")
(74021 . "CUNEIFORM SIGN GUR")
(74022 . "CUNEIFORM SIGN GUR7")
(74023 . "CUNEIFORM SIGN GURUN")
(74024 . "CUNEIFORM SIGN GURUSH")
(74025 . "CUNEIFORM SIGN HA")
(74026 . "CUNEIFORM SIGN HA TENU")
(74027 . "CUNEIFORM SIGN HA GUNU")
(74028 . "CUNEIFORM SIGN HAL")
(74029 . "CUNEIFORM SIGN HI")
(74030 . "CUNEIFORM SIGN HI TIMES ASH")
(74031 . "CUNEIFORM SIGN HI TIMES ASH2")
(74032 . "CUNEIFORM SIGN HI TIMES BAD")
(74033 . "CUNEIFORM SIGN HI TIMES DISH")
(74034 . "CUNEIFORM SIGN HI TIMES GAD")
(74035 . "CUNEIFORM SIGN HI TIMES KIN")
(74036 . "CUNEIFORM SIGN HI TIMES NUN")
(74037 . "CUNEIFORM SIGN HI TIMES SHE")
(74038 . "CUNEIFORM SIGN HI TIMES U")
(74039 . "CUNEIFORM SIGN HU")
(74040 . "CUNEIFORM SIGN HUB2")
(74041 . "CUNEIFORM SIGN HUB2 TIMES AN")
(74042 . "CUNEIFORM SIGN HUB2 TIMES HAL")
(74043 . "CUNEIFORM SIGN HUB2 TIMES KASKAL")
(74044 . "CUNEIFORM SIGN HUB2 TIMES LISH")
(74045 . "CUNEIFORM SIGN HUB2 TIMES UD")
(74046 . "CUNEIFORM SIGN HUL2")
(74047 . "CUNEIFORM SIGN I")
(74048 . "CUNEIFORM SIGN I A")
(74049 . "CUNEIFORM SIGN IB")
(74050 . "CUNEIFORM SIGN IDIM")
(74051 . "CUNEIFORM SIGN IDIM OVER IDIM BUR")
(74052 . "CUNEIFORM SIGN IDIM OVER IDIM SQUARED")
(74053 . "CUNEIFORM SIGN IG")
(74054 . "CUNEIFORM SIGN IGI")
(74055 . "CUNEIFORM SIGN IGI DIB")
(74056 . "CUNEIFORM SIGN IGI RI")
(74057 . "CUNEIFORM SIGN IGI OVER IGI SHIR OVER SHIR UD OVER UD")
(74058 . "CUNEIFORM SIGN IGI GUNU")
(74059 . "CUNEIFORM SIGN IL")
(74060 . "CUNEIFORM SIGN IL TIMES GAN2 TENU")
(74061 . "CUNEIFORM SIGN IL2")
(74062 . "CUNEIFORM SIGN IM")
(74063 . "CUNEIFORM SIGN IM TIMES TAK4")
(74064 . "CUNEIFORM SIGN IM CROSSING IM")
(74065 . "CUNEIFORM SIGN IM OPPOSING IM")
(74066 . "CUNEIFORM SIGN IM SQUARED")
(74067 . "CUNEIFORM SIGN IMIN")
(74068 . "CUNEIFORM SIGN IN")
(74069 . "CUNEIFORM SIGN IR")
(74070 . "CUNEIFORM SIGN ISH")
(74071 . "CUNEIFORM SIGN KA")
(74072 . "CUNEIFORM SIGN KA TIMES A")
(74073 . "CUNEIFORM SIGN KA TIMES AD")
(74074 . "CUNEIFORM SIGN KA TIMES AD PLUS KU3")
(74075 . "CUNEIFORM SIGN KA TIMES ASH2")
(74076 . "CUNEIFORM SIGN KA TIMES BAD")
(74077 . "CUNEIFORM SIGN KA TIMES BALAG")
(74078 . "CUNEIFORM SIGN KA TIMES BAR")
(74079 . "CUNEIFORM SIGN KA TIMES BI")
(74080 . "CUNEIFORM SIGN KA TIMES ERIN2")
(74081 . "CUNEIFORM SIGN KA TIMES ESH2")
(74082 . "CUNEIFORM SIGN KA TIMES GA")
(74083 . "CUNEIFORM SIGN KA TIMES GAL")
(74084 . "CUNEIFORM SIGN KA TIMES GAN2 TENU")
(74085 . "CUNEIFORM SIGN KA TIMES GAR")
(74086 . "CUNEIFORM SIGN KA TIMES GAR PLUS SHA3 PLUS A")
(74087 . "CUNEIFORM SIGN KA TIMES GI")
(74088 . "CUNEIFORM SIGN KA TIMES GIR2")
(74089 . "CUNEIFORM SIGN KA TIMES GISH PLUS SAR")
(74090 . "CUNEIFORM SIGN KA TIMES GISH CROSSING GISH")
(74091 . "CUNEIFORM SIGN KA TIMES GU")
(74092 . "CUNEIFORM SIGN KA TIMES GUR7")
(74093 . "CUNEIFORM SIGN KA TIMES IGI")
(74094 . "CUNEIFORM SIGN KA TIMES IM")
(74095 . "CUNEIFORM SIGN KA TIMES KAK")
(74096 . "CUNEIFORM SIGN KA TIMES KI")
(74097 . "CUNEIFORM SIGN KA TIMES KID")
(74098 . "CUNEIFORM SIGN KA TIMES LI")
(74099 . "CUNEIFORM SIGN KA TIMES LU")
(74100 . "CUNEIFORM SIGN KA TIMES ME")
(74101 . "CUNEIFORM SIGN KA TIMES ME PLUS DU")
(74102 . "CUNEIFORM SIGN KA TIMES ME PLUS GI")
(74103 . "CUNEIFORM SIGN KA TIMES ME PLUS TE")
(74104 . "CUNEIFORM SIGN KA TIMES MI")
(74105 . "CUNEIFORM SIGN KA TIMES MI PLUS NUNUZ")
(74106 . "CUNEIFORM SIGN KA TIMES NE")
(74107 . "CUNEIFORM SIGN KA TIMES NUN")
(74108 . "CUNEIFORM SIGN KA TIMES PI")
(74109 . "CUNEIFORM SIGN KA TIMES RU")
(74110 . "CUNEIFORM SIGN KA TIMES SA")
(74111 . "CUNEIFORM SIGN KA TIMES SAR")
(74112 . "CUNEIFORM SIGN KA TIMES SHA")
(74113 . "CUNEIFORM SIGN KA TIMES SHE")
(74114 . "CUNEIFORM SIGN KA TIMES SHID")
(74115 . "CUNEIFORM SIGN KA TIMES SHU")
(74116 . "CUNEIFORM SIGN KA TIMES SIG")
(74117 . "CUNEIFORM SIGN KA TIMES SUHUR")
(74118 . "CUNEIFORM SIGN KA TIMES TAR")
(74119 . "CUNEIFORM SIGN KA TIMES U")
(74120 . "CUNEIFORM SIGN KA TIMES U2")
(74121 . "CUNEIFORM SIGN KA TIMES UD")
(74122 . "CUNEIFORM SIGN KA TIMES UMUM TIMES PA")
(74123 . "CUNEIFORM SIGN KA TIMES USH")
(74124 . "CUNEIFORM SIGN KA TIMES ZI")
(74125 . "CUNEIFORM SIGN KA2")
(74126 . "CUNEIFORM SIGN KA2 CROSSING KA2")
(74127 . "CUNEIFORM SIGN KAB")
(74128 . "CUNEIFORM SIGN KAD2")
(74129 . "CUNEIFORM SIGN KAD3")
(74130 . "CUNEIFORM SIGN KAD4")
(74131 . "CUNEIFORM SIGN KAD5")
(74132 . "CUNEIFORM SIGN KAD5 OVER KAD5")
(74133 . "CUNEIFORM SIGN KAK")
(74134 . "CUNEIFORM SIGN KAK TIMES IGI GUNU")
(74135 . "CUNEIFORM SIGN KAL")
(74136 . "CUNEIFORM SIGN KAL TIMES BAD")
(74137 . "CUNEIFORM SIGN KAL CROSSING KAL")
(74138 . "CUNEIFORM SIGN KAM2")
(74139 . "CUNEIFORM SIGN KAM4")
(74140 . "CUNEIFORM SIGN KASKAL")
(74141 . "CUNEIFORM SIGN KASKAL LAGAB TIMES U OVER LAGAB TIMES U")
(74142 . "CUNEIFORM SIGN KASKAL OVER KASKAL LAGAB TIMES U OVER LAGAB TIMES U")
(74143 . "CUNEIFORM SIGN KESH2")
(74144 . "CUNEIFORM SIGN KI")
(74145 . "CUNEIFORM SIGN KI TIMES BAD")
(74146 . "CUNEIFORM SIGN KI TIMES U")
(74147 . "CUNEIFORM SIGN KI TIMES UD")
(74148 . "CUNEIFORM SIGN KID")
(74149 . "CUNEIFORM SIGN KIN")
(74150 . "CUNEIFORM SIGN KISAL")
(74151 . "CUNEIFORM SIGN KISH")
(74152 . "CUNEIFORM SIGN KISIM5")
(74153 . "CUNEIFORM SIGN KISIM5 OVER KISIM5")
(74154 . "CUNEIFORM SIGN KU")
(74155 . "CUNEIFORM SIGN KU OVER HI TIMES ASH2 KU OVER HI TIMES ASH2")
(74156 . "CUNEIFORM SIGN KU3")
(74157 . "CUNEIFORM SIGN KU4")
(74158 . "CUNEIFORM SIGN KU4 VARIANT FORM")
(74159 . "CUNEIFORM SIGN KU7")
(74160 . "CUNEIFORM SIGN KUL")
(74161 . "CUNEIFORM SIGN KUL GUNU")
(74162 . "CUNEIFORM SIGN KUN")
(74163 . "CUNEIFORM SIGN KUR")
(74164 . "CUNEIFORM SIGN KUR OPPOSING KUR")
(74165 . "CUNEIFORM SIGN KUSHU2")
(74166 . "CUNEIFORM SIGN KWU318")
(74167 . "CUNEIFORM SIGN LA")
(74168 . "CUNEIFORM SIGN LAGAB")
(74169 . "CUNEIFORM SIGN LAGAB TIMES A")
(74170 . "CUNEIFORM SIGN LAGAB TIMES A PLUS DA PLUS HA")
(74171 . "CUNEIFORM SIGN LAGAB TIMES A PLUS GAR")
(74172 . "CUNEIFORM SIGN LAGAB TIMES A PLUS LAL")
(74173 . "CUNEIFORM SIGN LAGAB TIMES AL")
(74174 . "CUNEIFORM SIGN LAGAB TIMES AN")
(74175 . "CUNEIFORM SIGN LAGAB TIMES ASH ZIDA TENU")
(74176 . "CUNEIFORM SIGN LAGAB TIMES BAD")
(74177 . "CUNEIFORM SIGN LAGAB TIMES BI")
(74178 . "CUNEIFORM SIGN LAGAB TIMES DAR")
(74179 . "CUNEIFORM SIGN LAGAB TIMES EN")
(74180 . "CUNEIFORM SIGN LAGAB TIMES GA")
(74181 . "CUNEIFORM SIGN LAGAB TIMES GAR")
(74182 . "CUNEIFORM SIGN LAGAB TIMES GUD")
(74183 . "CUNEIFORM SIGN LAGAB TIMES GUD PLUS GUD")
(74184 . "CUNEIFORM SIGN LAGAB TIMES HA")
(74185 . "CUNEIFORM SIGN LAGAB TIMES HAL")
(74186 . "CUNEIFORM SIGN LAGAB TIMES HI TIMES NUN")
(74187 . "CUNEIFORM SIGN LAGAB TIMES IGI GUNU")
(74188 . "CUNEIFORM SIGN LAGAB TIMES IM")
(74189 . "CUNEIFORM SIGN LAGAB TIMES IM PLUS HA")
(74190 . "CUNEIFORM SIGN LAGAB TIMES IM PLUS LU")
(74191 . "CUNEIFORM SIGN LAGAB TIMES KI")
(74192 . "CUNEIFORM SIGN LAGAB TIMES KIN")
(74193 . "CUNEIFORM SIGN LAGAB TIMES KU3")
(74194 . "CUNEIFORM SIGN LAGAB TIMES KUL")
(74195 . "CUNEIFORM SIGN LAGAB TIMES KUL PLUS HI PLUS A")
(74196 . "CUNEIFORM SIGN LAGAB TIMES LAGAB")
(74197 . "CUNEIFORM SIGN LAGAB TIMES LISH")
(74198 . "CUNEIFORM SIGN LAGAB TIMES LU")
(74199 . "CUNEIFORM SIGN LAGAB TIMES LUL")
(74200 . "CUNEIFORM SIGN LAGAB TIMES ME")
(74201 . "CUNEIFORM SIGN LAGAB TIMES ME PLUS EN")
(74202 . "CUNEIFORM SIGN LAGAB TIMES MUSH")
(74203 . "CUNEIFORM SIGN LAGAB TIMES NE")
(74204 . "CUNEIFORM SIGN LAGAB TIMES SHE PLUS SUM")
(74205 . "CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH PLUS ERIN2")
(74206 . "CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH TENU")
(74207 . "CUNEIFORM SIGN LAGAB TIMES SHU2")
(74208 . "CUNEIFORM SIGN LAGAB TIMES SHU2 PLUS SHU2")
(74209 . "CUNEIFORM SIGN LAGAB TIMES SUM")
(74210 . "CUNEIFORM SIGN LAGAB TIMES TAG")
(74211 . "CUNEIFORM SIGN LAGAB TIMES TAK4")
(74212 . "CUNEIFORM SIGN LAGAB TIMES TE PLUS A PLUS SU PLUS NA")
(74213 . "CUNEIFORM SIGN LAGAB TIMES U")
(74214 . "CUNEIFORM SIGN LAGAB TIMES U PLUS A")
(74215 . "CUNEIFORM SIGN LAGAB TIMES U PLUS U PLUS U")
(74216 . "CUNEIFORM SIGN LAGAB TIMES U2 PLUS ASH")
(74217 . "CUNEIFORM SIGN LAGAB TIMES UD")
(74218 . "CUNEIFORM SIGN LAGAB TIMES USH")
(74219 . "CUNEIFORM SIGN LAGAB SQUARED")
(74220 . "CUNEIFORM SIGN LAGAR")
(74221 . "CUNEIFORM SIGN LAGAR TIMES SHE")
(74222 . "CUNEIFORM SIGN LAGAR TIMES SHE PLUS SUM")
(74223 . "CUNEIFORM SIGN LAGAR GUNU")
(74224 . "CUNEIFORM SIGN LAGAR GUNU OVER LAGAR GUNU SHE")
(74225 . "CUNEIFORM SIGN LAHSHU")
(74226 . "CUNEIFORM SIGN LAL")
(74227 . "CUNEIFORM SIGN LAL TIMES LAL")
(74228 . "CUNEIFORM SIGN LAM")
(74229 . "CUNEIFORM SIGN LAM TIMES KUR")
(74230 . "CUNEIFORM SIGN LAM TIMES KUR PLUS RU")
(74231 . "CUNEIFORM SIGN LI")
(74232 . "CUNEIFORM SIGN LIL")
(74233 . "CUNEIFORM SIGN LIMMU2")
(74234 . "CUNEIFORM SIGN LISH")
(74235 . "CUNEIFORM SIGN LU")
(74236 . "CUNEIFORM SIGN LU TIMES BAD")
(74237 . "CUNEIFORM SIGN LU2")
(74238 . "CUNEIFORM SIGN LU2 TIMES AL")
(74239 . "CUNEIFORM SIGN LU2 TIMES BAD")
(74240 . "CUNEIFORM SIGN LU2 TIMES ESH2")
(74241 . "CUNEIFORM SIGN LU2 TIMES ESH2 TENU")
(74242 . "CUNEIFORM SIGN LU2 TIMES GAN2 TENU")
(74243 . "CUNEIFORM SIGN LU2 TIMES HI TIMES BAD")
(74244 . "CUNEIFORM SIGN LU2 TIMES IM")
(74245 . "CUNEIFORM SIGN LU2 TIMES KAD2")
(74246 . "CUNEIFORM SIGN LU2 TIMES KAD3")
(74247 . "CUNEIFORM SIGN LU2 TIMES KAD3 PLUS ASH")
(74248 . "CUNEIFORM SIGN LU2 TIMES KI")
(74249 . "CUNEIFORM SIGN LU2 TIMES LA PLUS ASH")
(74250 . "CUNEIFORM SIGN LU2 TIMES LAGAB")
(74251 . "CUNEIFORM SIGN LU2 TIMES ME PLUS EN")
(74252 . "CUNEIFORM SIGN LU2 TIMES NE")
(74253 . "CUNEIFORM SIGN LU2 TIMES NU")
(74254 . "CUNEIFORM SIGN LU2 TIMES SI PLUS ASH")
(74255 . "CUNEIFORM SIGN LU2 TIMES SIK2 PLUS BU")
(74256 . "CUNEIFORM SIGN LU2 TIMES TUG2")
(74257 . "CUNEIFORM SIGN LU2 TENU")
(74258 . "CUNEIFORM SIGN LU2 CROSSING LU2")
(74259 . "CUNEIFORM SIGN LU2 OPPOSING LU2")
(74260 . "CUNEIFORM SIGN LU2 SQUARED")
(74261 . "CUNEIFORM SIGN LU2 SHESHIG")
(74262 . "CUNEIFORM SIGN LU3")
(74263 . "CUNEIFORM SIGN LUGAL")
(74264 . "CUNEIFORM SIGN LUGAL OVER LUGAL")
(74265 . "CUNEIFORM SIGN LUGAL OPPOSING LUGAL")
(74266 . "CUNEIFORM SIGN LUGAL SHESHIG")
(74267 . "CUNEIFORM SIGN LUH")
(74268 . "CUNEIFORM SIGN LUL")
(74269 . "CUNEIFORM SIGN LUM")
(74270 . "CUNEIFORM SIGN LUM OVER LUM")
(74271 . "CUNEIFORM SIGN LUM OVER LUM GAR OVER GAR")
(74272 . "CUNEIFORM SIGN MA")
(74273 . "CUNEIFORM SIGN MA TIMES TAK4")
(74274 . "CUNEIFORM SIGN MA GUNU")
(74275 . "CUNEIFORM SIGN MA2")
(74276 . "CUNEIFORM SIGN MAH")
(74277 . "CUNEIFORM SIGN MAR")
(74278 . "CUNEIFORM SIGN MASH")
(74279 . "CUNEIFORM SIGN MASH2")
(74280 . "CUNEIFORM SIGN ME")
(74281 . "CUNEIFORM SIGN MES")
(74282 . "CUNEIFORM SIGN MI")
(74283 . "CUNEIFORM SIGN MIN")
(74284 . "CUNEIFORM SIGN MU")
(74285 . "CUNEIFORM SIGN MU OVER MU")
(74286 . "CUNEIFORM SIGN MUG")
(74287 . "CUNEIFORM SIGN MUG GUNU")
(74288 . "CUNEIFORM SIGN MUNSUB")
(74289 . "CUNEIFORM SIGN MURGU2")
(74290 . "CUNEIFORM SIGN MUSH")
(74291 . "CUNEIFORM SIGN MUSH TIMES A")
(74292 . "CUNEIFORM SIGN MUSH TIMES KUR")
(74293 . "CUNEIFORM SIGN MUSH TIMES ZA")
(74294 . "CUNEIFORM SIGN MUSH OVER MUSH")
(74295 . "CUNEIFORM SIGN MUSH OVER MUSH TIMES A PLUS NA")
(74296 . "CUNEIFORM SIGN MUSH CROSSING MUSH")
(74297 . "CUNEIFORM SIGN MUSH3")
(74298 . "CUNEIFORM SIGN MUSH3 TIMES A")
(74299 . "CUNEIFORM SIGN MUSH3 TIMES A PLUS DI")
(74300 . "CUNEIFORM SIGN MUSH3 TIMES DI")
(74301 . "CUNEIFORM SIGN MUSH3 GUNU")
(74302 . "CUNEIFORM SIGN NA")
(74303 . "CUNEIFORM SIGN NA2")
(74304 . "CUNEIFORM SIGN NAGA")
(74305 . "CUNEIFORM SIGN NAGA INVERTED")
(74306 . "CUNEIFORM SIGN NAGA TIMES SHU TENU")
(74307 . "CUNEIFORM SIGN NAGA OPPOSING NAGA")
(74308 . "CUNEIFORM SIGN NAGAR")
(74309 . "CUNEIFORM SIGN NAM NUTILLU")
(74310 . "CUNEIFORM SIGN NAM")
(74311 . "CUNEIFORM SIGN NAM2")
(74312 . "CUNEIFORM SIGN NE")
(74313 . "CUNEIFORM SIGN NE TIMES A")
(74314 . "CUNEIFORM SIGN NE TIMES UD")
(74315 . "CUNEIFORM SIGN NE SHESHIG")
(74316 . "CUNEIFORM SIGN NI")
(74317 . "CUNEIFORM SIGN NI TIMES E")
(74318 . "CUNEIFORM SIGN NI2")
(74319 . "CUNEIFORM SIGN NIM")
(74320 . "CUNEIFORM SIGN NIM TIMES GAN2 TENU")
(74321 . "CUNEIFORM SIGN NIM TIMES GAR PLUS GAN2 TENU")
(74322 . "CUNEIFORM SIGN NINDA2")
(74323 . "CUNEIFORM SIGN NINDA2 TIMES AN")
(74324 . "CUNEIFORM SIGN NINDA2 TIMES ASH")
(74325 . "CUNEIFORM SIGN NINDA2 TIMES ASH PLUS ASH")
(74326 . "CUNEIFORM SIGN NINDA2 TIMES GUD")
(74327 . "CUNEIFORM SIGN NINDA2 TIMES ME PLUS GAN2 TENU")
(74328 . "CUNEIFORM SIGN NINDA2 TIMES NE")
(74329 . "CUNEIFORM SIGN NINDA2 TIMES NUN")
(74330 . "CUNEIFORM SIGN NINDA2 TIMES SHE")
(74331 . "CUNEIFORM SIGN NINDA2 TIMES SHE PLUS A AN")
(74332 . "CUNEIFORM SIGN NINDA2 TIMES SHE PLUS ASH")
(74333 . "CUNEIFORM SIGN NINDA2 TIMES SHE PLUS ASH PLUS ASH")
(74334 . "CUNEIFORM SIGN NINDA2 TIMES U2 PLUS ASH")
(74335 . "CUNEIFORM SIGN NINDA2 TIMES USH")
(74336 . "CUNEIFORM SIGN NISAG")
(74337 . "CUNEIFORM SIGN NU")
(74338 . "CUNEIFORM SIGN NU11")
(74339 . "CUNEIFORM SIGN NUN")
(74340 . "CUNEIFORM SIGN NUN LAGAR TIMES GAR")
(74341 . "CUNEIFORM SIGN NUN LAGAR TIMES MASH")
(74342 . "CUNEIFORM SIGN NUN LAGAR TIMES SAL")
(74343 . "CUNEIFORM SIGN NUN LAGAR TIMES SAL OVER NUN LAGAR TIMES SAL")
(74344 . "CUNEIFORM SIGN NUN LAGAR TIMES USH")
(74345 . "CUNEIFORM SIGN NUN TENU")
(74346 . "CUNEIFORM SIGN NUN OVER NUN")
(74347 . "CUNEIFORM SIGN NUN CROSSING NUN")
(74348 . "CUNEIFORM SIGN NUN CROSSING NUN LAGAR OVER LAGAR")
(74349 . "CUNEIFORM SIGN NUNUZ")
(74350 . "CUNEIFORM SIGN NUNUZ AB2 TIMES ASHGAB")
(74351 . "CUNEIFORM SIGN NUNUZ AB2 TIMES BI")
(74352 . "CUNEIFORM SIGN NUNUZ AB2 TIMES DUG")
(74353 . "CUNEIFORM SIGN NUNUZ AB2 TIMES GUD")
(74354 . "CUNEIFORM SIGN NUNUZ AB2 TIMES IGI GUNU")
(74355 . "CUNEIFORM SIGN NUNUZ AB2 TIMES KAD3")
(74356 . "CUNEIFORM SIGN NUNUZ AB2 TIMES LA")
(74357 . "CUNEIFORM SIGN NUNUZ AB2 TIMES NE")
(74358 . "CUNEIFORM SIGN NUNUZ AB2 TIMES SILA3")
(74359 . "CUNEIFORM SIGN NUNUZ AB2 TIMES U2")
(74360 . "CUNEIFORM SIGN NUNUZ KISIM5 TIMES BI")
(74361 . "CUNEIFORM SIGN NUNUZ KISIM5 TIMES BI U")
(74362 . "CUNEIFORM SIGN PA")
(74363 . "CUNEIFORM SIGN PAD")
(74364 . "CUNEIFORM SIGN PAN")
(74365 . "CUNEIFORM SIGN PAP")
(74366 . "CUNEIFORM SIGN PESH2")
(74367 . "CUNEIFORM SIGN PI")
(74368 . "CUNEIFORM SIGN PI TIMES A")
(74369 . "CUNEIFORM SIGN PI TIMES AB")
(74370 . "CUNEIFORM SIGN PI TIMES BI")
(74371 . "CUNEIFORM SIGN PI TIMES BU")
(74372 . "CUNEIFORM SIGN PI TIMES E")
(74373 . "CUNEIFORM SIGN PI TIMES I")
(74374 . "CUNEIFORM SIGN PI TIMES IB")
(74375 . "CUNEIFORM SIGN PI TIMES U")
(74376 . "CUNEIFORM SIGN PI TIMES U2")
(74377 . "CUNEIFORM SIGN PI CROSSING PI")
(74378 . "CUNEIFORM SIGN PIRIG")
(74379 . "CUNEIFORM SIGN PIRIG TIMES KAL")
(74380 . "CUNEIFORM SIGN PIRIG TIMES UD")
(74381 . "CUNEIFORM SIGN PIRIG TIMES ZA")
(74382 . "CUNEIFORM SIGN PIRIG OPPOSING PIRIG")
(74383 . "CUNEIFORM SIGN RA")
(74384 . "CUNEIFORM SIGN RAB")
(74385 . "CUNEIFORM SIGN RI")
(74386 . "CUNEIFORM SIGN RU")
(74387 . "CUNEIFORM SIGN SA")
(74388 . "CUNEIFORM SIGN SAG NUTILLU")
(74389 . "CUNEIFORM SIGN SAG")
(74390 . "CUNEIFORM SIGN SAG TIMES A")
(74391 . "CUNEIFORM SIGN SAG TIMES DU")
(74392 . "CUNEIFORM SIGN SAG TIMES DUB")
(74393 . "CUNEIFORM SIGN SAG TIMES HA")
(74394 . "CUNEIFORM SIGN SAG TIMES KAK")
(74395 . "CUNEIFORM SIGN SAG TIMES KUR")
(74396 . "CUNEIFORM SIGN SAG TIMES LUM")
(74397 . "CUNEIFORM SIGN SAG TIMES MI")
(74398 . "CUNEIFORM SIGN SAG TIMES NUN")
(74399 . "CUNEIFORM SIGN SAG TIMES SAL")
(74400 . "CUNEIFORM SIGN SAG TIMES SHID")
(74401 . "CUNEIFORM SIGN SAG TIMES TAB")
(74402 . "CUNEIFORM SIGN SAG TIMES U2")
(74403 . "CUNEIFORM SIGN SAG TIMES UB")
(74404 . "CUNEIFORM SIGN SAG TIMES UM")
(74405 . "CUNEIFORM SIGN SAG TIMES UR")
(74406 . "CUNEIFORM SIGN SAG TIMES USH")
(74407 . "CUNEIFORM SIGN SAG OVER SAG")
(74408 . "CUNEIFORM SIGN SAG GUNU")
(74409 . "CUNEIFORM SIGN SAL")
(74410 . "CUNEIFORM SIGN SAL LAGAB TIMES ASH2")
(74411 . "CUNEIFORM SIGN SANGA2")
(74412 . "CUNEIFORM SIGN SAR")
(74413 . "CUNEIFORM SIGN SHA")
(74414 . "CUNEIFORM SIGN SHA3")
(74415 . "CUNEIFORM SIGN SHA3 TIMES A")
(74416 . "CUNEIFORM SIGN SHA3 TIMES BAD")
(74417 . "CUNEIFORM SIGN SHA3 TIMES GISH")
(74418 . "CUNEIFORM SIGN SHA3 TIMES NE")
(74419 . "CUNEIFORM SIGN SHA3 TIMES SHU2")
(74420 . "CUNEIFORM SIGN SHA3 TIMES TUR")
(74421 . "CUNEIFORM SIGN SHA3 TIMES U")
(74422 . "CUNEIFORM SIGN SHA3 TIMES U PLUS A")
(74423 . "CUNEIFORM SIGN SHA6")
(74424 . "CUNEIFORM SIGN SHAB6")
(74425 . "CUNEIFORM SIGN SHAR2")
(74426 . "CUNEIFORM SIGN SHE")
(74427 . "CUNEIFORM SIGN SHE HU")
(74428 . "CUNEIFORM SIGN SHE OVER SHE GAD OVER GAD GAR OVER GAR")
(74429 . "CUNEIFORM SIGN SHE OVER SHE TAB OVER TAB GAR OVER GAR")
(74430 . "CUNEIFORM SIGN SHEG9")
(74431 . "CUNEIFORM SIGN SHEN")
(74432 . "CUNEIFORM SIGN SHESH")
(74433 . "CUNEIFORM SIGN SHESH2")
(74434 . "CUNEIFORM SIGN SHESHLAM")
(74435 . "CUNEIFORM SIGN SHID")
(74436 . "CUNEIFORM SIGN SHID TIMES A")
(74437 . "CUNEIFORM SIGN SHID TIMES IM")
(74438 . "CUNEIFORM SIGN SHIM")
(74439 . "CUNEIFORM SIGN SHIM TIMES A")
(74440 . "CUNEIFORM SIGN SHIM TIMES BAL")
(74441 . "CUNEIFORM SIGN SHIM TIMES BULUG")
(74442 . "CUNEIFORM SIGN SHIM TIMES DIN")
(74443 . "CUNEIFORM SIGN SHIM TIMES GAR")
(74444 . "CUNEIFORM SIGN SHIM TIMES IGI")
(74445 . "CUNEIFORM SIGN SHIM TIMES IGI GUNU")
(74446 . "CUNEIFORM SIGN SHIM TIMES KUSHU2")
(74447 . "CUNEIFORM SIGN SHIM TIMES LUL")
(74448 . "CUNEIFORM SIGN SHIM TIMES MUG")
(74449 . "CUNEIFORM SIGN SHIM TIMES SAL")
(74450 . "CUNEIFORM SIGN SHINIG")
(74451 . "CUNEIFORM SIGN SHIR")
(74452 . "CUNEIFORM SIGN SHIR TENU")
(74453 . "CUNEIFORM SIGN SHIR OVER SHIR BUR OVER BUR")
(74454 . "CUNEIFORM SIGN SHITA")
(74455 . "CUNEIFORM SIGN SHU")
(74456 . "CUNEIFORM SIGN SHU OVER INVERTED SHU")
(74457 . "CUNEIFORM SIGN SHU2")
(74458 . "CUNEIFORM SIGN SHUBUR")
(74459 . "CUNEIFORM SIGN SI")
(74460 . "CUNEIFORM SIGN SI GUNU")
(74461 . "CUNEIFORM SIGN SIG")
(74462 . "CUNEIFORM SIGN SIG4")
(74463 . "CUNEIFORM SIGN SIG4 OVER SIG4 SHU2")
(74464 . "CUNEIFORM SIGN SIK2")
(74465 . "CUNEIFORM SIGN SILA3")
(74466 . "CUNEIFORM SIGN SU")
(74467 . "CUNEIFORM SIGN SU OVER SU")
(74468 . "CUNEIFORM SIGN SUD")
(74469 . "CUNEIFORM SIGN SUD2")
(74470 . "CUNEIFORM SIGN SUHUR")
(74471 . "CUNEIFORM SIGN SUM")
(74472 . "CUNEIFORM SIGN SUMASH")
(74473 . "CUNEIFORM SIGN SUR")
(74474 . "CUNEIFORM SIGN SUR9")
(74475 . "CUNEIFORM SIGN TA")
(74476 . "CUNEIFORM SIGN TA ASTERISK")
(74477 . "CUNEIFORM SIGN TA TIMES HI")
(74478 . "CUNEIFORM SIGN TA TIMES MI")
(74479 . "CUNEIFORM SIGN TA GUNU")
(74480 . "CUNEIFORM SIGN TAB")
(74481 . "CUNEIFORM SIGN TAB OVER TAB NI OVER NI DISH OVER DISH")
(74482 . "CUNEIFORM SIGN TAB SQUARED")
(74483 . "CUNEIFORM SIGN TAG")
(74484 . "CUNEIFORM SIGN TAG TIMES BI")
(74485 . "CUNEIFORM SIGN TAG TIMES GUD")
(74486 . "CUNEIFORM SIGN TAG TIMES SHE")
(74487 . "CUNEIFORM SIGN TAG TIMES SHU")
(74488 . "CUNEIFORM SIGN TAG TIMES TUG2")
(74489 . "CUNEIFORM SIGN TAG TIMES UD")
(74490 . "CUNEIFORM SIGN TAK4")
(74491 . "CUNEIFORM SIGN TAR")
(74492 . "CUNEIFORM SIGN TE")
(74493 . "CUNEIFORM SIGN TE GUNU")
(74494 . "CUNEIFORM SIGN TI")
(74495 . "CUNEIFORM SIGN TI TENU")
(74496 . "CUNEIFORM SIGN TIL")
(74497 . "CUNEIFORM SIGN TIR")
(74498 . "CUNEIFORM SIGN TIR TIMES TAK4")
(74499 . "CUNEIFORM SIGN TIR OVER TIR")
(74500 . "CUNEIFORM SIGN TIR OVER TIR GAD OVER GAD GAR OVER GAR")
(74501 . "CUNEIFORM SIGN TU")
(74502 . "CUNEIFORM SIGN TUG2")
(74503 . "CUNEIFORM SIGN TUK")
(74504 . "CUNEIFORM SIGN TUM")
(74505 . "CUNEIFORM SIGN TUR")
(74506 . "CUNEIFORM SIGN TUR OVER TUR ZA OVER ZA")
(74507 . "CUNEIFORM SIGN U")
(74508 . "CUNEIFORM SIGN U GUD")
(74509 . "CUNEIFORM SIGN U U U")
(74510 . "CUNEIFORM SIGN U OVER U PA OVER PA GAR OVER GAR")
(74511 . "CUNEIFORM SIGN U OVER U SUR OVER SUR")
(74512 . "CUNEIFORM SIGN U OVER U U REVERSED OVER U REVERSED")
(74513 . "CUNEIFORM SIGN U2")
(74514 . "CUNEIFORM SIGN UB")
(74515 . "CUNEIFORM SIGN UD")
(74516 . "CUNEIFORM SIGN UD KUSHU2")
(74517 . "CUNEIFORM SIGN UD TIMES BAD")
(74518 . "CUNEIFORM SIGN UD TIMES MI")
(74519 . "CUNEIFORM SIGN UD TIMES U PLUS U PLUS U")
(74520 . "CUNEIFORM SIGN UD TIMES U PLUS U PLUS U GUNU")
(74521 . "CUNEIFORM SIGN UD GUNU")
(74522 . "CUNEIFORM SIGN UD SHESHIG")
(74523 . "CUNEIFORM SIGN UD SHESHIG TIMES BAD")
(74524 . "CUNEIFORM SIGN UDUG")
(74525 . "CUNEIFORM SIGN UM")
(74526 . "CUNEIFORM SIGN UM TIMES LAGAB")
(74527 . "CUNEIFORM SIGN UM TIMES ME PLUS DA")
(74528 . "CUNEIFORM SIGN UM TIMES SHA3")
(74529 . "CUNEIFORM SIGN UM TIMES U")
(74530 . "CUNEIFORM SIGN UMBIN")
(74531 . "CUNEIFORM SIGN UMUM")
(74532 . "CUNEIFORM SIGN UMUM TIMES KASKAL")
(74533 . "CUNEIFORM SIGN UMUM TIMES PA")
(74534 . "CUNEIFORM SIGN UN")
(74535 . "CUNEIFORM SIGN UN GUNU")
(74536 . "CUNEIFORM SIGN UR")
(74537 . "CUNEIFORM SIGN UR CROSSING UR")
(74538 . "CUNEIFORM SIGN UR SHESHIG")
(74539 . "CUNEIFORM SIGN UR2")
(74540 . "CUNEIFORM SIGN UR2 TIMES A PLUS HA")
(74541 . "CUNEIFORM SIGN UR2 TIMES A PLUS NA")
(74542 . "CUNEIFORM SIGN UR2 TIMES AL")
(74543 . "CUNEIFORM SIGN UR2 TIMES HA")
(74544 . "CUNEIFORM SIGN UR2 TIMES NUN")
(74545 . "CUNEIFORM SIGN UR2 TIMES U2")
(74546 . "CUNEIFORM SIGN UR2 TIMES U2 PLUS ASH")
(74547 . "CUNEIFORM SIGN UR2 TIMES U2 PLUS BI")
(74548 . "CUNEIFORM SIGN UR4")
(74549 . "CUNEIFORM SIGN URI")
(74550 . "CUNEIFORM SIGN URI3")
(74551 . "CUNEIFORM SIGN URU")
(74552 . "CUNEIFORM SIGN URU TIMES A")
(74553 . "CUNEIFORM SIGN URU TIMES ASHGAB")
(74554 . "CUNEIFORM SIGN URU TIMES BAR")
(74555 . "CUNEIFORM SIGN URU TIMES DUN")
(74556 . "CUNEIFORM SIGN URU TIMES GA")
(74557 . "CUNEIFORM SIGN URU TIMES GAL")
(74558 . "CUNEIFORM SIGN URU TIMES GAN2 TENU")
(74559 . "CUNEIFORM SIGN URU TIMES GAR")
(74560 . "CUNEIFORM SIGN URU TIMES GU")
(74561 . "CUNEIFORM SIGN URU TIMES HA")
(74562 . "CUNEIFORM SIGN URU TIMES IGI")
(74563 . "CUNEIFORM SIGN URU TIMES IM")
(74564 . "CUNEIFORM SIGN URU TIMES ISH")
(74565 . "CUNEIFORM SIGN URU TIMES KI")
(74566 . "CUNEIFORM SIGN URU TIMES LUM")
(74567 . "CUNEIFORM SIGN URU TIMES MIN")
(74568 . "CUNEIFORM SIGN URU TIMES PA")
(74569 . "CUNEIFORM SIGN URU TIMES SHE")
(74570 . "CUNEIFORM SIGN URU TIMES SIG4")
(74571 . "CUNEIFORM SIGN URU TIMES TU")
(74572 . "CUNEIFORM SIGN URU TIMES U PLUS GUD")
(74573 . "CUNEIFORM SIGN URU TIMES UD")
(74574 . "CUNEIFORM SIGN URU TIMES URUDA")
(74575 . "CUNEIFORM SIGN URUDA")
(74576 . "CUNEIFORM SIGN URUDA TIMES U")
(74577 . "CUNEIFORM SIGN USH")
(74578 . "CUNEIFORM SIGN USH TIMES A")
(74579 . "CUNEIFORM SIGN USH TIMES KU")
(74580 . "CUNEIFORM SIGN USH TIMES KUR")
(74581 . "CUNEIFORM SIGN USH TIMES TAK4")
(74582 . "CUNEIFORM SIGN USHX")
(74583 . "CUNEIFORM SIGN USH2")
(74584 . "CUNEIFORM SIGN USHUMX")
(74585 . "CUNEIFORM SIGN UTUKI")
(74586 . "CUNEIFORM SIGN UZ3")
(74587 . "CUNEIFORM SIGN UZ3 TIMES KASKAL")
(74588 . "CUNEIFORM SIGN UZU")
(74589 . "CUNEIFORM SIGN ZA")
(74590 . "CUNEIFORM SIGN ZA TENU")
(74591 . "CUNEIFORM SIGN ZA SQUARED TIMES KUR")
(74592 . "CUNEIFORM SIGN ZAG")
(74593 . "CUNEIFORM SIGN ZAMX")
(74594 . "CUNEIFORM SIGN ZE2")
(74595 . "CUNEIFORM SIGN ZI")
(74596 . "CUNEIFORM SIGN ZI OVER ZI")
(74597 . "CUNEIFORM SIGN ZI3")
(74598 . "CUNEIFORM SIGN ZIB")
(74599 . "CUNEIFORM SIGN ZIB KABA TENU")
(74600 . "CUNEIFORM SIGN ZIG")
(74601 . "CUNEIFORM SIGN ZIZ2")
(74602 . "CUNEIFORM SIGN ZU")
(74603 . "CUNEIFORM SIGN ZU5")
(74604 . "CUNEIFORM SIGN ZU5 TIMES A")
(74605 . "CUNEIFORM SIGN ZUBUR")
(74606 . "CUNEIFORM SIGN ZUM")
(74607 . "CUNEIFORM SIGN KAP ELAMITE")
(74608 . "CUNEIFORM SIGN AB TIMES NUN")
(74609 . "CUNEIFORM SIGN AB2 TIMES A")
(74610 . "CUNEIFORM SIGN AMAR TIMES KUG")
(74611 . "CUNEIFORM SIGN DAG KISIM5 TIMES U2 PLUS MASH")
(74612 . "CUNEIFORM SIGN DAG3")
(74613 . "CUNEIFORM SIGN DISH PLUS SHU")
(74614 . "CUNEIFORM SIGN DUB TIMES SHE")
(74615 . "CUNEIFORM SIGN EZEN TIMES GUD")
(74616 . "CUNEIFORM SIGN EZEN TIMES SHE")
(74617 . "CUNEIFORM SIGN GA2 TIMES AN PLUS KAK PLUS A")
(74618 . "CUNEIFORM SIGN GA2 TIMES ASH2")
(74619 . "CUNEIFORM SIGN GE22")
(74620 . "CUNEIFORM SIGN GIG")
(74621 . "CUNEIFORM SIGN HUSH")
(74622 . "CUNEIFORM SIGN KA TIMES ANSHE")
(74623 . "CUNEIFORM SIGN KA TIMES ASH3")
(74624 . "CUNEIFORM SIGN KA TIMES GISH")
(74625 . "CUNEIFORM SIGN KA TIMES GUD")
(74626 . "CUNEIFORM SIGN KA TIMES HI TIMES ASH2")
(74627 . "CUNEIFORM SIGN KA TIMES LUM")
(74628 . "CUNEIFORM SIGN KA TIMES PA")
(74629 . "CUNEIFORM SIGN KA TIMES SHUL")
(74630 . "CUNEIFORM SIGN KA TIMES TU")
(74631 . "CUNEIFORM SIGN KA TIMES UR2")
(74632 . "CUNEIFORM SIGN LAGAB TIMES GI")
(74633 . "CUNEIFORM SIGN LU2 SHESHIG TIMES BAD")
(74634 . "CUNEIFORM SIGN LU2 TIMES ESH2 PLUS LAL")
(74635 . "CUNEIFORM SIGN LU2 TIMES SHU")
(74636 . "CUNEIFORM SIGN MESH")
(74637 . "CUNEIFORM SIGN MUSH3 TIMES ZA")
(74638 . "CUNEIFORM SIGN NA4")
(74639 . "CUNEIFORM SIGN NIN")
(74640 . "CUNEIFORM SIGN NIN9")
(74641 . "CUNEIFORM SIGN NINDA2 TIMES BAL")
(74642 . "CUNEIFORM SIGN NINDA2 TIMES GI")
(74643 . "CUNEIFORM SIGN NU11 ROTATED NINETY DEGREES")
(74644 . "CUNEIFORM SIGN PESH2 ASTERISK")
(74645 . "CUNEIFORM SIGN PIR2")
(74646 . "CUNEIFORM SIGN SAG TIMES IGI GUNU")
(74647 . "CUNEIFORM SIGN TI2")
(74648 . "CUNEIFORM SIGN UM TIMES ME")
(74649 . "CUNEIFORM SIGN U U")
((74650 . 74752) . #f)
(74752 . "CUNEIFORM NUMERIC SIGN TWO ASH")
(74753 . "CUNEIFORM NUMERIC SIGN THREE ASH")
(74754 . "CUNEIFORM NUMERIC SIGN FOUR ASH")
(74755 . "CUNEIFORM NUMERIC SIGN FIVE ASH")
(74756 . "CUNEIFORM NUMERIC SIGN SIX ASH")
(74757 . "CUNEIFORM NUMERIC SIGN SEVEN ASH")
(74758 . "CUNEIFORM NUMERIC SIGN EIGHT ASH")
(74759 . "CUNEIFORM NUMERIC SIGN NINE ASH")
(74760 . "CUNEIFORM NUMERIC SIGN THREE DISH")
(74761 . "CUNEIFORM NUMERIC SIGN FOUR DISH")
(74762 . "CUNEIFORM NUMERIC SIGN FIVE DISH")
(74763 . "CUNEIFORM NUMERIC SIGN SIX DISH")
(74764 . "CUNEIFORM NUMERIC SIGN SEVEN DISH")
(74765 . "CUNEIFORM NUMERIC SIGN EIGHT DISH")
(74766 . "CUNEIFORM NUMERIC SIGN NINE DISH")
(74767 . "CUNEIFORM NUMERIC SIGN FOUR U")
(74768 . "CUNEIFORM NUMERIC SIGN FIVE U")
(74769 . "CUNEIFORM NUMERIC SIGN SIX U")
(74770 . "CUNEIFORM NUMERIC SIGN SEVEN U")
(74771 . "CUNEIFORM NUMERIC SIGN EIGHT U")
(74772 . "CUNEIFORM NUMERIC SIGN NINE U")
(74773 . "CUNEIFORM NUMERIC SIGN ONE GESH2")
(74774 . "CUNEIFORM NUMERIC SIGN TWO GESH2")
(74775 . "CUNEIFORM NUMERIC SIGN THREE GESH2")
(74776 . "CUNEIFORM NUMERIC SIGN FOUR GESH2")
(74777 . "CUNEIFORM NUMERIC SIGN FIVE GESH2")
(74778 . "CUNEIFORM NUMERIC SIGN SIX GESH2")
(74779 . "CUNEIFORM NUMERIC SIGN SEVEN GESH2")
(74780 . "CUNEIFORM NUMERIC SIGN EIGHT GESH2")
(74781 . "CUNEIFORM NUMERIC SIGN NINE GESH2")
(74782 . "CUNEIFORM NUMERIC SIGN ONE GESHU")
(74783 . "CUNEIFORM NUMERIC SIGN TWO GESHU")
(74784 . "CUNEIFORM NUMERIC SIGN THREE GESHU")
(74785 . "CUNEIFORM NUMERIC SIGN FOUR GESHU")
(74786 . "CUNEIFORM NUMERIC SIGN FIVE GESHU")
(74787 . "CUNEIFORM NUMERIC SIGN TWO SHAR2")
(74788 . "CUNEIFORM NUMERIC SIGN THREE SHAR2")
(74789 . "CUNEIFORM NUMERIC SIGN THREE SHAR2 VARIANT FORM")
(74790 . "CUNEIFORM NUMERIC SIGN FOUR SHAR2")
(74791 . "CUNEIFORM NUMERIC SIGN FIVE SHAR2")
(74792 . "CUNEIFORM NUMERIC SIGN SIX SHAR2")
(74793 . "CUNEIFORM NUMERIC SIGN SEVEN SHAR2")
(74794 . "CUNEIFORM NUMERIC SIGN EIGHT SHAR2")
(74795 . "CUNEIFORM NUMERIC SIGN NINE SHAR2")
(74796 . "CUNEIFORM NUMERIC SIGN ONE SHARU")
(74797 . "CUNEIFORM NUMERIC SIGN TWO SHARU")
(74798 . "CUNEIFORM NUMERIC SIGN THREE SHARU")
(74799 . "CUNEIFORM NUMERIC SIGN THREE SHARU VARIANT FORM")
(74800 . "CUNEIFORM NUMERIC SIGN FOUR SHARU")
(74801 . "CUNEIFORM NUMERIC SIGN FIVE SHARU")
(74802 . "CUNEIFORM NUMERIC SIGN SHAR2 TIMES GAL PLUS DISH")
(74803 . "CUNEIFORM NUMERIC SIGN SHAR2 TIMES GAL PLUS MIN")
(74804 . "CUNEIFORM NUMERIC SIGN ONE BURU")
(74805 . "CUNEIFORM NUMERIC SIGN TWO BURU")
(74806 . "CUNEIFORM NUMERIC SIGN THREE BURU")
(74807 . "CUNEIFORM NUMERIC SIGN THREE BURU VARIANT FORM")
(74808 . "CUNEIFORM NUMERIC SIGN FOUR BURU")
(74809 . "CUNEIFORM NUMERIC SIGN FIVE BURU")
(74810 . "CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH16")
(74811 . "CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH21")
(74812 . "CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU")
(74813 . "CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU4")
(74814 . "CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU A")
(74815 . "CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU B")
(74816 . "CUNEIFORM NUMERIC SIGN SIX VARIANT FORM ASH9")
(74817 . "CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN3")
(74818 . "CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN A")
(74819 . "CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN B")
(74820 . "CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU")
(74821 . "CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU3")
(74822 . "CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU")
(74823 . "CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU3")
(74824 . "CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU4")
(74825 . "CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU A")
(74826 . "CUNEIFORM NUMERIC SIGN TWO ASH TENU")
(74827 . "CUNEIFORM NUMERIC SIGN THREE ASH TENU")
(74828 . "CUNEIFORM NUMERIC SIGN FOUR ASH TENU")
(74829 . "CUNEIFORM NUMERIC SIGN FIVE ASH TENU")
(74830 . "CUNEIFORM NUMERIC SIGN SIX ASH TENU")
(74831 . "CUNEIFORM NUMERIC SIGN ONE BAN2")
(74832 . "CUNEIFORM NUMERIC SIGN TWO BAN2")
(74833 . "CUNEIFORM NUMERIC SIGN THREE BAN2")
(74834 . "CUNEIFORM NUMERIC SIGN FOUR BAN2")
(74835 . "CUNEIFORM NUMERIC SIGN FOUR BAN2 VARIANT FORM")
(74836 . "CUNEIFORM NUMERIC SIGN FIVE BAN2")
(74837 . "CUNEIFORM NUMERIC SIGN FIVE BAN2 VARIANT FORM")
(74838 . "CUNEIFORM NUMERIC SIGN NIGIDAMIN")
(74839 . "CUNEIFORM NUMERIC SIGN NIGIDAESH")
(74840 . "CUNEIFORM NUMERIC SIGN ONE ESHE3")
(74841 . "CUNEIFORM NUMERIC SIGN TWO ESHE3")
(74842 . "CUNEIFORM NUMERIC SIGN ONE THIRD DISH")
(74843 . "CUNEIFORM NUMERIC SIGN TWO THIRDS DISH")
(74844 . "CUNEIFORM NUMERIC SIGN FIVE SIXTHS DISH")
(74845 . "CUNEIFORM NUMERIC SIGN ONE THIRD VARIANT FORM A")
(74846 . "CUNEIFORM NUMERIC SIGN TWO THIRDS VARIANT FORM A")
(74847 . "CUNEIFORM NUMERIC SIGN ONE EIGHTH ASH")
(74848 . "CUNEIFORM NUMERIC SIGN ONE QUARTER ASH")
(74849 . "CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE SIXTH")
(74850 . "CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE QUARTER")
(74851 . "CUNEIFORM NUMERIC SIGN ONE QUARTER GUR")
(74852 . "CUNEIFORM NUMERIC SIGN ONE HALF GUR")
(74853 . "CUNEIFORM NUMERIC SIGN ELAMITE ONE THIRD")
(74854 . "CUNEIFORM NUMERIC SIGN ELAMITE TWO THIRDS")
(74855 . "CUNEIFORM NUMERIC SIGN ELAMITE FORTY")
(74856 . "CUNEIFORM NUMERIC SIGN ELAMITE FIFTY")
(74857 . "CUNEIFORM NUMERIC SIGN FOUR U VARIANT FORM")
(74858 . "CUNEIFORM NUMERIC SIGN FIVE U VARIANT FORM")
(74859 . "CUNEIFORM NUMERIC SIGN SIX U VARIANT FORM")
(74860 . "CUNEIFORM NUMERIC SIGN SEVEN U VARIANT FORM")
(74861 . "CUNEIFORM NUMERIC SIGN EIGHT U VARIANT FORM")
(74862 . "CUNEIFORM NUMERIC SIGN NINE U VARIANT FORM")
(74863 . #f)
(74864 . "CUNEIFORM PUNCTUATION SIGN OLD ASSYRIAN WORD DIVIDER")
(74865 . "CUNEIFORM PUNCTUATION SIGN VERTICAL COLON")
(74866 . "CUNEIFORM PUNCTUATION SIGN DIAGONAL COLON")
(74867 . "CUNEIFORM PUNCTUATION SIGN DIAGONAL TRICOLON")
(74868 . "CUNEIFORM PUNCTUATION SIGN DIAGONAL QUADCOLON")
((74869 . 74880) . #f)
(74880 . "CUNEIFORM SIGN AB TIMES NUN TENU")
(74881 . "CUNEIFORM SIGN AB TIMES SHU2")
(74882 . "CUNEIFORM SIGN AD TIMES ESH2")
(74883 . "CUNEIFORM SIGN BAD TIMES DISH TENU")
(74884 . "CUNEIFORM SIGN BAHAR2 TIMES AB2")
(74885 . "CUNEIFORM SIGN BAHAR2 TIMES NI")
(74886 . "CUNEIFORM SIGN BAHAR2 TIMES ZA")
(74887 . "CUNEIFORM SIGN BU OVER BU TIMES NA2")
(74888 . "CUNEIFORM SIGN DA TIMES TAK4")
(74889 . "CUNEIFORM SIGN DAG TIMES KUR")
(74890 . "CUNEIFORM SIGN DIM TIMES IGI")
(74891 . "CUNEIFORM SIGN DIM TIMES U U U")
(74892 . "CUNEIFORM SIGN DIM2 TIMES UD")
(74893 . "CUNEIFORM SIGN DUG TIMES ANSHE")
(74894 . "CUNEIFORM SIGN DUG TIMES ASH")
(74895 . "CUNEIFORM SIGN DUG TIMES ASH AT LEFT")
(74896 . "CUNEIFORM SIGN DUG TIMES DIN")
(74897 . "CUNEIFORM SIGN DUG TIMES DUN")
(74898 . "CUNEIFORM SIGN DUG TIMES ERIN2")
(74899 . "CUNEIFORM SIGN DUG TIMES GA")
(74900 . "CUNEIFORM SIGN DUG TIMES GI")
(74901 . "CUNEIFORM SIGN DUG TIMES GIR2 GUNU")
(74902 . "CUNEIFORM SIGN DUG TIMES GISH")
(74903 . "CUNEIFORM SIGN DUG TIMES HA")
(74904 . "CUNEIFORM SIGN DUG TIMES HI")
(74905 . "CUNEIFORM SIGN DUG TIMES IGI GUNU")
(74906 . "CUNEIFORM SIGN DUG TIMES KASKAL")
(74907 . "CUNEIFORM SIGN DUG TIMES KUR")
(74908 . "CUNEIFORM SIGN DUG TIMES KUSHU2")
(74909 . "CUNEIFORM SIGN DUG TIMES KUSHU2 PLUS KASKAL")
(74910 . "CUNEIFORM SIGN DUG TIMES LAK-020")
(74911 . "CUNEIFORM SIGN DUG TIMES LAM")
(74912 . "CUNEIFORM SIGN DUG TIMES LAM TIMES KUR")
(74913 . "CUNEIFORM SIGN DUG TIMES LUH PLUS GISH")
(74914 . "CUNEIFORM SIGN DUG TIMES MASH")
(74915 . "CUNEIFORM SIGN DUG TIMES MES")
(74916 . "CUNEIFORM SIGN DUG TIMES MI")
(74917 . "CUNEIFORM SIGN DUG TIMES NI")
(74918 . "CUNEIFORM SIGN DUG TIMES PI")
(74919 . "CUNEIFORM SIGN DUG TIMES SHE")
(74920 . "CUNEIFORM SIGN DUG TIMES SI GUNU")
(74921 . "CUNEIFORM SIGN E2 TIMES KUR")
(74922 . "CUNEIFORM SIGN E2 TIMES PAP")
(74923 . "CUNEIFORM SIGN ERIN2 X")
(74924 . "CUNEIFORM SIGN ESH2 CROSSING ESH2")
(74925 . "CUNEIFORM SIGN EZEN SHESHIG TIMES ASH")
(74926 . "CUNEIFORM SIGN EZEN SHESHIG TIMES HI")
(74927 . "CUNEIFORM SIGN EZEN SHESHIG TIMES IGI GUNU")
(74928 . "CUNEIFORM SIGN EZEN SHESHIG TIMES LA")
(74929 . "CUNEIFORM SIGN EZEN SHESHIG TIMES LAL")
(74930 . "CUNEIFORM SIGN EZEN SHESHIG TIMES ME")
(74931 . "CUNEIFORM SIGN EZEN SHESHIG TIMES MES")
(74932 . "CUNEIFORM SIGN EZEN SHESHIG TIMES SU")
(74933 . "CUNEIFORM SIGN EZEN TIMES SU")
(74934 . "CUNEIFORM SIGN GA2 TIMES BAHAR2")
(74935 . "CUNEIFORM SIGN GA2 TIMES DIM GUNU")
(74936 . "CUNEIFORM SIGN GA2 TIMES DUG TIMES IGI GUNU")
(74937 . "CUNEIFORM SIGN GA2 TIMES DUG TIMES KASKAL")
(74938 . "CUNEIFORM SIGN GA2 TIMES EREN")
(74939 . "CUNEIFORM SIGN GA2 TIMES GA")
(74940 . "CUNEIFORM SIGN GA2 TIMES GAR PLUS DI")
(74941 . "CUNEIFORM SIGN GA2 TIMES GAR PLUS NE")
(74942 . "CUNEIFORM SIGN GA2 TIMES HA PLUS A")
(74943 . "CUNEIFORM SIGN GA2 TIMES KUSHU2 PLUS KASKAL")
(74944 . "CUNEIFORM SIGN GA2 TIMES LAM")
(74945 . "CUNEIFORM SIGN GA2 TIMES LAM TIMES KUR")
(74946 . "CUNEIFORM SIGN GA2 TIMES LUH")
(74947 . "CUNEIFORM SIGN GA2 TIMES MUSH")
(74948 . "CUNEIFORM SIGN GA2 TIMES NE")
(74949 . "CUNEIFORM SIGN GA2 TIMES NE PLUS E2")
(74950 . "CUNEIFORM SIGN GA2 TIMES NE PLUS GI")
(74951 . "CUNEIFORM SIGN GA2 TIMES SHIM")
(74952 . "CUNEIFORM SIGN GA2 TIMES ZIZ2")
(74953 . "CUNEIFORM SIGN GABA ROTATED NINETY DEGREES")
(74954 . "CUNEIFORM SIGN GESHTIN TIMES U")
(74955 . "CUNEIFORM SIGN GISH TIMES GISH CROSSING GISH")
(74956 . "CUNEIFORM SIGN GU2 TIMES IGI GUNU")
(74957 . "CUNEIFORM SIGN GUD PLUS GISH TIMES TAK4")
(74958 . "CUNEIFORM SIGN HA TENU GUNU")
(74959 . "CUNEIFORM SIGN HI TIMES ASH OVER HI TIMES ASH")
(74960 . "CUNEIFORM SIGN KA TIMES BU")
(74961 . "CUNEIFORM SIGN KA TIMES KA")
(74962 . "CUNEIFORM SIGN KA TIMES U U U")
(74963 . "CUNEIFORM SIGN KA TIMES UR")
(74964 . "CUNEIFORM SIGN LAGAB TIMES ZU OVER ZU")
(74965 . "CUNEIFORM SIGN LAK-003")
(74966 . "CUNEIFORM SIGN LAK-021")
(74967 . "CUNEIFORM SIGN LAK-025")
(74968 . "CUNEIFORM SIGN LAK-030")
(74969 . "CUNEIFORM SIGN LAK-050")
(74970 . "CUNEIFORM SIGN LAK-051")
(74971 . "CUNEIFORM SIGN LAK-062")
(74972 . "CUNEIFORM SIGN LAK-079 OVER LAK-079 GUNU")
(74973 . "CUNEIFORM SIGN LAK-080")
(74974 . "CUNEIFORM SIGN LAK-081 OVER LAK-081")
(74975 . "CUNEIFORM SIGN LAK-092")
(74976 . "CUNEIFORM SIGN LAK-130")
(74977 . "CUNEIFORM SIGN LAK-142")
(74978 . "CUNEIFORM SIGN LAK-210")
(74979 . "CUNEIFORM SIGN LAK-219")
(74980 . "CUNEIFORM SIGN LAK-220")
(74981 . "CUNEIFORM SIGN LAK-225")
(74982 . "CUNEIFORM SIGN LAK-228")
(74983 . "CUNEIFORM SIGN LAK-238")
(74984 . "CUNEIFORM SIGN LAK-265")
(74985 . "CUNEIFORM SIGN LAK-266")
(74986 . "CUNEIFORM SIGN LAK-343")
(74987 . "CUNEIFORM SIGN LAK-347")
(74988 . "CUNEIFORM SIGN LAK-348")
(74989 . "CUNEIFORM SIGN LAK-383")
(74990 . "CUNEIFORM SIGN LAK-384")
(74991 . "CUNEIFORM SIGN LAK-390")
(74992 . "CUNEIFORM SIGN LAK-441")
(74993 . "CUNEIFORM SIGN LAK-449")
(74994 . "CUNEIFORM SIGN LAK-449 TIMES GU")
(74995 . "CUNEIFORM SIGN LAK-449 TIMES IGI")
(74996 . "CUNEIFORM SIGN LAK-449 TIMES PAP PLUS LU3")
(74997 . "CUNEIFORM SIGN LAK-449 TIMES PAP PLUS PAP PLUS LU3")
(74998 . "CUNEIFORM SIGN LAK-449 TIMES U2 PLUS BA")
(74999 . "CUNEIFORM SIGN LAK-450")
(75000 . "CUNEIFORM SIGN LAK-457")
(75001 . "CUNEIFORM SIGN LAK-470")
(75002 . "CUNEIFORM SIGN LAK-483")
(75003 . "CUNEIFORM SIGN LAK-490")
(75004 . "CUNEIFORM SIGN LAK-492")
(75005 . "CUNEIFORM SIGN LAK-493")
(75006 . "CUNEIFORM SIGN LAK-495")
(75007 . "CUNEIFORM SIGN LAK-550")
(75008 . "CUNEIFORM SIGN LAK-608")
(75009 . "CUNEIFORM SIGN LAK-617")
(75010 . "CUNEIFORM SIGN LAK-617 TIMES ASH")
(75011 . "CUNEIFORM SIGN LAK-617 TIMES BAD")
(75012 . "CUNEIFORM SIGN LAK-617 TIMES DUN3 GUNU GUNU")
(75013 . "CUNEIFORM SIGN LAK-617 TIMES KU3")
(75014 . "CUNEIFORM SIGN LAK-617 TIMES LA")
(75015 . "CUNEIFORM SIGN LAK-617 TIMES TAR")
(75016 . "CUNEIFORM SIGN LAK-617 TIMES TE")
(75017 . "CUNEIFORM SIGN LAK-617 TIMES U2")
(75018 . "CUNEIFORM SIGN LAK-617 TIMES UD")
(75019 . "CUNEIFORM SIGN LAK-617 TIMES URUDA")
(75020 . "CUNEIFORM SIGN LAK-636")
(75021 . "CUNEIFORM SIGN LAK-648")
(75022 . "CUNEIFORM SIGN LAK-648 TIMES DUB")
(75023 . "CUNEIFORM SIGN LAK-648 TIMES GA")
(75024 . "CUNEIFORM SIGN LAK-648 TIMES IGI")
(75025 . "CUNEIFORM SIGN LAK-648 TIMES IGI GUNU")
(75026 . "CUNEIFORM SIGN LAK-648 TIMES NI")
(75027 . "CUNEIFORM SIGN LAK-648 TIMES PAP PLUS PAP PLUS LU3")
(75028 . "CUNEIFORM SIGN LAK-648 TIMES SHESH PLUS KI")
(75029 . "CUNEIFORM SIGN LAK-648 TIMES UD")
(75030 . "CUNEIFORM SIGN LAK-648 TIMES URUDA")
(75031 . "CUNEIFORM SIGN LAK-724")
(75032 . "CUNEIFORM SIGN LAK-749")
(75033 . "CUNEIFORM SIGN LU2 GUNU TIMES ASH")
(75034 . "CUNEIFORM SIGN LU2 TIMES DISH")
(75035 . "CUNEIFORM SIGN LU2 TIMES HAL")
(75036 . "CUNEIFORM SIGN LU2 TIMES PAP")
(75037 . "CUNEIFORM SIGN LU2 TIMES PAP PLUS PAP PLUS LU3")
(75038 . "CUNEIFORM SIGN LU2 TIMES TAK4")
(75039 . "CUNEIFORM SIGN MI PLUS ZA7")
(75040 . "CUNEIFORM SIGN MUSH OVER MUSH TIMES GA")
(75041 . "CUNEIFORM SIGN MUSH OVER MUSH TIMES KAK")
(75042 . "CUNEIFORM SIGN NINDA2 TIMES DIM GUNU")
(75043 . "CUNEIFORM SIGN NINDA2 TIMES GISH")
(75044 . "CUNEIFORM SIGN NINDA2 TIMES GUL")
(75045 . "CUNEIFORM SIGN NINDA2 TIMES HI")
(75046 . "CUNEIFORM SIGN NINDA2 TIMES KESH2")
(75047 . "CUNEIFORM SIGN NINDA2 TIMES LAK-050")
(75048 . "CUNEIFORM SIGN NINDA2 TIMES MASH")
(75049 . "CUNEIFORM SIGN NINDA2 TIMES PAP PLUS PAP")
(75050 . "CUNEIFORM SIGN NINDA2 TIMES U")
(75051 . "CUNEIFORM SIGN NINDA2 TIMES U PLUS U")
(75052 . "CUNEIFORM SIGN NINDA2 TIMES URUDA")
(75053 . "CUNEIFORM SIGN SAG GUNU TIMES HA")
(75054 . "CUNEIFORM SIGN SAG TIMES EN")
(75055 . "CUNEIFORM SIGN SAG TIMES SHE AT LEFT")
(75056 . "CUNEIFORM SIGN SAG TIMES TAK4")
(75057 . "CUNEIFORM SIGN SHA6 TENU")
(75058 . "CUNEIFORM SIGN SHE OVER SHE")
(75059 . "CUNEIFORM SIGN SHE PLUS HUB2")
(75060 . "CUNEIFORM SIGN SHE PLUS NAM2")
(75061 . "CUNEIFORM SIGN SHE PLUS SAR")
(75062 . "CUNEIFORM SIGN SHU2 PLUS DUG TIMES NI")
(75063 . "CUNEIFORM SIGN SHU2 PLUS E2 TIMES AN")
(75064 . "CUNEIFORM SIGN SI TIMES TAK4")
(75065 . "CUNEIFORM SIGN TAK4 PLUS SAG")
(75066 . "CUNEIFORM SIGN TUM TIMES GAN2 TENU")
(75067 . "CUNEIFORM SIGN TUM TIMES THREE DISH")
(75068 . "CUNEIFORM SIGN UR2 INVERTED")
(75069 . "CUNEIFORM SIGN UR2 TIMES UD")
(75070 . "CUNEIFORM SIGN URU TIMES DARA3")
(75071 . "CUNEIFORM SIGN URU TIMES LAK-668")
(75072 . "CUNEIFORM SIGN URU TIMES LU3")
(75073 . "CUNEIFORM SIGN ZA7")
(75074 . "CUNEIFORM SIGN ZU OVER ZU PLUS SAR")
(75075 . "CUNEIFORM SIGN ZU5 TIMES THREE DISH TENU")
((75076 . 77824) . #f)
(77824 . "EGYPTIAN HIEROGLYPH A001")
(77825 . "EGYPTIAN HIEROGLYPH A002")
(77826 . "EGYPTIAN HIEROGLYPH A003")
(77827 . "EGYPTIAN HIEROGLYPH A004")
(77828 . "EGYPTIAN HIEROGLYPH A005")
(77829 . "EGYPTIAN HIEROGLYPH A005A")
(77830 . "EGYPTIAN HIEROGLYPH A006")
(77831 . "EGYPTIAN HIEROGLYPH A006A")
(77832 . "EGYPTIAN HIEROGLYPH A006B")
(77833 . "EGYPTIAN HIEROGLYPH A007")
(77834 . "EGYPTIAN HIEROGLYPH A008")
(77835 . "EGYPTIAN HIEROGLYPH A009")
(77836 . "EGYPTIAN HIEROGLYPH A010")
(77837 . "EGYPTIAN HIEROGLYPH A011")
(77838 . "EGYPTIAN HIEROGLYPH A012")
(77839 . "EGYPTIAN HIEROGLYPH A013")
(77840 . "EGYPTIAN HIEROGLYPH A014")
(77841 . "EGYPTIAN HIEROGLYPH A014A")
(77842 . "EGYPTIAN HIEROGLYPH A015")
(77843 . "EGYPTIAN HIEROGLYPH A016")
(77844 . "EGYPTIAN HIEROGLYPH A017")
(77845 . "EGYPTIAN HIEROGLYPH A017A")
(77846 . "EGYPTIAN HIEROGLYPH A018")
(77847 . "EGYPTIAN HIEROGLYPH A019")
(77848 . "EGYPTIAN HIEROGLYPH A020")
(77849 . "EGYPTIAN HIEROGLYPH A021")
(77850 . "EGYPTIAN HIEROGLYPH A022")
(77851 . "EGYPTIAN HIEROGLYPH A023")
(77852 . "EGYPTIAN HIEROGLYPH A024")
(77853 . "EGYPTIAN HIEROGLYPH A025")
(77854 . "EGYPTIAN HIEROGLYPH A026")
(77855 . "EGYPTIAN HIEROGLYPH A027")
(77856 . "EGYPTIAN HIEROGLYPH A028")
(77857 . "EGYPTIAN HIEROGLYPH A029")
(77858 . "EGYPTIAN HIEROGLYPH A030")
(77859 . "EGYPTIAN HIEROGLYPH A031")
(77860 . "EGYPTIAN HIEROGLYPH A032")
(77861 . "EGYPTIAN HIEROGLYPH A032A")
(77862 . "EGYPTIAN HIEROGLYPH A033")
(77863 . "EGYPTIAN HIEROGLYPH A034")
(77864 . "EGYPTIAN HIEROGLYPH A035")
(77865 . "EGYPTIAN HIEROGLYPH A036")
(77866 . "EGYPTIAN HIEROGLYPH A037")
(77867 . "EGYPTIAN HIEROGLYPH A038")
(77868 . "EGYPTIAN HIEROGLYPH A039")
(77869 . "EGYPTIAN HIEROGLYPH A040")
(77870 . "EGYPTIAN HIEROGLYPH A040A")
(77871 . "EGYPTIAN HIEROGLYPH A041")
(77872 . "EGYPTIAN HIEROGLYPH A042")
(77873 . "EGYPTIAN HIEROGLYPH A042A")
(77874 . "EGYPTIAN HIEROGLYPH A043")
(77875 . "EGYPTIAN HIEROGLYPH A043A")
(77876 . "EGYPTIAN HIEROGLYPH A044")
(77877 . "EGYPTIAN HIEROGLYPH A045")
(77878 . "EGYPTIAN HIEROGLYPH A045A")
(77879 . "EGYPTIAN HIEROGLYPH A046")
(77880 . "EGYPTIAN HIEROGLYPH A047")
(77881 . "EGYPTIAN HIEROGLYPH A048")
(77882 . "EGYPTIAN HIEROGLYPH A049")
(77883 . "EGYPTIAN HIEROGLYPH A050")
(77884 . "EGYPTIAN HIEROGLYPH A051")
(77885 . "EGYPTIAN HIEROGLYPH A052")
(77886 . "EGYPTIAN HIEROGLYPH A053")
(77887 . "EGYPTIAN HIEROGLYPH A054")
(77888 . "EGYPTIAN HIEROGLYPH A055")
(77889 . "EGYPTIAN HIEROGLYPH A056")
(77890 . "EGYPTIAN HIEROGLYPH A057")
(77891 . "EGYPTIAN HIEROGLYPH A058")
(77892 . "EGYPTIAN HIEROGLYPH A059")
(77893 . "EGYPTIAN HIEROGLYPH A060")
(77894 . "EGYPTIAN HIEROGLYPH A061")
(77895 . "EGYPTIAN HIEROGLYPH A062")
(77896 . "EGYPTIAN HIEROGLYPH A063")
(77897 . "EGYPTIAN HIEROGLYPH A064")
(77898 . "EGYPTIAN HIEROGLYPH A065")
(77899 . "EGYPTIAN HIEROGLYPH A066")
(77900 . "EGYPTIAN HIEROGLYPH A067")
(77901 . "EGYPTIAN HIEROGLYPH A068")
(77902 . "EGYPTIAN HIEROGLYPH A069")
(77903 . "EGYPTIAN HIEROGLYPH A070")
(77904 . "EGYPTIAN HIEROGLYPH B001")
(77905 . "EGYPTIAN HIEROGLYPH B002")
(77906 . "EGYPTIAN HIEROGLYPH B003")
(77907 . "EGYPTIAN HIEROGLYPH B004")
(77908 . "EGYPTIAN HIEROGLYPH B005")
(77909 . "EGYPTIAN HIEROGLYPH B005A")
(77910 . "EGYPTIAN HIEROGLYPH B006")
(77911 . "EGYPTIAN HIEROGLYPH B007")
(77912 . "EGYPTIAN HIEROGLYPH B008")
(77913 . "EGYPTIAN HIEROGLYPH B009")
(77914 . "EGYPTIAN HIEROGLYPH C001")
(77915 . "EGYPTIAN HIEROGLYPH C002")
(77916 . "EGYPTIAN HIEROGLYPH C002A")
(77917 . "EGYPTIAN HIEROGLYPH C002B")
(77918 . "EGYPTIAN HIEROGLYPH C002C")
(77919 . "EGYPTIAN HIEROGLYPH C003")
(77920 . "EGYPTIAN HIEROGLYPH C004")
(77921 . "EGYPTIAN HIEROGLYPH C005")
(77922 . "EGYPTIAN HIEROGLYPH C006")
(77923 . "EGYPTIAN HIEROGLYPH C007")
(77924 . "EGYPTIAN HIEROGLYPH C008")
(77925 . "EGYPTIAN HIEROGLYPH C009")
(77926 . "EGYPTIAN HIEROGLYPH C010")
(77927 . "EGYPTIAN HIEROGLYPH C010A")
(77928 . "EGYPTIAN HIEROGLYPH C011")
(77929 . "EGYPTIAN HIEROGLYPH C012")
(77930 . "EGYPTIAN HIEROGLYPH C013")
(77931 . "EGYPTIAN HIEROGLYPH C014")
(77932 . "EGYPTIAN HIEROGLYPH C015")
(77933 . "EGYPTIAN HIEROGLYPH C016")
(77934 . "EGYPTIAN HIEROGLYPH C017")
(77935 . "EGYPTIAN HIEROGLYPH C018")
(77936 . "EGYPTIAN HIEROGLYPH C019")
(77937 . "EGYPTIAN HIEROGLYPH C020")
(77938 . "EGYPTIAN HIEROGLYPH C021")
(77939 . "EGYPTIAN HIEROGLYPH C022")
(77940 . "EGYPTIAN HIEROGLYPH C023")
(77941 . "EGYPTIAN HIEROGLYPH C024")
(77942 . "EGYPTIAN HIEROGLYPH D001")
(77943 . "EGYPTIAN HIEROGLYPH D002")
(77944 . "EGYPTIAN HIEROGLYPH D003")
(77945 . "EGYPTIAN HIEROGLYPH D004")
(77946 . "EGYPTIAN HIEROGLYPH D005")
(77947 . "EGYPTIAN HIEROGLYPH D006")
(77948 . "EGYPTIAN HIEROGLYPH D007")
(77949 . "EGYPTIAN HIEROGLYPH D008")
(77950 . "EGYPTIAN HIEROGLYPH D008A")
(77951 . "EGYPTIAN HIEROGLYPH D009")
(77952 . "EGYPTIAN HIEROGLYPH D010")
(77953 . "EGYPTIAN HIEROGLYPH D011")
(77954 . "EGYPTIAN HIEROGLYPH D012")
(77955 . "EGYPTIAN HIEROGLYPH D013")
(77956 . "EGYPTIAN HIEROGLYPH D014")
(77957 . "EGYPTIAN HIEROGLYPH D015")
(77958 . "EGYPTIAN HIEROGLYPH D016")
(77959 . "EGYPTIAN HIEROGLYPH D017")
(77960 . "EGYPTIAN HIEROGLYPH D018")
(77961 . "EGYPTIAN HIEROGLYPH D019")
(77962 . "EGYPTIAN HIEROGLYPH D020")
(77963 . "EGYPTIAN HIEROGLYPH D021")
(77964 . "EGYPTIAN HIEROGLYPH D022")
(77965 . "EGYPTIAN HIEROGLYPH D023")
(77966 . "EGYPTIAN HIEROGLYPH D024")
(77967 . "EGYPTIAN HIEROGLYPH D025")
(77968 . "EGYPTIAN HIEROGLYPH D026")
(77969 . "EGYPTIAN HIEROGLYPH D027")
(77970 . "EGYPTIAN HIEROGLYPH D027A")
(77971 . "EGYPTIAN HIEROGLYPH D028")
(77972 . "EGYPTIAN HIEROGLYPH D029")
(77973 . "EGYPTIAN HIEROGLYPH D030")
(77974 . "EGYPTIAN HIEROGLYPH D031")
(77975 . "EGYPTIAN HIEROGLYPH D031A")
(77976 . "EGYPTIAN HIEROGLYPH D032")
(77977 . "EGYPTIAN HIEROGLYPH D033")
(77978 . "EGYPTIAN HIEROGLYPH D034")
(77979 . "EGYPTIAN HIEROGLYPH D034A")
(77980 . "EGYPTIAN HIEROGLYPH D035")
(77981 . "EGYPTIAN HIEROGLYPH D036")
(77982 . "EGYPTIAN HIEROGLYPH D037")
(77983 . "EGYPTIAN HIEROGLYPH D038")
(77984 . "EGYPTIAN HIEROGLYPH D039")
(77985 . "EGYPTIAN HIEROGLYPH D040")
(77986 . "EGYPTIAN HIEROGLYPH D041")
(77987 . "EGYPTIAN HIEROGLYPH D042")
(77988 . "EGYPTIAN HIEROGLYPH D043")
(77989 . "EGYPTIAN HIEROGLYPH D044")
(77990 . "EGYPTIAN HIEROGLYPH D045")
(77991 . "EGYPTIAN HIEROGLYPH D046")
(77992 . "EGYPTIAN HIEROGLYPH D046A")
(77993 . "EGYPTIAN HIEROGLYPH D047")
(77994 . "EGYPTIAN HIEROGLYPH D048")
(77995 . "EGYPTIAN HIEROGLYPH D048A")
(77996 . "EGYPTIAN HIEROGLYPH D049")
(77997 . "EGYPTIAN HIEROGLYPH D050")
(77998 . "EGYPTIAN HIEROGLYPH D050A")
(77999 . "EGYPTIAN HIEROGLYPH D050B")
(78000 . "EGYPTIAN HIEROGLYPH D050C")
(78001 . "EGYPTIAN HIEROGLYPH D050D")
(78002 . "EGYPTIAN HIEROGLYPH D050E")
(78003 . "EGYPTIAN HIEROGLYPH D050F")
(78004 . "EGYPTIAN HIEROGLYPH D050G")
(78005 . "EGYPTIAN HIEROGLYPH D050H")
(78006 . "EGYPTIAN HIEROGLYPH D050I")
(78007 . "EGYPTIAN HIEROGLYPH D051")
(78008 . "EGYPTIAN HIEROGLYPH D052")
(78009 . "EGYPTIAN HIEROGLYPH D052A")
(78010 . "EGYPTIAN HIEROGLYPH D053")
(78011 . "EGYPTIAN HIEROGLYPH D054")
(78012 . "EGYPTIAN HIEROGLYPH D054A")
(78013 . "EGYPTIAN HIEROGLYPH D055")
(78014 . "EGYPTIAN HIEROGLYPH D056")
(78015 . "EGYPTIAN HIEROGLYPH D057")
(78016 . "EGYPTIAN HIEROGLYPH D058")
(78017 . "EGYPTIAN HIEROGLYPH D059")
(78018 . "EGYPTIAN HIEROGLYPH D060")
(78019 . "EGYPTIAN HIEROGLYPH D061")
(78020 . "EGYPTIAN HIEROGLYPH D062")
(78021 . "EGYPTIAN HIEROGLYPH D063")
(78022 . "EGYPTIAN HIEROGLYPH D064")
(78023 . "EGYPTIAN HIEROGLYPH D065")
(78024 . "EGYPTIAN HIEROGLYPH D066")
(78025 . "EGYPTIAN HIEROGLYPH D067")
(78026 . "EGYPTIAN HIEROGLYPH D067A")
(78027 . "EGYPTIAN HIEROGLYPH D067B")
(78028 . "EGYPTIAN HIEROGLYPH D067C")
(78029 . "EGYPTIAN HIEROGLYPH D067D")
(78030 . "EGYPTIAN HIEROGLYPH D067E")
(78031 . "EGYPTIAN HIEROGLYPH D067F")
(78032 . "EGYPTIAN HIEROGLYPH D067G")
(78033 . "EGYPTIAN HIEROGLYPH D067H")
(78034 . "EGYPTIAN HIEROGLYPH E001")
(78035 . "EGYPTIAN HIEROGLYPH E002")
(78036 . "EGYPTIAN HIEROGLYPH E003")
(78037 . "EGYPTIAN HIEROGLYPH E004")
(78038 . "EGYPTIAN HIEROGLYPH E005")
(78039 . "EGYPTIAN HIEROGLYPH E006")
(78040 . "EGYPTIAN HIEROGLYPH E007")
(78041 . "EGYPTIAN HIEROGLYPH E008")
(78042 . "EGYPTIAN HIEROGLYPH E008A")
(78043 . "EGYPTIAN HIEROGLYPH E009")
(78044 . "EGYPTIAN HIEROGLYPH E009A")
(78045 . "EGYPTIAN HIEROGLYPH E010")
(78046 . "EGYPTIAN HIEROGLYPH E011")
(78047 . "EGYPTIAN HIEROGLYPH E012")
(78048 . "EGYPTIAN HIEROGLYPH E013")
(78049 . "EGYPTIAN HIEROGLYPH E014")
(78050 . "EGYPTIAN HIEROGLYPH E015")
(78051 . "EGYPTIAN HIEROGLYPH E016")
(78052 . "EGYPTIAN HIEROGLYPH E016A")
(78053 . "EGYPTIAN HIEROGLYPH E017")
(78054 . "EGYPTIAN HIEROGLYPH E017A")
(78055 . "EGYPTIAN HIEROGLYPH E018")
(78056 . "EGYPTIAN HIEROGLYPH E019")
(78057 . "EGYPTIAN HIEROGLYPH E020")
(78058 . "EGYPTIAN HIEROGLYPH E020A")
(78059 . "EGYPTIAN HIEROGLYPH E021")
(78060 . "EGYPTIAN HIEROGLYPH E022")
(78061 . "EGYPTIAN HIEROGLYPH E023")
(78062 . "EGYPTIAN HIEROGLYPH E024")
(78063 . "EGYPTIAN HIEROGLYPH E025")
(78064 . "EGYPTIAN HIEROGLYPH E026")
(78065 . "EGYPTIAN HIEROGLYPH E027")
(78066 . "EGYPTIAN HIEROGLYPH E028")
(78067 . "EGYPTIAN HIEROGLYPH E028A")
(78068 . "EGYPTIAN HIEROGLYPH E029")
(78069 . "EGYPTIAN HIEROGLYPH E030")
(78070 . "EGYPTIAN HIEROGLYPH E031")
(78071 . "EGYPTIAN HIEROGLYPH E032")
(78072 . "EGYPTIAN HIEROGLYPH E033")
(78073 . "EGYPTIAN HIEROGLYPH E034")
(78074 . "EGYPTIAN HIEROGLYPH E034A")
(78075 . "EGYPTIAN HIEROGLYPH E036")
(78076 . "EGYPTIAN HIEROGLYPH E037")
(78077 . "EGYPTIAN HIEROGLYPH E038")
(78078 . "EGYPTIAN HIEROGLYPH F001")
(78079 . "EGYPTIAN HIEROGLYPH F001A")
(78080 . "EGYPTIAN HIEROGLYPH F002")
(78081 . "EGYPTIAN HIEROGLYPH F003")
(78082 . "EGYPTIAN HIEROGLYPH F004")
(78083 . "EGYPTIAN HIEROGLYPH F005")
(78084 . "EGYPTIAN HIEROGLYPH F006")
(78085 . "EGYPTIAN HIEROGLYPH F007")
(78086 . "EGYPTIAN HIEROGLYPH F008")
(78087 . "EGYPTIAN HIEROGLYPH F009")
(78088 . "EGYPTIAN HIEROGLYPH F010")
(78089 . "EGYPTIAN HIEROGLYPH F011")
(78090 . "EGYPTIAN HIEROGLYPH F012")
(78091 . "EGYPTIAN HIEROGLYPH F013")
(78092 . "EGYPTIAN HIEROGLYPH F013A")
(78093 . "EGYPTIAN HIEROGLYPH F014")
(78094 . "EGYPTIAN HIEROGLYPH F015")
(78095 . "EGYPTIAN HIEROGLYPH F016")
(78096 . "EGYPTIAN HIEROGLYPH F017")
(78097 . "EGYPTIAN HIEROGLYPH F018")
(78098 . "EGYPTIAN HIEROGLYPH F019")
(78099 . "EGYPTIAN HIEROGLYPH F020")
(78100 . "EGYPTIAN HIEROGLYPH F021")
(78101 . "EGYPTIAN HIEROGLYPH F021A")
(78102 . "EGYPTIAN HIEROGLYPH F022")
(78103 . "EGYPTIAN HIEROGLYPH F023")
(78104 . "EGYPTIAN HIEROGLYPH F024")
(78105 . "EGYPTIAN HIEROGLYPH F025")
(78106 . "EGYPTIAN HIEROGLYPH F026")
(78107 . "EGYPTIAN HIEROGLYPH F027")
(78108 . "EGYPTIAN HIEROGLYPH F028")
(78109 . "EGYPTIAN HIEROGLYPH F029")
(78110 . "EGYPTIAN HIEROGLYPH F030")
(78111 . "EGYPTIAN HIEROGLYPH F031")
(78112 . "EGYPTIAN HIEROGLYPH F031A")
(78113 . "EGYPTIAN HIEROGLYPH F032")
(78114 . "EGYPTIAN HIEROGLYPH F033")
(78115 . "EGYPTIAN HIEROGLYPH F034")
(78116 . "EGYPTIAN HIEROGLYPH F035")
(78117 . "EGYPTIAN HIEROGLYPH F036")
(78118 . "EGYPTIAN HIEROGLYPH F037")
(78119 . "EGYPTIAN HIEROGLYPH F037A")
(78120 . "EGYPTIAN HIEROGLYPH F038")
(78121 . "EGYPTIAN HIEROGLYPH F038A")
(78122 . "EGYPTIAN HIEROGLYPH F039")
(78123 . "EGYPTIAN HIEROGLYPH F040")
(78124 . "EGYPTIAN HIEROGLYPH F041")
(78125 . "EGYPTIAN HIEROGLYPH F042")
(78126 . "EGYPTIAN HIEROGLYPH F043")
(78127 . "EGYPTIAN HIEROGLYPH F044")
(78128 . "EGYPTIAN HIEROGLYPH F045")
(78129 . "EGYPTIAN HIEROGLYPH F045A")
(78130 . "EGYPTIAN HIEROGLYPH F046")
(78131 . "EGYPTIAN HIEROGLYPH F046A")
(78132 . "EGYPTIAN HIEROGLYPH F047")
(78133 . "EGYPTIAN HIEROGLYPH F047A")
(78134 . "EGYPTIAN HIEROGLYPH F048")
(78135 . "EGYPTIAN HIEROGLYPH F049")
(78136 . "EGYPTIAN HIEROGLYPH F050")
(78137 . "EGYPTIAN HIEROGLYPH F051")
(78138 . "EGYPTIAN HIEROGLYPH F051A")
(78139 . "EGYPTIAN HIEROGLYPH F051B")
(78140 . "EGYPTIAN HIEROGLYPH F051C")
(78141 . "EGYPTIAN HIEROGLYPH F052")
(78142 . "EGYPTIAN HIEROGLYPH F053")
(78143 . "EGYPTIAN HIEROGLYPH G001")
(78144 . "EGYPTIAN HIEROGLYPH G002")
(78145 . "EGYPTIAN HIEROGLYPH G003")
(78146 . "EGYPTIAN HIEROGLYPH G004")
(78147 . "EGYPTIAN HIEROGLYPH G005")
(78148 . "EGYPTIAN HIEROGLYPH G006")
(78149 . "EGYPTIAN HIEROGLYPH G006A")
(78150 . "EGYPTIAN HIEROGLYPH G007")
(78151 . "EGYPTIAN HIEROGLYPH G007A")
(78152 . "EGYPTIAN HIEROGLYPH G007B")
(78153 . "EGYPTIAN HIEROGLYPH G008")
(78154 . "EGYPTIAN HIEROGLYPH G009")
(78155 . "EGYPTIAN HIEROGLYPH G010")
(78156 . "EGYPTIAN HIEROGLYPH G011")
(78157 . "EGYPTIAN HIEROGLYPH G011A")
(78158 . "EGYPTIAN HIEROGLYPH G012")
(78159 . "EGYPTIAN HIEROGLYPH G013")
(78160 . "EGYPTIAN HIEROGLYPH G014")
(78161 . "EGYPTIAN HIEROGLYPH G015")
(78162 . "EGYPTIAN HIEROGLYPH G016")
(78163 . "EGYPTIAN HIEROGLYPH G017")
(78164 . "EGYPTIAN HIEROGLYPH G018")
(78165 . "EGYPTIAN HIEROGLYPH G019")
(78166 . "EGYPTIAN HIEROGLYPH G020")
(78167 . "EGYPTIAN HIEROGLYPH G020A")
(78168 . "EGYPTIAN HIEROGLYPH G021")
(78169 . "EGYPTIAN HIEROGLYPH G022")
(78170 . "EGYPTIAN HIEROGLYPH G023")
(78171 . "EGYPTIAN HIEROGLYPH G024")
(78172 . "EGYPTIAN HIEROGLYPH G025")
(78173 . "EGYPTIAN HIEROGLYPH G026")
(78174 . "EGYPTIAN HIEROGLYPH G026A")
(78175 . "EGYPTIAN HIEROGLYPH G027")
(78176 . "EGYPTIAN HIEROGLYPH G028")
(78177 . "EGYPTIAN HIEROGLYPH G029")
(78178 . "EGYPTIAN HIEROGLYPH G030")
(78179 . "EGYPTIAN HIEROGLYPH G031")
(78180 . "EGYPTIAN HIEROGLYPH G032")
(78181 . "EGYPTIAN HIEROGLYPH G033")
(78182 . "EGYPTIAN HIEROGLYPH G034")
(78183 . "EGYPTIAN HIEROGLYPH G035")
(78184 . "EGYPTIAN HIEROGLYPH G036")
(78185 . "EGYPTIAN HIEROGLYPH G036A")
(78186 . "EGYPTIAN HIEROGLYPH G037")
(78187 . "EGYPTIAN HIEROGLYPH G037A")
(78188 . "EGYPTIAN HIEROGLYPH G038")
(78189 . "EGYPTIAN HIEROGLYPH G039")
(78190 . "EGYPTIAN HIEROGLYPH G040")
(78191 . "EGYPTIAN HIEROGLYPH G041")
(78192 . "EGYPTIAN HIEROGLYPH G042")
(78193 . "EGYPTIAN HIEROGLYPH G043")
(78194 . "EGYPTIAN HIEROGLYPH G043A")
(78195 . "EGYPTIAN HIEROGLYPH G044")
(78196 . "EGYPTIAN HIEROGLYPH G045")
(78197 . "EGYPTIAN HIEROGLYPH G045A")
(78198 . "EGYPTIAN HIEROGLYPH G046")
(78199 . "EGYPTIAN HIEROGLYPH G047")
(78200 . "EGYPTIAN HIEROGLYPH G048")
(78201 . "EGYPTIAN HIEROGLYPH G049")
(78202 . "EGYPTIAN HIEROGLYPH G050")
(78203 . "EGYPTIAN HIEROGLYPH G051")
(78204 . "EGYPTIAN HIEROGLYPH G052")
(78205 . "EGYPTIAN HIEROGLYPH G053")
(78206 . "EGYPTIAN HIEROGLYPH G054")
(78207 . "EGYPTIAN HIEROGLYPH H001")
(78208 . "EGYPTIAN HIEROGLYPH H002")
(78209 . "EGYPTIAN HIEROGLYPH H003")
(78210 . "EGYPTIAN HIEROGLYPH H004")
(78211 . "EGYPTIAN HIEROGLYPH H005")
(78212 . "EGYPTIAN HIEROGLYPH H006")
(78213 . "EGYPTIAN HIEROGLYPH H006A")
(78214 . "EGYPTIAN HIEROGLYPH H007")
(78215 . "EGYPTIAN HIEROGLYPH H008")
(78216 . "EGYPTIAN HIEROGLYPH I001")
(78217 . "EGYPTIAN HIEROGLYPH I002")
(78218 . "EGYPTIAN HIEROGLYPH I003")
(78219 . "EGYPTIAN HIEROGLYPH I004")
(78220 . "EGYPTIAN HIEROGLYPH I005")
(78221 . "EGYPTIAN HIEROGLYPH I005A")
(78222 . "EGYPTIAN HIEROGLYPH I006")
(78223 . "EGYPTIAN HIEROGLYPH I007")
(78224 . "EGYPTIAN HIEROGLYPH I008")
(78225 . "EGYPTIAN HIEROGLYPH I009")
(78226 . "EGYPTIAN HIEROGLYPH I009A")
(78227 . "EGYPTIAN HIEROGLYPH I010")
(78228 . "EGYPTIAN HIEROGLYPH I010A")
(78229 . "EGYPTIAN HIEROGLYPH I011")
(78230 . "EGYPTIAN HIEROGLYPH I011A")
(78231 . "EGYPTIAN HIEROGLYPH I012")
(78232 . "EGYPTIAN HIEROGLYPH I013")
(78233 . "EGYPTIAN HIEROGLYPH I014")
(78234 . "EGYPTIAN HIEROGLYPH I015")
(78235 . "EGYPTIAN HIEROGLYPH K001")
(78236 . "EGYPTIAN HIEROGLYPH K002")
(78237 . "EGYPTIAN HIEROGLYPH K003")
(78238 . "EGYPTIAN HIEROGLYPH K004")
(78239 . "EGYPTIAN HIEROGLYPH K005")
(78240 . "EGYPTIAN HIEROGLYPH K006")
(78241 . "EGYPTIAN HIEROGLYPH K007")
(78242 . "EGYPTIAN HIEROGLYPH K008")
(78243 . "EGYPTIAN HIEROGLYPH L001")
(78244 . "EGYPTIAN HIEROGLYPH L002")
(78245 . "EGYPTIAN HIEROGLYPH L002A")
(78246 . "EGYPTIAN HIEROGLYPH L003")
(78247 . "EGYPTIAN HIEROGLYPH L004")
(78248 . "EGYPTIAN HIEROGLYPH L005")
(78249 . "EGYPTIAN HIEROGLYPH L006")
(78250 . "EGYPTIAN HIEROGLYPH L006A")
(78251 . "EGYPTIAN HIEROGLYPH L007")
(78252 . "EGYPTIAN HIEROGLYPH L008")
(78253 . "EGYPTIAN HIEROGLYPH M001")
(78254 . "EGYPTIAN HIEROGLYPH M001A")
(78255 . "EGYPTIAN HIEROGLYPH M001B")
(78256 . "EGYPTIAN HIEROGLYPH M002")
(78257 . "EGYPTIAN HIEROGLYPH M003")
(78258 . "EGYPTIAN HIEROGLYPH M003A")
(78259 . "EGYPTIAN HIEROGLYPH M004")
(78260 . "EGYPTIAN HIEROGLYPH M005")
(78261 . "EGYPTIAN HIEROGLYPH M006")
(78262 . "EGYPTIAN HIEROGLYPH M007")
(78263 . "EGYPTIAN HIEROGLYPH M008")
(78264 . "EGYPTIAN HIEROGLYPH M009")
(78265 . "EGYPTIAN HIEROGLYPH M010")
(78266 . "EGYPTIAN HIEROGLYPH M010A")
(78267 . "EGYPTIAN HIEROGLYPH M011")
(78268 . "EGYPTIAN HIEROGLYPH M012")
(78269 . "EGYPTIAN HIEROGLYPH M012A")
(78270 . "EGYPTIAN HIEROGLYPH M012B")
(78271 . "EGYPTIAN HIEROGLYPH M012C")
(78272 . "EGYPTIAN HIEROGLYPH M012D")
(78273 . "EGYPTIAN HIEROGLYPH M012E")
(78274 . "EGYPTIAN HIEROGLYPH M012F")
(78275 . "EGYPTIAN HIEROGLYPH M012G")
(78276 . "EGYPTIAN HIEROGLYPH M012H")
(78277 . "EGYPTIAN HIEROGLYPH M013")
(78278 . "EGYPTIAN HIEROGLYPH M014")
(78279 . "EGYPTIAN HIEROGLYPH M015")
(78280 . "EGYPTIAN HIEROGLYPH M015A")
(78281 . "EGYPTIAN HIEROGLYPH M016")
(78282 . "EGYPTIAN HIEROGLYPH M016A")
(78283 . "EGYPTIAN HIEROGLYPH M017")
(78284 . "EGYPTIAN HIEROGLYPH M017A")
(78285 . "EGYPTIAN HIEROGLYPH M018")
(78286 . "EGYPTIAN HIEROGLYPH M019")
(78287 . "EGYPTIAN HIEROGLYPH M020")
(78288 . "EGYPTIAN HIEROGLYPH M021")
(78289 . "EGYPTIAN HIEROGLYPH M022")
(78290 . "EGYPTIAN HIEROGLYPH M022A")
(78291 . "EGYPTIAN HIEROGLYPH M023")
(78292 . "EGYPTIAN HIEROGLYPH M024")
(78293 . "EGYPTIAN HIEROGLYPH M024A")
(78294 . "EGYPTIAN HIEROGLYPH M025")
(78295 . "EGYPTIAN HIEROGLYPH M026")
(78296 . "EGYPTIAN HIEROGLYPH M027")
(78297 . "EGYPTIAN HIEROGLYPH M028")
(78298 . "EGYPTIAN HIEROGLYPH M028A")
(78299 . "EGYPTIAN HIEROGLYPH M029")
(78300 . "EGYPTIAN HIEROGLYPH M030")
(78301 . "EGYPTIAN HIEROGLYPH M031")
(78302 . "EGYPTIAN HIEROGLYPH M031A")
(78303 . "EGYPTIAN HIEROGLYPH M032")
(78304 . "EGYPTIAN HIEROGLYPH M033")
(78305 . "EGYPTIAN HIEROGLYPH M033A")
(78306 . "EGYPTIAN HIEROGLYPH M033B")
(78307 . "EGYPTIAN HIEROGLYPH M034")
(78308 . "EGYPTIAN HIEROGLYPH M035")
(78309 . "EGYPTIAN HIEROGLYPH M036")
(78310 . "EGYPTIAN HIEROGLYPH M037")
(78311 . "EGYPTIAN HIEROGLYPH M038")
(78312 . "EGYPTIAN HIEROGLYPH M039")
(78313 . "EGYPTIAN HIEROGLYPH M040")
(78314 . "EGYPTIAN HIEROGLYPH M040A")
(78315 . "EGYPTIAN HIEROGLYPH M041")
(78316 . "EGYPTIAN HIEROGLYPH M042")
(78317 . "EGYPTIAN HIEROGLYPH M043")
(78318 . "EGYPTIAN HIEROGLYPH M044")
(78319 . "EGYPTIAN HIEROGLYPH N001")
(78320 . "EGYPTIAN HIEROGLYPH N002")
(78321 . "EGYPTIAN HIEROGLYPH N003")
(78322 . "EGYPTIAN HIEROGLYPH N004")
(78323 . "EGYPTIAN HIEROGLYPH N005")
(78324 . "EGYPTIAN HIEROGLYPH N006")
(78325 . "EGYPTIAN HIEROGLYPH N007")
(78326 . "EGYPTIAN HIEROGLYPH N008")
(78327 . "EGYPTIAN HIEROGLYPH N009")
(78328 . "EGYPTIAN HIEROGLYPH N010")
(78329 . "EGYPTIAN HIEROGLYPH N011")
(78330 . "EGYPTIAN HIEROGLYPH N012")
(78331 . "EGYPTIAN HIEROGLYPH N013")
(78332 . "EGYPTIAN HIEROGLYPH N014")
(78333 . "EGYPTIAN HIEROGLYPH N015")
(78334 . "EGYPTIAN HIEROGLYPH N016")
(78335 . "EGYPTIAN HIEROGLYPH N017")
(78336 . "EGYPTIAN HIEROGLYPH N018")
(78337 . "EGYPTIAN HIEROGLYPH N018A")
(78338 . "EGYPTIAN HIEROGLYPH N018B")
(78339 . "EGYPTIAN HIEROGLYPH N019")
(78340 . "EGYPTIAN HIEROGLYPH N020")
(78341 . "EGYPTIAN HIEROGLYPH N021")
(78342 . "EGYPTIAN HIEROGLYPH N022")
(78343 . "EGYPTIAN HIEROGLYPH N023")
(78344 . "EGYPTIAN HIEROGLYPH N024")
(78345 . "EGYPTIAN HIEROGLYPH N025")
(78346 . "EGYPTIAN HIEROGLYPH N025A")
(78347 . "EGYPTIAN HIEROGLYPH N026")
(78348 . "EGYPTIAN HIEROGLYPH N027")
(78349 . "EGYPTIAN HIEROGLYPH N028")
(78350 . "EGYPTIAN HIEROGLYPH N029")
(78351 . "EGYPTIAN HIEROGLYPH N030")
(78352 . "EGYPTIAN HIEROGLYPH N031")
(78353 . "EGYPTIAN HIEROGLYPH N032")
(78354 . "EGYPTIAN HIEROGLYPH N033")
(78355 . "EGYPTIAN HIEROGLYPH N033A")
(78356 . "EGYPTIAN HIEROGLYPH N034")
(78357 . "EGYPTIAN HIEROGLYPH N034A")
(78358 . "EGYPTIAN HIEROGLYPH N035")
(78359 . "EGYPTIAN HIEROGLYPH N035A")
(78360 . "EGYPTIAN HIEROGLYPH N036")
(78361 . "EGYPTIAN HIEROGLYPH N037")
(78362 . "EGYPTIAN HIEROGLYPH N037A")
(78363 . "EGYPTIAN HIEROGLYPH N038")
(78364 . "EGYPTIAN HIEROGLYPH N039")
(78365 . "EGYPTIAN HIEROGLYPH N040")
(78366 . "EGYPTIAN HIEROGLYPH N041")
(78367 . "EGYPTIAN HIEROGLYPH N042")
(78368 . "EGYPTIAN HIEROGLYPH NL001")
(78369 . "EGYPTIAN HIEROGLYPH NL002")
(78370 . "EGYPTIAN HIEROGLYPH NL003")
(78371 . "EGYPTIAN HIEROGLYPH NL004")
(78372 . "EGYPTIAN HIEROGLYPH NL005")
(78373 . "EGYPTIAN HIEROGLYPH NL005A")
(78374 . "EGYPTIAN HIEROGLYPH NL006")
(78375 . "EGYPTIAN HIEROGLYPH NL007")
(78376 . "EGYPTIAN HIEROGLYPH NL008")
(78377 . "EGYPTIAN HIEROGLYPH NL009")
(78378 . "EGYPTIAN HIEROGLYPH NL010")
(78379 . "EGYPTIAN HIEROGLYPH NL011")
(78380 . "EGYPTIAN HIEROGLYPH NL012")
(78381 . "EGYPTIAN HIEROGLYPH NL013")
(78382 . "EGYPTIAN HIEROGLYPH NL014")
(78383 . "EGYPTIAN HIEROGLYPH NL015")
(78384 . "EGYPTIAN HIEROGLYPH NL016")
(78385 . "EGYPTIAN HIEROGLYPH NL017")
(78386 . "EGYPTIAN HIEROGLYPH NL017A")
(78387 . "EGYPTIAN HIEROGLYPH NL018")
(78388 . "EGYPTIAN HIEROGLYPH NL019")
(78389 . "EGYPTIAN HIEROGLYPH NL020")
(78390 . "EGYPTIAN HIEROGLYPH NU001")
(78391 . "EGYPTIAN HIEROGLYPH NU002")
(78392 . "EGYPTIAN HIEROGLYPH NU003")
(78393 . "EGYPTIAN HIEROGLYPH NU004")
(78394 . "EGYPTIAN HIEROGLYPH NU005")
(78395 . "EGYPTIAN HIEROGLYPH NU006")
(78396 . "EGYPTIAN HIEROGLYPH NU007")
(78397 . "EGYPTIAN HIEROGLYPH NU008")
(78398 . "EGYPTIAN HIEROGLYPH NU009")
(78399 . "EGYPTIAN HIEROGLYPH NU010")
(78400 . "EGYPTIAN HIEROGLYPH NU010A")
(78401 . "EGYPTIAN HIEROGLYPH NU011")
(78402 . "EGYPTIAN HIEROGLYPH NU011A")
(78403 . "EGYPTIAN HIEROGLYPH NU012")
(78404 . "EGYPTIAN HIEROGLYPH NU013")
(78405 . "EGYPTIAN HIEROGLYPH NU014")
(78406 . "EGYPTIAN HIEROGLYPH NU015")
(78407 . "EGYPTIAN HIEROGLYPH NU016")
(78408 . "EGYPTIAN HIEROGLYPH NU017")
(78409 . "EGYPTIAN HIEROGLYPH NU018")
(78410 . "EGYPTIAN HIEROGLYPH NU018A")
(78411 . "EGYPTIAN HIEROGLYPH NU019")
(78412 . "EGYPTIAN HIEROGLYPH NU020")
(78413 . "EGYPTIAN HIEROGLYPH NU021")
(78414 . "EGYPTIAN HIEROGLYPH NU022")
(78415 . "EGYPTIAN HIEROGLYPH NU022A")
(78416 . "EGYPTIAN HIEROGLYPH O001")
(78417 . "EGYPTIAN HIEROGLYPH O001A")
(78418 . "EGYPTIAN HIEROGLYPH O002")
(78419 . "EGYPTIAN HIEROGLYPH O003")
(78420 . "EGYPTIAN HIEROGLYPH O004")
(78421 . "EGYPTIAN HIEROGLYPH O005")
(78422 . "EGYPTIAN HIEROGLYPH O005A")
(78423 . "EGYPTIAN HIEROGLYPH O006")
(78424 . "EGYPTIAN HIEROGLYPH O006A")
(78425 . "EGYPTIAN HIEROGLYPH O006B")
(78426 . "EGYPTIAN HIEROGLYPH O006C")
(78427 . "EGYPTIAN HIEROGLYPH O006D")
(78428 . "EGYPTIAN HIEROGLYPH O006E")
(78429 . "EGYPTIAN HIEROGLYPH O006F")
(78430 . "EGYPTIAN HIEROGLYPH O007")
(78431 . "EGYPTIAN HIEROGLYPH O008")
(78432 . "EGYPTIAN HIEROGLYPH O009")
(78433 . "EGYPTIAN HIEROGLYPH O010")
(78434 . "EGYPTIAN HIEROGLYPH O010A")
(78435 . "EGYPTIAN HIEROGLYPH O010B")
(78436 . "EGYPTIAN HIEROGLYPH O010C")
(78437 . "EGYPTIAN HIEROGLYPH O011")
(78438 . "EGYPTIAN HIEROGLYPH O012")
(78439 . "EGYPTIAN HIEROGLYPH O013")
(78440 . "EGYPTIAN HIEROGLYPH O014")
(78441 . "EGYPTIAN HIEROGLYPH O015")
(78442 . "EGYPTIAN HIEROGLYPH O016")
(78443 . "EGYPTIAN HIEROGLYPH O017")
(78444 . "EGYPTIAN HIEROGLYPH O018")
(78445 . "EGYPTIAN HIEROGLYPH O019")
(78446 . "EGYPTIAN HIEROGLYPH O019A")
(78447 . "EGYPTIAN HIEROGLYPH O020")
(78448 . "EGYPTIAN HIEROGLYPH O020A")
(78449 . "EGYPTIAN HIEROGLYPH O021")
(78450 . "EGYPTIAN HIEROGLYPH O022")
(78451 . "EGYPTIAN HIEROGLYPH O023")
(78452 . "EGYPTIAN HIEROGLYPH O024")
(78453 . "EGYPTIAN HIEROGLYPH O024A")
(78454 . "EGYPTIAN HIEROGLYPH O025")
(78455 . "EGYPTIAN HIEROGLYPH O025A")
(78456 . "EGYPTIAN HIEROGLYPH O026")
(78457 . "EGYPTIAN HIEROGLYPH O027")
(78458 . "EGYPTIAN HIEROGLYPH O028")
(78459 . "EGYPTIAN HIEROGLYPH O029")
(78460 . "EGYPTIAN HIEROGLYPH O029A")
(78461 . "EGYPTIAN HIEROGLYPH O030")
(78462 . "EGYPTIAN HIEROGLYPH O030A")
(78463 . "EGYPTIAN HIEROGLYPH O031")
(78464 . "EGYPTIAN HIEROGLYPH O032")
(78465 . "EGYPTIAN HIEROGLYPH O033")
(78466 . "EGYPTIAN HIEROGLYPH O033A")
(78467 . "EGYPTIAN HIEROGLYPH O034")
(78468 . "EGYPTIAN HIEROGLYPH O035")
(78469 . "EGYPTIAN HIEROGLYPH O036")
(78470 . "EGYPTIAN HIEROGLYPH O036A")
(78471 . "EGYPTIAN HIEROGLYPH O036B")
(78472 . "EGYPTIAN HIEROGLYPH O036C")
(78473 . "EGYPTIAN HIEROGLYPH O036D")
(78474 . "EGYPTIAN HIEROGLYPH O037")
(78475 . "EGYPTIAN HIEROGLYPH O038")
(78476 . "EGYPTIAN HIEROGLYPH O039")
(78477 . "EGYPTIAN HIEROGLYPH O040")
(78478 . "EGYPTIAN HIEROGLYPH O041")
(78479 . "EGYPTIAN HIEROGLYPH O042")
(78480 . "EGYPTIAN HIEROGLYPH O043")
(78481 . "EGYPTIAN HIEROGLYPH O044")
(78482 . "EGYPTIAN HIEROGLYPH O045")
(78483 . "EGYPTIAN HIEROGLYPH O046")
(78484 . "EGYPTIAN HIEROGLYPH O047")
(78485 . "EGYPTIAN HIEROGLYPH O048")
(78486 . "EGYPTIAN HIEROGLYPH O049")
(78487 . "EGYPTIAN HIEROGLYPH O050")
(78488 . "EGYPTIAN HIEROGLYPH O050A")
(78489 . "EGYPTIAN HIEROGLYPH O050B")
(78490 . "EGYPTIAN HIEROGLYPH O051")
(78491 . "EGYPTIAN HIEROGLYPH P001")
(78492 . "EGYPTIAN HIEROGLYPH P001A")
(78493 . "EGYPTIAN HIEROGLYPH P002")
(78494 . "EGYPTIAN HIEROGLYPH P003")
(78495 . "EGYPTIAN HIEROGLYPH P003A")
(78496 . "EGYPTIAN HIEROGLYPH P004")
(78497 . "EGYPTIAN HIEROGLYPH P005")
(78498 . "EGYPTIAN HIEROGLYPH P006")
(78499 . "EGYPTIAN HIEROGLYPH P007")
(78500 . "EGYPTIAN HIEROGLYPH P008")
(78501 . "EGYPTIAN HIEROGLYPH P009")
(78502 . "EGYPTIAN HIEROGLYPH P010")
(78503 . "EGYPTIAN HIEROGLYPH P011")
(78504 . "EGYPTIAN HIEROGLYPH Q001")
(78505 . "EGYPTIAN HIEROGLYPH Q002")
(78506 . "EGYPTIAN HIEROGLYPH Q003")
(78507 . "EGYPTIAN HIEROGLYPH Q004")
(78508 . "EGYPTIAN HIEROGLYPH Q005")
(78509 . "EGYPTIAN HIEROGLYPH Q006")
(78510 . "EGYPTIAN HIEROGLYPH Q007")
(78511 . "EGYPTIAN HIEROGLYPH R001")
(78512 . "EGYPTIAN HIEROGLYPH R002")
(78513 . "EGYPTIAN HIEROGLYPH R002A")
(78514 . "EGYPTIAN HIEROGLYPH R003")
(78515 . "EGYPTIAN HIEROGLYPH R003A")
(78516 . "EGYPTIAN HIEROGLYPH R003B")
(78517 . "EGYPTIAN HIEROGLYPH R004")
(78518 . "EGYPTIAN HIEROGLYPH R005")
(78519 . "EGYPTIAN HIEROGLYPH R006")
(78520 . "EGYPTIAN HIEROGLYPH R007")
(78521 . "EGYPTIAN HIEROGLYPH R008")
(78522 . "EGYPTIAN HIEROGLYPH R009")
(78523 . "EGYPTIAN HIEROGLYPH R010")
(78524 . "EGYPTIAN HIEROGLYPH R010A")
(78525 . "EGYPTIAN HIEROGLYPH R011")
(78526 . "EGYPTIAN HIEROGLYPH R012")
(78527 . "EGYPTIAN HIEROGLYPH R013")
(78528 . "EGYPTIAN HIEROGLYPH R014")
(78529 . "EGYPTIAN HIEROGLYPH R015")
(78530 . "EGYPTIAN HIEROGLYPH R016")
(78531 . "EGYPTIAN HIEROGLYPH R016A")
(78532 . "EGYPTIAN HIEROGLYPH R017")
(78533 . "EGYPTIAN HIEROGLYPH R018")
(78534 . "EGYPTIAN HIEROGLYPH R019")
(78535 . "EGYPTIAN HIEROGLYPH R020")
(78536 . "EGYPTIAN HIEROGLYPH R021")
(78537 . "EGYPTIAN HIEROGLYPH R022")
(78538 . "EGYPTIAN HIEROGLYPH R023")
(78539 . "EGYPTIAN HIEROGLYPH R024")
(78540 . "EGYPTIAN HIEROGLYPH R025")
(78541 . "EGYPTIAN HIEROGLYPH R026")
(78542 . "EGYPTIAN HIEROGLYPH R027")
(78543 . "EGYPTIAN HIEROGLYPH R028")
(78544 . "EGYPTIAN HIEROGLYPH R029")
(78545 . "EGYPTIAN HIEROGLYPH S001")
(78546 . "EGYPTIAN HIEROGLYPH S002")
(78547 . "EGYPTIAN HIEROGLYPH S002A")
(78548 . "EGYPTIAN HIEROGLYPH S003")
(78549 . "EGYPTIAN HIEROGLYPH S004")
(78550 . "EGYPTIAN HIEROGLYPH S005")
(78551 . "EGYPTIAN HIEROGLYPH S006")
(78552 . "EGYPTIAN HIEROGLYPH S006A")
(78553 . "EGYPTIAN HIEROGLYPH S007")
(78554 . "EGYPTIAN HIEROGLYPH S008")
(78555 . "EGYPTIAN HIEROGLYPH S009")
(78556 . "EGYPTIAN HIEROGLYPH S010")
(78557 . "EGYPTIAN HIEROGLYPH S011")
(78558 . "EGYPTIAN HIEROGLYPH S012")
(78559 . "EGYPTIAN HIEROGLYPH S013")
(78560 . "EGYPTIAN HIEROGLYPH S014")
(78561 . "EGYPTIAN HIEROGLYPH S014A")
(78562 . "EGYPTIAN HIEROGLYPH S014B")
(78563 . "EGYPTIAN HIEROGLYPH S015")
(78564 . "EGYPTIAN HIEROGLYPH S016")
(78565 . "EGYPTIAN HIEROGLYPH S017")
(78566 . "EGYPTIAN HIEROGLYPH S017A")
(78567 . "EGYPTIAN HIEROGLYPH S018")
(78568 . "EGYPTIAN HIEROGLYPH S019")
(78569 . "EGYPTIAN HIEROGLYPH S020")
(78570 . "EGYPTIAN HIEROGLYPH S021")
(78571 . "EGYPTIAN HIEROGLYPH S022")
(78572 . "EGYPTIAN HIEROGLYPH S023")
(78573 . "EGYPTIAN HIEROGLYPH S024")
(78574 . "EGYPTIAN HIEROGLYPH S025")
(78575 . "EGYPTIAN HIEROGLYPH S026")
(78576 . "EGYPTIAN HIEROGLYPH S026A")
(78577 . "EGYPTIAN HIEROGLYPH S026B")
(78578 . "EGYPTIAN HIEROGLYPH S027")
(78579 . "EGYPTIAN HIEROGLYPH S028")
(78580 . "EGYPTIAN HIEROGLYPH S029")
(78581 . "EGYPTIAN HIEROGLYPH S030")
(78582 . "EGYPTIAN HIEROGLYPH S031")
(78583 . "EGYPTIAN HIEROGLYPH S032")
(78584 . "EGYPTIAN HIEROGLYPH S033")
(78585 . "EGYPTIAN HIEROGLYPH S034")
(78586 . "EGYPTIAN HIEROGLYPH S035")
(78587 . "EGYPTIAN HIEROGLYPH S035A")
(78588 . "EGYPTIAN HIEROGLYPH S036")
(78589 . "EGYPTIAN HIEROGLYPH S037")
(78590 . "EGYPTIAN HIEROGLYPH S038")
(78591 . "EGYPTIAN HIEROGLYPH S039")
(78592 . "EGYPTIAN HIEROGLYPH S040")
(78593 . "EGYPTIAN HIEROGLYPH S041")
(78594 . "EGYPTIAN HIEROGLYPH S042")
(78595 . "EGYPTIAN HIEROGLYPH S043")
(78596 . "EGYPTIAN HIEROGLYPH S044")
(78597 . "EGYPTIAN HIEROGLYPH S045")
(78598 . "EGYPTIAN HIEROGLYPH S046")
(78599 . "EGYPTIAN HIEROGLYPH T001")
(78600 . "EGYPTIAN HIEROGLYPH T002")
(78601 . "EGYPTIAN HIEROGLYPH T003")
(78602 . "EGYPTIAN HIEROGLYPH T003A")
(78603 . "EGYPTIAN HIEROGLYPH T004")
(78604 . "EGYPTIAN HIEROGLYPH T005")
(78605 . "EGYPTIAN HIEROGLYPH T006")
(78606 . "EGYPTIAN HIEROGLYPH T007")
(78607 . "EGYPTIAN HIEROGLYPH T007A")
(78608 . "EGYPTIAN HIEROGLYPH T008")
(78609 . "EGYPTIAN HIEROGLYPH T008A")
(78610 . "EGYPTIAN HIEROGLYPH T009")
(78611 . "EGYPTIAN HIEROGLYPH T009A")
(78612 . "EGYPTIAN HIEROGLYPH T010")
(78613 . "EGYPTIAN HIEROGLYPH T011")
(78614 . "EGYPTIAN HIEROGLYPH T011A")
(78615 . "EGYPTIAN HIEROGLYPH T012")
(78616 . "EGYPTIAN HIEROGLYPH T013")
(78617 . "EGYPTIAN HIEROGLYPH T014")
(78618 . "EGYPTIAN HIEROGLYPH T015")
(78619 . "EGYPTIAN HIEROGLYPH T016")
(78620 . "EGYPTIAN HIEROGLYPH T016A")
(78621 . "EGYPTIAN HIEROGLYPH T017")
(78622 . "EGYPTIAN HIEROGLYPH T018")
(78623 . "EGYPTIAN HIEROGLYPH T019")
(78624 . "EGYPTIAN HIEROGLYPH T020")
(78625 . "EGYPTIAN HIEROGLYPH T021")
(78626 . "EGYPTIAN HIEROGLYPH T022")
(78627 . "EGYPTIAN HIEROGLYPH T023")
(78628 . "EGYPTIAN HIEROGLYPH T024")
(78629 . "EGYPTIAN HIEROGLYPH T025")
(78630 . "EGYPTIAN HIEROGLYPH T026")
(78631 . "EGYPTIAN HIEROGLYPH T027")
(78632 . "EGYPTIAN HIEROGLYPH T028")
(78633 . "EGYPTIAN HIEROGLYPH T029")
(78634 . "EGYPTIAN HIEROGLYPH T030")
(78635 . "EGYPTIAN HIEROGLYPH T031")
(78636 . "EGYPTIAN HIEROGLYPH T032")
(78637 . "EGYPTIAN HIEROGLYPH T032A")
(78638 . "EGYPTIAN HIEROGLYPH T033")
(78639 . "EGYPTIAN HIEROGLYPH T033A")
(78640 . "EGYPTIAN HIEROGLYPH T034")
(78641 . "EGYPTIAN HIEROGLYPH T035")
(78642 . "EGYPTIAN HIEROGLYPH T036")
(78643 . "EGYPTIAN HIEROGLYPH U001")
(78644 . "EGYPTIAN HIEROGLYPH U002")
(78645 . "EGYPTIAN HIEROGLYPH U003")
(78646 . "EGYPTIAN HIEROGLYPH U004")
(78647 . "EGYPTIAN HIEROGLYPH U005")
(78648 . "EGYPTIAN HIEROGLYPH U006")
(78649 . "EGYPTIAN HIEROGLYPH U006A")
(78650 . "EGYPTIAN HIEROGLYPH U006B")
(78651 . "EGYPTIAN HIEROGLYPH U007")
(78652 . "EGYPTIAN HIEROGLYPH U008")
(78653 . "EGYPTIAN HIEROGLYPH U009")
(78654 . "EGYPTIAN HIEROGLYPH U010")
(78655 . "EGYPTIAN HIEROGLYPH U011")
(78656 . "EGYPTIAN HIEROGLYPH U012")
(78657 . "EGYPTIAN HIEROGLYPH U013")
(78658 . "EGYPTIAN HIEROGLYPH U014")
(78659 . "EGYPTIAN HIEROGLYPH U015")
(78660 . "EGYPTIAN HIEROGLYPH U016")
(78661 . "EGYPTIAN HIEROGLYPH U017")
(78662 . "EGYPTIAN HIEROGLYPH U018")
(78663 . "EGYPTIAN HIEROGLYPH U019")
(78664 . "EGYPTIAN HIEROGLYPH U020")
(78665 . "EGYPTIAN HIEROGLYPH U021")
(78666 . "EGYPTIAN HIEROGLYPH U022")
(78667 . "EGYPTIAN HIEROGLYPH U023")
(78668 . "EGYPTIAN HIEROGLYPH U023A")
(78669 . "EGYPTIAN HIEROGLYPH U024")
(78670 . "EGYPTIAN HIEROGLYPH U025")
(78671 . "EGYPTIAN HIEROGLYPH U026")
(78672 . "EGYPTIAN HIEROGLYPH U027")
(78673 . "EGYPTIAN HIEROGLYPH U028")
(78674 . "EGYPTIAN HIEROGLYPH U029")
(78675 . "EGYPTIAN HIEROGLYPH U029A")
(78676 . "EGYPTIAN HIEROGLYPH U030")
(78677 . "EGYPTIAN HIEROGLYPH U031")
(78678 . "EGYPTIAN HIEROGLYPH U032")
(78679 . "EGYPTIAN HIEROGLYPH U032A")
(78680 . "EGYPTIAN HIEROGLYPH U033")
(78681 . "EGYPTIAN HIEROGLYPH U034")
(78682 . "EGYPTIAN HIEROGLYPH U035")
(78683 . "EGYPTIAN HIEROGLYPH U036")
(78684 . "EGYPTIAN HIEROGLYPH U037")
(78685 . "EGYPTIAN HIEROGLYPH U038")
(78686 . "EGYPTIAN HIEROGLYPH U039")
(78687 . "EGYPTIAN HIEROGLYPH U040")
(78688 . "EGYPTIAN HIEROGLYPH U041")
(78689 . "EGYPTIAN HIEROGLYPH U042")
(78690 . "EGYPTIAN HIEROGLYPH V001")
(78691 . "EGYPTIAN HIEROGLYPH V001A")
(78692 . "EGYPTIAN HIEROGLYPH V001B")
(78693 . "EGYPTIAN HIEROGLYPH V001C")
(78694 . "EGYPTIAN HIEROGLYPH V001D")
(78695 . "EGYPTIAN HIEROGLYPH V001E")
(78696 . "EGYPTIAN HIEROGLYPH V001F")
(78697 . "EGYPTIAN HIEROGLYPH V001G")
(78698 . "EGYPTIAN HIEROGLYPH V001H")
(78699 . "EGYPTIAN HIEROGLYPH V001I")
(78700 . "EGYPTIAN HIEROGLYPH V002")
(78701 . "EGYPTIAN HIEROGLYPH V002A")
(78702 . "EGYPTIAN HIEROGLYPH V003")
(78703 . "EGYPTIAN HIEROGLYPH V004")
(78704 . "EGYPTIAN HIEROGLYPH V005")
(78705 . "EGYPTIAN HIEROGLYPH V006")
(78706 . "EGYPTIAN HIEROGLYPH V007")
(78707 . "EGYPTIAN HIEROGLYPH V007A")
(78708 . "EGYPTIAN HIEROGLYPH V007B")
(78709 . "EGYPTIAN HIEROGLYPH V008")
(78710 . "EGYPTIAN HIEROGLYPH V009")
(78711 . "EGYPTIAN HIEROGLYPH V010")
(78712 . "EGYPTIAN HIEROGLYPH V011")
(78713 . "EGYPTIAN HIEROGLYPH V011A")
(78714 . "EGYPTIAN HIEROGLYPH V011B")
(78715 . "EGYPTIAN HIEROGLYPH V011C")
(78716 . "EGYPTIAN HIEROGLYPH V012")
(78717 . "EGYPTIAN HIEROGLYPH V012A")
(78718 . "EGYPTIAN HIEROGLYPH V012B")
(78719 . "EGYPTIAN HIEROGLYPH V013")
(78720 . "EGYPTIAN HIEROGLYPH V014")
(78721 . "EGYPTIAN HIEROGLYPH V015")
(78722 . "EGYPTIAN HIEROGLYPH V016")
(78723 . "EGYPTIAN HIEROGLYPH V017")
(78724 . "EGYPTIAN HIEROGLYPH V018")
(78725 . "EGYPTIAN HIEROGLYPH V019")
(78726 . "EGYPTIAN HIEROGLYPH V020")
(78727 . "EGYPTIAN HIEROGLYPH V020A")
(78728 . "EGYPTIAN HIEROGLYPH V020B")
(78729 . "EGYPTIAN HIEROGLYPH V020C")
(78730 . "EGYPTIAN HIEROGLYPH V020D")
(78731 . "EGYPTIAN HIEROGLYPH V020E")
(78732 . "EGYPTIAN HIEROGLYPH V020F")
(78733 . "EGYPTIAN HIEROGLYPH V020G")
(78734 . "EGYPTIAN HIEROGLYPH V020H")
(78735 . "EGYPTIAN HIEROGLYPH V020I")
(78736 . "EGYPTIAN HIEROGLYPH V020J")
(78737 . "EGYPTIAN HIEROGLYPH V020K")
(78738 . "EGYPTIAN HIEROGLYPH V020L")
(78739 . "EGYPTIAN HIEROGLYPH V021")
(78740 . "EGYPTIAN HIEROGLYPH V022")
(78741 . "EGYPTIAN HIEROGLYPH V023")
(78742 . "EGYPTIAN HIEROGLYPH V023A")
(78743 . "EGYPTIAN HIEROGLYPH V024")
(78744 . "EGYPTIAN HIEROGLYPH V025")
(78745 . "EGYPTIAN HIEROGLYPH V026")
(78746 . "EGYPTIAN HIEROGLYPH V027")
(78747 . "EGYPTIAN HIEROGLYPH V028")
(78748 . "EGYPTIAN HIEROGLYPH V028A")
(78749 . "EGYPTIAN HIEROGLYPH V029")
(78750 . "EGYPTIAN HIEROGLYPH V029A")
(78751 . "EGYPTIAN HIEROGLYPH V030")
(78752 . "EGYPTIAN HIEROGLYPH V030A")
(78753 . "EGYPTIAN HIEROGLYPH V031")
(78754 . "EGYPTIAN HIEROGLYPH V031A")
(78755 . "EGYPTIAN HIEROGLYPH V032")
(78756 . "EGYPTIAN HIEROGLYPH V033")
(78757 . "EGYPTIAN HIEROGLYPH V033A")
(78758 . "EGYPTIAN HIEROGLYPH V034")
(78759 . "EGYPTIAN HIEROGLYPH V035")
(78760 . "EGYPTIAN HIEROGLYPH V036")
(78761 . "EGYPTIAN HIEROGLYPH V037")
(78762 . "EGYPTIAN HIEROGLYPH V037A")
(78763 . "EGYPTIAN HIEROGLYPH V038")
(78764 . "EGYPTIAN HIEROGLYPH V039")
(78765 . "EGYPTIAN HIEROGLYPH V040")
(78766 . "EGYPTIAN HIEROGLYPH V040A")
(78767 . "EGYPTIAN HIEROGLYPH W001")
(78768 . "EGYPTIAN HIEROGLYPH W002")
(78769 . "EGYPTIAN HIEROGLYPH W003")
(78770 . "EGYPTIAN HIEROGLYPH W003A")
(78771 . "EGYPTIAN HIEROGLYPH W004")
(78772 . "EGYPTIAN HIEROGLYPH W005")
(78773 . "EGYPTIAN HIEROGLYPH W006")
(78774 . "EGYPTIAN HIEROGLYPH W007")
(78775 . "EGYPTIAN HIEROGLYPH W008")
(78776 . "EGYPTIAN HIEROGLYPH W009")
(78777 . "EGYPTIAN HIEROGLYPH W009A")
(78778 . "EGYPTIAN HIEROGLYPH W010")
(78779 . "EGYPTIAN HIEROGLYPH W010A")
(78780 . "EGYPTIAN HIEROGLYPH W011")
(78781 . "EGYPTIAN HIEROGLYPH W012")
(78782 . "EGYPTIAN HIEROGLYPH W013")
(78783 . "EGYPTIAN HIEROGLYPH W014")
(78784 . "EGYPTIAN HIEROGLYPH W014A")
(78785 . "EGYPTIAN HIEROGLYPH W015")
(78786 . "EGYPTIAN HIEROGLYPH W016")
(78787 . "EGYPTIAN HIEROGLYPH W017")
(78788 . "EGYPTIAN HIEROGLYPH W017A")
(78789 . "EGYPTIAN HIEROGLYPH W018")
(78790 . "EGYPTIAN HIEROGLYPH W018A")
(78791 . "EGYPTIAN HIEROGLYPH W019")
(78792 . "EGYPTIAN HIEROGLYPH W020")
(78793 . "EGYPTIAN HIEROGLYPH W021")
(78794 . "EGYPTIAN HIEROGLYPH W022")
(78795 . "EGYPTIAN HIEROGLYPH W023")
(78796 . "EGYPTIAN HIEROGLYPH W024")
(78797 . "EGYPTIAN HIEROGLYPH W024A")
(78798 . "EGYPTIAN HIEROGLYPH W025")
(78799 . "EGYPTIAN HIEROGLYPH X001")
(78800 . "EGYPTIAN HIEROGLYPH X002")
(78801 . "EGYPTIAN HIEROGLYPH X003")
(78802 . "EGYPTIAN HIEROGLYPH X004")
(78803 . "EGYPTIAN HIEROGLYPH X004A")
(78804 . "EGYPTIAN HIEROGLYPH X004B")
(78805 . "EGYPTIAN HIEROGLYPH X005")
(78806 . "EGYPTIAN HIEROGLYPH X006")
(78807 . "EGYPTIAN HIEROGLYPH X006A")
(78808 . "EGYPTIAN HIEROGLYPH X007")
(78809 . "EGYPTIAN HIEROGLYPH X008")
(78810 . "EGYPTIAN HIEROGLYPH X008A")
(78811 . "EGYPTIAN HIEROGLYPH Y001")
(78812 . "EGYPTIAN HIEROGLYPH Y001A")
(78813 . "EGYPTIAN HIEROGLYPH Y002")
(78814 . "EGYPTIAN HIEROGLYPH Y003")
(78815 . "EGYPTIAN HIEROGLYPH Y004")
(78816 . "EGYPTIAN HIEROGLYPH Y005")
(78817 . "EGYPTIAN HIEROGLYPH Y006")
(78818 . "EGYPTIAN HIEROGLYPH Y007")
(78819 . "EGYPTIAN HIEROGLYPH Y008")
(78820 . "EGYPTIAN HIEROGLYPH Z001")
(78821 . "EGYPTIAN HIEROGLYPH Z002")
(78822 . "EGYPTIAN HIEROGLYPH Z002A")
(78823 . "EGYPTIAN HIEROGLYPH Z002B")
(78824 . "EGYPTIAN HIEROGLYPH Z002C")
(78825 . "EGYPTIAN HIEROGLYPH Z002D")
(78826 . "EGYPTIAN HIEROGLYPH Z003")
(78827 . "EGYPTIAN HIEROGLYPH Z003A")
(78828 . "EGYPTIAN HIEROGLYPH Z003B")
(78829 . "EGYPTIAN HIEROGLYPH Z004")
(78830 . "EGYPTIAN HIEROGLYPH Z004A")
(78831 . "EGYPTIAN HIEROGLYPH Z005")
(78832 . "EGYPTIAN HIEROGLYPH Z005A")
(78833 . "EGYPTIAN HIEROGLYPH Z006")
(78834 . "EGYPTIAN HIEROGLYPH Z007")
(78835 . "EGYPTIAN HIEROGLYPH Z008")
(78836 . "EGYPTIAN HIEROGLYPH Z009")
(78837 . "EGYPTIAN HIEROGLYPH Z010")
(78838 . "EGYPTIAN HIEROGLYPH Z011")
(78839 . "EGYPTIAN HIEROGLYPH Z012")
(78840 . "EGYPTIAN HIEROGLYPH Z013")
(78841 . "EGYPTIAN HIEROGLYPH Z014")
(78842 . "EGYPTIAN HIEROGLYPH Z015")
(78843 . "EGYPTIAN HIEROGLYPH Z015A")
(78844 . "EGYPTIAN HIEROGLYPH Z015B")
(78845 . "EGYPTIAN HIEROGLYPH Z015C")
(78846 . "EGYPTIAN HIEROGLYPH Z015D")
(78847 . "EGYPTIAN HIEROGLYPH Z015E")
(78848 . "EGYPTIAN HIEROGLYPH Z015F")
(78849 . "EGYPTIAN HIEROGLYPH Z015G")
(78850 . "EGYPTIAN HIEROGLYPH Z015H")
(78851 . "EGYPTIAN HIEROGLYPH Z015I")
(78852 . "EGYPTIAN HIEROGLYPH Z016")
(78853 . "EGYPTIAN HIEROGLYPH Z016A")
(78854 . "EGYPTIAN HIEROGLYPH Z016B")
(78855 . "EGYPTIAN HIEROGLYPH Z016C")
(78856 . "EGYPTIAN HIEROGLYPH Z016D")
(78857 . "EGYPTIAN HIEROGLYPH Z016E")
(78858 . "EGYPTIAN HIEROGLYPH Z016F")
(78859 . "EGYPTIAN HIEROGLYPH Z016G")
(78860 . "EGYPTIAN HIEROGLYPH Z016H")
(78861 . "EGYPTIAN HIEROGLYPH AA001")
(78862 . "EGYPTIAN HIEROGLYPH AA002")
(78863 . "EGYPTIAN HIEROGLYPH AA003")
(78864 . "EGYPTIAN HIEROGLYPH AA004")
(78865 . "EGYPTIAN HIEROGLYPH AA005")
(78866 . "EGYPTIAN HIEROGLYPH AA006")
(78867 . "EGYPTIAN HIEROGLYPH AA007")
(78868 . "EGYPTIAN HIEROGLYPH AA007A")
(78869 . "EGYPTIAN HIEROGLYPH AA007B")
(78870 . "EGYPTIAN HIEROGLYPH AA008")
(78871 . "EGYPTIAN HIEROGLYPH AA009")
(78872 . "EGYPTIAN HIEROGLYPH AA010")
(78873 . "EGYPTIAN HIEROGLYPH AA011")
(78874 . "EGYPTIAN HIEROGLYPH AA012")
(78875 . "EGYPTIAN HIEROGLYPH AA013")
(78876 . "EGYPTIAN HIEROGLYPH AA014")
(78877 . "EGYPTIAN HIEROGLYPH AA015")
(78878 . "EGYPTIAN HIEROGLYPH AA016")
(78879 . "EGYPTIAN HIEROGLYPH AA017")
(78880 . "EGYPTIAN HIEROGLYPH AA018")
(78881 . "EGYPTIAN HIEROGLYPH AA019")
(78882 . "EGYPTIAN HIEROGLYPH AA020")
(78883 . "EGYPTIAN HIEROGLYPH AA021")
(78884 . "EGYPTIAN HIEROGLYPH AA022")
(78885 . "EGYPTIAN HIEROGLYPH AA023")
(78886 . "EGYPTIAN HIEROGLYPH AA024")
(78887 . "EGYPTIAN HIEROGLYPH AA025")
(78888 . "EGYPTIAN HIEROGLYPH AA026")
(78889 . "EGYPTIAN HIEROGLYPH AA027")
(78890 . "EGYPTIAN HIEROGLYPH AA028")
(78891 . "EGYPTIAN HIEROGLYPH AA029")
(78892 . "EGYPTIAN HIEROGLYPH AA030")
(78893 . "EGYPTIAN HIEROGLYPH AA031")
(78894 . "EGYPTIAN HIEROGLYPH AA032")
((78895 . 82944) . #f)
(82944 . "ANATOLIAN HIEROGLYPH A001")
(82945 . "ANATOLIAN HIEROGLYPH A002")
(82946 . "ANATOLIAN HIEROGLYPH A003")
(82947 . "ANATOLIAN HIEROGLYPH A004")
(82948 . "ANATOLIAN HIEROGLYPH A005")
(82949 . "ANATOLIAN HIEROGLYPH A006")
(82950 . "ANATOLIAN HIEROGLYPH A007")
(82951 . "ANATOLIAN HIEROGLYPH A008")
(82952 . "ANATOLIAN HIEROGLYPH A009")
(82953 . "ANATOLIAN HIEROGLYPH A010")
(82954 . "ANATOLIAN HIEROGLYPH A010A")
(82955 . "ANATOLIAN HIEROGLYPH A011")
(82956 . "ANATOLIAN HIEROGLYPH A012")
(82957 . "ANATOLIAN HIEROGLYPH A013")
(82958 . "ANATOLIAN HIEROGLYPH A014")
(82959 . "ANATOLIAN HIEROGLYPH A015")
(82960 . "ANATOLIAN HIEROGLYPH A016")
(82961 . "ANATOLIAN HIEROGLYPH A017")
(82962 . "ANATOLIAN HIEROGLYPH A018")
(82963 . "ANATOLIAN HIEROGLYPH A019")
(82964 . "ANATOLIAN HIEROGLYPH A020")
(82965 . "ANATOLIAN HIEROGLYPH A021")
(82966 . "ANATOLIAN HIEROGLYPH A022")
(82967 . "ANATOLIAN HIEROGLYPH A023")
(82968 . "ANATOLIAN HIEROGLYPH A024")
(82969 . "ANATOLIAN HIEROGLYPH A025")
(82970 . "ANATOLIAN HIEROGLYPH A026")
(82971 . "ANATOLIAN HIEROGLYPH A026A")
(82972 . "ANATOLIAN HIEROGLYPH A027")
(82973 . "ANATOLIAN HIEROGLYPH A028")
(82974 . "ANATOLIAN HIEROGLYPH A029")
(82975 . "ANATOLIAN HIEROGLYPH A030")
(82976 . "ANATOLIAN HIEROGLYPH A031")
(82977 . "ANATOLIAN HIEROGLYPH A032")
(82978 . "ANATOLIAN HIEROGLYPH A033")
(82979 . "ANATOLIAN HIEROGLYPH A034")
(82980 . "ANATOLIAN HIEROGLYPH A035")
(82981 . "ANATOLIAN HIEROGLYPH A036")
(82982 . "ANATOLIAN HIEROGLYPH A037")
(82983 . "ANATOLIAN HIEROGLYPH A038")
(82984 . "ANATOLIAN HIEROGLYPH A039")
(82985 . "ANATOLIAN HIEROGLYPH A039A")
(82986 . "ANATOLIAN HIEROGLYPH A040")
(82987 . "ANATOLIAN HIEROGLYPH A041")
(82988 . "ANATOLIAN HIEROGLYPH A041A")
(82989 . "ANATOLIAN HIEROGLYPH A042")
(82990 . "ANATOLIAN HIEROGLYPH A043")
(82991 . "ANATOLIAN HIEROGLYPH A044")
(82992 . "ANATOLIAN HIEROGLYPH A045")
(82993 . "ANATOLIAN HIEROGLYPH A045A")
(82994 . "ANATOLIAN HIEROGLYPH A046")
(82995 . "ANATOLIAN HIEROGLYPH A046A")
(82996 . "ANATOLIAN HIEROGLYPH A046B")
(82997 . "ANATOLIAN HIEROGLYPH A047")
(82998 . "ANATOLIAN HIEROGLYPH A048")
(82999 . "ANATOLIAN HIEROGLYPH A049")
(83000 . "ANATOLIAN HIEROGLYPH A050")
(83001 . "ANATOLIAN HIEROGLYPH A051")
(83002 . "ANATOLIAN HIEROGLYPH A052")
(83003 . "ANATOLIAN HIEROGLYPH A053")
(83004 . "ANATOLIAN HIEROGLYPH A054")
(83005 . "ANATOLIAN HIEROGLYPH A055")
(83006 . "ANATOLIAN HIEROGLYPH A056")
(83007 . "ANATOLIAN HIEROGLYPH A057")
(83008 . "ANATOLIAN HIEROGLYPH A058")
(83009 . "ANATOLIAN HIEROGLYPH A059")
(83010 . "ANATOLIAN HIEROGLYPH A060")
(83011 . "ANATOLIAN HIEROGLYPH A061")
(83012 . "ANATOLIAN HIEROGLYPH A062")
(83013 . "ANATOLIAN HIEROGLYPH A063")
(83014 . "ANATOLIAN HIEROGLYPH A064")
(83015 . "ANATOLIAN HIEROGLYPH A065")
(83016 . "ANATOLIAN HIEROGLYPH A066")
(83017 . "ANATOLIAN HIEROGLYPH A066A")
(83018 . "ANATOLIAN HIEROGLYPH A066B")
(83019 . "ANATOLIAN HIEROGLYPH A066C")
(83020 . "ANATOLIAN HIEROGLYPH A067")
(83021 . "ANATOLIAN HIEROGLYPH A068")
(83022 . "ANATOLIAN HIEROGLYPH A069")
(83023 . "ANATOLIAN HIEROGLYPH A070")
(83024 . "ANATOLIAN HIEROGLYPH A071")
(83025 . "ANATOLIAN HIEROGLYPH A072")
(83026 . "ANATOLIAN HIEROGLYPH A073")
(83027 . "ANATOLIAN HIEROGLYPH A074")
(83028 . "ANATOLIAN HIEROGLYPH A075")
(83029 . "ANATOLIAN HIEROGLYPH A076")
(83030 . "ANATOLIAN HIEROGLYPH A077")
(83031 . "ANATOLIAN HIEROGLYPH A078")
(83032 . "ANATOLIAN HIEROGLYPH A079")
(83033 . "ANATOLIAN HIEROGLYPH A080")
(83034 . "ANATOLIAN HIEROGLYPH A081")
(83035 . "ANATOLIAN HIEROGLYPH A082")
(83036 . "ANATOLIAN HIEROGLYPH A083")
(83037 . "ANATOLIAN HIEROGLYPH A084")
(83038 . "ANATOLIAN HIEROGLYPH A085")
(83039 . "ANATOLIAN HIEROGLYPH A086")
(83040 . "ANATOLIAN HIEROGLYPH A087")
(83041 . "ANATOLIAN HIEROGLYPH A088")
(83042 . "ANATOLIAN HIEROGLYPH A089")
(83043 . "ANATOLIAN HIEROGLYPH A090")
(83044 . "ANATOLIAN HIEROGLYPH A091")
(83045 . "ANATOLIAN HIEROGLYPH A092")
(83046 . "ANATOLIAN HIEROGLYPH A093")
(83047 . "ANATOLIAN HIEROGLYPH A094")
(83048 . "ANATOLIAN HIEROGLYPH A095")
(83049 . "ANATOLIAN HIEROGLYPH A096")
(83050 . "ANATOLIAN HIEROGLYPH A097")
(83051 . "ANATOLIAN HIEROGLYPH A097A")
(83052 . "ANATOLIAN HIEROGLYPH A098")
(83053 . "ANATOLIAN HIEROGLYPH A098A")
(83054 . "ANATOLIAN HIEROGLYPH A099")
(83055 . "ANATOLIAN HIEROGLYPH A100")
(83056 . "ANATOLIAN HIEROGLYPH A100A")
(83057 . "ANATOLIAN HIEROGLYPH A101")
(83058 . "ANATOLIAN HIEROGLYPH A101A")
(83059 . "ANATOLIAN HIEROGLYPH A102")
(83060 . "ANATOLIAN HIEROGLYPH A102A")
(83061 . "ANATOLIAN HIEROGLYPH A103")
(83062 . "ANATOLIAN HIEROGLYPH A104")
(83063 . "ANATOLIAN HIEROGLYPH A104A")
(83064 . "ANATOLIAN HIEROGLYPH A104B")
(83065 . "ANATOLIAN HIEROGLYPH A104C")
(83066 . "ANATOLIAN HIEROGLYPH A105")
(83067 . "ANATOLIAN HIEROGLYPH A105A")
(83068 . "ANATOLIAN HIEROGLYPH A105B")
(83069 . "ANATOLIAN HIEROGLYPH A106")
(83070 . "ANATOLIAN HIEROGLYPH A107")
(83071 . "ANATOLIAN HIEROGLYPH A107A")
(83072 . "ANATOLIAN HIEROGLYPH A107B")
(83073 . "ANATOLIAN HIEROGLYPH A107C")
(83074 . "ANATOLIAN HIEROGLYPH A108")
(83075 . "ANATOLIAN HIEROGLYPH A109")
(83076 . "ANATOLIAN HIEROGLYPH A110")
(83077 . "ANATOLIAN HIEROGLYPH A110A")
(83078 . "ANATOLIAN HIEROGLYPH A110B")
(83079 . "ANATOLIAN HIEROGLYPH A111")
(83080 . "ANATOLIAN HIEROGLYPH A112")
(83081 . "ANATOLIAN HIEROGLYPH A113")
(83082 . "ANATOLIAN HIEROGLYPH A114")
(83083 . "ANATOLIAN HIEROGLYPH A115")
(83084 . "ANATOLIAN HIEROGLYPH A115A")
(83085 . "ANATOLIAN HIEROGLYPH A116")
(83086 . "ANATOLIAN HIEROGLYPH A117")
(83087 . "ANATOLIAN HIEROGLYPH A118")
(83088 . "ANATOLIAN HIEROGLYPH A119")
(83089 . "ANATOLIAN HIEROGLYPH A120")
(83090 . "ANATOLIAN HIEROGLYPH A121")
(83091 . "ANATOLIAN HIEROGLYPH A122")
(83092 . "ANATOLIAN HIEROGLYPH A123")
(83093 . "ANATOLIAN HIEROGLYPH A124")
(83094 . "ANATOLIAN HIEROGLYPH A125")
(83095 . "ANATOLIAN HIEROGLYPH A125A")
(83096 . "ANATOLIAN HIEROGLYPH A126")
(83097 . "ANATOLIAN HIEROGLYPH A127")
(83098 . "ANATOLIAN HIEROGLYPH A128")
(83099 . "ANATOLIAN HIEROGLYPH A129")
(83100 . "ANATOLIAN HIEROGLYPH A130")
(83101 . "ANATOLIAN HIEROGLYPH A131")
(83102 . "ANATOLIAN HIEROGLYPH A132")
(83103 . "ANATOLIAN HIEROGLYPH A133")
(83104 . "ANATOLIAN HIEROGLYPH A134")
(83105 . "ANATOLIAN HIEROGLYPH A135")
(83106 . "ANATOLIAN HIEROGLYPH A135A")
(83107 . "ANATOLIAN HIEROGLYPH A136")
(83108 . "ANATOLIAN HIEROGLYPH A137")
(83109 . "ANATOLIAN HIEROGLYPH A138")
(83110 . "ANATOLIAN HIEROGLYPH A139")
(83111 . "ANATOLIAN HIEROGLYPH A140")
(83112 . "ANATOLIAN HIEROGLYPH A141")
(83113 . "ANATOLIAN HIEROGLYPH A142")
(83114 . "ANATOLIAN HIEROGLYPH A143")
(83115 . "ANATOLIAN HIEROGLYPH A144")
(83116 . "ANATOLIAN HIEROGLYPH A145")
(83117 . "ANATOLIAN HIEROGLYPH A146")
(83118 . "ANATOLIAN HIEROGLYPH A147")
(83119 . "ANATOLIAN HIEROGLYPH A148")
(83120 . "ANATOLIAN HIEROGLYPH A149")
(83121 . "ANATOLIAN HIEROGLYPH A150")
(83122 . "ANATOLIAN HIEROGLYPH A151")
(83123 . "ANATOLIAN HIEROGLYPH A152")
(83124 . "ANATOLIAN HIEROGLYPH A153")
(83125 . "ANATOLIAN HIEROGLYPH A154")
(83126 . "ANATOLIAN HIEROGLYPH A155")
(83127 . "ANATOLIAN HIEROGLYPH A156")
(83128 . "ANATOLIAN HIEROGLYPH A157")
(83129 . "ANATOLIAN HIEROGLYPH A158")
(83130 . "ANATOLIAN HIEROGLYPH A159")
(83131 . "ANATOLIAN HIEROGLYPH A160")
(83132 . "ANATOLIAN HIEROGLYPH A161")
(83133 . "ANATOLIAN HIEROGLYPH A162")
(83134 . "ANATOLIAN HIEROGLYPH A163")
(83135 . "ANATOLIAN HIEROGLYPH A164")
(83136 . "ANATOLIAN HIEROGLYPH A165")
(83137 . "ANATOLIAN HIEROGLYPH A166")
(83138 . "ANATOLIAN HIEROGLYPH A167")
(83139 . "ANATOLIAN HIEROGLYPH A168")
(83140 . "ANATOLIAN HIEROGLYPH A169")
(83141 . "ANATOLIAN HIEROGLYPH A170")
(83142 . "ANATOLIAN HIEROGLYPH A171")
(83143 . "ANATOLIAN HIEROGLYPH A172")
(83144 . "ANATOLIAN HIEROGLYPH A173")
(83145 . "ANATOLIAN HIEROGLYPH A174")
(83146 . "ANATOLIAN HIEROGLYPH A175")
(83147 . "ANATOLIAN HIEROGLYPH A176")
(83148 . "ANATOLIAN HIEROGLYPH A177")
(83149 . "ANATOLIAN HIEROGLYPH A178")
(83150 . "ANATOLIAN HIEROGLYPH A179")
(83151 . "ANATOLIAN HIEROGLYPH A180")
(83152 . "ANATOLIAN HIEROGLYPH A181")
(83153 . "ANATOLIAN HIEROGLYPH A182")
(83154 . "ANATOLIAN HIEROGLYPH A183")
(83155 . "ANATOLIAN HIEROGLYPH A184")
(83156 . "ANATOLIAN HIEROGLYPH A185")
(83157 . "ANATOLIAN HIEROGLYPH A186")
(83158 . "ANATOLIAN HIEROGLYPH A187")
(83159 . "ANATOLIAN HIEROGLYPH A188")
(83160 . "ANATOLIAN HIEROGLYPH A189")
(83161 . "ANATOLIAN HIEROGLYPH A190")
(83162 . "ANATOLIAN HIEROGLYPH A191")
(83163 . "ANATOLIAN HIEROGLYPH A192")
(83164 . "ANATOLIAN HIEROGLYPH A193")
(83165 . "ANATOLIAN HIEROGLYPH A194")
(83166 . "ANATOLIAN HIEROGLYPH A195")
(83167 . "ANATOLIAN HIEROGLYPH A196")
(83168 . "ANATOLIAN HIEROGLYPH A197")
(83169 . "ANATOLIAN HIEROGLYPH A198")
(83170 . "ANATOLIAN HIEROGLYPH A199")
(83171 . "ANATOLIAN HIEROGLYPH A200")
(83172 . "ANATOLIAN HIEROGLYPH A201")
(83173 . "ANATOLIAN HIEROGLYPH A202")
(83174 . "ANATOLIAN HIEROGLYPH A202A")
(83175 . "ANATOLIAN HIEROGLYPH A202B")
(83176 . "ANATOLIAN HIEROGLYPH A203")
(83177 . "ANATOLIAN HIEROGLYPH A204")
(83178 . "ANATOLIAN HIEROGLYPH A205")
(83179 . "ANATOLIAN HIEROGLYPH A206")
(83180 . "ANATOLIAN HIEROGLYPH A207")
(83181 . "ANATOLIAN HIEROGLYPH A207A")
(83182 . "ANATOLIAN HIEROGLYPH A208")
(83183 . "ANATOLIAN HIEROGLYPH A209")
(83184 . "ANATOLIAN HIEROGLYPH A209A")
(83185 . "ANATOLIAN HIEROGLYPH A210")
(83186 . "ANATOLIAN HIEROGLYPH A211")
(83187 . "ANATOLIAN HIEROGLYPH A212")
(83188 . "ANATOLIAN HIEROGLYPH A213")
(83189 . "ANATOLIAN HIEROGLYPH A214")
(83190 . "ANATOLIAN HIEROGLYPH A215")
(83191 . "ANATOLIAN HIEROGLYPH A215A")
(83192 . "ANATOLIAN HIEROGLYPH A216")
(83193 . "ANATOLIAN HIEROGLYPH A216A")
(83194 . "ANATOLIAN HIEROGLYPH A217")
(83195 . "ANATOLIAN HIEROGLYPH A218")
(83196 . "ANATOLIAN HIEROGLYPH A219")
(83197 . "ANATOLIAN HIEROGLYPH A220")
(83198 . "ANATOLIAN HIEROGLYPH A221")
(83199 . "ANATOLIAN HIEROGLYPH A222")
(83200 . "ANATOLIAN HIEROGLYPH A223")
(83201 . "ANATOLIAN HIEROGLYPH A224")
(83202 . "ANATOLIAN HIEROGLYPH A225")
(83203 . "ANATOLIAN HIEROGLYPH A226")
(83204 . "ANATOLIAN HIEROGLYPH A227")
(83205 . "ANATOLIAN HIEROGLYPH A227A")
(83206 . "ANATOLIAN HIEROGLYPH A228")
(83207 . "ANATOLIAN HIEROGLYPH A229")
(83208 . "ANATOLIAN HIEROGLYPH A230")
(83209 . "ANATOLIAN HIEROGLYPH A231")
(83210 . "ANATOLIAN HIEROGLYPH A232")
(83211 . "ANATOLIAN HIEROGLYPH A233")
(83212 . "ANATOLIAN HIEROGLYPH A234")
(83213 . "ANATOLIAN HIEROGLYPH A235")
(83214 . "ANATOLIAN HIEROGLYPH A236")
(83215 . "ANATOLIAN HIEROGLYPH A237")
(83216 . "ANATOLIAN HIEROGLYPH A238")
(83217 . "ANATOLIAN HIEROGLYPH A239")
(83218 . "ANATOLIAN HIEROGLYPH A240")
(83219 . "ANATOLIAN HIEROGLYPH A241")
(83220 . "ANATOLIAN HIEROGLYPH A242")
(83221 . "ANATOLIAN HIEROGLYPH A243")
(83222 . "ANATOLIAN HIEROGLYPH A244")
(83223 . "ANATOLIAN HIEROGLYPH A245")
(83224 . "ANATOLIAN HIEROGLYPH A246")
(83225 . "ANATOLIAN HIEROGLYPH A247")
(83226 . "ANATOLIAN HIEROGLYPH A248")
(83227 . "ANATOLIAN HIEROGLYPH A249")
(83228 . "ANATOLIAN HIEROGLYPH A250")
(83229 . "ANATOLIAN HIEROGLYPH A251")
(83230 . "ANATOLIAN HIEROGLYPH A252")
(83231 . "ANATOLIAN HIEROGLYPH A253")
(83232 . "ANATOLIAN HIEROGLYPH A254")
(83233 . "ANATOLIAN HIEROGLYPH A255")
(83234 . "ANATOLIAN HIEROGLYPH A256")
(83235 . "ANATOLIAN HIEROGLYPH A257")
(83236 . "ANATOLIAN HIEROGLYPH A258")
(83237 . "ANATOLIAN HIEROGLYPH A259")
(83238 . "ANATOLIAN HIEROGLYPH A260")
(83239 . "ANATOLIAN HIEROGLYPH A261")
(83240 . "ANATOLIAN HIEROGLYPH A262")
(83241 . "ANATOLIAN HIEROGLYPH A263")
(83242 . "ANATOLIAN HIEROGLYPH A264")
(83243 . "ANATOLIAN HIEROGLYPH A265")
(83244 . "ANATOLIAN HIEROGLYPH A266")
(83245 . "ANATOLIAN HIEROGLYPH A267")
(83246 . "ANATOLIAN HIEROGLYPH A267A")
(83247 . "ANATOLIAN HIEROGLYPH A268")
(83248 . "ANATOLIAN HIEROGLYPH A269")
(83249 . "ANATOLIAN HIEROGLYPH A270")
(83250 . "ANATOLIAN HIEROGLYPH A271")
(83251 . "ANATOLIAN HIEROGLYPH A272")
(83252 . "ANATOLIAN HIEROGLYPH A273")
(83253 . "ANATOLIAN HIEROGLYPH A274")
(83254 . "ANATOLIAN HIEROGLYPH A275")
(83255 . "ANATOLIAN HIEROGLYPH A276")
(83256 . "ANATOLIAN HIEROGLYPH A277")
(83257 . "ANATOLIAN HIEROGLYPH A278")
(83258 . "ANATOLIAN HIEROGLYPH A279")
(83259 . "ANATOLIAN HIEROGLYPH A280")
(83260 . "ANATOLIAN HIEROGLYPH A281")
(83261 . "ANATOLIAN HIEROGLYPH A282")
(83262 . "ANATOLIAN HIEROGLYPH A283")
(83263 . "ANATOLIAN HIEROGLYPH A284")
(83264 . "ANATOLIAN HIEROGLYPH A285")
(83265 . "ANATOLIAN HIEROGLYPH A286")
(83266 . "ANATOLIAN HIEROGLYPH A287")
(83267 . "ANATOLIAN HIEROGLYPH A288")
(83268 . "ANATOLIAN HIEROGLYPH A289")
(83269 . "ANATOLIAN HIEROGLYPH A289A")
(83270 . "ANATOLIAN HIEROGLYPH A290")
(83271 . "ANATOLIAN HIEROGLYPH A291")
(83272 . "ANATOLIAN HIEROGLYPH A292")
(83273 . "ANATOLIAN HIEROGLYPH A293")
(83274 . "ANATOLIAN HIEROGLYPH A294")
(83275 . "ANATOLIAN HIEROGLYPH A294A")
(83276 . "ANATOLIAN HIEROGLYPH A295")
(83277 . "ANATOLIAN HIEROGLYPH A296")
(83278 . "ANATOLIAN HIEROGLYPH A297")
(83279 . "ANATOLIAN HIEROGLYPH A298")
(83280 . "ANATOLIAN HIEROGLYPH A299")
(83281 . "ANATOLIAN HIEROGLYPH A299A")
(83282 . "ANATOLIAN HIEROGLYPH A300")
(83283 . "ANATOLIAN HIEROGLYPH A301")
(83284 . "ANATOLIAN HIEROGLYPH A302")
(83285 . "ANATOLIAN HIEROGLYPH A303")
(83286 . "ANATOLIAN HIEROGLYPH A304")
(83287 . "ANATOLIAN HIEROGLYPH A305")
(83288 . "ANATOLIAN HIEROGLYPH A306")
(83289 . "ANATOLIAN HIEROGLYPH A307")
(83290 . "ANATOLIAN HIEROGLYPH A308")
(83291 . "ANATOLIAN HIEROGLYPH A309")
(83292 . "ANATOLIAN HIEROGLYPH A309A")
(83293 . "ANATOLIAN HIEROGLYPH A310")
(83294 . "ANATOLIAN HIEROGLYPH A311")
(83295 . "ANATOLIAN HIEROGLYPH A312")
(83296 . "ANATOLIAN HIEROGLYPH A313")
(83297 . "ANATOLIAN HIEROGLYPH A314")
(83298 . "ANATOLIAN HIEROGLYPH A315")
(83299 . "ANATOLIAN HIEROGLYPH A316")
(83300 . "ANATOLIAN HIEROGLYPH A317")
(83301 . "ANATOLIAN HIEROGLYPH A318")
(83302 . "ANATOLIAN HIEROGLYPH A319")
(83303 . "ANATOLIAN HIEROGLYPH A320")
(83304 . "ANATOLIAN HIEROGLYPH A321")
(83305 . "ANATOLIAN HIEROGLYPH A322")
(83306 . "ANATOLIAN HIEROGLYPH A323")
(83307 . "ANATOLIAN HIEROGLYPH A324")
(83308 . "ANATOLIAN HIEROGLYPH A325")
(83309 . "ANATOLIAN HIEROGLYPH A326")
(83310 . "ANATOLIAN HIEROGLYPH A327")
(83311 . "ANATOLIAN HIEROGLYPH A328")
(83312 . "ANATOLIAN HIEROGLYPH A329")
(83313 . "ANATOLIAN HIEROGLYPH A329A")
(83314 . "ANATOLIAN HIEROGLYPH A330")
(83315 . "ANATOLIAN HIEROGLYPH A331")
(83316 . "ANATOLIAN HIEROGLYPH A332A")
(83317 . "ANATOLIAN HIEROGLYPH A332B")
(83318 . "ANATOLIAN HIEROGLYPH A332C")
(83319 . "ANATOLIAN HIEROGLYPH A333")
(83320 . "ANATOLIAN HIEROGLYPH A334")
(83321 . "ANATOLIAN HIEROGLYPH A335")
(83322 . "ANATOLIAN HIEROGLYPH A336")
(83323 . "ANATOLIAN HIEROGLYPH A336A")
(83324 . "ANATOLIAN HIEROGLYPH A336B")
(83325 . "ANATOLIAN HIEROGLYPH A336C")
(83326 . "ANATOLIAN HIEROGLYPH A337")
(83327 . "ANATOLIAN HIEROGLYPH A338")
(83328 . "ANATOLIAN HIEROGLYPH A339")
(83329 . "ANATOLIAN HIEROGLYPH A340")
(83330 . "ANATOLIAN HIEROGLYPH A341")
(83331 . "ANATOLIAN HIEROGLYPH A342")
(83332 . "ANATOLIAN HIEROGLYPH A343")
(83333 . "ANATOLIAN HIEROGLYPH A344")
(83334 . "ANATOLIAN HIEROGLYPH A345")
(83335 . "ANATOLIAN HIEROGLYPH A346")
(83336 . "ANATOLIAN HIEROGLYPH A347")
(83337 . "ANATOLIAN HIEROGLYPH A348")
(83338 . "ANATOLIAN HIEROGLYPH A349")
(83339 . "ANATOLIAN HIEROGLYPH A350")
(83340 . "ANATOLIAN HIEROGLYPH A351")
(83341 . "ANATOLIAN HIEROGLYPH A352")
(83342 . "ANATOLIAN HIEROGLYPH A353")
(83343 . "ANATOLIAN HIEROGLYPH A354")
(83344 . "ANATOLIAN HIEROGLYPH A355")
(83345 . "ANATOLIAN HIEROGLYPH A356")
(83346 . "ANATOLIAN HIEROGLYPH A357")
(83347 . "ANATOLIAN HIEROGLYPH A358")
(83348 . "ANATOLIAN HIEROGLYPH A359")
(83349 . "ANATOLIAN HIEROGLYPH A359A")
(83350 . "ANATOLIAN HIEROGLYPH A360")
(83351 . "ANATOLIAN HIEROGLYPH A361")
(83352 . "ANATOLIAN HIEROGLYPH A362")
(83353 . "ANATOLIAN HIEROGLYPH A363")
(83354 . "ANATOLIAN HIEROGLYPH A364")
(83355 . "ANATOLIAN HIEROGLYPH A364A")
(83356 . "ANATOLIAN HIEROGLYPH A365")
(83357 . "ANATOLIAN HIEROGLYPH A366")
(83358 . "ANATOLIAN HIEROGLYPH A367")
(83359 . "ANATOLIAN HIEROGLYPH A368")
(83360 . "ANATOLIAN HIEROGLYPH A368A")
(83361 . "ANATOLIAN HIEROGLYPH A369")
(83362 . "ANATOLIAN HIEROGLYPH A370")
(83363 . "ANATOLIAN HIEROGLYPH A371")
(83364 . "ANATOLIAN HIEROGLYPH A371A")
(83365 . "ANATOLIAN HIEROGLYPH A372")
(83366 . "ANATOLIAN HIEROGLYPH A373")
(83367 . "ANATOLIAN HIEROGLYPH A374")
(83368 . "ANATOLIAN HIEROGLYPH A375")
(83369 . "ANATOLIAN HIEROGLYPH A376")
(83370 . "ANATOLIAN HIEROGLYPH A377")
(83371 . "ANATOLIAN HIEROGLYPH A378")
(83372 . "ANATOLIAN HIEROGLYPH A379")
(83373 . "ANATOLIAN HIEROGLYPH A380")
(83374 . "ANATOLIAN HIEROGLYPH A381")
(83375 . "ANATOLIAN HIEROGLYPH A381A")
(83376 . "ANATOLIAN HIEROGLYPH A382")
(83377 . "ANATOLIAN HIEROGLYPH A383 RA OR RI")
(83378 . "ANATOLIAN HIEROGLYPH A383A")
(83379 . "ANATOLIAN HIEROGLYPH A384")
(83380 . "ANATOLIAN HIEROGLYPH A385")
(83381 . "ANATOLIAN HIEROGLYPH A386")
(83382 . "ANATOLIAN HIEROGLYPH A386A")
(83383 . "ANATOLIAN HIEROGLYPH A387")
(83384 . "ANATOLIAN HIEROGLYPH A388")
(83385 . "ANATOLIAN HIEROGLYPH A389")
(83386 . "ANATOLIAN HIEROGLYPH A390")
(83387 . "ANATOLIAN HIEROGLYPH A391")
(83388 . "ANATOLIAN HIEROGLYPH A392")
(83389 . "ANATOLIAN HIEROGLYPH A393 EIGHT")
(83390 . "ANATOLIAN HIEROGLYPH A394")
(83391 . "ANATOLIAN HIEROGLYPH A395")
(83392 . "ANATOLIAN HIEROGLYPH A396")
(83393 . "ANATOLIAN HIEROGLYPH A397")
(83394 . "ANATOLIAN HIEROGLYPH A398")
(83395 . "ANATOLIAN HIEROGLYPH A399")
(83396 . "ANATOLIAN HIEROGLYPH A400")
(83397 . "ANATOLIAN HIEROGLYPH A401")
(83398 . "ANATOLIAN HIEROGLYPH A402")
(83399 . "ANATOLIAN HIEROGLYPH A403")
(83400 . "ANATOLIAN HIEROGLYPH A404")
(83401 . "ANATOLIAN HIEROGLYPH A405")
(83402 . "ANATOLIAN HIEROGLYPH A406")
(83403 . "ANATOLIAN HIEROGLYPH A407")
(83404 . "ANATOLIAN HIEROGLYPH A408")
(83405 . "ANATOLIAN HIEROGLYPH A409")
(83406 . "ANATOLIAN HIEROGLYPH A410 BEGIN LOGOGRAM MARK")
(83407 . "ANATOLIAN HIEROGLYPH A410A END LOGOGRAM MARK")
(83408 . "ANATOLIAN HIEROGLYPH A411")
(83409 . "ANATOLIAN HIEROGLYPH A412")
(83410 . "ANATOLIAN HIEROGLYPH A413")
(83411 . "ANATOLIAN HIEROGLYPH A414")
(83412 . "ANATOLIAN HIEROGLYPH A415")
(83413 . "ANATOLIAN HIEROGLYPH A416")
(83414 . "ANATOLIAN HIEROGLYPH A417")
(83415 . "ANATOLIAN HIEROGLYPH A418")
(83416 . "ANATOLIAN HIEROGLYPH A419")
(83417 . "ANATOLIAN HIEROGLYPH A420")
(83418 . "ANATOLIAN HIEROGLYPH A421")
(83419 . "ANATOLIAN HIEROGLYPH A422")
(83420 . "ANATOLIAN HIEROGLYPH A423")
(83421 . "ANATOLIAN HIEROGLYPH A424")
(83422 . "ANATOLIAN HIEROGLYPH A425")
(83423 . "ANATOLIAN HIEROGLYPH A426")
(83424 . "ANATOLIAN HIEROGLYPH A427")
(83425 . "ANATOLIAN HIEROGLYPH A428")
(83426 . "ANATOLIAN HIEROGLYPH A429")
(83427 . "ANATOLIAN HIEROGLYPH A430")
(83428 . "ANATOLIAN HIEROGLYPH A431")
(83429 . "ANATOLIAN HIEROGLYPH A432")
(83430 . "ANATOLIAN HIEROGLYPH A433")
(83431 . "ANATOLIAN HIEROGLYPH A434")
(83432 . "ANATOLIAN HIEROGLYPH A435")
(83433 . "ANATOLIAN HIEROGLYPH A436")
(83434 . "ANATOLIAN HIEROGLYPH A437")
(83435 . "ANATOLIAN HIEROGLYPH A438")
(83436 . "ANATOLIAN HIEROGLYPH A439")
(83437 . "ANATOLIAN HIEROGLYPH A440")
(83438 . "ANATOLIAN HIEROGLYPH A441")
(83439 . "ANATOLIAN HIEROGLYPH A442")
(83440 . "ANATOLIAN HIEROGLYPH A443")
(83441 . "ANATOLIAN HIEROGLYPH A444")
(83442 . "ANATOLIAN HIEROGLYPH A445")
(83443 . "ANATOLIAN HIEROGLYPH A446")
(83444 . "ANATOLIAN HIEROGLYPH A447")
(83445 . "ANATOLIAN HIEROGLYPH A448")
(83446 . "ANATOLIAN HIEROGLYPH A449")
(83447 . "ANATOLIAN HIEROGLYPH A450")
(83448 . "ANATOLIAN HIEROGLYPH A450A")
(83449 . "ANATOLIAN HIEROGLYPH A451")
(83450 . "ANATOLIAN HIEROGLYPH A452")
(83451 . "ANATOLIAN HIEROGLYPH A453")
(83452 . "ANATOLIAN HIEROGLYPH A454")
(83453 . "ANATOLIAN HIEROGLYPH A455")
(83454 . "ANATOLIAN HIEROGLYPH A456")
(83455 . "ANATOLIAN HIEROGLYPH A457")
(83456 . "ANATOLIAN HIEROGLYPH A457A")
(83457 . "ANATOLIAN HIEROGLYPH A458")
(83458 . "ANATOLIAN HIEROGLYPH A459")
(83459 . "ANATOLIAN HIEROGLYPH A460")
(83460 . "ANATOLIAN HIEROGLYPH A461")
(83461 . "ANATOLIAN HIEROGLYPH A462")
(83462 . "ANATOLIAN HIEROGLYPH A463")
(83463 . "ANATOLIAN HIEROGLYPH A464")
(83464 . "ANATOLIAN HIEROGLYPH A465")
(83465 . "ANATOLIAN HIEROGLYPH A466")
(83466 . "ANATOLIAN HIEROGLYPH A467")
(83467 . "ANATOLIAN HIEROGLYPH A468")
(83468 . "ANATOLIAN HIEROGLYPH A469")
(83469 . "ANATOLIAN HIEROGLYPH A470")
(83470 . "ANATOLIAN HIEROGLYPH A471")
(83471 . "ANATOLIAN HIEROGLYPH A472")
(83472 . "ANATOLIAN HIEROGLYPH A473")
(83473 . "ANATOLIAN HIEROGLYPH A474")
(83474 . "ANATOLIAN HIEROGLYPH A475")
(83475 . "ANATOLIAN HIEROGLYPH A476")
(83476 . "ANATOLIAN HIEROGLYPH A477")
(83477 . "ANATOLIAN HIEROGLYPH A478")
(83478 . "ANATOLIAN HIEROGLYPH A479")
(83479 . "ANATOLIAN HIEROGLYPH A480")
(83480 . "ANATOLIAN HIEROGLYPH A481")
(83481 . "ANATOLIAN HIEROGLYPH A482")
(83482 . "ANATOLIAN HIEROGLYPH A483")
(83483 . "ANATOLIAN HIEROGLYPH A484")
(83484 . "ANATOLIAN HIEROGLYPH A485")
(83485 . "ANATOLIAN HIEROGLYPH A486")
(83486 . "ANATOLIAN HIEROGLYPH A487")
(83487 . "ANATOLIAN HIEROGLYPH A488")
(83488 . "ANATOLIAN HIEROGLYPH A489")
(83489 . "ANATOLIAN HIEROGLYPH A490")
(83490 . "ANATOLIAN HIEROGLYPH A491")
(83491 . "ANATOLIAN HIEROGLYPH A492")
(83492 . "ANATOLIAN HIEROGLYPH A493")
(83493 . "ANATOLIAN HIEROGLYPH A494")
(83494 . "ANATOLIAN HIEROGLYPH A495")
(83495 . "ANATOLIAN HIEROGLYPH A496")
(83496 . "ANATOLIAN HIEROGLYPH A497")
(83497 . "ANATOLIAN HIEROGLYPH A501")
(83498 . "ANATOLIAN HIEROGLYPH A502")
(83499 . "ANATOLIAN HIEROGLYPH A503")
(83500 . "ANATOLIAN HIEROGLYPH A504")
(83501 . "ANATOLIAN HIEROGLYPH A505")
(83502 . "ANATOLIAN HIEROGLYPH A506")
(83503 . "ANATOLIAN HIEROGLYPH A507")
(83504 . "ANATOLIAN HIEROGLYPH A508")
(83505 . "ANATOLIAN HIEROGLYPH A509")
(83506 . "ANATOLIAN HIEROGLYPH A510")
(83507 . "ANATOLIAN HIEROGLYPH A511")
(83508 . "ANATOLIAN HIEROGLYPH A512")
(83509 . "ANATOLIAN HIEROGLYPH A513")
(83510 . "ANATOLIAN HIEROGLYPH A514")
(83511 . "ANATOLIAN HIEROGLYPH A515")
(83512 . "ANATOLIAN HIEROGLYPH A516")
(83513 . "ANATOLIAN HIEROGLYPH A517")
(83514 . "ANATOLIAN HIEROGLYPH A518")
(83515 . "ANATOLIAN HIEROGLYPH A519")
(83516 . "ANATOLIAN HIEROGLYPH A520")
(83517 . "ANATOLIAN HIEROGLYPH A521")
(83518 . "ANATOLIAN HIEROGLYPH A522")
(83519 . "ANATOLIAN HIEROGLYPH A523")
(83520 . "ANATOLIAN HIEROGLYPH A524")
(83521 . "ANATOLIAN HIEROGLYPH A525")
(83522 . "ANATOLIAN HIEROGLYPH A526")
(83523 . "ANATOLIAN HIEROGLYPH A527")
(83524 . "ANATOLIAN HIEROGLYPH A528")
(83525 . "ANATOLIAN HIEROGLYPH A529")
(83526 . "ANATOLIAN HIEROGLYPH A530")
((83527 . 92160) . #f)
(92160 . "BAMUM LETTER PHASE-A NGKUE MFON")
(92161 . "BAMUM LETTER PHASE-A GBIEE FON")
(92162 . "BAMUM LETTER PHASE-A PON MFON PIPAEMGBIEE")
(92163 . "BAMUM LETTER PHASE-A PON MFON PIPAEMBA")
(92164 . "BAMUM LETTER PHASE-A NAA MFON")
(92165 . "BAMUM LETTER PHASE-A SHUENSHUET")
(92166 . "BAMUM LETTER PHASE-A TITA MFON")
(92167 . "BAMUM LETTER PHASE-A NZA MFON")
(92168 . "BAMUM LETTER PHASE-A SHINDA PA NJI")
(92169 . "BAMUM LETTER PHASE-A PON PA NJI PIPAEMGBIEE")
(92170 . "BAMUM LETTER PHASE-A PON PA NJI PIPAEMBA")
(92171 . "BAMUM LETTER PHASE-A MAEMBGBIEE")
(92172 . "BAMUM LETTER PHASE-A TU MAEMBA")
(92173 . "BAMUM LETTER PHASE-A NGANGU")
(92174 . "BAMUM LETTER PHASE-A MAEMVEUX")
(92175 . "BAMUM LETTER PHASE-A MANSUAE")
(92176 . "BAMUM LETTER PHASE-A MVEUAENGAM")
(92177 . "BAMUM LETTER PHASE-A SEUNYAM")
(92178 . "BAMUM LETTER PHASE-A NTOQPEN")
(92179 . "BAMUM LETTER PHASE-A KEUKEUTNDA")
(92180 . "BAMUM LETTER PHASE-A NKINDI")
(92181 . "BAMUM LETTER PHASE-A SUU")
(92182 . "BAMUM LETTER PHASE-A NGKUENZEUM")
(92183 . "BAMUM LETTER PHASE-A LAPAQ")
(92184 . "BAMUM LETTER PHASE-A LET KUT")
(92185 . "BAMUM LETTER PHASE-A NTAP MFAA")
(92186 . "BAMUM LETTER PHASE-A MAEKEUP")
(92187 . "BAMUM LETTER PHASE-A PASHAE")
(92188 . "BAMUM LETTER PHASE-A GHEUAERAE")
(92189 . "BAMUM LETTER PHASE-A PAMSHAE")
(92190 . "BAMUM LETTER PHASE-A MON NGGEUAET")
(92191 . "BAMUM LETTER PHASE-A NZUN MEUT")
(92192 . "BAMUM LETTER PHASE-A U YUQ NAE")
(92193 . "BAMUM LETTER PHASE-A GHEUAEGHEUAE")
(92194 . "BAMUM LETTER PHASE-A NTAP NTAA")
(92195 . "BAMUM LETTER PHASE-A SISA")
(92196 . "BAMUM LETTER PHASE-A MGBASA")
(92197 . "BAMUM LETTER PHASE-A MEUNJOMNDEUQ")
(92198 . "BAMUM LETTER PHASE-A MOOMPUQ")
(92199 . "BAMUM LETTER PHASE-A KAFA")
(92200 . "BAMUM LETTER PHASE-A PA LEERAEWA")
(92201 . "BAMUM LETTER PHASE-A NDA LEERAEWA")
(92202 . "BAMUM LETTER PHASE-A PET")
(92203 . "BAMUM LETTER PHASE-A MAEMKPEN")
(92204 . "BAMUM LETTER PHASE-A NIKA")
(92205 . "BAMUM LETTER PHASE-A PUP")
(92206 . "BAMUM LETTER PHASE-A TUAEP")
(92207 . "BAMUM LETTER PHASE-A LUAEP")
(92208 . "BAMUM LETTER PHASE-A SONJAM")
(92209 . "BAMUM LETTER PHASE-A TEUTEUWEN")
(92210 . "BAMUM LETTER PHASE-A MAENYI")
(92211 . "BAMUM LETTER PHASE-A KET")
(92212 . "BAMUM LETTER PHASE-A NDAANGGEUAET")
(92213 . "BAMUM LETTER PHASE-A KUOQ")
(92214 . "BAMUM LETTER PHASE-A MOOMEUT")
(92215 . "BAMUM LETTER PHASE-A SHUM")
(92216 . "BAMUM LETTER PHASE-A LOMMAE")
(92217 . "BAMUM LETTER PHASE-A FIRI")
(92218 . "BAMUM LETTER PHASE-A ROM")
(92219 . "BAMUM LETTER PHASE-A KPOQ")
(92220 . "BAMUM LETTER PHASE-A SOQ")
(92221 . "BAMUM LETTER PHASE-A MAP PIEET")
(92222 . "BAMUM LETTER PHASE-A SHIRAE")
(92223 . "BAMUM LETTER PHASE-A NTAP")
(92224 . "BAMUM LETTER PHASE-A SHOQ NSHUT YUM")
(92225 . "BAMUM LETTER PHASE-A NYIT MONGKEUAEQ")
(92226 . "BAMUM LETTER PHASE-A PAARAE")
(92227 . "BAMUM LETTER PHASE-A NKAARAE")
(92228 . "BAMUM LETTER PHASE-A UNKNOWN")
(92229 . "BAMUM LETTER PHASE-A NGGEN")
(92230 . "BAMUM LETTER PHASE-A MAESI")
(92231 . "BAMUM LETTER PHASE-A NJAM")
(92232 . "BAMUM LETTER PHASE-A MBANYI")
(92233 . "BAMUM LETTER PHASE-A NYET")
(92234 . "BAMUM LETTER PHASE-A TEUAEN")
(92235 . "BAMUM LETTER PHASE-A SOT")
(92236 . "BAMUM LETTER PHASE-A PAAM")
(92237 . "BAMUM LETTER PHASE-A NSHIEE")
(92238 . "BAMUM LETTER PHASE-A MAEM")
(92239 . "BAMUM LETTER PHASE-A NYI")
(92240 . "BAMUM LETTER PHASE-A KAQ")
(92241 . "BAMUM LETTER PHASE-A NSHA")
(92242 . "BAMUM LETTER PHASE-A VEE")
(92243 . "BAMUM LETTER PHASE-A LU")
(92244 . "BAMUM LETTER PHASE-A NEN")
(92245 . "BAMUM LETTER PHASE-A NAQ")
(92246 . "BAMUM LETTER PHASE-A MBAQ")
(92247 . "BAMUM LETTER PHASE-B NSHUET")
(92248 . "BAMUM LETTER PHASE-B TU MAEMGBIEE")
(92249 . "BAMUM LETTER PHASE-B SIEE")
(92250 . "BAMUM LETTER PHASE-B SET TU")
(92251 . "BAMUM LETTER PHASE-B LOM NTEUM")
(92252 . "BAMUM LETTER PHASE-B MBA MAELEE")
(92253 . "BAMUM LETTER PHASE-B KIEEM")
(92254 . "BAMUM LETTER PHASE-B YEURAE")
(92255 . "BAMUM LETTER PHASE-B MBAARAE")
(92256 . "BAMUM LETTER PHASE-B KAM")
(92257 . "BAMUM LETTER PHASE-B PEESHI")
(92258 . "BAMUM LETTER PHASE-B YAFU LEERAEWA")
(92259 . "BAMUM LETTER PHASE-B LAM NSHUT NYAM")
(92260 . "BAMUM LETTER PHASE-B NTIEE SHEUOQ")
(92261 . "BAMUM LETTER PHASE-B NDU NJAA")
(92262 . "BAMUM LETTER PHASE-B GHEUGHEUAEM")
(92263 . "BAMUM LETTER PHASE-B PIT")
(92264 . "BAMUM LETTER PHASE-B TU NSIEE")
(92265 . "BAMUM LETTER PHASE-B SHET NJAQ")
(92266 . "BAMUM LETTER PHASE-B SHEUAEQTU")
(92267 . "BAMUM LETTER PHASE-B MFON TEUAEQ")
(92268 . "BAMUM LETTER PHASE-B MBIT MBAAKET")
(92269 . "BAMUM LETTER PHASE-B NYI NTEUM")
(92270 . "BAMUM LETTER PHASE-B KEUPUQ")
(92271 . "BAMUM LETTER PHASE-B GHEUGHEN")
(92272 . "BAMUM LETTER PHASE-B KEUYEUX")
(92273 . "BAMUM LETTER PHASE-B LAANAE")
(92274 . "BAMUM LETTER PHASE-B PARUM")
(92275 . "BAMUM LETTER PHASE-B VEUM")
(92276 . "BAMUM LETTER PHASE-B NGKINDI MVOP")
(92277 . "BAMUM LETTER PHASE-B NGGEU MBU")
(92278 . "BAMUM LETTER PHASE-B WUAET")
(92279 . "BAMUM LETTER PHASE-B SAKEUAE")
(92280 . "BAMUM LETTER PHASE-B TAAM")
(92281 . "BAMUM LETTER PHASE-B MEUQ")
(92282 . "BAMUM LETTER PHASE-B NGGUOQ")
(92283 . "BAMUM LETTER PHASE-B NGGUOQ LARGE")
(92284 . "BAMUM LETTER PHASE-B MFIYAQ")
(92285 . "BAMUM LETTER PHASE-B SUE")
(92286 . "BAMUM LETTER PHASE-B MBEURI")
(92287 . "BAMUM LETTER PHASE-B MONTIEEN")
(92288 . "BAMUM LETTER PHASE-B NYAEMAE")
(92289 . "BAMUM LETTER PHASE-B PUNGAAM")
(92290 . "BAMUM LETTER PHASE-B MEUT NGGEET")
(92291 . "BAMUM LETTER PHASE-B FEUX")
(92292 . "BAMUM LETTER PHASE-B MBUOQ")
(92293 . "BAMUM LETTER PHASE-B FEE")
(92294 . "BAMUM LETTER PHASE-B KEUAEM")
(92295 . "BAMUM LETTER PHASE-B MA NJEUAENA")
(92296 . "BAMUM LETTER PHASE-B MA NJUQA")
(92297 . "BAMUM LETTER PHASE-B LET")
(92298 . "BAMUM LETTER PHASE-B NGGAAM")
(92299 . "BAMUM LETTER PHASE-B NSEN")
(92300 . "BAMUM LETTER PHASE-B MA")
(92301 . "BAMUM LETTER PHASE-B KIQ")
(92302 . "BAMUM LETTER PHASE-B NGOM")
(92303 . "BAMUM LETTER PHASE-C NGKUE MAEMBA")
(92304 . "BAMUM LETTER PHASE-C NZA")
(92305 . "BAMUM LETTER PHASE-C YUM")
(92306 . "BAMUM LETTER PHASE-C WANGKUOQ")
(92307 . "BAMUM LETTER PHASE-C NGGEN")
(92308 . "BAMUM LETTER PHASE-C NDEUAEREE")
(92309 . "BAMUM LETTER PHASE-C NGKAQ")
(92310 . "BAMUM LETTER PHASE-C GHARAE")
(92311 . "BAMUM LETTER PHASE-C MBEEKEET")
(92312 . "BAMUM LETTER PHASE-C GBAYI")
(92313 . "BAMUM LETTER PHASE-C NYIR MKPARAQ MEUN")
(92314 . "BAMUM LETTER PHASE-C NTU MBIT")
(92315 . "BAMUM LETTER PHASE-C MBEUM")
(92316 . "BAMUM LETTER PHASE-C PIRIEEN")
(92317 . "BAMUM LETTER PHASE-C NDOMBU")
(92318 . "BAMUM LETTER PHASE-C MBAA CABBAGE-TREE")
(92319 . "BAMUM LETTER PHASE-C KEUSHEUAEP")
(92320 . "BAMUM LETTER PHASE-C GHAP")
(92321 . "BAMUM LETTER PHASE-C KEUKAQ")
(92322 . "BAMUM LETTER PHASE-C YU MUOMAE")
(92323 . "BAMUM LETTER PHASE-C NZEUM")
(92324 . "BAMUM LETTER PHASE-C MBUE")
(92325 . "BAMUM LETTER PHASE-C NSEUAEN")
(92326 . "BAMUM LETTER PHASE-C MBIT")
(92327 . "BAMUM LETTER PHASE-C YEUQ")
(92328 . "BAMUM LETTER PHASE-C KPARAQ")
(92329 . "BAMUM LETTER PHASE-C KAA")
(92330 . "BAMUM LETTER PHASE-C SEUX")
(92331 . "BAMUM LETTER PHASE-C NDIDA")
(92332 . "BAMUM LETTER PHASE-C TAASHAE")
(92333 . "BAMUM LETTER PHASE-C NJUEQ")
(92334 . "BAMUM LETTER PHASE-C TITA YUE")
(92335 . "BAMUM LETTER PHASE-C SUAET")
(92336 . "BAMUM LETTER PHASE-C NGGUAEN NYAM")
(92337 . "BAMUM LETTER PHASE-C VEUX")
(92338 . "BAMUM LETTER PHASE-C NANSANAQ")
(92339 . "BAMUM LETTER PHASE-C MA KEUAERI")
(92340 . "BAMUM LETTER PHASE-C NTAA")
(92341 . "BAMUM LETTER PHASE-C NGGUON")
(92342 . "BAMUM LETTER PHASE-C LAP")
(92343 . "BAMUM LETTER PHASE-C MBIRIEEN")
(92344 . "BAMUM LETTER PHASE-C MGBASAQ")
(92345 . "BAMUM LETTER PHASE-C NTEUNGBA")
(92346 . "BAMUM LETTER PHASE-C TEUTEUX")
(92347 . "BAMUM LETTER PHASE-C NGGUM")
(92348 . "BAMUM LETTER PHASE-C FUE")
(92349 . "BAMUM LETTER PHASE-C NDEUT")
(92350 . "BAMUM LETTER PHASE-C NSA")
(92351 . "BAMUM LETTER PHASE-C NSHAQ")
(92352 . "BAMUM LETTER PHASE-C BUNG")
(92353 . "BAMUM LETTER PHASE-C VEUAEPEN")
(92354 . "BAMUM LETTER PHASE-C MBERAE")
(92355 . "BAMUM LETTER PHASE-C RU")
(92356 . "BAMUM LETTER PHASE-C NJAEM")
(92357 . "BAMUM LETTER PHASE-C LAM")
(92358 . "BAMUM LETTER PHASE-C TITUAEP")
(92359 . "BAMUM LETTER PHASE-C NSUOT NGOM")
(92360 . "BAMUM LETTER PHASE-C NJEEEE")
(92361 . "BAMUM LETTER PHASE-C KET")
(92362 . "BAMUM LETTER PHASE-C NGGU")
(92363 . "BAMUM LETTER PHASE-C MAESI")
(92364 . "BAMUM LETTER PHASE-C MBUAEM")
(92365 . "BAMUM LETTER PHASE-C LU")
(92366 . "BAMUM LETTER PHASE-C KUT")
(92367 . "BAMUM LETTER PHASE-C NJAM")
(92368 . "BAMUM LETTER PHASE-C NGOM")
(92369 . "BAMUM LETTER PHASE-C WUP")
(92370 . "BAMUM LETTER PHASE-C NGGUEET")
(92371 . "BAMUM LETTER PHASE-C NSOM")
(92372 . "BAMUM LETTER PHASE-C NTEN")
(92373 . "BAMUM LETTER PHASE-C KUOP NKAARAE")
(92374 . "BAMUM LETTER PHASE-C NSUN")
(92375 . "BAMUM LETTER PHASE-C NDAM")
(92376 . "BAMUM LETTER PHASE-C MA NSIEE")
(92377 . "BAMUM LETTER PHASE-C YAA")
(92378 . "BAMUM LETTER PHASE-C NDAP")
(92379 . "BAMUM LETTER PHASE-C SHUEQ")
(92380 . "BAMUM LETTER PHASE-C SETFON")
(92381 . "BAMUM LETTER PHASE-C MBI")
(92382 . "BAMUM LETTER PHASE-C MAEMBA")
(92383 . "BAMUM LETTER PHASE-C MBANYI")
(92384 . "BAMUM LETTER PHASE-C KEUSEUX")
(92385 . "BAMUM LETTER PHASE-C MBEUX")
(92386 . "BAMUM LETTER PHASE-C KEUM")
(92387 . "BAMUM LETTER PHASE-C MBAA PICKET")
(92388 . "BAMUM LETTER PHASE-C YUWOQ")
(92389 . "BAMUM LETTER PHASE-C NJEUX")
(92390 . "BAMUM LETTER PHASE-C MIEE")
(92391 . "BAMUM LETTER PHASE-C MUAE")
(92392 . "BAMUM LETTER PHASE-C SHIQ")
(92393 . "BAMUM LETTER PHASE-C KEN LAW")
(92394 . "BAMUM LETTER PHASE-C KEN FATIGUE")
(92395 . "BAMUM LETTER PHASE-C NGAQ")
(92396 . "BAMUM LETTER PHASE-C NAQ")
(92397 . "BAMUM LETTER PHASE-C LIQ")
(92398 . "BAMUM LETTER PHASE-C PIN")
(92399 . "BAMUM LETTER PHASE-C PEN")
(92400 . "BAMUM LETTER PHASE-C TET")
(92401 . "BAMUM LETTER PHASE-D MBUO")
(92402 . "BAMUM LETTER PHASE-D WAP")
(92403 . "BAMUM LETTER PHASE-D NJI")
(92404 . "BAMUM LETTER PHASE-D MFON")
(92405 . "BAMUM LETTER PHASE-D NJIEE")
(92406 . "BAMUM LETTER PHASE-D LIEE")
(92407 . "BAMUM LETTER PHASE-D NJEUT")
(92408 . "BAMUM LETTER PHASE-D NSHEE")
(92409 . "BAMUM LETTER PHASE-D NGGAAMAE")
(92410 . "BAMUM LETTER PHASE-D NYAM")
(92411 . "BAMUM LETTER PHASE-D WUAEN")
(92412 . "BAMUM LETTER PHASE-D NGKUN")
(92413 . "BAMUM LETTER PHASE-D SHEE")
(92414 . "BAMUM LETTER PHASE-D NGKAP")
(92415 . "BAMUM LETTER PHASE-D KEUAETMEUN")
(92416 . "BAMUM LETTER PHASE-D TEUT")
(92417 . "BAMUM LETTER PHASE-D SHEUAE")
(92418 . "BAMUM LETTER PHASE-D NJAP")
(92419 . "BAMUM LETTER PHASE-D SUE")
(92420 . "BAMUM LETTER PHASE-D KET")
(92421 . "BAMUM LETTER PHASE-D YAEMMAE")
(92422 . "BAMUM LETTER PHASE-D KUOM")
(92423 . "BAMUM LETTER PHASE-D SAP")
(92424 . "BAMUM LETTER PHASE-D MFEUT")
(92425 . "BAMUM LETTER PHASE-D NDEUX")
(92426 . "BAMUM LETTER PHASE-D MALEERI")
(92427 . "BAMUM LETTER PHASE-D MEUT")
(92428 . "BAMUM LETTER PHASE-D SEUAEQ")
(92429 . "BAMUM LETTER PHASE-D YEN")
(92430 . "BAMUM LETTER PHASE-D NJEUAEM")
(92431 . "BAMUM LETTER PHASE-D KEUOT MBUAE")
(92432 . "BAMUM LETTER PHASE-D NGKEURI")
(92433 . "BAMUM LETTER PHASE-D TU")
(92434 . "BAMUM LETTER PHASE-D GHAA")
(92435 . "BAMUM LETTER PHASE-D NGKYEE")
(92436 . "BAMUM LETTER PHASE-D FEUFEUAET")
(92437 . "BAMUM LETTER PHASE-D NDEE")
(92438 . "BAMUM LETTER PHASE-D MGBOFUM")
(92439 . "BAMUM LETTER PHASE-D LEUAEP")
(92440 . "BAMUM LETTER PHASE-D NDON")
(92441 . "BAMUM LETTER PHASE-D MONI")
(92442 . "BAMUM LETTER PHASE-D MGBEUN")
(92443 . "BAMUM LETTER PHASE-D PUUT")
(92444 . "BAMUM LETTER PHASE-D MGBIEE")
(92445 . "BAMUM LETTER PHASE-D MFO")
(92446 . "BAMUM LETTER PHASE-D LUM")
(92447 . "BAMUM LETTER PHASE-D NSIEEP")
(92448 . "BAMUM LETTER PHASE-D MBAA")
(92449 . "BAMUM LETTER PHASE-D KWAET")
(92450 . "BAMUM LETTER PHASE-D NYET")
(92451 . "BAMUM LETTER PHASE-D TEUAEN")
(92452 . "BAMUM LETTER PHASE-D SOT")
(92453 . "BAMUM LETTER PHASE-D YUWOQ")
(92454 . "BAMUM LETTER PHASE-D KEUM")
(92455 . "BAMUM LETTER PHASE-D RAEM")
(92456 . "BAMUM LETTER PHASE-D TEEEE")
(92457 . "BAMUM LETTER PHASE-D NGKEUAEQ")
(92458 . "BAMUM LETTER PHASE-D MFEUAE")
(92459 . "BAMUM LETTER PHASE-D NSIEET")
(92460 . "BAMUM LETTER PHASE-D KEUP")
(92461 . "BAMUM LETTER PHASE-D PIP")
(92462 . "BAMUM LETTER PHASE-D PEUTAE")
(92463 . "BAMUM LETTER PHASE-D NYUE")
(92464 . "BAMUM LETTER PHASE-D LET")
(92465 . "BAMUM LETTER PHASE-D NGGAAM")
(92466 . "BAMUM LETTER PHASE-D MFIEE")
(92467 . "BAMUM LETTER PHASE-D NGGWAEN")
(92468 . "BAMUM LETTER PHASE-D YUOM")
(92469 . "BAMUM LETTER PHASE-D PAP")
(92470 . "BAMUM LETTER PHASE-D YUOP")
(92471 . "BAMUM LETTER PHASE-D NDAM")
(92472 . "BAMUM LETTER PHASE-D NTEUM")
(92473 . "BAMUM LETTER PHASE-D SUAE")
(92474 . "BAMUM LETTER PHASE-D KUN")
(92475 . "BAMUM LETTER PHASE-D NGGEUX")
(92476 . "BAMUM LETTER PHASE-D NGKIEE")
(92477 . "BAMUM LETTER PHASE-D TUOT")
(92478 . "BAMUM LETTER PHASE-D MEUN")
(92479 . "BAMUM LETTER PHASE-D KUQ")
(92480 . "BAMUM LETTER PHASE-D NSUM")
(92481 . "BAMUM LETTER PHASE-D TEUN")
(92482 . "BAMUM LETTER PHASE-D MAENJET")
(92483 . "BAMUM LETTER PHASE-D NGGAP")
(92484 . "BAMUM LETTER PHASE-D LEUM")
(92485 . "BAMUM LETTER PHASE-D NGGUOM")
(92486 . "BAMUM LETTER PHASE-D NSHUT")
(92487 . "BAMUM LETTER PHASE-D NJUEQ")
(92488 . "BAMUM LETTER PHASE-D GHEUAE")
(92489 . "BAMUM LETTER PHASE-D KU")
(92490 . "BAMUM LETTER PHASE-D REN OLD")
(92491 . "BAMUM LETTER PHASE-D TAE")
(92492 . "BAMUM LETTER PHASE-D TOQ")
(92493 . "BAMUM LETTER PHASE-D NYI")
(92494 . "BAMUM LETTER PHASE-D RII")
(92495 . "BAMUM LETTER PHASE-D LEEEE")
(92496 . "BAMUM LETTER PHASE-D MEEEE")
(92497 . "BAMUM LETTER PHASE-D M")
(92498 . "BAMUM LETTER PHASE-D SUU")
(92499 . "BAMUM LETTER PHASE-D MU")
(92500 . "BAMUM LETTER PHASE-D SHII")
(92501 . "BAMUM LETTER PHASE-D SHEUX")
(92502 . "BAMUM LETTER PHASE-D KYEE")
(92503 . "BAMUM LETTER PHASE-D NU")
(92504 . "BAMUM LETTER PHASE-D SHU")
(92505 . "BAMUM LETTER PHASE-D NTEE")
(92506 . "BAMUM LETTER PHASE-D PEE")
(92507 . "BAMUM LETTER PHASE-D NI")
(92508 . "BAMUM LETTER PHASE-D SHOQ")
(92509 . "BAMUM LETTER PHASE-D PUQ")
(92510 . "BAMUM LETTER PHASE-D MVOP")
(92511 . "BAMUM LETTER PHASE-D LOQ")
(92512 . "BAMUM LETTER PHASE-D REN MUCH")
(92513 . "BAMUM LETTER PHASE-D TI")
(92514 . "BAMUM LETTER PHASE-D NTUU")
(92515 . "BAMUM LETTER PHASE-D MBAA SEVEN")
(92516 . "BAMUM LETTER PHASE-D SAQ")
(92517 . "BAMUM LETTER PHASE-D FAA")
(92518 . "BAMUM LETTER PHASE-E NDAP")
(92519 . "BAMUM LETTER PHASE-E TOON")
(92520 . "BAMUM LETTER PHASE-E MBEUM")
(92521 . "BAMUM LETTER PHASE-E LAP")
(92522 . "BAMUM LETTER PHASE-E VOM")
(92523 . "BAMUM LETTER PHASE-E LOON")
(92524 . "BAMUM LETTER PHASE-E PAA")
(92525 . "BAMUM LETTER PHASE-E SOM")
(92526 . "BAMUM LETTER PHASE-E RAQ")
(92527 . "BAMUM LETTER PHASE-E NSHUOP")
(92528 . "BAMUM LETTER PHASE-E NDUN")
(92529 . "BAMUM LETTER PHASE-E PUAE")
(92530 . "BAMUM LETTER PHASE-E TAM")
(92531 . "BAMUM LETTER PHASE-E NGKA")
(92532 . "BAMUM LETTER PHASE-E KPEUX")
(92533 . "BAMUM LETTER PHASE-E WUO")
(92534 . "BAMUM LETTER PHASE-E SEE")
(92535 . "BAMUM LETTER PHASE-E NGGEUAET")
(92536 . "BAMUM LETTER PHASE-E PAAM")
(92537 . "BAMUM LETTER PHASE-E TOO")
(92538 . "BAMUM LETTER PHASE-E KUOP")
(92539 . "BAMUM LETTER PHASE-E LOM")
(92540 . "BAMUM LETTER PHASE-E NSHIEE")
(92541 . "BAMUM LETTER PHASE-E NGOP")
(92542 . "BAMUM LETTER PHASE-E MAEM")
(92543 . "BAMUM LETTER PHASE-E NGKEUX")
(92544 . "BAMUM LETTER PHASE-E NGOQ")
(92545 . "BAMUM LETTER PHASE-E NSHUE")
(92546 . "BAMUM LETTER PHASE-E RIMGBA")
(92547 . "BAMUM LETTER PHASE-E NJEUX")
(92548 . "BAMUM LETTER PHASE-E PEEM")
(92549 . "BAMUM LETTER PHASE-E SAA")
(92550 . "BAMUM LETTER PHASE-E NGGURAE")
(92551 . "BAMUM LETTER PHASE-E MGBA")
(92552 . "BAMUM LETTER PHASE-E GHEUX")
(92553 . "BAMUM LETTER PHASE-E NGKEUAEM")
(92554 . "BAMUM LETTER PHASE-E NJAEMLI")
(92555 . "BAMUM LETTER PHASE-E MAP")
(92556 . "BAMUM LETTER PHASE-E LOOT")
(92557 . "BAMUM LETTER PHASE-E NGGEEEE")
(92558 . "BAMUM LETTER PHASE-E NDIQ")
(92559 . "BAMUM LETTER PHASE-E TAEN NTEUM")
(92560 . "BAMUM LETTER PHASE-E SET")
(92561 . "BAMUM LETTER PHASE-E PUM")
(92562 . "BAMUM LETTER PHASE-E NDAA SOFTNESS")
(92563 . "BAMUM LETTER PHASE-E NGGUAESHAE NYAM")
(92564 . "BAMUM LETTER PHASE-E YIEE")
(92565 . "BAMUM LETTER PHASE-E GHEUN")
(92566 . "BAMUM LETTER PHASE-E TUAE")
(92567 . "BAMUM LETTER PHASE-E YEUAE")
(92568 . "BAMUM LETTER PHASE-E PO")
(92569 . "BAMUM LETTER PHASE-E TUMAE")
(92570 . "BAMUM LETTER PHASE-E KEUAE")
(92571 . "BAMUM LETTER PHASE-E SUAEN")
(92572 . "BAMUM LETTER PHASE-E TEUAEQ")
(92573 . "BAMUM LETTER PHASE-E VEUAE")
(92574 . "BAMUM LETTER PHASE-E WEUX")
(92575 . "BAMUM LETTER PHASE-E LAAM")
(92576 . "BAMUM LETTER PHASE-E PU")
(92577 . "BAMUM LETTER PHASE-E TAAQ")
(92578 . "BAMUM LETTER PHASE-E GHAAMAE")
(92579 . "BAMUM LETTER PHASE-E NGEUREUT")
(92580 . "BAMUM LETTER PHASE-E SHEUAEQ")
(92581 . "BAMUM LETTER PHASE-E MGBEN")
(92582 . "BAMUM LETTER PHASE-E MBEE")
(92583 . "BAMUM LETTER PHASE-E NZAQ")
(92584 . "BAMUM LETTER PHASE-E NKOM")
(92585 . "BAMUM LETTER PHASE-E GBET")
(92586 . "BAMUM LETTER PHASE-E TUM")
(92587 . "BAMUM LETTER PHASE-E KUET")
(92588 . "BAMUM LETTER PHASE-E YAP")
(92589 . "BAMUM LETTER PHASE-E NYI CLEAVER")
(92590 . "BAMUM LETTER PHASE-E YIT")
(92591 . "BAMUM LETTER PHASE-E MFEUQ")
(92592 . "BAMUM LETTER PHASE-E NDIAQ")
(92593 . "BAMUM LETTER PHASE-E PIEEQ")
(92594 . "BAMUM LETTER PHASE-E YUEQ")
(92595 . "BAMUM LETTER PHASE-E LEUAEM")
(92596 . "BAMUM LETTER PHASE-E FUE")
(92597 . "BAMUM LETTER PHASE-E GBEUX")
(92598 . "BAMUM LETTER PHASE-E NGKUP")
(92599 . "BAMUM LETTER PHASE-E KET")
(92600 . "BAMUM LETTER PHASE-E MAE")
(92601 . "BAMUM LETTER PHASE-E NGKAAMI")
(92602 . "BAMUM LETTER PHASE-E GHET")
(92603 . "BAMUM LETTER PHASE-E FA")
(92604 . "BAMUM LETTER PHASE-E NTUM")
(92605 . "BAMUM LETTER PHASE-E PEUT")
(92606 . "BAMUM LETTER PHASE-E YEUM")
(92607 . "BAMUM LETTER PHASE-E NGGEUAE")
(92608 . "BAMUM LETTER PHASE-E NYI BETWEEN")
(92609 . "BAMUM LETTER PHASE-E NZUQ")
(92610 . "BAMUM LETTER PHASE-E POON")
(92611 . "BAMUM LETTER PHASE-E MIEE")
(92612 . "BAMUM LETTER PHASE-E FUET")
(92613 . "BAMUM LETTER PHASE-E NAE")
(92614 . "BAMUM LETTER PHASE-E MUAE")
(92615 . "BAMUM LETTER PHASE-E GHEUAE")
(92616 . "BAMUM LETTER PHASE-E FU I")
(92617 . "BAMUM LETTER PHASE-E MVI")
(92618 . "BAMUM LETTER PHASE-E PUAQ")
(92619 . "BAMUM LETTER PHASE-E NGKUM")
(92620 . "BAMUM LETTER PHASE-E KUT")
(92621 . "BAMUM LETTER PHASE-E PIET")
(92622 . "BAMUM LETTER PHASE-E NTAP")
(92623 . "BAMUM LETTER PHASE-E YEUAET")
(92624 . "BAMUM LETTER PHASE-E NGGUP")
(92625 . "BAMUM LETTER PHASE-E PA PEOPLE")
(92626 . "BAMUM LETTER PHASE-E FU CALL")
(92627 . "BAMUM LETTER PHASE-E FOM")
(92628 . "BAMUM LETTER PHASE-E NJEE")
(92629 . "BAMUM LETTER PHASE-E A")
(92630 . "BAMUM LETTER PHASE-E TOQ")
(92631 . "BAMUM LETTER PHASE-E O")
(92632 . "BAMUM LETTER PHASE-E I")
(92633 . "BAMUM LETTER PHASE-E LAQ")
(92634 . "BAMUM LETTER PHASE-E PA PLURAL")
(92635 . "BAMUM LETTER PHASE-E TAA")
(92636 . "BAMUM LETTER PHASE-E TAQ")
(92637 . "BAMUM LETTER PHASE-E NDAA MY HOUSE")
(92638 . "BAMUM LETTER PHASE-E SHIQ")
(92639 . "BAMUM LETTER PHASE-E YEUX")
(92640 . "BAMUM LETTER PHASE-E NGUAE")
(92641 . "BAMUM LETTER PHASE-E YUAEN")
(92642 . "BAMUM LETTER PHASE-E YOQ SWIMMING")
(92643 . "BAMUM LETTER PHASE-E YOQ COVER")
(92644 . "BAMUM LETTER PHASE-E YUQ")
(92645 . "BAMUM LETTER PHASE-E YUN")
(92646 . "BAMUM LETTER PHASE-E KEUX")
(92647 . "BAMUM LETTER PHASE-E PEUX")
(92648 . "BAMUM LETTER PHASE-E NJEE EPOCH")
(92649 . "BAMUM LETTER PHASE-E PUE")
(92650 . "BAMUM LETTER PHASE-E WUE")
(92651 . "BAMUM LETTER PHASE-E FEE")
(92652 . "BAMUM LETTER PHASE-E VEE")
(92653 . "BAMUM LETTER PHASE-E LU")
(92654 . "BAMUM LETTER PHASE-E MI")
(92655 . "BAMUM LETTER PHASE-E REUX")
(92656 . "BAMUM LETTER PHASE-E RAE")
(92657 . "BAMUM LETTER PHASE-E NGUAET")
(92658 . "BAMUM LETTER PHASE-E NGA")
(92659 . "BAMUM LETTER PHASE-E SHO")
(92660 . "BAMUM LETTER PHASE-E SHOQ")
(92661 . "BAMUM LETTER PHASE-E FU REMEDY")
(92662 . "BAMUM LETTER PHASE-E NA")
(92663 . "BAMUM LETTER PHASE-E PI")
(92664 . "BAMUM LETTER PHASE-E LOQ")
(92665 . "BAMUM LETTER PHASE-E KO")
(92666 . "BAMUM LETTER PHASE-E MEN")
(92667 . "BAMUM LETTER PHASE-E MA")
(92668 . "BAMUM LETTER PHASE-E MAQ")
(92669 . "BAMUM LETTER PHASE-E TEU")
(92670 . "BAMUM LETTER PHASE-E KI")
(92671 . "BAMUM LETTER PHASE-E MON")
(92672 . "BAMUM LETTER PHASE-E TEN")
(92673 . "BAMUM LETTER PHASE-E FAQ")
(92674 . "BAMUM LETTER PHASE-E GHOM")
(92675 . "BAMUM LETTER PHASE-F KA")
(92676 . "BAMUM LETTER PHASE-F U")
(92677 . "BAMUM LETTER PHASE-F KU")
(92678 . "BAMUM LETTER PHASE-F EE")
(92679 . "BAMUM LETTER PHASE-F REE")
(92680 . "BAMUM LETTER PHASE-F TAE")
(92681 . "BAMUM LETTER PHASE-F NYI")
(92682 . "BAMUM LETTER PHASE-F LA")
(92683 . "BAMUM LETTER PHASE-F RII")
(92684 . "BAMUM LETTER PHASE-F RIEE")
(92685 . "BAMUM LETTER PHASE-F MEEEE")
(92686 . "BAMUM LETTER PHASE-F TAA")
(92687 . "BAMUM LETTER PHASE-F NDAA")
(92688 . "BAMUM LETTER PHASE-F NJAEM")
(92689 . "BAMUM LETTER PHASE-F M")
(92690 . "BAMUM LETTER PHASE-F SUU")
(92691 . "BAMUM LETTER PHASE-F SHII")
(92692 . "BAMUM LETTER PHASE-F SI")
(92693 . "BAMUM LETTER PHASE-F SEUX")
(92694 . "BAMUM LETTER PHASE-F KYEE")
(92695 . "BAMUM LETTER PHASE-F KET")
(92696 . "BAMUM LETTER PHASE-F NUAE")
(92697 . "BAMUM LETTER PHASE-F NU")
(92698 . "BAMUM LETTER PHASE-F NJUAE")
(92699 . "BAMUM LETTER PHASE-F YOQ")
(92700 . "BAMUM LETTER PHASE-F SHU")
(92701 . "BAMUM LETTER PHASE-F YA")
(92702 . "BAMUM LETTER PHASE-F NSHA")
(92703 . "BAMUM LETTER PHASE-F PEUX")
(92704 . "BAMUM LETTER PHASE-F NTEE")
(92705 . "BAMUM LETTER PHASE-F WUE")
(92706 . "BAMUM LETTER PHASE-F PEE")
(92707 . "BAMUM LETTER PHASE-F RU")
(92708 . "BAMUM LETTER PHASE-F NI")
(92709 . "BAMUM LETTER PHASE-F REUX")
(92710 . "BAMUM LETTER PHASE-F KEN")
(92711 . "BAMUM LETTER PHASE-F NGKWAEN")
(92712 . "BAMUM LETTER PHASE-F NGGA")
(92713 . "BAMUM LETTER PHASE-F SHO")
(92714 . "BAMUM LETTER PHASE-F PUAE")
(92715 . "BAMUM LETTER PHASE-F FOM")
(92716 . "BAMUM LETTER PHASE-F WA")
(92717 . "BAMUM LETTER PHASE-F LI")
(92718 . "BAMUM LETTER PHASE-F LOQ")
(92719 . "BAMUM LETTER PHASE-F KO")
(92720 . "BAMUM LETTER PHASE-F MBEN")
(92721 . "BAMUM LETTER PHASE-F REN")
(92722 . "BAMUM LETTER PHASE-F MA")
(92723 . "BAMUM LETTER PHASE-F MO")
(92724 . "BAMUM LETTER PHASE-F MBAA")
(92725 . "BAMUM LETTER PHASE-F TET")
(92726 . "BAMUM LETTER PHASE-F KPA")
(92727 . "BAMUM LETTER PHASE-F SAMBA")
(92728 . "BAMUM LETTER PHASE-F VUEQ")
((92729 . 92736) . #f)
(92736 . "MRO LETTER TA")
(92737 . "MRO LETTER NGI")
(92738 . "MRO LETTER YO")
(92739 . "MRO LETTER MIM")
(92740 . "MRO LETTER BA")
(92741 . "MRO LETTER DA")
(92742 . "MRO LETTER A")
(92743 . "MRO LETTER PHI")
(92744 . "MRO LETTER KHAI")
(92745 . "MRO LETTER HAO")
(92746 . "MRO LETTER DAI")
(92747 . "MRO LETTER CHU")
(92748 . "MRO LETTER KEAAE")
(92749 . "MRO LETTER OL")
(92750 . "MRO LETTER MAEM")
(92751 . "MRO LETTER NIN")
(92752 . "MRO LETTER PA")
(92753 . "MRO LETTER OO")
(92754 . "MRO LETTER O")
(92755 . "MRO LETTER RO")
(92756 . "MRO LETTER SHI")
(92757 . "MRO LETTER THEA")
(92758 . "MRO LETTER EA")
(92759 . "MRO LETTER WA")
(92760 . "MRO LETTER E")
(92761 . "MRO LETTER KO")
(92762 . "MRO LETTER LAN")
(92763 . "MRO LETTER LA")
(92764 . "MRO LETTER HAI")
(92765 . "MRO LETTER RI")
(92766 . "MRO LETTER TEK")
(92767 . #f)
(92768 . "MRO DIGIT ZERO")
(92769 . "MRO DIGIT ONE")
(92770 . "MRO DIGIT TWO")
(92771 . "MRO DIGIT THREE")
(92772 . "MRO DIGIT FOUR")
(92773 . "MRO DIGIT FIVE")
(92774 . "MRO DIGIT SIX")
(92775 . "MRO DIGIT SEVEN")
(92776 . "MRO DIGIT EIGHT")
(92777 . "MRO DIGIT NINE")
((92778 . 92782) . #f)
(92782 . "MRO DANDA")
(92783 . "MRO DOUBLE DANDA")
((92784 . 92880) . #f)
(92880 . "BASSA VAH LETTER ENNI")
(92881 . "BASSA VAH LETTER KA")
(92882 . "BASSA VAH LETTER SE")
(92883 . "BASSA VAH LETTER FA")
(92884 . "BASSA VAH LETTER MBE")
(92885 . "BASSA VAH LETTER YIE")
(92886 . "BASSA VAH LETTER GAH")
(92887 . "BASSA VAH LETTER DHII")
(92888 . "BASSA VAH LETTER KPAH")
(92889 . "BASSA VAH LETTER JO")
(92890 . "BASSA VAH LETTER HWAH")
(92891 . "BASSA VAH LETTER WA")
(92892 . "BASSA VAH LETTER ZO")
(92893 . "BASSA VAH LETTER GBU")
(92894 . "BASSA VAH LETTER DO")
(92895 . "BASSA VAH LETTER CE")
(92896 . "BASSA VAH LETTER UWU")
(92897 . "BASSA VAH LETTER TO")
(92898 . "BASSA VAH LETTER BA")
(92899 . "BASSA VAH LETTER VU")
(92900 . "BASSA VAH LETTER YEIN")
(92901 . "BASSA VAH LETTER PA")
(92902 . "BASSA VAH LETTER WADDA")
(92903 . "BASSA VAH LETTER A")
(92904 . "BASSA VAH LETTER O")
(92905 . "BASSA VAH LETTER OO")
(92906 . "BASSA VAH LETTER U")
(92907 . "BASSA VAH LETTER EE")
(92908 . "BASSA VAH LETTER E")
(92909 . "BASSA VAH LETTER I")
((92910 . 92912) . #f)
(92912 . "BASSA VAH COMBINING HIGH TONE")
(92913 . "BASSA VAH COMBINING LOW TONE")
(92914 . "BASSA VAH COMBINING MID TONE")
(92915 . "BASSA VAH COMBINING LOW-MID TONE")
(92916 . "BASSA VAH COMBINING HIGH-LOW TONE")
(92917 . "BASSA VAH FULL STOP")
((92918 . 92928) . #f)
(92928 . "PAHAWH HMONG VOWEL KEEB")
(92929 . "PAHAWH HMONG VOWEL KEEV")
(92930 . "PAHAWH HMONG VOWEL KIB")
(92931 . "PAHAWH HMONG VOWEL KIV")
(92932 . "PAHAWH HMONG VOWEL KAUB")
(92933 . "PAHAWH HMONG VOWEL KAUV")
(92934 . "PAHAWH HMONG VOWEL KUB")
(92935 . "PAHAWH HMONG VOWEL KUV")
(92936 . "PAHAWH HMONG VOWEL KEB")
(92937 . "PAHAWH HMONG VOWEL KEV")
(92938 . "PAHAWH HMONG VOWEL KAIB")
(92939 . "PAHAWH HMONG VOWEL KAIV")
(92940 . "PAHAWH HMONG VOWEL KOOB")
(92941 . "PAHAWH HMONG VOWEL KOOV")
(92942 . "PAHAWH HMONG VOWEL KAWB")
(92943 . "PAHAWH HMONG VOWEL KAWV")
(92944 . "PAHAWH HMONG VOWEL KUAB")
(92945 . "PAHAWH HMONG VOWEL KUAV")
(92946 . "PAHAWH HMONG VOWEL KOB")
(92947 . "PAHAWH HMONG VOWEL KOV")
(92948 . "PAHAWH HMONG VOWEL KIAB")
(92949 . "PAHAWH HMONG VOWEL KIAV")
(92950 . "PAHAWH HMONG VOWEL KAB")
(92951 . "PAHAWH HMONG VOWEL KAV")
(92952 . "PAHAWH HMONG VOWEL KWB")
(92953 . "PAHAWH HMONG VOWEL KWV")
(92954 . "PAHAWH HMONG VOWEL KAAB")
(92955 . "PAHAWH HMONG VOWEL KAAV")
(92956 . "PAHAWH HMONG CONSONANT VAU")
(92957 . "PAHAWH HMONG CONSONANT NTSAU")
(92958 . "PAHAWH HMONG CONSONANT LAU")
(92959 . "PAHAWH HMONG CONSONANT HAU")
(92960 . "PAHAWH HMONG CONSONANT NLAU")
(92961 . "PAHAWH HMONG CONSONANT RAU")
(92962 . "PAHAWH HMONG CONSONANT NKAU")
(92963 . "PAHAWH HMONG CONSONANT QHAU")
(92964 . "PAHAWH HMONG CONSONANT YAU")
(92965 . "PAHAWH HMONG CONSONANT HLAU")
(92966 . "PAHAWH HMONG CONSONANT MAU")
(92967 . "PAHAWH HMONG CONSONANT CHAU")
(92968 . "PAHAWH HMONG CONSONANT NCHAU")
(92969 . "PAHAWH HMONG CONSONANT HNAU")
(92970 . "PAHAWH HMONG CONSONANT PLHAU")
(92971 . "PAHAWH HMONG CONSONANT NTHAU")
(92972 . "PAHAWH HMONG CONSONANT NAU")
(92973 . "PAHAWH HMONG CONSONANT AU")
(92974 . "PAHAWH HMONG CONSONANT XAU")
(92975 . "PAHAWH HMONG CONSONANT CAU")
(92976 . "PAHAWH HMONG MARK CIM TUB")
(92977 . "PAHAWH HMONG MARK CIM SO")
(92978 . "PAHAWH HMONG MARK CIM KES")
(92979 . "PAHAWH HMONG MARK CIM KHAV")
(92980 . "PAHAWH HMONG MARK CIM SUAM")
(92981 . "PAHAWH HMONG MARK CIM HOM")
(92982 . "PAHAWH HMONG MARK CIM TAUM")
(92983 . "PAHAWH HMONG SIGN VOS THOM")
(92984 . "PAHAWH HMONG SIGN VOS TSHAB CEEB")
(92985 . "PAHAWH HMONG SIGN CIM CHEEM")
(92986 . "PAHAWH HMONG SIGN VOS THIAB")
(92987 . "PAHAWH HMONG SIGN VOS FEEM")
(92988 . "PAHAWH HMONG SIGN XYEEM NTXIV")
(92989 . "PAHAWH HMONG SIGN XYEEM RHO")
(92990 . "PAHAWH HMONG SIGN XYEEM TOV")
(92991 . "PAHAWH HMONG SIGN XYEEM FAIB")
(92992 . "PAHAWH HMONG SIGN VOS SEEV")
(92993 . "PAHAWH HMONG SIGN MEEJ SUAB")
(92994 . "PAHAWH HMONG SIGN VOS NRUA")
(92995 . "PAHAWH HMONG SIGN IB YAM")
(92996 . "PAHAWH HMONG SIGN XAUS")
(92997 . "PAHAWH HMONG SIGN CIM TSOV ROG")
((92998 . 93008) . #f)
(93008 . "PAHAWH HMONG DIGIT ZERO")
(93009 . "PAHAWH HMONG DIGIT ONE")
(93010 . "PAHAWH HMONG DIGIT TWO")
(93011 . "PAHAWH HMONG DIGIT THREE")
(93012 . "PAHAWH HMONG DIGIT FOUR")
(93013 . "PAHAWH HMONG DIGIT FIVE")
(93014 . "PAHAWH HMONG DIGIT SIX")
(93015 . "PAHAWH HMONG DIGIT SEVEN")
(93016 . "PAHAWH HMONG DIGIT EIGHT")
(93017 . "PAHAWH HMONG DIGIT NINE")
(93018 . #f)
(93019 . "PAHAWH HMONG NUMBER TENS")
(93020 . "PAHAWH HMONG NUMBER HUNDREDS")
(93021 . "PAHAWH HMONG NUMBER TEN THOUSANDS")
(93022 . "PAHAWH HMONG NUMBER MILLIONS")
(93023 . "PAHAWH HMONG NUMBER HUNDRED MILLIONS")
(93024 . "PAHAWH HMONG NUMBER TEN BILLIONS")
(93025 . "PAHAWH HMONG NUMBER TRILLIONS")
(93026 . #f)
(93027 . "PAHAWH HMONG SIGN VOS LUB")
(93028 . "PAHAWH HMONG SIGN XYOO")
(93029 . "PAHAWH HMONG SIGN HLI")
(93030 . "PAHAWH HMONG SIGN THIRD-STAGE HLI")
(93031 . "PAHAWH HMONG SIGN ZWJ THAJ")
(93032 . "PAHAWH HMONG SIGN HNUB")
(93033 . "PAHAWH HMONG SIGN NQIG")
(93034 . "PAHAWH HMONG SIGN XIAB")
(93035 . "PAHAWH HMONG SIGN NTUJ")
(93036 . "PAHAWH HMONG SIGN AV")
(93037 . "PAHAWH HMONG SIGN TXHEEJ CEEV")
(93038 . "PAHAWH HMONG SIGN MEEJ TSEEB")
(93039 . "PAHAWH HMONG SIGN TAU")
(93040 . "PAHAWH HMONG SIGN LOS")
(93041 . "PAHAWH HMONG SIGN MUS")
(93042 . "PAHAWH HMONG SIGN CIM HAIS LUS NTOG NTOG")
(93043 . "PAHAWH HMONG SIGN CIM CUAM TSHOOJ")
(93044 . "PAHAWH HMONG SIGN CIM TXWV")
(93045 . "PAHAWH HMONG SIGN CIM TXWV CHWV")
(93046 . "PAHAWH HMONG SIGN CIM PUB DAWB")
(93047 . "PAHAWH HMONG SIGN CIM NRES TOS")
((93048 . 93053) . #f)
(93053 . "PAHAWH HMONG CLAN SIGN TSHEEJ")
(93054 . "PAHAWH HMONG CLAN SIGN YEEG")
(93055 . "PAHAWH HMONG CLAN SIGN LIS")
(93056 . "PAHAWH HMONG CLAN SIGN LAUJ")
(93057 . "PAHAWH HMONG CLAN SIGN XYOOJ")
(93058 . "PAHAWH HMONG CLAN SIGN KOO")
(93059 . "PAHAWH HMONG CLAN SIGN HAWJ")
(93060 . "PAHAWH HMONG CLAN SIGN MUAS")
(93061 . "PAHAWH HMONG CLAN SIGN THOJ")
(93062 . "PAHAWH HMONG CLAN SIGN TSAB")
(93063 . "PAHAWH HMONG CLAN SIGN PHAB")
(93064 . "PAHAWH HMONG CLAN SIGN KHAB")
(93065 . "PAHAWH HMONG CLAN SIGN HAM")
(93066 . "PAHAWH HMONG CLAN SIGN VAJ")
(93067 . "PAHAWH HMONG CLAN SIGN FAJ")
(93068 . "PAHAWH HMONG CLAN SIGN YAJ")
(93069 . "PAHAWH HMONG CLAN SIGN TSWB")
(93070 . "PAHAWH HMONG CLAN SIGN KWM")
(93071 . "PAHAWH HMONG CLAN SIGN VWJ")
((93072 . 93952) . #f)
(93952 . "MIAO LETTER PA")
(93953 . "MIAO LETTER BA")
(93954 . "MIAO LETTER YI PA")
(93955 . "MIAO LETTER PLA")
(93956 . "MIAO LETTER MA")
(93957 . "MIAO LETTER MHA")
(93958 . "MIAO LETTER ARCHAIC MA")
(93959 . "MIAO LETTER FA")
(93960 . "MIAO LETTER VA")
(93961 . "MIAO LETTER VFA")
(93962 . "MIAO LETTER TA")
(93963 . "MIAO LETTER DA")
(93964 . "MIAO LETTER YI TTA")
(93965 . "MIAO LETTER YI TA")
(93966 . "MIAO LETTER TTA")
(93967 . "MIAO LETTER DDA")
(93968 . "MIAO LETTER NA")
(93969 . "MIAO LETTER NHA")
(93970 . "MIAO LETTER YI NNA")
(93971 . "MIAO LETTER ARCHAIC NA")
(93972 . "MIAO LETTER NNA")
(93973 . "MIAO LETTER NNHA")
(93974 . "MIAO LETTER LA")
(93975 . "MIAO LETTER LYA")
(93976 . "MIAO LETTER LHA")
(93977 . "MIAO LETTER LHYA")
(93978 . "MIAO LETTER TLHA")
(93979 . "MIAO LETTER DLHA")
(93980 . "MIAO LETTER TLHYA")
(93981 . "MIAO LETTER DLHYA")
(93982 . "MIAO LETTER KA")
(93983 . "MIAO LETTER GA")
(93984 . "MIAO LETTER YI KA")
(93985 . "MIAO LETTER QA")
(93986 . "MIAO LETTER QGA")
(93987 . "MIAO LETTER NGA")
(93988 . "MIAO LETTER NGHA")
(93989 . "MIAO LETTER ARCHAIC NGA")
(93990 . "MIAO LETTER HA")
(93991 . "MIAO LETTER XA")
(93992 . "MIAO LETTER GHA")
(93993 . "MIAO LETTER GHHA")
(93994 . "MIAO LETTER TSSA")
(93995 . "MIAO LETTER DZZA")
(93996 . "MIAO LETTER NYA")
(93997 . "MIAO LETTER NYHA")
(93998 . "MIAO LETTER TSHA")
(93999 . "MIAO LETTER DZHA")
(94000 . "MIAO LETTER YI TSHA")
(94001 . "MIAO LETTER YI DZHA")
(94002 . "MIAO LETTER REFORMED TSHA")
(94003 . "MIAO LETTER SHA")
(94004 . "MIAO LETTER SSA")
(94005 . "MIAO LETTER ZHA")
(94006 . "MIAO LETTER ZSHA")
(94007 . "MIAO LETTER TSA")
(94008 . "MIAO LETTER DZA")
(94009 . "MIAO LETTER YI TSA")
(94010 . "MIAO LETTER SA")
(94011 . "MIAO LETTER ZA")
(94012 . "MIAO LETTER ZSA")
(94013 . "MIAO LETTER ZZA")
(94014 . "MIAO LETTER ZZSA")
(94015 . "MIAO LETTER ARCHAIC ZZA")
(94016 . "MIAO LETTER ZZYA")
(94017 . "MIAO LETTER ZZSYA")
(94018 . "MIAO LETTER WA")
(94019 . "MIAO LETTER AH")
(94020 . "MIAO LETTER HHA")
((94021 . 94032) . #f)
(94032 . "MIAO LETTER NASALIZATION")
(94033 . "MIAO SIGN ASPIRATION")
(94034 . "MIAO SIGN REFORMED VOICING")
(94035 . "MIAO SIGN REFORMED ASPIRATION")
(94036 . "MIAO VOWEL SIGN A")
(94037 . "MIAO VOWEL SIGN AA")
(94038 . "MIAO VOWEL SIGN AHH")
(94039 . "MIAO VOWEL SIGN AN")
(94040 . "MIAO VOWEL SIGN ANG")
(94041 . "MIAO VOWEL SIGN O")
(94042 . "MIAO VOWEL SIGN OO")
(94043 . "MIAO VOWEL SIGN WO")
(94044 . "MIAO VOWEL SIGN W")
(94045 . "MIAO VOWEL SIGN E")
(94046 . "MIAO VOWEL SIGN EN")
(94047 . "MIAO VOWEL SIGN ENG")
(94048 . "MIAO VOWEL SIGN OEY")
(94049 . "MIAO VOWEL SIGN I")
(94050 . "MIAO VOWEL SIGN IA")
(94051 . "MIAO VOWEL SIGN IAN")
(94052 . "MIAO VOWEL SIGN IANG")
(94053 . "MIAO VOWEL SIGN IO")
(94054 . "MIAO VOWEL SIGN IE")
(94055 . "MIAO VOWEL SIGN II")
(94056 . "MIAO VOWEL SIGN IU")
(94057 . "MIAO VOWEL SIGN ING")
(94058 . "MIAO VOWEL SIGN U")
(94059 . "MIAO VOWEL SIGN UA")
(94060 . "MIAO VOWEL SIGN UAN")
(94061 . "MIAO VOWEL SIGN UANG")
(94062 . "MIAO VOWEL SIGN UU")
(94063 . "MIAO VOWEL SIGN UEI")
(94064 . "MIAO VOWEL SIGN UNG")
(94065 . "MIAO VOWEL SIGN Y")
(94066 . "MIAO VOWEL SIGN YI")
(94067 . "MIAO VOWEL SIGN AE")
(94068 . "MIAO VOWEL SIGN AEE")
(94069 . "MIAO VOWEL SIGN ERR")
(94070 . "MIAO VOWEL SIGN ROUNDED ERR")
(94071 . "MIAO VOWEL SIGN ER")
(94072 . "MIAO VOWEL SIGN ROUNDED ER")
(94073 . "MIAO VOWEL SIGN AI")
(94074 . "MIAO VOWEL SIGN EI")
(94075 . "MIAO VOWEL SIGN AU")
(94076 . "MIAO VOWEL SIGN OU")
(94077 . "MIAO VOWEL SIGN N")
(94078 . "MIAO VOWEL SIGN NG")
((94079 . 94095) . #f)
(94095 . "MIAO TONE RIGHT")
(94096 . "MIAO TONE TOP RIGHT")
(94097 . "MIAO TONE ABOVE")
(94098 . "MIAO TONE BELOW")
(94099 . "MIAO LETTER TONE-2")
(94100 . "MIAO LETTER TONE-3")
(94101 . "MIAO LETTER TONE-4")
(94102 . "MIAO LETTER TONE-5")
(94103 . "MIAO LETTER TONE-6")
(94104 . "MIAO LETTER TONE-7")
(94105 . "MIAO LETTER TONE-8")
(94106 . "MIAO LETTER REFORMED TONE-1")
(94107 . "MIAO LETTER REFORMED TONE-2")
(94108 . "MIAO LETTER REFORMED TONE-4")
(94109 . "MIAO LETTER REFORMED TONE-5")
(94110 . "MIAO LETTER REFORMED TONE-6")
(94111 . "MIAO LETTER REFORMED TONE-8")
((94112 . 94176) . #f)
(94176 . "TANGUT ITERATION MARK")
((94177 . 94208) . #f)
((94208 . 100352) . "TANGUT IDEOGRAPH-#")
(100352 . "TANGUT COMPONENT-001")
(100353 . "TANGUT COMPONENT-002")
(100354 . "TANGUT COMPONENT-003")
(100355 . "TANGUT COMPONENT-004")
(100356 . "TANGUT COMPONENT-005")
(100357 . "TANGUT COMPONENT-006")
(100358 . "TANGUT COMPONENT-007")
(100359 . "TANGUT COMPONENT-008")
(100360 . "TANGUT COMPONENT-009")
(100361 . "TANGUT COMPONENT-010")
(100362 . "TANGUT COMPONENT-011")
(100363 . "TANGUT COMPONENT-012")
(100364 . "TANGUT COMPONENT-013")
(100365 . "TANGUT COMPONENT-014")
(100366 . "TANGUT COMPONENT-015")
(100367 . "TANGUT COMPONENT-016")
(100368 . "TANGUT COMPONENT-017")
(100369 . "TANGUT COMPONENT-018")
(100370 . "TANGUT COMPONENT-019")
(100371 . "TANGUT COMPONENT-020")
(100372 . "TANGUT COMPONENT-021")
(100373 . "TANGUT COMPONENT-022")
(100374 . "TANGUT COMPONENT-023")
(100375 . "TANGUT COMPONENT-024")
(100376 . "TANGUT COMPONENT-025")
(100377 . "TANGUT COMPONENT-026")
(100378 . "TANGUT COMPONENT-027")
(100379 . "TANGUT COMPONENT-028")
(100380 . "TANGUT COMPONENT-029")
(100381 . "TANGUT COMPONENT-030")
(100382 . "TANGUT COMPONENT-031")
(100383 . "TANGUT COMPONENT-032")
(100384 . "TANGUT COMPONENT-033")
(100385 . "TANGUT COMPONENT-034")
(100386 . "TANGUT COMPONENT-035")
(100387 . "TANGUT COMPONENT-036")
(100388 . "TANGUT COMPONENT-037")
(100389 . "TANGUT COMPONENT-038")
(100390 . "TANGUT COMPONENT-039")
(100391 . "TANGUT COMPONENT-040")
(100392 . "TANGUT COMPONENT-041")
(100393 . "TANGUT COMPONENT-042")
(100394 . "TANGUT COMPONENT-043")
(100395 . "TANGUT COMPONENT-044")
(100396 . "TANGUT COMPONENT-045")
(100397 . "TANGUT COMPONENT-046")
(100398 . "TANGUT COMPONENT-047")
(100399 . "TANGUT COMPONENT-048")
(100400 . "TANGUT COMPONENT-049")
(100401 . "TANGUT COMPONENT-050")
(100402 . "TANGUT COMPONENT-051")
(100403 . "TANGUT COMPONENT-052")
(100404 . "TANGUT COMPONENT-053")
(100405 . "TANGUT COMPONENT-054")
(100406 . "TANGUT COMPONENT-055")
(100407 . "TANGUT COMPONENT-056")
(100408 . "TANGUT COMPONENT-057")
(100409 . "TANGUT COMPONENT-058")
(100410 . "TANGUT COMPONENT-059")
(100411 . "TANGUT COMPONENT-060")
(100412 . "TANGUT COMPONENT-061")
(100413 . "TANGUT COMPONENT-062")
(100414 . "TANGUT COMPONENT-063")
(100415 . "TANGUT COMPONENT-064")
(100416 . "TANGUT COMPONENT-065")
(100417 . "TANGUT COMPONENT-066")
(100418 . "TANGUT COMPONENT-067")
(100419 . "TANGUT COMPONENT-068")
(100420 . "TANGUT COMPONENT-069")
(100421 . "TANGUT COMPONENT-070")
(100422 . "TANGUT COMPONENT-071")
(100423 . "TANGUT COMPONENT-072")
(100424 . "TANGUT COMPONENT-073")
(100425 . "TANGUT COMPONENT-074")
(100426 . "TANGUT COMPONENT-075")
(100427 . "TANGUT COMPONENT-076")
(100428 . "TANGUT COMPONENT-077")
(100429 . "TANGUT COMPONENT-078")
(100430 . "TANGUT COMPONENT-079")
(100431 . "TANGUT COMPONENT-080")
(100432 . "TANGUT COMPONENT-081")
(100433 . "TANGUT COMPONENT-082")
(100434 . "TANGUT COMPONENT-083")
(100435 . "TANGUT COMPONENT-084")
(100436 . "TANGUT COMPONENT-085")
(100437 . "TANGUT COMPONENT-086")
(100438 . "TANGUT COMPONENT-087")
(100439 . "TANGUT COMPONENT-088")
(100440 . "TANGUT COMPONENT-089")
(100441 . "TANGUT COMPONENT-090")
(100442 . "TANGUT COMPONENT-091")
(100443 . "TANGUT COMPONENT-092")
(100444 . "TANGUT COMPONENT-093")
(100445 . "TANGUT COMPONENT-094")
(100446 . "TANGUT COMPONENT-095")
(100447 . "TANGUT COMPONENT-096")
(100448 . "TANGUT COMPONENT-097")
(100449 . "TANGUT COMPONENT-098")
(100450 . "TANGUT COMPONENT-099")
(100451 . "TANGUT COMPONENT-100")
(100452 . "TANGUT COMPONENT-101")
(100453 . "TANGUT COMPONENT-102")
(100454 . "TANGUT COMPONENT-103")
(100455 . "TANGUT COMPONENT-104")
(100456 . "TANGUT COMPONENT-105")
(100457 . "TANGUT COMPONENT-106")
(100458 . "TANGUT COMPONENT-107")
(100459 . "TANGUT COMPONENT-108")
(100460 . "TANGUT COMPONENT-109")
(100461 . "TANGUT COMPONENT-110")
(100462 . "TANGUT COMPONENT-111")
(100463 . "TANGUT COMPONENT-112")
(100464 . "TANGUT COMPONENT-113")
(100465 . "TANGUT COMPONENT-114")
(100466 . "TANGUT COMPONENT-115")
(100467 . "TANGUT COMPONENT-116")
(100468 . "TANGUT COMPONENT-117")
(100469 . "TANGUT COMPONENT-118")
(100470 . "TANGUT COMPONENT-119")
(100471 . "TANGUT COMPONENT-120")
(100472 . "TANGUT COMPONENT-121")
(100473 . "TANGUT COMPONENT-122")
(100474 . "TANGUT COMPONENT-123")
(100475 . "TANGUT COMPONENT-124")
(100476 . "TANGUT COMPONENT-125")
(100477 . "TANGUT COMPONENT-126")
(100478 . "TANGUT COMPONENT-127")
(100479 . "TANGUT COMPONENT-128")
(100480 . "TANGUT COMPONENT-129")
(100481 . "TANGUT COMPONENT-130")
(100482 . "TANGUT COMPONENT-131")
(100483 . "TANGUT COMPONENT-132")
(100484 . "TANGUT COMPONENT-133")
(100485 . "TANGUT COMPONENT-134")
(100486 . "TANGUT COMPONENT-135")
(100487 . "TANGUT COMPONENT-136")
(100488 . "TANGUT COMPONENT-137")
(100489 . "TANGUT COMPONENT-138")
(100490 . "TANGUT COMPONENT-139")
(100491 . "TANGUT COMPONENT-140")
(100492 . "TANGUT COMPONENT-141")
(100493 . "TANGUT COMPONENT-142")
(100494 . "TANGUT COMPONENT-143")
(100495 . "TANGUT COMPONENT-144")
(100496 . "TANGUT COMPONENT-145")
(100497 . "TANGUT COMPONENT-146")
(100498 . "TANGUT COMPONENT-147")
(100499 . "TANGUT COMPONENT-148")
(100500 . "TANGUT COMPONENT-149")
(100501 . "TANGUT COMPONENT-150")
(100502 . "TANGUT COMPONENT-151")
(100503 . "TANGUT COMPONENT-152")
(100504 . "TANGUT COMPONENT-153")
(100505 . "TANGUT COMPONENT-154")
(100506 . "TANGUT COMPONENT-155")
(100507 . "TANGUT COMPONENT-156")
(100508 . "TANGUT COMPONENT-157")
(100509 . "TANGUT COMPONENT-158")
(100510 . "TANGUT COMPONENT-159")
(100511 . "TANGUT COMPONENT-160")
(100512 . "TANGUT COMPONENT-161")
(100513 . "TANGUT COMPONENT-162")
(100514 . "TANGUT COMPONENT-163")
(100515 . "TANGUT COMPONENT-164")
(100516 . "TANGUT COMPONENT-165")
(100517 . "TANGUT COMPONENT-166")
(100518 . "TANGUT COMPONENT-167")
(100519 . "TANGUT COMPONENT-168")
(100520 . "TANGUT COMPONENT-169")
(100521 . "TANGUT COMPONENT-170")
(100522 . "TANGUT COMPONENT-171")
(100523 . "TANGUT COMPONENT-172")
(100524 . "TANGUT COMPONENT-173")
(100525 . "TANGUT COMPONENT-174")
(100526 . "TANGUT COMPONENT-175")
(100527 . "TANGUT COMPONENT-176")
(100528 . "TANGUT COMPONENT-177")
(100529 . "TANGUT COMPONENT-178")
(100530 . "TANGUT COMPONENT-179")
(100531 . "TANGUT COMPONENT-180")
(100532 . "TANGUT COMPONENT-181")
(100533 . "TANGUT COMPONENT-182")
(100534 . "TANGUT COMPONENT-183")
(100535 . "TANGUT COMPONENT-184")
(100536 . "TANGUT COMPONENT-185")
(100537 . "TANGUT COMPONENT-186")
(100538 . "TANGUT COMPONENT-187")
(100539 . "TANGUT COMPONENT-188")
(100540 . "TANGUT COMPONENT-189")
(100541 . "TANGUT COMPONENT-190")
(100542 . "TANGUT COMPONENT-191")
(100543 . "TANGUT COMPONENT-192")
(100544 . "TANGUT COMPONENT-193")
(100545 . "TANGUT COMPONENT-194")
(100546 . "TANGUT COMPONENT-195")
(100547 . "TANGUT COMPONENT-196")
(100548 . "TANGUT COMPONENT-197")
(100549 . "TANGUT COMPONENT-198")
(100550 . "TANGUT COMPONENT-199")
(100551 . "TANGUT COMPONENT-200")
(100552 . "TANGUT COMPONENT-201")
(100553 . "TANGUT COMPONENT-202")
(100554 . "TANGUT COMPONENT-203")
(100555 . "TANGUT COMPONENT-204")
(100556 . "TANGUT COMPONENT-205")
(100557 . "TANGUT COMPONENT-206")
(100558 . "TANGUT COMPONENT-207")
(100559 . "TANGUT COMPONENT-208")
(100560 . "TANGUT COMPONENT-209")
(100561 . "TANGUT COMPONENT-210")
(100562 . "TANGUT COMPONENT-211")
(100563 . "TANGUT COMPONENT-212")
(100564 . "TANGUT COMPONENT-213")
(100565 . "TANGUT COMPONENT-214")
(100566 . "TANGUT COMPONENT-215")
(100567 . "TANGUT COMPONENT-216")
(100568 . "TANGUT COMPONENT-217")
(100569 . "TANGUT COMPONENT-218")
(100570 . "TANGUT COMPONENT-219")
(100571 . "TANGUT COMPONENT-220")
(100572 . "TANGUT COMPONENT-221")
(100573 . "TANGUT COMPONENT-222")
(100574 . "TANGUT COMPONENT-223")
(100575 . "TANGUT COMPONENT-224")
(100576 . "TANGUT COMPONENT-225")
(100577 . "TANGUT COMPONENT-226")
(100578 . "TANGUT COMPONENT-227")
(100579 . "TANGUT COMPONENT-228")
(100580 . "TANGUT COMPONENT-229")
(100581 . "TANGUT COMPONENT-230")
(100582 . "TANGUT COMPONENT-231")
(100583 . "TANGUT COMPONENT-232")
(100584 . "TANGUT COMPONENT-233")
(100585 . "TANGUT COMPONENT-234")
(100586 . "TANGUT COMPONENT-235")
(100587 . "TANGUT COMPONENT-236")
(100588 . "TANGUT COMPONENT-237")
(100589 . "TANGUT COMPONENT-238")
(100590 . "TANGUT COMPONENT-239")
(100591 . "TANGUT COMPONENT-240")
(100592 . "TANGUT COMPONENT-241")
(100593 . "TANGUT COMPONENT-242")
(100594 . "TANGUT COMPONENT-243")
(100595 . "TANGUT COMPONENT-244")
(100596 . "TANGUT COMPONENT-245")
(100597 . "TANGUT COMPONENT-246")
(100598 . "TANGUT COMPONENT-247")
(100599 . "TANGUT COMPONENT-248")
(100600 . "TANGUT COMPONENT-249")
(100601 . "TANGUT COMPONENT-250")
(100602 . "TANGUT COMPONENT-251")
(100603 . "TANGUT COMPONENT-252")
(100604 . "TANGUT COMPONENT-253")
(100605 . "TANGUT COMPONENT-254")
(100606 . "TANGUT COMPONENT-255")
(100607 . "TANGUT COMPONENT-256")
(100608 . "TANGUT COMPONENT-257")
(100609 . "TANGUT COMPONENT-258")
(100610 . "TANGUT COMPONENT-259")
(100611 . "TANGUT COMPONENT-260")
(100612 . "TANGUT COMPONENT-261")
(100613 . "TANGUT COMPONENT-262")
(100614 . "TANGUT COMPONENT-263")
(100615 . "TANGUT COMPONENT-264")
(100616 . "TANGUT COMPONENT-265")
(100617 . "TANGUT COMPONENT-266")
(100618 . "TANGUT COMPONENT-267")
(100619 . "TANGUT COMPONENT-268")
(100620 . "TANGUT COMPONENT-269")
(100621 . "TANGUT COMPONENT-270")
(100622 . "TANGUT COMPONENT-271")
(100623 . "TANGUT COMPONENT-272")
(100624 . "TANGUT COMPONENT-273")
(100625 . "TANGUT COMPONENT-274")
(100626 . "TANGUT COMPONENT-275")
(100627 . "TANGUT COMPONENT-276")
(100628 . "TANGUT COMPONENT-277")
(100629 . "TANGUT COMPONENT-278")
(100630 . "TANGUT COMPONENT-279")
(100631 . "TANGUT COMPONENT-280")
(100632 . "TANGUT COMPONENT-281")
(100633 . "TANGUT COMPONENT-282")
(100634 . "TANGUT COMPONENT-283")
(100635 . "TANGUT COMPONENT-284")
(100636 . "TANGUT COMPONENT-285")
(100637 . "TANGUT COMPONENT-286")
(100638 . "TANGUT COMPONENT-287")
(100639 . "TANGUT COMPONENT-288")
(100640 . "TANGUT COMPONENT-289")
(100641 . "TANGUT COMPONENT-290")
(100642 . "TANGUT COMPONENT-291")
(100643 . "TANGUT COMPONENT-292")
(100644 . "TANGUT COMPONENT-293")
(100645 . "TANGUT COMPONENT-294")
(100646 . "TANGUT COMPONENT-295")
(100647 . "TANGUT COMPONENT-296")
(100648 . "TANGUT COMPONENT-297")
(100649 . "TANGUT COMPONENT-298")
(100650 . "TANGUT COMPONENT-299")
(100651 . "TANGUT COMPONENT-300")
(100652 . "TANGUT COMPONENT-301")
(100653 . "TANGUT COMPONENT-302")
(100654 . "TANGUT COMPONENT-303")
(100655 . "TANGUT COMPONENT-304")
(100656 . "TANGUT COMPONENT-305")
(100657 . "TANGUT COMPONENT-306")
(100658 . "TANGUT COMPONENT-307")
(100659 . "TANGUT COMPONENT-308")
(100660 . "TANGUT COMPONENT-309")
(100661 . "TANGUT COMPONENT-310")
(100662 . "TANGUT COMPONENT-311")
(100663 . "TANGUT COMPONENT-312")
(100664 . "TANGUT COMPONENT-313")
(100665 . "TANGUT COMPONENT-314")
(100666 . "TANGUT COMPONENT-315")
(100667 . "TANGUT COMPONENT-316")
(100668 . "TANGUT COMPONENT-317")
(100669 . "TANGUT COMPONENT-318")
(100670 . "TANGUT COMPONENT-319")
(100671 . "TANGUT COMPONENT-320")
(100672 . "TANGUT COMPONENT-321")
(100673 . "TANGUT COMPONENT-322")
(100674 . "TANGUT COMPONENT-323")
(100675 . "TANGUT COMPONENT-324")
(100676 . "TANGUT COMPONENT-325")
(100677 . "TANGUT COMPONENT-326")
(100678 . "TANGUT COMPONENT-327")
(100679 . "TANGUT COMPONENT-328")
(100680 . "TANGUT COMPONENT-329")
(100681 . "TANGUT COMPONENT-330")
(100682 . "TANGUT COMPONENT-331")
(100683 . "TANGUT COMPONENT-332")
(100684 . "TANGUT COMPONENT-333")
(100685 . "TANGUT COMPONENT-334")
(100686 . "TANGUT COMPONENT-335")
(100687 . "TANGUT COMPONENT-336")
(100688 . "TANGUT COMPONENT-337")
(100689 . "TANGUT COMPONENT-338")
(100690 . "TANGUT COMPONENT-339")
(100691 . "TANGUT COMPONENT-340")
(100692 . "TANGUT COMPONENT-341")
(100693 . "TANGUT COMPONENT-342")
(100694 . "TANGUT COMPONENT-343")
(100695 . "TANGUT COMPONENT-344")
(100696 . "TANGUT COMPONENT-345")
(100697 . "TANGUT COMPONENT-346")
(100698 . "TANGUT COMPONENT-347")
(100699 . "TANGUT COMPONENT-348")
(100700 . "TANGUT COMPONENT-349")
(100701 . "TANGUT COMPONENT-350")
(100702 . "TANGUT COMPONENT-351")
(100703 . "TANGUT COMPONENT-352")
(100704 . "TANGUT COMPONENT-353")
(100705 . "TANGUT COMPONENT-354")
(100706 . "TANGUT COMPONENT-355")
(100707 . "TANGUT COMPONENT-356")
(100708 . "TANGUT COMPONENT-357")
(100709 . "TANGUT COMPONENT-358")
(100710 . "TANGUT COMPONENT-359")
(100711 . "TANGUT COMPONENT-360")
(100712 . "TANGUT COMPONENT-361")
(100713 . "TANGUT COMPONENT-362")
(100714 . "TANGUT COMPONENT-363")
(100715 . "TANGUT COMPONENT-364")
(100716 . "TANGUT COMPONENT-365")
(100717 . "TANGUT COMPONENT-366")
(100718 . "TANGUT COMPONENT-367")
(100719 . "TANGUT COMPONENT-368")
(100720 . "TANGUT COMPONENT-369")
(100721 . "TANGUT COMPONENT-370")
(100722 . "TANGUT COMPONENT-371")
(100723 . "TANGUT COMPONENT-372")
(100724 . "TANGUT COMPONENT-373")
(100725 . "TANGUT COMPONENT-374")
(100726 . "TANGUT COMPONENT-375")
(100727 . "TANGUT COMPONENT-376")
(100728 . "TANGUT COMPONENT-377")
(100729 . "TANGUT COMPONENT-378")
(100730 . "TANGUT COMPONENT-379")
(100731 . "TANGUT COMPONENT-380")
(100732 . "TANGUT COMPONENT-381")
(100733 . "TANGUT COMPONENT-382")
(100734 . "TANGUT COMPONENT-383")
(100735 . "TANGUT COMPONENT-384")
(100736 . "TANGUT COMPONENT-385")
(100737 . "TANGUT COMPONENT-386")
(100738 . "TANGUT COMPONENT-387")
(100739 . "TANGUT COMPONENT-388")
(100740 . "TANGUT COMPONENT-389")
(100741 . "TANGUT COMPONENT-390")
(100742 . "TANGUT COMPONENT-391")
(100743 . "TANGUT COMPONENT-392")
(100744 . "TANGUT COMPONENT-393")
(100745 . "TANGUT COMPONENT-394")
(100746 . "TANGUT COMPONENT-395")
(100747 . "TANGUT COMPONENT-396")
(100748 . "TANGUT COMPONENT-397")
(100749 . "TANGUT COMPONENT-398")
(100750 . "TANGUT COMPONENT-399")
(100751 . "TANGUT COMPONENT-400")
(100752 . "TANGUT COMPONENT-401")
(100753 . "TANGUT COMPONENT-402")
(100754 . "TANGUT COMPONENT-403")
(100755 . "TANGUT COMPONENT-404")
(100756 . "TANGUT COMPONENT-405")
(100757 . "TANGUT COMPONENT-406")
(100758 . "TANGUT COMPONENT-407")
(100759 . "TANGUT COMPONENT-408")
(100760 . "TANGUT COMPONENT-409")
(100761 . "TANGUT COMPONENT-410")
(100762 . "TANGUT COMPONENT-411")
(100763 . "TANGUT COMPONENT-412")
(100764 . "TANGUT COMPONENT-413")
(100765 . "TANGUT COMPONENT-414")
(100766 . "TANGUT COMPONENT-415")
(100767 . "TANGUT COMPONENT-416")
(100768 . "TANGUT COMPONENT-417")
(100769 . "TANGUT COMPONENT-418")
(100770 . "TANGUT COMPONENT-419")
(100771 . "TANGUT COMPONENT-420")
(100772 . "TANGUT COMPONENT-421")
(100773 . "TANGUT COMPONENT-422")
(100774 . "TANGUT COMPONENT-423")
(100775 . "TANGUT COMPONENT-424")
(100776 . "TANGUT COMPONENT-425")
(100777 . "TANGUT COMPONENT-426")
(100778 . "TANGUT COMPONENT-427")
(100779 . "TANGUT COMPONENT-428")
(100780 . "TANGUT COMPONENT-429")
(100781 . "TANGUT COMPONENT-430")
(100782 . "TANGUT COMPONENT-431")
(100783 . "TANGUT COMPONENT-432")
(100784 . "TANGUT COMPONENT-433")
(100785 . "TANGUT COMPONENT-434")
(100786 . "TANGUT COMPONENT-435")
(100787 . "TANGUT COMPONENT-436")
(100788 . "TANGUT COMPONENT-437")
(100789 . "TANGUT COMPONENT-438")
(100790 . "TANGUT COMPONENT-439")
(100791 . "TANGUT COMPONENT-440")
(100792 . "TANGUT COMPONENT-441")
(100793 . "TANGUT COMPONENT-442")
(100794 . "TANGUT COMPONENT-443")
(100795 . "TANGUT COMPONENT-444")
(100796 . "TANGUT COMPONENT-445")
(100797 . "TANGUT COMPONENT-446")
(100798 . "TANGUT COMPONENT-447")
(100799 . "TANGUT COMPONENT-448")
(100800 . "TANGUT COMPONENT-449")
(100801 . "TANGUT COMPONENT-450")
(100802 . "TANGUT COMPONENT-451")
(100803 . "TANGUT COMPONENT-452")
(100804 . "TANGUT COMPONENT-453")
(100805 . "TANGUT COMPONENT-454")
(100806 . "TANGUT COMPONENT-455")
(100807 . "TANGUT COMPONENT-456")
(100808 . "TANGUT COMPONENT-457")
(100809 . "TANGUT COMPONENT-458")
(100810 . "TANGUT COMPONENT-459")
(100811 . "TANGUT COMPONENT-460")
(100812 . "TANGUT COMPONENT-461")
(100813 . "TANGUT COMPONENT-462")
(100814 . "TANGUT COMPONENT-463")
(100815 . "TANGUT COMPONENT-464")
(100816 . "TANGUT COMPONENT-465")
(100817 . "TANGUT COMPONENT-466")
(100818 . "TANGUT COMPONENT-467")
(100819 . "TANGUT COMPONENT-468")
(100820 . "TANGUT COMPONENT-469")
(100821 . "TANGUT COMPONENT-470")
(100822 . "TANGUT COMPONENT-471")
(100823 . "TANGUT COMPONENT-472")
(100824 . "TANGUT COMPONENT-473")
(100825 . "TANGUT COMPONENT-474")
(100826 . "TANGUT COMPONENT-475")
(100827 . "TANGUT COMPONENT-476")
(100828 . "TANGUT COMPONENT-477")
(100829 . "TANGUT COMPONENT-478")
(100830 . "TANGUT COMPONENT-479")
(100831 . "TANGUT COMPONENT-480")
(100832 . "TANGUT COMPONENT-481")
(100833 . "TANGUT COMPONENT-482")
(100834 . "TANGUT COMPONENT-483")
(100835 . "TANGUT COMPONENT-484")
(100836 . "TANGUT COMPONENT-485")
(100837 . "TANGUT COMPONENT-486")
(100838 . "TANGUT COMPONENT-487")
(100839 . "TANGUT COMPONENT-488")
(100840 . "TANGUT COMPONENT-489")
(100841 . "TANGUT COMPONENT-490")
(100842 . "TANGUT COMPONENT-491")
(100843 . "TANGUT COMPONENT-492")
(100844 . "TANGUT COMPONENT-493")
(100845 . "TANGUT COMPONENT-494")
(100846 . "TANGUT COMPONENT-495")
(100847 . "TANGUT COMPONENT-496")
(100848 . "TANGUT COMPONENT-497")
(100849 . "TANGUT COMPONENT-498")
(100850 . "TANGUT COMPONENT-499")
(100851 . "TANGUT COMPONENT-500")
(100852 . "TANGUT COMPONENT-501")
(100853 . "TANGUT COMPONENT-502")
(100854 . "TANGUT COMPONENT-503")
(100855 . "TANGUT COMPONENT-504")
(100856 . "TANGUT COMPONENT-505")
(100857 . "TANGUT COMPONENT-506")
(100858 . "TANGUT COMPONENT-507")
(100859 . "TANGUT COMPONENT-508")
(100860 . "TANGUT COMPONENT-509")
(100861 . "TANGUT COMPONENT-510")
(100862 . "TANGUT COMPONENT-511")
(100863 . "TANGUT COMPONENT-512")
(100864 . "TANGUT COMPONENT-513")
(100865 . "TANGUT COMPONENT-514")
(100866 . "TANGUT COMPONENT-515")
(100867 . "TANGUT COMPONENT-516")
(100868 . "TANGUT COMPONENT-517")
(100869 . "TANGUT COMPONENT-518")
(100870 . "TANGUT COMPONENT-519")
(100871 . "TANGUT COMPONENT-520")
(100872 . "TANGUT COMPONENT-521")
(100873 . "TANGUT COMPONENT-522")
(100874 . "TANGUT COMPONENT-523")
(100875 . "TANGUT COMPONENT-524")
(100876 . "TANGUT COMPONENT-525")
(100877 . "TANGUT COMPONENT-526")
(100878 . "TANGUT COMPONENT-527")
(100879 . "TANGUT COMPONENT-528")
(100880 . "TANGUT COMPONENT-529")
(100881 . "TANGUT COMPONENT-530")
(100882 . "TANGUT COMPONENT-531")
(100883 . "TANGUT COMPONENT-532")
(100884 . "TANGUT COMPONENT-533")
(100885 . "TANGUT COMPONENT-534")
(100886 . "TANGUT COMPONENT-535")
(100887 . "TANGUT COMPONENT-536")
(100888 . "TANGUT COMPONENT-537")
(100889 . "TANGUT COMPONENT-538")
(100890 . "TANGUT COMPONENT-539")
(100891 . "TANGUT COMPONENT-540")
(100892 . "TANGUT COMPONENT-541")
(100893 . "TANGUT COMPONENT-542")
(100894 . "TANGUT COMPONENT-543")
(100895 . "TANGUT COMPONENT-544")
(100896 . "TANGUT COMPONENT-545")
(100897 . "TANGUT COMPONENT-546")
(100898 . "TANGUT COMPONENT-547")
(100899 . "TANGUT COMPONENT-548")
(100900 . "TANGUT COMPONENT-549")
(100901 . "TANGUT COMPONENT-550")
(100902 . "TANGUT COMPONENT-551")
(100903 . "TANGUT COMPONENT-552")
(100904 . "TANGUT COMPONENT-553")
(100905 . "TANGUT COMPONENT-554")
(100906 . "TANGUT COMPONENT-555")
(100907 . "TANGUT COMPONENT-556")
(100908 . "TANGUT COMPONENT-557")
(100909 . "TANGUT COMPONENT-558")
(100910 . "TANGUT COMPONENT-559")
(100911 . "TANGUT COMPONENT-560")
(100912 . "TANGUT COMPONENT-561")
(100913 . "TANGUT COMPONENT-562")
(100914 . "TANGUT COMPONENT-563")
(100915 . "TANGUT COMPONENT-564")
(100916 . "TANGUT COMPONENT-565")
(100917 . "TANGUT COMPONENT-566")
(100918 . "TANGUT COMPONENT-567")
(100919 . "TANGUT COMPONENT-568")
(100920 . "TANGUT COMPONENT-569")
(100921 . "TANGUT COMPONENT-570")
(100922 . "TANGUT COMPONENT-571")
(100923 . "TANGUT COMPONENT-572")
(100924 . "TANGUT COMPONENT-573")
(100925 . "TANGUT COMPONENT-574")
(100926 . "TANGUT COMPONENT-575")
(100927 . "TANGUT COMPONENT-576")
(100928 . "TANGUT COMPONENT-577")
(100929 . "TANGUT COMPONENT-578")
(100930 . "TANGUT COMPONENT-579")
(100931 . "TANGUT COMPONENT-580")
(100932 . "TANGUT COMPONENT-581")
(100933 . "TANGUT COMPONENT-582")
(100934 . "TANGUT COMPONENT-583")
(100935 . "TANGUT COMPONENT-584")
(100936 . "TANGUT COMPONENT-585")
(100937 . "TANGUT COMPONENT-586")
(100938 . "TANGUT COMPONENT-587")
(100939 . "TANGUT COMPONENT-588")
(100940 . "TANGUT COMPONENT-589")
(100941 . "TANGUT COMPONENT-590")
(100942 . "TANGUT COMPONENT-591")
(100943 . "TANGUT COMPONENT-592")
(100944 . "TANGUT COMPONENT-593")
(100945 . "TANGUT COMPONENT-594")
(100946 . "TANGUT COMPONENT-595")
(100947 . "TANGUT COMPONENT-596")
(100948 . "TANGUT COMPONENT-597")
(100949 . "TANGUT COMPONENT-598")
(100950 . "TANGUT COMPONENT-599")
(100951 . "TANGUT COMPONENT-600")
(100952 . "TANGUT COMPONENT-601")
(100953 . "TANGUT COMPONENT-602")
(100954 . "TANGUT COMPONENT-603")
(100955 . "TANGUT COMPONENT-604")
(100956 . "TANGUT COMPONENT-605")
(100957 . "TANGUT COMPONENT-606")
(100958 . "TANGUT COMPONENT-607")
(100959 . "TANGUT COMPONENT-608")
(100960 . "TANGUT COMPONENT-609")
(100961 . "TANGUT COMPONENT-610")
(100962 . "TANGUT COMPONENT-611")
(100963 . "TANGUT COMPONENT-612")
(100964 . "TANGUT COMPONENT-613")
(100965 . "TANGUT COMPONENT-614")
(100966 . "TANGUT COMPONENT-615")
(100967 . "TANGUT COMPONENT-616")
(100968 . "TANGUT COMPONENT-617")
(100969 . "TANGUT COMPONENT-618")
(100970 . "TANGUT COMPONENT-619")
(100971 . "TANGUT COMPONENT-620")
(100972 . "TANGUT COMPONENT-621")
(100973 . "TANGUT COMPONENT-622")
(100974 . "TANGUT COMPONENT-623")
(100975 . "TANGUT COMPONENT-624")
(100976 . "TANGUT COMPONENT-625")
(100977 . "TANGUT COMPONENT-626")
(100978 . "TANGUT COMPONENT-627")
(100979 . "TANGUT COMPONENT-628")
(100980 . "TANGUT COMPONENT-629")
(100981 . "TANGUT COMPONENT-630")
(100982 . "TANGUT COMPONENT-631")
(100983 . "TANGUT COMPONENT-632")
(100984 . "TANGUT COMPONENT-633")
(100985 . "TANGUT COMPONENT-634")
(100986 . "TANGUT COMPONENT-635")
(100987 . "TANGUT COMPONENT-636")
(100988 . "TANGUT COMPONENT-637")
(100989 . "TANGUT COMPONENT-638")
(100990 . "TANGUT COMPONENT-639")
(100991 . "TANGUT COMPONENT-640")
(100992 . "TANGUT COMPONENT-641")
(100993 . "TANGUT COMPONENT-642")
(100994 . "TANGUT COMPONENT-643")
(100995 . "TANGUT COMPONENT-644")
(100996 . "TANGUT COMPONENT-645")
(100997 . "TANGUT COMPONENT-646")
(100998 . "TANGUT COMPONENT-647")
(100999 . "TANGUT COMPONENT-648")
(101000 . "TANGUT COMPONENT-649")
(101001 . "TANGUT COMPONENT-650")
(101002 . "TANGUT COMPONENT-651")
(101003 . "TANGUT COMPONENT-652")
(101004 . "TANGUT COMPONENT-653")
(101005 . "TANGUT COMPONENT-654")
(101006 . "TANGUT COMPONENT-655")
(101007 . "TANGUT COMPONENT-656")
(101008 . "TANGUT COMPONENT-657")
(101009 . "TANGUT COMPONENT-658")
(101010 . "TANGUT COMPONENT-659")
(101011 . "TANGUT COMPONENT-660")
(101012 . "TANGUT COMPONENT-661")
(101013 . "TANGUT COMPONENT-662")
(101014 . "TANGUT COMPONENT-663")
(101015 . "TANGUT COMPONENT-664")
(101016 . "TANGUT COMPONENT-665")
(101017 . "TANGUT COMPONENT-666")
(101018 . "TANGUT COMPONENT-667")
(101019 . "TANGUT COMPONENT-668")
(101020 . "TANGUT COMPONENT-669")
(101021 . "TANGUT COMPONENT-670")
(101022 . "TANGUT COMPONENT-671")
(101023 . "TANGUT COMPONENT-672")
(101024 . "TANGUT COMPONENT-673")
(101025 . "TANGUT COMPONENT-674")
(101026 . "TANGUT COMPONENT-675")
(101027 . "TANGUT COMPONENT-676")
(101028 . "TANGUT COMPONENT-677")
(101029 . "TANGUT COMPONENT-678")
(101030 . "TANGUT COMPONENT-679")
(101031 . "TANGUT COMPONENT-680")
(101032 . "TANGUT COMPONENT-681")
(101033 . "TANGUT COMPONENT-682")
(101034 . "TANGUT COMPONENT-683")
(101035 . "TANGUT COMPONENT-684")
(101036 . "TANGUT COMPONENT-685")
(101037 . "TANGUT COMPONENT-686")
(101038 . "TANGUT COMPONENT-687")
(101039 . "TANGUT COMPONENT-688")
(101040 . "TANGUT COMPONENT-689")
(101041 . "TANGUT COMPONENT-690")
(101042 . "TANGUT COMPONENT-691")
(101043 . "TANGUT COMPONENT-692")
(101044 . "TANGUT COMPONENT-693")
(101045 . "TANGUT COMPONENT-694")
(101046 . "TANGUT COMPONENT-695")
(101047 . "TANGUT COMPONENT-696")
(101048 . "TANGUT COMPONENT-697")
(101049 . "TANGUT COMPONENT-698")
(101050 . "TANGUT COMPONENT-699")
(101051 . "TANGUT COMPONENT-700")
(101052 . "TANGUT COMPONENT-701")
(101053 . "TANGUT COMPONENT-702")
(101054 . "TANGUT COMPONENT-703")
(101055 . "TANGUT COMPONENT-704")
(101056 . "TANGUT COMPONENT-705")
(101057 . "TANGUT COMPONENT-706")
(101058 . "TANGUT COMPONENT-707")
(101059 . "TANGUT COMPONENT-708")
(101060 . "TANGUT COMPONENT-709")
(101061 . "TANGUT COMPONENT-710")
(101062 . "TANGUT COMPONENT-711")
(101063 . "TANGUT COMPONENT-712")
(101064 . "TANGUT COMPONENT-713")
(101065 . "TANGUT COMPONENT-714")
(101066 . "TANGUT COMPONENT-715")
(101067 . "TANGUT COMPONENT-716")
(101068 . "TANGUT COMPONENT-717")
(101069 . "TANGUT COMPONENT-718")
(101070 . "TANGUT COMPONENT-719")
(101071 . "TANGUT COMPONENT-720")
(101072 . "TANGUT COMPONENT-721")
(101073 . "TANGUT COMPONENT-722")
(101074 . "TANGUT COMPONENT-723")
(101075 . "TANGUT COMPONENT-724")
(101076 . "TANGUT COMPONENT-725")
(101077 . "TANGUT COMPONENT-726")
(101078 . "TANGUT COMPONENT-727")
(101079 . "TANGUT COMPONENT-728")
(101080 . "TANGUT COMPONENT-729")
(101081 . "TANGUT COMPONENT-730")
(101082 . "TANGUT COMPONENT-731")
(101083 . "TANGUT COMPONENT-732")
(101084 . "TANGUT COMPONENT-733")
(101085 . "TANGUT COMPONENT-734")
(101086 . "TANGUT COMPONENT-735")
(101087 . "TANGUT COMPONENT-736")
(101088 . "TANGUT COMPONENT-737")
(101089 . "TANGUT COMPONENT-738")
(101090 . "TANGUT COMPONENT-739")
(101091 . "TANGUT COMPONENT-740")
(101092 . "TANGUT COMPONENT-741")
(101093 . "TANGUT COMPONENT-742")
(101094 . "TANGUT COMPONENT-743")
(101095 . "TANGUT COMPONENT-744")
(101096 . "TANGUT COMPONENT-745")
(101097 . "TANGUT COMPONENT-746")
(101098 . "TANGUT COMPONENT-747")
(101099 . "TANGUT COMPONENT-748")
(101100 . "TANGUT COMPONENT-749")
(101101 . "TANGUT COMPONENT-750")
(101102 . "TANGUT COMPONENT-751")
(101103 . "TANGUT COMPONENT-752")
(101104 . "TANGUT COMPONENT-753")
(101105 . "TANGUT COMPONENT-754")
(101106 . "TANGUT COMPONENT-755")
((101107 . 110592) . #f)
(110592 . "KATAKANA LETTER ARCHAIC E")
(110593 . "HIRAGANA LETTER ARCHAIC YE")
((110594 . 113664) . #f)
(113664 . "DUPLOYAN LETTER H")
(113665 . "DUPLOYAN LETTER X")
(113666 . "DUPLOYAN LETTER P")
(113667 . "DUPLOYAN LETTER T")
(113668 . "DUPLOYAN LETTER F")
(113669 . "DUPLOYAN LETTER K")
(113670 . "DUPLOYAN LETTER L")
(113671 . "DUPLOYAN LETTER B")
(113672 . "DUPLOYAN LETTER D")
(113673 . "DUPLOYAN LETTER V")
(113674 . "DUPLOYAN LETTER G")
(113675 . "DUPLOYAN LETTER R")
(113676 . "DUPLOYAN LETTER P N")
(113677 . "DUPLOYAN LETTER D S")
(113678 . "DUPLOYAN LETTER F N")
(113679 . "DUPLOYAN LETTER K M")
(113680 . "DUPLOYAN LETTER R S")
(113681 . "DUPLOYAN LETTER TH")
(113682 . "DUPLOYAN LETTER SLOAN DH")
(113683 . "DUPLOYAN LETTER DH")
(113684 . "DUPLOYAN LETTER KK")
(113685 . "DUPLOYAN LETTER SLOAN J")
(113686 . "DUPLOYAN LETTER HL")
(113687 . "DUPLOYAN LETTER LH")
(113688 . "DUPLOYAN LETTER RH")
(113689 . "DUPLOYAN LETTER M")
(113690 . "DUPLOYAN LETTER N")
(113691 . "DUPLOYAN LETTER J")
(113692 . "DUPLOYAN LETTER S")
(113693 . "DUPLOYAN LETTER M N")
(113694 . "DUPLOYAN LETTER N M")
(113695 . "DUPLOYAN LETTER J M")
(113696 . "DUPLOYAN LETTER S J")
(113697 . "DUPLOYAN LETTER M WITH DOT")
(113698 . "DUPLOYAN LETTER N WITH DOT")
(113699 . "DUPLOYAN LETTER J WITH DOT")
(113700 . "DUPLOYAN LETTER J WITH DOTS INSIDE AND ABOVE")
(113701 . "DUPLOYAN LETTER S WITH DOT")
(113702 . "DUPLOYAN LETTER S WITH DOT BELOW")
(113703 . "DUPLOYAN LETTER M S")
(113704 . "DUPLOYAN LETTER N S")
(113705 . "DUPLOYAN LETTER J S")
(113706 . "DUPLOYAN LETTER S S")
(113707 . "DUPLOYAN LETTER M N S")
(113708 . "DUPLOYAN LETTER N M S")
(113709 . "DUPLOYAN LETTER J M S")
(113710 . "DUPLOYAN LETTER S J S")
(113711 . "DUPLOYAN LETTER J S WITH DOT")
(113712 . "DUPLOYAN LETTER J N")
(113713 . "DUPLOYAN LETTER J N S")
(113714 . "DUPLOYAN LETTER S T")
(113715 . "DUPLOYAN LETTER S T R")
(113716 . "DUPLOYAN LETTER S P")
(113717 . "DUPLOYAN LETTER S P R")
(113718 . "DUPLOYAN LETTER T S")
(113719 . "DUPLOYAN LETTER T R S")
(113720 . "DUPLOYAN LETTER W")
(113721 . "DUPLOYAN LETTER WH")
(113722 . "DUPLOYAN LETTER W R")
(113723 . "DUPLOYAN LETTER S N")
(113724 . "DUPLOYAN LETTER S M")
(113725 . "DUPLOYAN LETTER K R S")
(113726 . "DUPLOYAN LETTER G R S")
(113727 . "DUPLOYAN LETTER S K")
(113728 . "DUPLOYAN LETTER S K R")
(113729 . "DUPLOYAN LETTER A")
(113730 . "DUPLOYAN LETTER SLOAN OW")
(113731 . "DUPLOYAN LETTER OA")
(113732 . "DUPLOYAN LETTER O")
(113733 . "DUPLOYAN LETTER AOU")
(113734 . "DUPLOYAN LETTER I")
(113735 . "DUPLOYAN LETTER E")
(113736 . "DUPLOYAN LETTER IE")
(113737 . "DUPLOYAN LETTER SHORT I")
(113738 . "DUPLOYAN LETTER UI")
(113739 . "DUPLOYAN LETTER EE")
(113740 . "DUPLOYAN LETTER SLOAN EH")
(113741 . "DUPLOYAN LETTER ROMANIAN I")
(113742 . "DUPLOYAN LETTER SLOAN EE")
(113743 . "DUPLOYAN LETTER LONG I")
(113744 . "DUPLOYAN LETTER YE")
(113745 . "DUPLOYAN LETTER U")
(113746 . "DUPLOYAN LETTER EU")
(113747 . "DUPLOYAN LETTER XW")
(113748 . "DUPLOYAN LETTER U N")
(113749 . "DUPLOYAN LETTER LONG U")
(113750 . "DUPLOYAN LETTER ROMANIAN U")
(113751 . "DUPLOYAN LETTER UH")
(113752 . "DUPLOYAN LETTER SLOAN U")
(113753 . "DUPLOYAN LETTER OOH")
(113754 . "DUPLOYAN LETTER OW")
(113755 . "DUPLOYAN LETTER OU")
(113756 . "DUPLOYAN LETTER WA")
(113757 . "DUPLOYAN LETTER WO")
(113758 . "DUPLOYAN LETTER WI")
(113759 . "DUPLOYAN LETTER WEI")
(113760 . "DUPLOYAN LETTER WOW")
(113761 . "DUPLOYAN LETTER NASAL U")
(113762 . "DUPLOYAN LETTER NASAL O")
(113763 . "DUPLOYAN LETTER NASAL I")
(113764 . "DUPLOYAN LETTER NASAL A")
(113765 . "DUPLOYAN LETTER PERNIN AN")
(113766 . "DUPLOYAN LETTER PERNIN AM")
(113767 . "DUPLOYAN LETTER SLOAN EN")
(113768 . "DUPLOYAN LETTER SLOAN AN")
(113769 . "DUPLOYAN LETTER SLOAN ON")
(113770 . "DUPLOYAN LETTER VOCALIC M")
((113771 . 113776) . #f)
(113776 . "DUPLOYAN AFFIX LEFT HORIZONTAL SECANT")
(113777 . "DUPLOYAN AFFIX MID HORIZONTAL SECANT")
(113778 . "DUPLOYAN AFFIX RIGHT HORIZONTAL SECANT")
(113779 . "DUPLOYAN AFFIX LOW VERTICAL SECANT")
(113780 . "DUPLOYAN AFFIX MID VERTICAL SECANT")
(113781 . "DUPLOYAN AFFIX HIGH VERTICAL SECANT")
(113782 . "DUPLOYAN AFFIX ATTACHED SECANT")
(113783 . "DUPLOYAN AFFIX ATTACHED LEFT-TO-RIGHT SECANT")
(113784 . "DUPLOYAN AFFIX ATTACHED TANGENT")
(113785 . "DUPLOYAN AFFIX ATTACHED TAIL")
(113786 . "DUPLOYAN AFFIX ATTACHED E HOOK")
(113787 . "DUPLOYAN AFFIX ATTACHED I HOOK")
(113788 . "DUPLOYAN AFFIX ATTACHED TANGENT HOOK")
((113789 . 113792) . #f)
(113792 . "DUPLOYAN AFFIX HIGH ACUTE")
(113793 . "DUPLOYAN AFFIX HIGH TIGHT ACUTE")
(113794 . "DUPLOYAN AFFIX HIGH GRAVE")
(113795 . "DUPLOYAN AFFIX HIGH LONG GRAVE")
(113796 . "DUPLOYAN AFFIX HIGH DOT")
(113797 . "DUPLOYAN AFFIX HIGH CIRCLE")
(113798 . "DUPLOYAN AFFIX HIGH LINE")
(113799 . "DUPLOYAN AFFIX HIGH WAVE")
(113800 . "DUPLOYAN AFFIX HIGH VERTICAL")
((113801 . 113808) . #f)
(113808 . "DUPLOYAN AFFIX LOW ACUTE")
(113809 . "DUPLOYAN AFFIX LOW TIGHT ACUTE")
(113810 . "DUPLOYAN AFFIX LOW GRAVE")
(113811 . "DUPLOYAN AFFIX LOW LONG GRAVE")
(113812 . "DUPLOYAN AFFIX LOW DOT")
(113813 . "DUPLOYAN AFFIX LOW CIRCLE")
(113814 . "DUPLOYAN AFFIX LOW LINE")
(113815 . "DUPLOYAN AFFIX LOW WAVE")
(113816 . "DUPLOYAN AFFIX LOW VERTICAL")
(113817 . "DUPLOYAN AFFIX LOW ARROW")
((113818 . 113820) . #f)
(113820 . "DUPLOYAN SIGN O WITH CROSS")
(113821 . "DUPLOYAN THICK LETTER SELECTOR")
(113822 . "DUPLOYAN DOUBLE MARK")
(113823 . "DUPLOYAN PUNCTUATION CHINOOK FULL STOP")
(113824 . "SHORTHAND FORMAT LETTER OVERLAP")
(113825 . "SHORTHAND FORMAT CONTINUING OVERLAP")
(113826 . "SHORTHAND FORMAT DOWN STEP")
(113827 . "SHORTHAND FORMAT UP STEP")
((113828 . 118784) . #f)
(118784 . "BYZANTINE MUSICAL SYMBOL PSILI")
(118785 . "BYZANTINE MUSICAL SYMBOL DASEIA")
(118786 . "BYZANTINE MUSICAL SYMBOL PERISPOMENI")
(118787 . "BYZANTINE MUSICAL SYMBOL OXEIA EKFONITIKON")
(118788 . "BYZANTINE MUSICAL SYMBOL OXEIA DIPLI")
(118789 . "BYZANTINE MUSICAL SYMBOL VAREIA EKFONITIKON")
(118790 . "BYZANTINE MUSICAL SYMBOL VAREIA DIPLI")
(118791 . "BYZANTINE MUSICAL SYMBOL KATHISTI")
(118792 . "BYZANTINE MUSICAL SYMBOL SYRMATIKI")
(118793 . "BYZANTINE MUSICAL SYMBOL PARAKLITIKI")
(118794 . "BYZANTINE MUSICAL SYMBOL YPOKRISIS")
(118795 . "BYZANTINE MUSICAL SYMBOL YPOKRISIS DIPLI")
(118796 . "BYZANTINE MUSICAL SYMBOL KREMASTI")
(118797 . "BYZANTINE MUSICAL SYMBOL APESO EKFONITIKON")
(118798 . "BYZANTINE MUSICAL SYMBOL EXO EKFONITIKON")
(118799 . "BYZANTINE MUSICAL SYMBOL TELEIA")
(118800 . "BYZANTINE MUSICAL SYMBOL KENTIMATA")
(118801 . "BYZANTINE MUSICAL SYMBOL APOSTROFOS")
(118802 . "BYZANTINE MUSICAL SYMBOL APOSTROFOS DIPLI")
(118803 . "BYZANTINE MUSICAL SYMBOL SYNEVMA")
(118804 . "BYZANTINE MUSICAL SYMBOL THITA")
(118805 . "BYZANTINE MUSICAL SYMBOL OLIGON ARCHAION")
(118806 . "BYZANTINE MUSICAL SYMBOL GORGON ARCHAION")
(118807 . "BYZANTINE MUSICAL SYMBOL PSILON")
(118808 . "BYZANTINE MUSICAL SYMBOL CHAMILON")
(118809 . "BYZANTINE MUSICAL SYMBOL VATHY")
(118810 . "BYZANTINE MUSICAL SYMBOL ISON ARCHAION")
(118811 . "BYZANTINE MUSICAL SYMBOL KENTIMA ARCHAION")
(118812 . "BYZANTINE MUSICAL SYMBOL KENTIMATA ARCHAION")
(118813 . "BYZANTINE MUSICAL SYMBOL SAXIMATA")
(118814 . "BYZANTINE MUSICAL SYMBOL PARICHON")
(118815 . "BYZANTINE MUSICAL SYMBOL STAVROS APODEXIA")
(118816 . "BYZANTINE MUSICAL SYMBOL OXEIAI ARCHAION")
(118817 . "BYZANTINE MUSICAL SYMBOL VAREIAI ARCHAION")
(118818 . "BYZANTINE MUSICAL SYMBOL APODERMA ARCHAION")
(118819 . "BYZANTINE MUSICAL SYMBOL APOTHEMA")
(118820 . "BYZANTINE MUSICAL SYMBOL KLASMA")
(118821 . "BYZANTINE MUSICAL SYMBOL REVMA")
(118822 . "BYZANTINE MUSICAL SYMBOL PIASMA ARCHAION")
(118823 . "BYZANTINE MUSICAL SYMBOL TINAGMA")
(118824 . "BYZANTINE MUSICAL SYMBOL ANATRICHISMA")
(118825 . "BYZANTINE MUSICAL SYMBOL SEISMA")
(118826 . "BYZANTINE MUSICAL SYMBOL SYNAGMA ARCHAION")
(118827 . "BYZANTINE MUSICAL SYMBOL SYNAGMA META STAVROU")
(118828 . "BYZANTINE MUSICAL SYMBOL OYRANISMA ARCHAION")
(118829 . "BYZANTINE MUSICAL SYMBOL THEMA")
(118830 . "BYZANTINE MUSICAL SYMBOL LEMOI")
(118831 . "BYZANTINE MUSICAL SYMBOL DYO")
(118832 . "BYZANTINE MUSICAL SYMBOL TRIA")
(118833 . "BYZANTINE MUSICAL SYMBOL TESSERA")
(118834 . "BYZANTINE MUSICAL SYMBOL KRATIMATA")
(118835 . "BYZANTINE MUSICAL SYMBOL APESO EXO NEO")
(118836 . "BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION")
(118837 . "BYZANTINE MUSICAL SYMBOL IMIFTHORA")
(118838 . "BYZANTINE MUSICAL SYMBOL TROMIKON ARCHAION")
(118839 . "BYZANTINE MUSICAL SYMBOL KATAVA TROMIKON")
(118840 . "BYZANTINE MUSICAL SYMBOL PELASTON")
(118841 . "BYZANTINE MUSICAL SYMBOL PSIFISTON")
(118842 . "BYZANTINE MUSICAL SYMBOL KONTEVMA")
(118843 . "BYZANTINE MUSICAL SYMBOL CHOREVMA ARCHAION")
(118844 . "BYZANTINE MUSICAL SYMBOL RAPISMA")
(118845 . "BYZANTINE MUSICAL SYMBOL PARAKALESMA ARCHAION")
(118846 . "BYZANTINE MUSICAL SYMBOL PARAKLITIKI ARCHAION")
(118847 . "BYZANTINE MUSICAL SYMBOL ICHADIN")
(118848 . "BYZANTINE MUSICAL SYMBOL NANA")
(118849 . "BYZANTINE MUSICAL SYMBOL PETASMA")
(118850 . "BYZANTINE MUSICAL SYMBOL KONTEVMA ALLO")
(118851 . "BYZANTINE MUSICAL SYMBOL TROMIKON ALLO")
(118852 . "BYZANTINE MUSICAL SYMBOL STRAGGISMATA")
(118853 . "BYZANTINE MUSICAL SYMBOL GRONTHISMATA")
(118854 . "BYZANTINE MUSICAL SYMBOL ISON NEO")
(118855 . "BYZANTINE MUSICAL SYMBOL OLIGON NEO")
(118856 . "BYZANTINE MUSICAL SYMBOL OXEIA NEO")
(118857 . "BYZANTINE MUSICAL SYMBOL PETASTI")
(118858 . "BYZANTINE MUSICAL SYMBOL KOUFISMA")
(118859 . "BYZANTINE MUSICAL SYMBOL PETASTOKOUFISMA")
(118860 . "BYZANTINE MUSICAL SYMBOL KRATIMOKOUFISMA")
(118861 . "BYZANTINE MUSICAL SYMBOL PELASTON NEO")
(118862 . "BYZANTINE MUSICAL SYMBOL KENTIMATA NEO ANO")
(118863 . "BYZANTINE MUSICAL SYMBOL KENTIMA NEO ANO")
(118864 . "BYZANTINE MUSICAL SYMBOL YPSILI")
(118865 . "BYZANTINE MUSICAL SYMBOL APOSTROFOS NEO")
(118866 . "BYZANTINE MUSICAL SYMBOL APOSTROFOI SYNDESMOS NEO")
(118867 . "BYZANTINE MUSICAL SYMBOL YPORROI")
(118868 . "BYZANTINE MUSICAL SYMBOL KRATIMOYPORROON")
(118869 . "BYZANTINE MUSICAL SYMBOL ELAFRON")
(118870 . "BYZANTINE MUSICAL SYMBOL CHAMILI")
(118871 . "BYZANTINE MUSICAL SYMBOL MIKRON ISON")
(118872 . "BYZANTINE MUSICAL SYMBOL VAREIA NEO")
(118873 . "BYZANTINE MUSICAL SYMBOL PIASMA NEO")
(118874 . "BYZANTINE MUSICAL SYMBOL PSIFISTON NEO")
(118875 . "BYZANTINE MUSICAL SYMBOL OMALON")
(118876 . "BYZANTINE MUSICAL SYMBOL ANTIKENOMA")
(118877 . "BYZANTINE MUSICAL SYMBOL LYGISMA")
(118878 . "BYZANTINE MUSICAL SYMBOL PARAKLITIKI NEO")
(118879 . "BYZANTINE MUSICAL SYMBOL PARAKALESMA NEO")
(118880 . "BYZANTINE MUSICAL SYMBOL ETERON PARAKALESMA")
(118881 . "BYZANTINE MUSICAL SYMBOL KYLISMA")
(118882 . "BYZANTINE MUSICAL SYMBOL ANTIKENOKYLISMA")
(118883 . "BYZANTINE MUSICAL SYMBOL TROMIKON NEO")
(118884 . "BYZANTINE MUSICAL SYMBOL EKSTREPTON")
(118885 . "BYZANTINE MUSICAL SYMBOL SYNAGMA NEO")
(118886 . "BYZANTINE MUSICAL SYMBOL SYRMA")
(118887 . "BYZANTINE MUSICAL SYMBOL CHOREVMA NEO")
(118888 . "BYZANTINE MUSICAL SYMBOL EPEGERMA")
(118889 . "BYZANTINE MUSICAL SYMBOL SEISMA NEO")
(118890 . "BYZANTINE MUSICAL SYMBOL XIRON KLASMA")
(118891 . "BYZANTINE MUSICAL SYMBOL TROMIKOPSIFISTON")
(118892 . "BYZANTINE MUSICAL SYMBOL PSIFISTOLYGISMA")
(118893 . "BYZANTINE MUSICAL SYMBOL TROMIKOLYGISMA")
(118894 . "BYZANTINE MUSICAL SYMBOL TROMIKOPARAKALESMA")
(118895 . "BYZANTINE MUSICAL SYMBOL PSIFISTOPARAKALESMA")
(118896 . "BYZANTINE MUSICAL SYMBOL TROMIKOSYNAGMA")
(118897 . "BYZANTINE MUSICAL SYMBOL PSIFISTOSYNAGMA")
(118898 . "BYZANTINE MUSICAL SYMBOL GORGOSYNTHETON")
(118899 . "BYZANTINE MUSICAL SYMBOL ARGOSYNTHETON")
(118900 . "BYZANTINE MUSICAL SYMBOL ETERON ARGOSYNTHETON")
(118901 . "BYZANTINE MUSICAL SYMBOL OYRANISMA NEO")
(118902 . "BYZANTINE MUSICAL SYMBOL THEMATISMOS ESO")
(118903 . "BYZANTINE MUSICAL SYMBOL THEMATISMOS EXO")
(118904 . "BYZANTINE MUSICAL SYMBOL THEMA APLOUN")
(118905 . "BYZANTINE MUSICAL SYMBOL THES KAI APOTHES")
(118906 . "BYZANTINE MUSICAL SYMBOL KATAVASMA")
(118907 . "BYZANTINE MUSICAL SYMBOL ENDOFONON")
(118908 . "BYZANTINE MUSICAL SYMBOL YFEN KATO")
(118909 . "BYZANTINE MUSICAL SYMBOL YFEN ANO")
(118910 . "BYZANTINE MUSICAL SYMBOL STAVROS")
(118911 . "BYZANTINE MUSICAL SYMBOL KLASMA ANO")
(118912 . "BYZANTINE MUSICAL SYMBOL DIPLI ARCHAION")
(118913 . "BYZANTINE MUSICAL SYMBOL KRATIMA ARCHAION")
(118914 . "BYZANTINE MUSICAL SYMBOL KRATIMA ALLO")
(118915 . "BYZANTINE MUSICAL SYMBOL KRATIMA NEO")
(118916 . "BYZANTINE MUSICAL SYMBOL APODERMA NEO")
(118917 . "BYZANTINE MUSICAL SYMBOL APLI")
(118918 . "BYZANTINE MUSICAL SYMBOL DIPLI")
(118919 . "BYZANTINE MUSICAL SYMBOL TRIPLI")
(118920 . "BYZANTINE MUSICAL SYMBOL TETRAPLI")
(118921 . "BYZANTINE MUSICAL SYMBOL KORONIS")
(118922 . "BYZANTINE MUSICAL SYMBOL LEIMMA ENOS CHRONOU")
(118923 . "BYZANTINE MUSICAL SYMBOL LEIMMA DYO CHRONON")
(118924 . "BYZANTINE MUSICAL SYMBOL LEIMMA TRION CHRONON")
(118925 . "BYZANTINE MUSICAL SYMBOL LEIMMA TESSARON CHRONON")
(118926 . "BYZANTINE MUSICAL SYMBOL LEIMMA IMISEOS CHRONOU")
(118927 . "BYZANTINE MUSICAL SYMBOL GORGON NEO ANO")
(118928 . "BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON ARISTERA")
(118929 . "BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON DEXIA")
(118930 . "BYZANTINE MUSICAL SYMBOL DIGORGON")
(118931 . "BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA KATO")
(118932 . "BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA ANO")
(118933 . "BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON DEXIA")
(118934 . "BYZANTINE MUSICAL SYMBOL TRIGORGON")
(118935 . "BYZANTINE MUSICAL SYMBOL ARGON")
(118936 . "BYZANTINE MUSICAL SYMBOL IMIDIARGON")
(118937 . "BYZANTINE MUSICAL SYMBOL DIARGON")
(118938 . "BYZANTINE MUSICAL SYMBOL AGOGI POLI ARGI")
(118939 . "BYZANTINE MUSICAL SYMBOL AGOGI ARGOTERI")
(118940 . "BYZANTINE MUSICAL SYMBOL AGOGI ARGI")
(118941 . "BYZANTINE MUSICAL SYMBOL AGOGI METRIA")
(118942 . "BYZANTINE MUSICAL SYMBOL AGOGI MESI")
(118943 . "BYZANTINE MUSICAL SYMBOL AGOGI GORGI")
(118944 . "BYZANTINE MUSICAL SYMBOL AGOGI GORGOTERI")
(118945 . "BYZANTINE MUSICAL SYMBOL AGOGI POLI GORGI")
(118946 . "BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOS ICHOS")
(118947 . "BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI PROTOS ICHOS")
(118948 . "BYZANTINE MUSICAL SYMBOL MARTYRIA DEYTEROS ICHOS")
(118949 . "BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI DEYTEROS ICHOS")
(118950 . "BYZANTINE MUSICAL SYMBOL MARTYRIA TRITOS ICHOS")
(118951 . "BYZANTINE MUSICAL SYMBOL MARTYRIA TRIFONIAS")
(118952 . "BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS ICHOS")
(118953 . "BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS LEGETOS ICHOS")
(118954 . "BYZANTINE MUSICAL SYMBOL MARTYRIA LEGETOS ICHOS")
(118955 . "BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS ICHOS")
(118956 . "BYZANTINE MUSICAL SYMBOL ISAKIA TELOUS ICHIMATOS")
(118957 . "BYZANTINE MUSICAL SYMBOL APOSTROFOI TELOUS ICHIMATOS")
(118958 . "BYZANTINE MUSICAL SYMBOL FANEROSIS TETRAFONIAS")
(118959 . "BYZANTINE MUSICAL SYMBOL FANEROSIS MONOFONIAS")
(118960 . "BYZANTINE MUSICAL SYMBOL FANEROSIS DIFONIAS")
(118961 . "BYZANTINE MUSICAL SYMBOL MARTYRIA VARYS ICHOS")
(118962 . "BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOVARYS ICHOS")
(118963 . "BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS TETARTOS ICHOS")
(118964 . "BYZANTINE MUSICAL SYMBOL GORTHMIKON N APLOUN")
(118965 . "BYZANTINE MUSICAL SYMBOL GORTHMIKON N DIPLOUN")
(118966 . "BYZANTINE MUSICAL SYMBOL ENARXIS KAI FTHORA VOU")
(118967 . "BYZANTINE MUSICAL SYMBOL IMIFONON")
(118968 . "BYZANTINE MUSICAL SYMBOL IMIFTHORON")
(118969 . "BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION DEYTEROU ICHOU")
(118970 . "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI PA")
(118971 . "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NANA")
(118972 . "BYZANTINE MUSICAL SYMBOL FTHORA NAOS ICHOS")
(118973 . "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI DI")
(118974 . "BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON DIATONON DI")
(118975 . "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI KE")
(118976 . "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI ZO")
(118977 . "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI KATO")
(118978 . "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI ANO")
(118979 . "BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA DIFONIAS")
(118980 . "BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA MONOFONIAS")
(118981 . "BYZANTINE MUSICAL SYMBOL FHTORA SKLIRON CHROMA VASIS")
(118982 . "BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON CHROMA SYNAFI")
(118983 . "BYZANTINE MUSICAL SYMBOL FTHORA NENANO")
(118984 . "BYZANTINE MUSICAL SYMBOL CHROA ZYGOS")
(118985 . "BYZANTINE MUSICAL SYMBOL CHROA KLITON")
(118986 . "BYZANTINE MUSICAL SYMBOL CHROA SPATHI")
(118987 . "BYZANTINE MUSICAL SYMBOL FTHORA I YFESIS TETARTIMORION")
(118988 . "BYZANTINE MUSICAL SYMBOL FTHORA ENARMONIOS ANTIFONIA")
(118989 . "BYZANTINE MUSICAL SYMBOL YFESIS TRITIMORION")
(118990 . "BYZANTINE MUSICAL SYMBOL DIESIS TRITIMORION")
(118991 . "BYZANTINE MUSICAL SYMBOL DIESIS TETARTIMORION")
(118992 . "BYZANTINE MUSICAL SYMBOL DIESIS APLI DYO DODEKATA")
(118993 . "BYZANTINE MUSICAL SYMBOL DIESIS MONOGRAMMOS TESSERA DODEKATA")
(118994 . "BYZANTINE MUSICAL SYMBOL DIESIS DIGRAMMOS EX DODEKATA")
(118995 . "BYZANTINE MUSICAL SYMBOL DIESIS TRIGRAMMOS OKTO DODEKATA")
(118996 . "BYZANTINE MUSICAL SYMBOL YFESIS APLI DYO DODEKATA")
(118997 . "BYZANTINE MUSICAL SYMBOL YFESIS MONOGRAMMOS TESSERA DODEKATA")
(118998 . "BYZANTINE MUSICAL SYMBOL YFESIS DIGRAMMOS EX DODEKATA")
(118999 . "BYZANTINE MUSICAL SYMBOL YFESIS TRIGRAMMOS OKTO DODEKATA")
(119000 . "BYZANTINE MUSICAL SYMBOL GENIKI DIESIS")
(119001 . "BYZANTINE MUSICAL SYMBOL GENIKI YFESIS")
(119002 . "BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MIKRI")
(119003 . "BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MEGALI")
(119004 . "BYZANTINE MUSICAL SYMBOL DIASTOLI DIPLI")
(119005 . "BYZANTINE MUSICAL SYMBOL DIASTOLI THESEOS")
(119006 . "BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS")
(119007 . "BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS DISIMOU")
(119008 . "BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TRISIMOU")
(119009 . "BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TETRASIMOU")
(119010 . "BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS")
(119011 . "BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS DISIMOU")
(119012 . "BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TRISIMOU")
(119013 . "BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TETRASIMOU")
(119014 . "BYZANTINE MUSICAL SYMBOL DIGRAMMA GG")
(119015 . "BYZANTINE MUSICAL SYMBOL DIFTOGGOS OU")
(119016 . "BYZANTINE MUSICAL SYMBOL STIGMA")
(119017 . "BYZANTINE MUSICAL SYMBOL ARKTIKO PA")
(119018 . "BYZANTINE MUSICAL SYMBOL ARKTIKO VOU")
(119019 . "BYZANTINE MUSICAL SYMBOL ARKTIKO GA")
(119020 . "BYZANTINE MUSICAL SYMBOL ARKTIKO DI")
(119021 . "BYZANTINE MUSICAL SYMBOL ARKTIKO KE")
(119022 . "BYZANTINE MUSICAL SYMBOL ARKTIKO ZO")
(119023 . "BYZANTINE MUSICAL SYMBOL ARKTIKO NI")
(119024 . "BYZANTINE MUSICAL SYMBOL KENTIMATA NEO MESO")
(119025 . "BYZANTINE MUSICAL SYMBOL KENTIMA NEO MESO")
(119026 . "BYZANTINE MUSICAL SYMBOL KENTIMATA NEO KATO")
(119027 . "BYZANTINE MUSICAL SYMBOL KENTIMA NEO KATO")
(119028 . "BYZANTINE MUSICAL SYMBOL KLASMA KATO")
(119029 . "BYZANTINE MUSICAL SYMBOL GORGON NEO KATO")
((119030 . 119040) . #f)
(119040 . "MUSICAL SYMBOL SINGLE BARLINE")
(119041 . "MUSICAL SYMBOL DOUBLE BARLINE")
(119042 . "MUSICAL SYMBOL FINAL BARLINE")
(119043 . "MUSICAL SYMBOL REVERSE FINAL BARLINE")
(119044 . "MUSICAL SYMBOL DASHED BARLINE")
(119045 . "MUSICAL SYMBOL SHORT BARLINE")
(119046 . "MUSICAL SYMBOL LEFT REPEAT SIGN")
(119047 . "MUSICAL SYMBOL RIGHT REPEAT SIGN")
(119048 . "MUSICAL SYMBOL REPEAT DOTS")
(119049 . "MUSICAL SYMBOL DAL SEGNO")
(119050 . "MUSICAL SYMBOL DA CAPO")
(119051 . "MUSICAL SYMBOL SEGNO")
(119052 . "MUSICAL SYMBOL CODA")
(119053 . "MUSICAL SYMBOL REPEATED FIGURE-1")
(119054 . "MUSICAL SYMBOL REPEATED FIGURE-2")
(119055 . "MUSICAL SYMBOL REPEATED FIGURE-3")
(119056 . "MUSICAL SYMBOL FERMATA")
(119057 . "MUSICAL SYMBOL FERMATA BELOW")
(119058 . "MUSICAL SYMBOL BREATH MARK")
(119059 . "MUSICAL SYMBOL CAESURA")
(119060 . "MUSICAL SYMBOL BRACE")
(119061 . "MUSICAL SYMBOL BRACKET")
(119062 . "MUSICAL SYMBOL ONE-LINE STAFF")
(119063 . "MUSICAL SYMBOL TWO-LINE STAFF")
(119064 . "MUSICAL SYMBOL THREE-LINE STAFF")
(119065 . "MUSICAL SYMBOL FOUR-LINE STAFF")
(119066 . "MUSICAL SYMBOL FIVE-LINE STAFF")
(119067 . "MUSICAL SYMBOL SIX-LINE STAFF")
(119068 . "MUSICAL SYMBOL SIX-STRING FRETBOARD")
(119069 . "MUSICAL SYMBOL FOUR-STRING FRETBOARD")
(119070 . "MUSICAL SYMBOL G CLEF")
(119071 . "MUSICAL SYMBOL G CLEF OTTAVA ALTA")
(119072 . "MUSICAL SYMBOL G CLEF OTTAVA BASSA")
(119073 . "MUSICAL SYMBOL C CLEF")
(119074 . "MUSICAL SYMBOL F CLEF")
(119075 . "MUSICAL SYMBOL F CLEF OTTAVA ALTA")
(119076 . "MUSICAL SYMBOL F CLEF OTTAVA BASSA")
(119077 . "MUSICAL SYMBOL DRUM CLEF-1")
(119078 . "MUSICAL SYMBOL DRUM CLEF-2")
((119079 . 119081) . #f)
(119081 . "MUSICAL SYMBOL MULTIPLE MEASURE REST")
(119082 . "MUSICAL SYMBOL DOUBLE SHARP")
(119083 . "MUSICAL SYMBOL DOUBLE FLAT")
(119084 . "MUSICAL SYMBOL FLAT UP")
(119085 . "MUSICAL SYMBOL FLAT DOWN")
(119086 . "MUSICAL SYMBOL NATURAL UP")
(119087 . "MUSICAL SYMBOL NATURAL DOWN")
(119088 . "MUSICAL SYMBOL SHARP UP")
(119089 . "MUSICAL SYMBOL SHARP DOWN")
(119090 . "MUSICAL SYMBOL QUARTER TONE SHARP")
(119091 . "MUSICAL SYMBOL QUARTER TONE FLAT")
(119092 . "MUSICAL SYMBOL COMMON TIME")
(119093 . "MUSICAL SYMBOL CUT TIME")
(119094 . "MUSICAL SYMBOL OTTAVA ALTA")
(119095 . "MUSICAL SYMBOL OTTAVA BASSA")
(119096 . "MUSICAL SYMBOL QUINDICESIMA ALTA")
(119097 . "MUSICAL SYMBOL QUINDICESIMA BASSA")
(119098 . "MUSICAL SYMBOL MULTI REST")
(119099 . "MUSICAL SYMBOL WHOLE REST")
(119100 . "MUSICAL SYMBOL HALF REST")
(119101 . "MUSICAL SYMBOL QUARTER REST")
(119102 . "MUSICAL SYMBOL EIGHTH REST")
(119103 . "MUSICAL SYMBOL SIXTEENTH REST")
(119104 . "MUSICAL SYMBOL THIRTY-SECOND REST")
(119105 . "MUSICAL SYMBOL SIXTY-FOURTH REST")
(119106 . "MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH REST")
(119107 . "MUSICAL SYMBOL X NOTEHEAD")
(119108 . "MUSICAL SYMBOL PLUS NOTEHEAD")
(119109 . "MUSICAL SYMBOL CIRCLE X NOTEHEAD")
(119110 . "MUSICAL SYMBOL SQUARE NOTEHEAD WHITE")
(119111 . "MUSICAL SYMBOL SQUARE NOTEHEAD BLACK")
(119112 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD UP WHITE")
(119113 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD UP BLACK")
(119114 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT WHITE")
(119115 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT BLACK")
(119116 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT WHITE")
(119117 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT BLACK")
(119118 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN WHITE")
(119119 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN BLACK")
(119120 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT WHITE")
(119121 . "MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT BLACK")
(119122 . "MUSICAL SYMBOL MOON NOTEHEAD WHITE")
(119123 . "MUSICAL SYMBOL MOON NOTEHEAD BLACK")
(119124 . "MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN WHITE")
(119125 . "MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN BLACK")
(119126 . "MUSICAL SYMBOL PARENTHESIS NOTEHEAD")
(119127 . "MUSICAL SYMBOL VOID NOTEHEAD")
(119128 . "MUSICAL SYMBOL NOTEHEAD BLACK")
(119129 . "MUSICAL SYMBOL NULL NOTEHEAD")
(119130 . "MUSICAL SYMBOL CLUSTER NOTEHEAD WHITE")
(119131 . "MUSICAL SYMBOL CLUSTER NOTEHEAD BLACK")
(119132 . "MUSICAL SYMBOL BREVE")
(119133 . "MUSICAL SYMBOL WHOLE NOTE")
(119134 . "MUSICAL SYMBOL HALF NOTE")
(119135 . "MUSICAL SYMBOL QUARTER NOTE")
(119136 . "MUSICAL SYMBOL EIGHTH NOTE")
(119137 . "MUSICAL SYMBOL SIXTEENTH NOTE")
(119138 . "MUSICAL SYMBOL THIRTY-SECOND NOTE")
(119139 . "MUSICAL SYMBOL SIXTY-FOURTH NOTE")
(119140 . "MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH NOTE")
(119141 . "MUSICAL SYMBOL COMBINING STEM")
(119142 . "MUSICAL SYMBOL COMBINING SPRECHGESANG STEM")
(119143 . "MUSICAL SYMBOL COMBINING TREMOLO-1")
(119144 . "MUSICAL SYMBOL COMBINING TREMOLO-2")
(119145 . "MUSICAL SYMBOL COMBINING TREMOLO-3")
(119146 . "MUSICAL SYMBOL FINGERED TREMOLO-1")
(119147 . "MUSICAL SYMBOL FINGERED TREMOLO-2")
(119148 . "MUSICAL SYMBOL FINGERED TREMOLO-3")
(119149 . "MUSICAL SYMBOL COMBINING AUGMENTATION DOT")
(119150 . "MUSICAL SYMBOL COMBINING FLAG-1")
(119151 . "MUSICAL SYMBOL COMBINING FLAG-2")
(119152 . "MUSICAL SYMBOL COMBINING FLAG-3")
(119153 . "MUSICAL SYMBOL COMBINING FLAG-4")
(119154 . "MUSICAL SYMBOL COMBINING FLAG-5")
(119155 . "MUSICAL SYMBOL BEGIN BEAM")
(119156 . "MUSICAL SYMBOL END BEAM")
(119157 . "MUSICAL SYMBOL BEGIN TIE")
(119158 . "MUSICAL SYMBOL END TIE")
(119159 . "MUSICAL SYMBOL BEGIN SLUR")
(119160 . "MUSICAL SYMBOL END SLUR")
(119161 . "MUSICAL SYMBOL BEGIN PHRASE")
(119162 . "MUSICAL SYMBOL END PHRASE")
(119163 . "MUSICAL SYMBOL COMBINING ACCENT")
(119164 . "MUSICAL SYMBOL COMBINING STACCATO")
(119165 . "MUSICAL SYMBOL COMBINING TENUTO")
(119166 . "MUSICAL SYMBOL COMBINING STACCATISSIMO")
(119167 . "MUSICAL SYMBOL COMBINING MARCATO")
(119168 . "MUSICAL SYMBOL COMBINING MARCATO-STACCATO")
(119169 . "MUSICAL SYMBOL COMBINING ACCENT-STACCATO")
(119170 . "MUSICAL SYMBOL COMBINING LOURE")
(119171 . "MUSICAL SYMBOL ARPEGGIATO UP")
(119172 . "MUSICAL SYMBOL ARPEGGIATO DOWN")
(119173 . "MUSICAL SYMBOL COMBINING DOIT")
(119174 . "MUSICAL SYMBOL COMBINING RIP")
(119175 . "MUSICAL SYMBOL COMBINING FLIP")
(119176 . "MUSICAL SYMBOL COMBINING SMEAR")
(119177 . "MUSICAL SYMBOL COMBINING BEND")
(119178 . "MUSICAL SYMBOL COMBINING DOUBLE TONGUE")
(119179 . "MUSICAL SYMBOL COMBINING TRIPLE TONGUE")
(119180 . "MUSICAL SYMBOL RINFORZANDO")
(119181 . "MUSICAL SYMBOL SUBITO")
(119182 . "MUSICAL SYMBOL Z")
(119183 . "MUSICAL SYMBOL PIANO")
(119184 . "MUSICAL SYMBOL MEZZO")
(119185 . "MUSICAL SYMBOL FORTE")
(119186 . "MUSICAL SYMBOL CRESCENDO")
(119187 . "MUSICAL SYMBOL DECRESCENDO")
(119188 . "MUSICAL SYMBOL GRACE NOTE SLASH")
(119189 . "MUSICAL SYMBOL GRACE NOTE NO SLASH")
(119190 . "MUSICAL SYMBOL TR")
(119191 . "MUSICAL SYMBOL TURN")
(119192 . "MUSICAL SYMBOL INVERTED TURN")
(119193 . "MUSICAL SYMBOL TURN SLASH")
(119194 . "MUSICAL SYMBOL TURN UP")
(119195 . "MUSICAL SYMBOL ORNAMENT STROKE-1")
(119196 . "MUSICAL SYMBOL ORNAMENT STROKE-2")
(119197 . "MUSICAL SYMBOL ORNAMENT STROKE-3")
(119198 . "MUSICAL SYMBOL ORNAMENT STROKE-4")
(119199 . "MUSICAL SYMBOL ORNAMENT STROKE-5")
(119200 . "MUSICAL SYMBOL ORNAMENT STROKE-6")
(119201 . "MUSICAL SYMBOL ORNAMENT STROKE-7")
(119202 . "MUSICAL SYMBOL ORNAMENT STROKE-8")
(119203 . "MUSICAL SYMBOL ORNAMENT STROKE-9")
(119204 . "MUSICAL SYMBOL ORNAMENT STROKE-10")
(119205 . "MUSICAL SYMBOL ORNAMENT STROKE-11")
(119206 . "MUSICAL SYMBOL HAUPTSTIMME")
(119207 . "MUSICAL SYMBOL NEBENSTIMME")
(119208 . "MUSICAL SYMBOL END OF STIMME")
(119209 . "MUSICAL SYMBOL DEGREE SLASH")
(119210 . "MUSICAL SYMBOL COMBINING DOWN BOW")
(119211 . "MUSICAL SYMBOL COMBINING UP BOW")
(119212 . "MUSICAL SYMBOL COMBINING HARMONIC")
(119213 . "MUSICAL SYMBOL COMBINING SNAP PIZZICATO")
(119214 . "MUSICAL SYMBOL PEDAL MARK")
(119215 . "MUSICAL SYMBOL PEDAL UP MARK")
(119216 . "MUSICAL SYMBOL HALF PEDAL MARK")
(119217 . "MUSICAL SYMBOL GLISSANDO UP")
(119218 . "MUSICAL SYMBOL GLISSANDO DOWN")
(119219 . "MUSICAL SYMBOL WITH FINGERNAILS")
(119220 . "MUSICAL SYMBOL DAMP")
(119221 . "MUSICAL SYMBOL DAMP ALL")
(119222 . "MUSICAL SYMBOL MAXIMA")
(119223 . "MUSICAL SYMBOL LONGA")
(119224 . "MUSICAL SYMBOL BREVIS")
(119225 . "MUSICAL SYMBOL SEMIBREVIS WHITE")
(119226 . "MUSICAL SYMBOL SEMIBREVIS BLACK")
(119227 . "MUSICAL SYMBOL MINIMA")
(119228 . "MUSICAL SYMBOL MINIMA BLACK")
(119229 . "MUSICAL SYMBOL SEMIMINIMA WHITE")
(119230 . "MUSICAL SYMBOL SEMIMINIMA BLACK")
(119231 . "MUSICAL SYMBOL FUSA WHITE")
(119232 . "MUSICAL SYMBOL FUSA BLACK")
(119233 . "MUSICAL SYMBOL LONGA PERFECTA REST")
(119234 . "MUSICAL SYMBOL LONGA IMPERFECTA REST")
(119235 . "MUSICAL SYMBOL BREVIS REST")
(119236 . "MUSICAL SYMBOL SEMIBREVIS REST")
(119237 . "MUSICAL SYMBOL MINIMA REST")
(119238 . "MUSICAL SYMBOL SEMIMINIMA REST")
(119239 . "MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA")
(119240 . "MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE IMPERFECTA")
(119241 . "MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA DIMINUTION-1")
(119242 . "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE PERFECTA")
(119243 . "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA")
(119244 . "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-1")
(119245 . "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-2")
(119246 . "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-3")
(119247 . "MUSICAL SYMBOL CROIX")
(119248 . "MUSICAL SYMBOL GREGORIAN C CLEF")
(119249 . "MUSICAL SYMBOL GREGORIAN F CLEF")
(119250 . "MUSICAL SYMBOL SQUARE B")
(119251 . "MUSICAL SYMBOL VIRGA")
(119252 . "MUSICAL SYMBOL PODATUS")
(119253 . "MUSICAL SYMBOL CLIVIS")
(119254 . "MUSICAL SYMBOL SCANDICUS")
(119255 . "MUSICAL SYMBOL CLIMACUS")
(119256 . "MUSICAL SYMBOL TORCULUS")
(119257 . "MUSICAL SYMBOL PORRECTUS")
(119258 . "MUSICAL SYMBOL PORRECTUS FLEXUS")
(119259 . "MUSICAL SYMBOL SCANDICUS FLEXUS")
(119260 . "MUSICAL SYMBOL TORCULUS RESUPINUS")
(119261 . "MUSICAL SYMBOL PES SUBPUNCTIS")
(119262 . "MUSICAL SYMBOL KIEVAN C CLEF")
(119263 . "MUSICAL SYMBOL KIEVAN END OF PIECE")
(119264 . "MUSICAL SYMBOL KIEVAN FINAL NOTE")
(119265 . "MUSICAL SYMBOL KIEVAN RECITATIVE MARK")
(119266 . "MUSICAL SYMBOL KIEVAN WHOLE NOTE")
(119267 . "MUSICAL SYMBOL KIEVAN HALF NOTE")
(119268 . "MUSICAL SYMBOL KIEVAN QUARTER NOTE STEM DOWN")
(119269 . "MUSICAL SYMBOL KIEVAN QUARTER NOTE STEM UP")
(119270 . "MUSICAL SYMBOL KIEVAN EIGHTH NOTE STEM DOWN")
(119271 . "MUSICAL SYMBOL KIEVAN EIGHTH NOTE STEM UP")
(119272 . "MUSICAL SYMBOL KIEVAN FLAT SIGN")
((119273 . 119296) . #f)
(119296 . "GREEK VOCAL NOTATION SYMBOL-1")
(119297 . "GREEK VOCAL NOTATION SYMBOL-2")
(119298 . "GREEK VOCAL NOTATION SYMBOL-3")
(119299 . "GREEK VOCAL NOTATION SYMBOL-4")
(119300 . "GREEK VOCAL NOTATION SYMBOL-5")
(119301 . "GREEK VOCAL NOTATION SYMBOL-6")
(119302 . "GREEK VOCAL NOTATION SYMBOL-7")
(119303 . "GREEK VOCAL NOTATION SYMBOL-8")
(119304 . "GREEK VOCAL NOTATION SYMBOL-9")
(119305 . "GREEK VOCAL NOTATION SYMBOL-10")
(119306 . "GREEK VOCAL NOTATION SYMBOL-11")
(119307 . "GREEK VOCAL NOTATION SYMBOL-12")
(119308 . "GREEK VOCAL NOTATION SYMBOL-13")
(119309 . "GREEK VOCAL NOTATION SYMBOL-14")
(119310 . "GREEK VOCAL NOTATION SYMBOL-15")
(119311 . "GREEK VOCAL NOTATION SYMBOL-16")
(119312 . "GREEK VOCAL NOTATION SYMBOL-17")
(119313 . "GREEK VOCAL NOTATION SYMBOL-18")
(119314 . "GREEK VOCAL NOTATION SYMBOL-19")
(119315 . "GREEK VOCAL NOTATION SYMBOL-20")
(119316 . "GREEK VOCAL NOTATION SYMBOL-21")
(119317 . "GREEK VOCAL NOTATION SYMBOL-22")
(119318 . "GREEK VOCAL NOTATION SYMBOL-23")
(119319 . "GREEK VOCAL NOTATION SYMBOL-24")
(119320 . "GREEK VOCAL NOTATION SYMBOL-50")
(119321 . "GREEK VOCAL NOTATION SYMBOL-51")
(119322 . "GREEK VOCAL NOTATION SYMBOL-52")
(119323 . "GREEK VOCAL NOTATION SYMBOL-53")
(119324 . "GREEK VOCAL NOTATION SYMBOL-54")
(119325 . "GREEK INSTRUMENTAL NOTATION SYMBOL-1")
(119326 . "GREEK INSTRUMENTAL NOTATION SYMBOL-2")
(119327 . "GREEK INSTRUMENTAL NOTATION SYMBOL-4")
(119328 . "GREEK INSTRUMENTAL NOTATION SYMBOL-5")
(119329 . "GREEK INSTRUMENTAL NOTATION SYMBOL-7")
(119330 . "GREEK INSTRUMENTAL NOTATION SYMBOL-8")
(119331 . "GREEK INSTRUMENTAL NOTATION SYMBOL-11")
(119332 . "GREEK INSTRUMENTAL NOTATION SYMBOL-12")
(119333 . "GREEK INSTRUMENTAL NOTATION SYMBOL-13")
(119334 . "GREEK INSTRUMENTAL NOTATION SYMBOL-14")
(119335 . "GREEK INSTRUMENTAL NOTATION SYMBOL-17")
(119336 . "GREEK INSTRUMENTAL NOTATION SYMBOL-18")
(119337 . "GREEK INSTRUMENTAL NOTATION SYMBOL-19")
(119338 . "GREEK INSTRUMENTAL NOTATION SYMBOL-23")
(119339 . "GREEK INSTRUMENTAL NOTATION SYMBOL-24")
(119340 . "GREEK INSTRUMENTAL NOTATION SYMBOL-25")
(119341 . "GREEK INSTRUMENTAL NOTATION SYMBOL-26")
(119342 . "GREEK INSTRUMENTAL NOTATION SYMBOL-27")
(119343 . "GREEK INSTRUMENTAL NOTATION SYMBOL-29")
(119344 . "GREEK INSTRUMENTAL NOTATION SYMBOL-30")
(119345 . "GREEK INSTRUMENTAL NOTATION SYMBOL-32")
(119346 . "GREEK INSTRUMENTAL NOTATION SYMBOL-36")
(119347 . "GREEK INSTRUMENTAL NOTATION SYMBOL-37")
(119348 . "GREEK INSTRUMENTAL NOTATION SYMBOL-38")
(119349 . "GREEK INSTRUMENTAL NOTATION SYMBOL-39")
(119350 . "GREEK INSTRUMENTAL NOTATION SYMBOL-40")
(119351 . "GREEK INSTRUMENTAL NOTATION SYMBOL-42")
(119352 . "GREEK INSTRUMENTAL NOTATION SYMBOL-43")
(119353 . "GREEK INSTRUMENTAL NOTATION SYMBOL-45")
(119354 . "GREEK INSTRUMENTAL NOTATION SYMBOL-47")
(119355 . "GREEK INSTRUMENTAL NOTATION SYMBOL-48")
(119356 . "GREEK INSTRUMENTAL NOTATION SYMBOL-49")
(119357 . "GREEK INSTRUMENTAL NOTATION SYMBOL-50")
(119358 . "GREEK INSTRUMENTAL NOTATION SYMBOL-51")
(119359 . "GREEK INSTRUMENTAL NOTATION SYMBOL-52")
(119360 . "GREEK INSTRUMENTAL NOTATION SYMBOL-53")
(119361 . "GREEK INSTRUMENTAL NOTATION SYMBOL-54")
(119362 . "COMBINING GREEK MUSICAL TRISEME")
(119363 . "COMBINING GREEK MUSICAL TETRASEME")
(119364 . "COMBINING GREEK MUSICAL PENTASEME")
(119365 . "GREEK MUSICAL LEIMMA")
((119366 . 119552) . #f)
(119552 . "MONOGRAM FOR EARTH")
(119553 . "DIGRAM FOR HEAVENLY EARTH")
(119554 . "DIGRAM FOR HUMAN EARTH")
(119555 . "DIGRAM FOR EARTHLY HEAVEN")
(119556 . "DIGRAM FOR EARTHLY HUMAN")
(119557 . "DIGRAM FOR EARTH")
(119558 . "TETRAGRAM FOR CENTRE")
(119559 . "TETRAGRAM FOR FULL CIRCLE")
(119560 . "TETRAGRAM FOR MIRED")
(119561 . "TETRAGRAM FOR BARRIER")
(119562 . "TETRAGRAM FOR KEEPING SMALL")
(119563 . "TETRAGRAM FOR CONTRARIETY")
(119564 . "TETRAGRAM FOR ASCENT")
(119565 . "TETRAGRAM FOR OPPOSITION")
(119566 . "TETRAGRAM FOR BRANCHING OUT")
(119567 . "TETRAGRAM FOR DEFECTIVENESS OR DISTORTION")
(119568 . "TETRAGRAM FOR DIVERGENCE")
(119569 . "TETRAGRAM FOR YOUTHFULNESS")
(119570 . "TETRAGRAM FOR INCREASE")
(119571 . "TETRAGRAM FOR PENETRATION")
(119572 . "TETRAGRAM FOR REACH")
(119573 . "TETRAGRAM FOR CONTACT")
(119574 . "TETRAGRAM FOR HOLDING BACK")
(119575 . "TETRAGRAM FOR WAITING")
(119576 . "TETRAGRAM FOR FOLLOWING")
(119577 . "TETRAGRAM FOR ADVANCE")
(119578 . "TETRAGRAM FOR RELEASE")
(119579 . "TETRAGRAM FOR RESISTANCE")
(119580 . "TETRAGRAM FOR EASE")
(119581 . "TETRAGRAM FOR JOY")
(119582 . "TETRAGRAM FOR CONTENTION")
(119583 . "TETRAGRAM FOR ENDEAVOUR")
(119584 . "TETRAGRAM FOR DUTIES")
(119585 . "TETRAGRAM FOR CHANGE")
(119586 . "TETRAGRAM FOR DECISIVENESS")
(119587 . "TETRAGRAM FOR BOLD RESOLUTION")
(119588 . "TETRAGRAM FOR PACKING")
(119589 . "TETRAGRAM FOR LEGION")
(119590 . "TETRAGRAM FOR CLOSENESS")
(119591 . "TETRAGRAM FOR KINSHIP")
(119592 . "TETRAGRAM FOR GATHERING")
(119593 . "TETRAGRAM FOR STRENGTH")
(119594 . "TETRAGRAM FOR PURITY")
(119595 . "TETRAGRAM FOR FULLNESS")
(119596 . "TETRAGRAM FOR RESIDENCE")
(119597 . "TETRAGRAM FOR LAW OR MODEL")
(119598 . "TETRAGRAM FOR RESPONSE")
(119599 . "TETRAGRAM FOR GOING TO MEET")
(119600 . "TETRAGRAM FOR ENCOUNTERS")
(119601 . "TETRAGRAM FOR STOVE")
(119602 . "TETRAGRAM FOR GREATNESS")
(119603 . "TETRAGRAM FOR ENLARGEMENT")
(119604 . "TETRAGRAM FOR PATTERN")
(119605 . "TETRAGRAM FOR RITUAL")
(119606 . "TETRAGRAM FOR FLIGHT")
(119607 . "TETRAGRAM FOR VASTNESS OR WASTING")
(119608 . "TETRAGRAM FOR CONSTANCY")
(119609 . "TETRAGRAM FOR MEASURE")
(119610 . "TETRAGRAM FOR ETERNITY")
(119611 . "TETRAGRAM FOR UNITY")
(119612 . "TETRAGRAM FOR DIMINISHMENT")
(119613 . "TETRAGRAM FOR CLOSED MOUTH")
(119614 . "TETRAGRAM FOR GUARDEDNESS")
(119615 . "TETRAGRAM FOR GATHERING IN")
(119616 . "TETRAGRAM FOR MASSING")
(119617 . "TETRAGRAM FOR ACCUMULATION")
(119618 . "TETRAGRAM FOR EMBELLISHMENT")
(119619 . "TETRAGRAM FOR DOUBT")
(119620 . "TETRAGRAM FOR WATCH")
(119621 . "TETRAGRAM FOR SINKING")
(119622 . "TETRAGRAM FOR INNER")
(119623 . "TETRAGRAM FOR DEPARTURE")
(119624 . "TETRAGRAM FOR DARKENING")
(119625 . "TETRAGRAM FOR DIMMING")
(119626 . "TETRAGRAM FOR EXHAUSTION")
(119627 . "TETRAGRAM FOR SEVERANCE")
(119628 . "TETRAGRAM FOR STOPPAGE")
(119629 . "TETRAGRAM FOR HARDNESS")
(119630 . "TETRAGRAM FOR COMPLETION")
(119631 . "TETRAGRAM FOR CLOSURE")
(119632 . "TETRAGRAM FOR FAILURE")
(119633 . "TETRAGRAM FOR AGGRAVATION")
(119634 . "TETRAGRAM FOR COMPLIANCE")
(119635 . "TETRAGRAM FOR ON THE VERGE")
(119636 . "TETRAGRAM FOR DIFFICULTIES")
(119637 . "TETRAGRAM FOR LABOURING")
(119638 . "TETRAGRAM FOR FOSTERING")
((119639 . 119648) . #f)
(119648 . "COUNTING ROD UNIT DIGIT ONE")
(119649 . "COUNTING ROD UNIT DIGIT TWO")
(119650 . "COUNTING ROD UNIT DIGIT THREE")
(119651 . "COUNTING ROD UNIT DIGIT FOUR")
(119652 . "COUNTING ROD UNIT DIGIT FIVE")
(119653 . "COUNTING ROD UNIT DIGIT SIX")
(119654 . "COUNTING ROD UNIT DIGIT SEVEN")
(119655 . "COUNTING ROD UNIT DIGIT EIGHT")
(119656 . "COUNTING ROD UNIT DIGIT NINE")
(119657 . "COUNTING ROD TENS DIGIT ONE")
(119658 . "COUNTING ROD TENS DIGIT TWO")
(119659 . "COUNTING ROD TENS DIGIT THREE")
(119660 . "COUNTING ROD TENS DIGIT FOUR")
(119661 . "COUNTING ROD TENS DIGIT FIVE")
(119662 . "COUNTING ROD TENS DIGIT SIX")
(119663 . "COUNTING ROD TENS DIGIT SEVEN")
(119664 . "COUNTING ROD TENS DIGIT EIGHT")
(119665 . "COUNTING ROD TENS DIGIT NINE")
((119666 . 119808) . #f)
(119808 . "MATHEMATICAL BOLD CAPITAL A")
(119809 . "MATHEMATICAL BOLD CAPITAL B")
(119810 . "MATHEMATICAL BOLD CAPITAL C")
(119811 . "MATHEMATICAL BOLD CAPITAL D")
(119812 . "MATHEMATICAL BOLD CAPITAL E")
(119813 . "MATHEMATICAL BOLD CAPITAL F")
(119814 . "MATHEMATICAL BOLD CAPITAL G")
(119815 . "MATHEMATICAL BOLD CAPITAL H")
(119816 . "MATHEMATICAL BOLD CAPITAL I")
(119817 . "MATHEMATICAL BOLD CAPITAL J")
(119818 . "MATHEMATICAL BOLD CAPITAL K")
(119819 . "MATHEMATICAL BOLD CAPITAL L")
(119820 . "MATHEMATICAL BOLD CAPITAL M")
(119821 . "MATHEMATICAL BOLD CAPITAL N")
(119822 . "MATHEMATICAL BOLD CAPITAL O")
(119823 . "MATHEMATICAL BOLD CAPITAL P")
(119824 . "MATHEMATICAL BOLD CAPITAL Q")
(119825 . "MATHEMATICAL BOLD CAPITAL R")
(119826 . "MATHEMATICAL BOLD CAPITAL S")
(119827 . "MATHEMATICAL BOLD CAPITAL T")
(119828 . "MATHEMATICAL BOLD CAPITAL U")
(119829 . "MATHEMATICAL BOLD CAPITAL V")
(119830 . "MATHEMATICAL BOLD CAPITAL W")
(119831 . "MATHEMATICAL BOLD CAPITAL X")
(119832 . "MATHEMATICAL BOLD CAPITAL Y")
(119833 . "MATHEMATICAL BOLD CAPITAL Z")
(119834 . "MATHEMATICAL BOLD SMALL A")
(119835 . "MATHEMATICAL BOLD SMALL B")
(119836 . "MATHEMATICAL BOLD SMALL C")
(119837 . "MATHEMATICAL BOLD SMALL D")
(119838 . "MATHEMATICAL BOLD SMALL E")
(119839 . "MATHEMATICAL BOLD SMALL F")
(119840 . "MATHEMATICAL BOLD SMALL G")
(119841 . "MATHEMATICAL BOLD SMALL H")
(119842 . "MATHEMATICAL BOLD SMALL I")
(119843 . "MATHEMATICAL BOLD SMALL J")
(119844 . "MATHEMATICAL BOLD SMALL K")
(119845 . "MATHEMATICAL BOLD SMALL L")
(119846 . "MATHEMATICAL BOLD SMALL M")
(119847 . "MATHEMATICAL BOLD SMALL N")
(119848 . "MATHEMATICAL BOLD SMALL O")
(119849 . "MATHEMATICAL BOLD SMALL P")
(119850 . "MATHEMATICAL BOLD SMALL Q")
(119851 . "MATHEMATICAL BOLD SMALL R")
(119852 . "MATHEMATICAL BOLD SMALL S")
(119853 . "MATHEMATICAL BOLD SMALL T")
(119854 . "MATHEMATICAL BOLD SMALL U")
(119855 . "MATHEMATICAL BOLD SMALL V")
(119856 . "MATHEMATICAL BOLD SMALL W")
(119857 . "MATHEMATICAL BOLD SMALL X")
(119858 . "MATHEMATICAL BOLD SMALL Y")
(119859 . "MATHEMATICAL BOLD SMALL Z")
(119860 . "MATHEMATICAL ITALIC CAPITAL A")
(119861 . "MATHEMATICAL ITALIC CAPITAL B")
(119862 . "MATHEMATICAL ITALIC CAPITAL C")
(119863 . "MATHEMATICAL ITALIC CAPITAL D")
(119864 . "MATHEMATICAL ITALIC CAPITAL E")
(119865 . "MATHEMATICAL ITALIC CAPITAL F")
(119866 . "MATHEMATICAL ITALIC CAPITAL G")
(119867 . "MATHEMATICAL ITALIC CAPITAL H")
(119868 . "MATHEMATICAL ITALIC CAPITAL I")
(119869 . "MATHEMATICAL ITALIC CAPITAL J")
(119870 . "MATHEMATICAL ITALIC CAPITAL K")
(119871 . "MATHEMATICAL ITALIC CAPITAL L")
(119872 . "MATHEMATICAL ITALIC CAPITAL M")
(119873 . "MATHEMATICAL ITALIC CAPITAL N")
(119874 . "MATHEMATICAL ITALIC CAPITAL O")
(119875 . "MATHEMATICAL ITALIC CAPITAL P")
(119876 . "MATHEMATICAL ITALIC CAPITAL Q")
(119877 . "MATHEMATICAL ITALIC CAPITAL R")
(119878 . "MATHEMATICAL ITALIC CAPITAL S")
(119879 . "MATHEMATICAL ITALIC CAPITAL T")
(119880 . "MATHEMATICAL ITALIC CAPITAL U")
(119881 . "MATHEMATICAL ITALIC CAPITAL V")
(119882 . "MATHEMATICAL ITALIC CAPITAL W")
(119883 . "MATHEMATICAL ITALIC CAPITAL X")
(119884 . "MATHEMATICAL ITALIC CAPITAL Y")
(119885 . "MATHEMATICAL ITALIC CAPITAL Z")
(119886 . "MATHEMATICAL ITALIC SMALL A")
(119887 . "MATHEMATICAL ITALIC SMALL B")
(119888 . "MATHEMATICAL ITALIC SMALL C")
(119889 . "MATHEMATICAL ITALIC SMALL D")
(119890 . "MATHEMATICAL ITALIC SMALL E")
(119891 . "MATHEMATICAL ITALIC SMALL F")
(119892 . "MATHEMATICAL ITALIC SMALL G")
(119893 . #f)
(119894 . "MATHEMATICAL ITALIC SMALL I")
(119895 . "MATHEMATICAL ITALIC SMALL J")
(119896 . "MATHEMATICAL ITALIC SMALL K")
(119897 . "MATHEMATICAL ITALIC SMALL L")
(119898 . "MATHEMATICAL ITALIC SMALL M")
(119899 . "MATHEMATICAL ITALIC SMALL N")
(119900 . "MATHEMATICAL ITALIC SMALL O")
(119901 . "MATHEMATICAL ITALIC SMALL P")
(119902 . "MATHEMATICAL ITALIC SMALL Q")
(119903 . "MATHEMATICAL ITALIC SMALL R")
(119904 . "MATHEMATICAL ITALIC SMALL S")
(119905 . "MATHEMATICAL ITALIC SMALL T")
(119906 . "MATHEMATICAL ITALIC SMALL U")
(119907 . "MATHEMATICAL ITALIC SMALL V")
(119908 . "MATHEMATICAL ITALIC SMALL W")
(119909 . "MATHEMATICAL ITALIC SMALL X")
(119910 . "MATHEMATICAL ITALIC SMALL Y")
(119911 . "MATHEMATICAL ITALIC SMALL Z")
(119912 . "MATHEMATICAL BOLD ITALIC CAPITAL A")
(119913 . "MATHEMATICAL BOLD ITALIC CAPITAL B")
(119914 . "MATHEMATICAL BOLD ITALIC CAPITAL C")
(119915 . "MATHEMATICAL BOLD ITALIC CAPITAL D")
(119916 . "MATHEMATICAL BOLD ITALIC CAPITAL E")
(119917 . "MATHEMATICAL BOLD ITALIC CAPITAL F")
(119918 . "MATHEMATICAL BOLD ITALIC CAPITAL G")
(119919 . "MATHEMATICAL BOLD ITALIC CAPITAL H")
(119920 . "MATHEMATICAL BOLD ITALIC CAPITAL I")
(119921 . "MATHEMATICAL BOLD ITALIC CAPITAL J")
(119922 . "MATHEMATICAL BOLD ITALIC CAPITAL K")
(119923 . "MATHEMATICAL BOLD ITALIC CAPITAL L")
(119924 . "MATHEMATICAL BOLD ITALIC CAPITAL M")
(119925 . "MATHEMATICAL BOLD ITALIC CAPITAL N")
(119926 . "MATHEMATICAL BOLD ITALIC CAPITAL O")
(119927 . "MATHEMATICAL BOLD ITALIC CAPITAL P")
(119928 . "MATHEMATICAL BOLD ITALIC CAPITAL Q")
(119929 . "MATHEMATICAL BOLD ITALIC CAPITAL R")
(119930 . "MATHEMATICAL BOLD ITALIC CAPITAL S")
(119931 . "MATHEMATICAL BOLD ITALIC CAPITAL T")
(119932 . "MATHEMATICAL BOLD ITALIC CAPITAL U")
(119933 . "MATHEMATICAL BOLD ITALIC CAPITAL V")
(119934 . "MATHEMATICAL BOLD ITALIC CAPITAL W")
(119935 . "MATHEMATICAL BOLD ITALIC CAPITAL X")
(119936 . "MATHEMATICAL BOLD ITALIC CAPITAL Y")
(119937 . "MATHEMATICAL BOLD ITALIC CAPITAL Z")
(119938 . "MATHEMATICAL BOLD ITALIC SMALL A")
(119939 . "MATHEMATICAL BOLD ITALIC SMALL B")
(119940 . "MATHEMATICAL BOLD ITALIC SMALL C")
(119941 . "MATHEMATICAL BOLD ITALIC SMALL D")
(119942 . "MATHEMATICAL BOLD ITALIC SMALL E")
(119943 . "MATHEMATICAL BOLD ITALIC SMALL F")
(119944 . "MATHEMATICAL BOLD ITALIC SMALL G")
(119945 . "MATHEMATICAL BOLD ITALIC SMALL H")
(119946 . "MATHEMATICAL BOLD ITALIC SMALL I")
(119947 . "MATHEMATICAL BOLD ITALIC SMALL J")
(119948 . "MATHEMATICAL BOLD ITALIC SMALL K")
(119949 . "MATHEMATICAL BOLD ITALIC SMALL L")
(119950 . "MATHEMATICAL BOLD ITALIC SMALL M")
(119951 . "MATHEMATICAL BOLD ITALIC SMALL N")
(119952 . "MATHEMATICAL BOLD ITALIC SMALL O")
(119953 . "MATHEMATICAL BOLD ITALIC SMALL P")
(119954 . "MATHEMATICAL BOLD ITALIC SMALL Q")
(119955 . "MATHEMATICAL BOLD ITALIC SMALL R")
(119956 . "MATHEMATICAL BOLD ITALIC SMALL S")
(119957 . "MATHEMATICAL BOLD ITALIC SMALL T")
(119958 . "MATHEMATICAL BOLD ITALIC SMALL U")
(119959 . "MATHEMATICAL BOLD ITALIC SMALL V")
(119960 . "MATHEMATICAL BOLD ITALIC SMALL W")
(119961 . "MATHEMATICAL BOLD ITALIC SMALL X")
(119962 . "MATHEMATICAL BOLD ITALIC SMALL Y")
(119963 . "MATHEMATICAL BOLD ITALIC SMALL Z")
(119964 . "MATHEMATICAL SCRIPT CAPITAL A")
(119965 . #f)
(119966 . "MATHEMATICAL SCRIPT CAPITAL C")
(119967 . "MATHEMATICAL SCRIPT CAPITAL D")
((119968 . 119970) . #f)
(119970 . "MATHEMATICAL SCRIPT CAPITAL G")
((119971 . 119973) . #f)
(119973 . "MATHEMATICAL SCRIPT CAPITAL J")
(119974 . "MATHEMATICAL SCRIPT CAPITAL K")
((119975 . 119977) . #f)
(119977 . "MATHEMATICAL SCRIPT CAPITAL N")
(119978 . "MATHEMATICAL SCRIPT CAPITAL O")
(119979 . "MATHEMATICAL SCRIPT CAPITAL P")
(119980 . "MATHEMATICAL SCRIPT CAPITAL Q")
(119981 . #f)
(119982 . "MATHEMATICAL SCRIPT CAPITAL S")
(119983 . "MATHEMATICAL SCRIPT CAPITAL T")
(119984 . "MATHEMATICAL SCRIPT CAPITAL U")
(119985 . "MATHEMATICAL SCRIPT CAPITAL V")
(119986 . "MATHEMATICAL SCRIPT CAPITAL W")
(119987 . "MATHEMATICAL SCRIPT CAPITAL X")
(119988 . "MATHEMATICAL SCRIPT CAPITAL Y")
(119989 . "MATHEMATICAL SCRIPT CAPITAL Z")
(119990 . "MATHEMATICAL SCRIPT SMALL A")
(119991 . "MATHEMATICAL SCRIPT SMALL B")
(119992 . "MATHEMATICAL SCRIPT SMALL C")
(119993 . "MATHEMATICAL SCRIPT SMALL D")
(119994 . #f)
(119995 . "MATHEMATICAL SCRIPT SMALL F")
(119996 . #f)
(119997 . "MATHEMATICAL SCRIPT SMALL H")
(119998 . "MATHEMATICAL SCRIPT SMALL I")
(119999 . "MATHEMATICAL SCRIPT SMALL J")
(120000 . "MATHEMATICAL SCRIPT SMALL K")
(120001 . "MATHEMATICAL SCRIPT SMALL L")
(120002 . "MATHEMATICAL SCRIPT SMALL M")
(120003 . "MATHEMATICAL SCRIPT SMALL N")
(120004 . #f)
(120005 . "MATHEMATICAL SCRIPT SMALL P")
(120006 . "MATHEMATICAL SCRIPT SMALL Q")
(120007 . "MATHEMATICAL SCRIPT SMALL R")
(120008 . "MATHEMATICAL SCRIPT SMALL S")
(120009 . "MATHEMATICAL SCRIPT SMALL T")
(120010 . "MATHEMATICAL SCRIPT SMALL U")
(120011 . "MATHEMATICAL SCRIPT SMALL V")
(120012 . "MATHEMATICAL SCRIPT SMALL W")
(120013 . "MATHEMATICAL SCRIPT SMALL X")
(120014 . "MATHEMATICAL SCRIPT SMALL Y")
(120015 . "MATHEMATICAL SCRIPT SMALL Z")
(120016 . "MATHEMATICAL BOLD SCRIPT CAPITAL A")
(120017 . "MATHEMATICAL BOLD SCRIPT CAPITAL B")
(120018 . "MATHEMATICAL BOLD SCRIPT CAPITAL C")
(120019 . "MATHEMATICAL BOLD SCRIPT CAPITAL D")
(120020 . "MATHEMATICAL BOLD SCRIPT CAPITAL E")
(120021 . "MATHEMATICAL BOLD SCRIPT CAPITAL F")
(120022 . "MATHEMATICAL BOLD SCRIPT CAPITAL G")
(120023 . "MATHEMATICAL BOLD SCRIPT CAPITAL H")
(120024 . "MATHEMATICAL BOLD SCRIPT CAPITAL I")
(120025 . "MATHEMATICAL BOLD SCRIPT CAPITAL J")
(120026 . "MATHEMATICAL BOLD SCRIPT CAPITAL K")
(120027 . "MATHEMATICAL BOLD SCRIPT CAPITAL L")
(120028 . "MATHEMATICAL BOLD SCRIPT CAPITAL M")
(120029 . "MATHEMATICAL BOLD SCRIPT CAPITAL N")
(120030 . "MATHEMATICAL BOLD SCRIPT CAPITAL O")
(120031 . "MATHEMATICAL BOLD SCRIPT CAPITAL P")
(120032 . "MATHEMATICAL BOLD SCRIPT CAPITAL Q")
(120033 . "MATHEMATICAL BOLD SCRIPT CAPITAL R")
(120034 . "MATHEMATICAL BOLD SCRIPT CAPITAL S")
(120035 . "MATHEMATICAL BOLD SCRIPT CAPITAL T")
(120036 . "MATHEMATICAL BOLD SCRIPT CAPITAL U")
(120037 . "MATHEMATICAL BOLD SCRIPT CAPITAL V")
(120038 . "MATHEMATICAL BOLD SCRIPT CAPITAL W")
(120039 . "MATHEMATICAL BOLD SCRIPT CAPITAL X")
(120040 . "MATHEMATICAL BOLD SCRIPT CAPITAL Y")
(120041 . "MATHEMATICAL BOLD SCRIPT CAPITAL Z")
(120042 . "MATHEMATICAL BOLD SCRIPT SMALL A")
(120043 . "MATHEMATICAL BOLD SCRIPT SMALL B")
(120044 . "MATHEMATICAL BOLD SCRIPT SMALL C")
(120045 . "MATHEMATICAL BOLD SCRIPT SMALL D")
(120046 . "MATHEMATICAL BOLD SCRIPT SMALL E")
(120047 . "MATHEMATICAL BOLD SCRIPT SMALL F")
(120048 . "MATHEMATICAL BOLD SCRIPT SMALL G")
(120049 . "MATHEMATICAL BOLD SCRIPT SMALL H")
(120050 . "MATHEMATICAL BOLD SCRIPT SMALL I")
(120051 . "MATHEMATICAL BOLD SCRIPT SMALL J")
(120052 . "MATHEMATICAL BOLD SCRIPT SMALL K")
(120053 . "MATHEMATICAL BOLD SCRIPT SMALL L")
(120054 . "MATHEMATICAL BOLD SCRIPT SMALL M")
(120055 . "MATHEMATICAL BOLD SCRIPT SMALL N")
(120056 . "MATHEMATICAL BOLD SCRIPT SMALL O")
(120057 . "MATHEMATICAL BOLD SCRIPT SMALL P")
(120058 . "MATHEMATICAL BOLD SCRIPT SMALL Q")
(120059 . "MATHEMATICAL BOLD SCRIPT SMALL R")
(120060 . "MATHEMATICAL BOLD SCRIPT SMALL S")
(120061 . "MATHEMATICAL BOLD SCRIPT SMALL T")
(120062 . "MATHEMATICAL BOLD SCRIPT SMALL U")
(120063 . "MATHEMATICAL BOLD SCRIPT SMALL V")
(120064 . "MATHEMATICAL BOLD SCRIPT SMALL W")
(120065 . "MATHEMATICAL BOLD SCRIPT SMALL X")
(120066 . "MATHEMATICAL BOLD SCRIPT SMALL Y")
(120067 . "MATHEMATICAL BOLD SCRIPT SMALL Z")
(120068 . "MATHEMATICAL FRAKTUR CAPITAL A")
(120069 . "MATHEMATICAL FRAKTUR CAPITAL B")
(120070 . #f)
(120071 . "MATHEMATICAL FRAKTUR CAPITAL D")
(120072 . "MATHEMATICAL FRAKTUR CAPITAL E")
(120073 . "MATHEMATICAL FRAKTUR CAPITAL F")
(120074 . "MATHEMATICAL FRAKTUR CAPITAL G")
((120075 . 120077) . #f)
(120077 . "MATHEMATICAL FRAKTUR CAPITAL J")
(120078 . "MATHEMATICAL FRAKTUR CAPITAL K")
(120079 . "MATHEMATICAL FRAKTUR CAPITAL L")
(120080 . "MATHEMATICAL FRAKTUR CAPITAL M")
(120081 . "MATHEMATICAL FRAKTUR CAPITAL N")
(120082 . "MATHEMATICAL FRAKTUR CAPITAL O")
(120083 . "MATHEMATICAL FRAKTUR CAPITAL P")
(120084 . "MATHEMATICAL FRAKTUR CAPITAL Q")
(120085 . #f)
(120086 . "MATHEMATICAL FRAKTUR CAPITAL S")
(120087 . "MATHEMATICAL FRAKTUR CAPITAL T")
(120088 . "MATHEMATICAL FRAKTUR CAPITAL U")
(120089 . "MATHEMATICAL FRAKTUR CAPITAL V")
(120090 . "MATHEMATICAL FRAKTUR CAPITAL W")
(120091 . "MATHEMATICAL FRAKTUR CAPITAL X")
(120092 . "MATHEMATICAL FRAKTUR CAPITAL Y")
(120093 . #f)
(120094 . "MATHEMATICAL FRAKTUR SMALL A")
(120095 . "MATHEMATICAL FRAKTUR SMALL B")
(120096 . "MATHEMATICAL FRAKTUR SMALL C")
(120097 . "MATHEMATICAL FRAKTUR SMALL D")
(120098 . "MATHEMATICAL FRAKTUR SMALL E")
(120099 . "MATHEMATICAL FRAKTUR SMALL F")
(120100 . "MATHEMATICAL FRAKTUR SMALL G")
(120101 . "MATHEMATICAL FRAKTUR SMALL H")
(120102 . "MATHEMATICAL FRAKTUR SMALL I")
(120103 . "MATHEMATICAL FRAKTUR SMALL J")
(120104 . "MATHEMATICAL FRAKTUR SMALL K")
(120105 . "MATHEMATICAL FRAKTUR SMALL L")
(120106 . "MATHEMATICAL FRAKTUR SMALL M")
(120107 . "MATHEMATICAL FRAKTUR SMALL N")
(120108 . "MATHEMATICAL FRAKTUR SMALL O")
(120109 . "MATHEMATICAL FRAKTUR SMALL P")
(120110 . "MATHEMATICAL FRAKTUR SMALL Q")
(120111 . "MATHEMATICAL FRAKTUR SMALL R")
(120112 . "MATHEMATICAL FRAKTUR SMALL S")
(120113 . "MATHEMATICAL FRAKTUR SMALL T")
(120114 . "MATHEMATICAL FRAKTUR SMALL U")
(120115 . "MATHEMATICAL FRAKTUR SMALL V")
(120116 . "MATHEMATICAL FRAKTUR SMALL W")
(120117 . "MATHEMATICAL FRAKTUR SMALL X")
(120118 . "MATHEMATICAL FRAKTUR SMALL Y")
(120119 . "MATHEMATICAL FRAKTUR SMALL Z")
(120120 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL A")
(120121 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL B")
(120122 . #f)
(120123 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL D")
(120124 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL E")
(120125 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL F")
(120126 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL G")
(120127 . #f)
(120128 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL I")
(120129 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL J")
(120130 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL K")
(120131 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL L")
(120132 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL M")
(120133 . #f)
(120134 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL O")
((120135 . 120138) . #f)
(120138 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL S")
(120139 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL T")
(120140 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL U")
(120141 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL V")
(120142 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL W")
(120143 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL X")
(120144 . "MATHEMATICAL DOUBLE-STRUCK CAPITAL Y")
(120145 . #f)
(120146 . "MATHEMATICAL DOUBLE-STRUCK SMALL A")
(120147 . "MATHEMATICAL DOUBLE-STRUCK SMALL B")
(120148 . "MATHEMATICAL DOUBLE-STRUCK SMALL C")
(120149 . "MATHEMATICAL DOUBLE-STRUCK SMALL D")
(120150 . "MATHEMATICAL DOUBLE-STRUCK SMALL E")
(120151 . "MATHEMATICAL DOUBLE-STRUCK SMALL F")
(120152 . "MATHEMATICAL DOUBLE-STRUCK SMALL G")
(120153 . "MATHEMATICAL DOUBLE-STRUCK SMALL H")
(120154 . "MATHEMATICAL DOUBLE-STRUCK SMALL I")
(120155 . "MATHEMATICAL DOUBLE-STRUCK SMALL J")
(120156 . "MATHEMATICAL DOUBLE-STRUCK SMALL K")
(120157 . "MATHEMATICAL DOUBLE-STRUCK SMALL L")
(120158 . "MATHEMATICAL DOUBLE-STRUCK SMALL M")
(120159 . "MATHEMATICAL DOUBLE-STRUCK SMALL N")
(120160 . "MATHEMATICAL DOUBLE-STRUCK SMALL O")
(120161 . "MATHEMATICAL DOUBLE-STRUCK SMALL P")
(120162 . "MATHEMATICAL DOUBLE-STRUCK SMALL Q")
(120163 . "MATHEMATICAL DOUBLE-STRUCK SMALL R")
(120164 . "MATHEMATICAL DOUBLE-STRUCK SMALL S")
(120165 . "MATHEMATICAL DOUBLE-STRUCK SMALL T")
(120166 . "MATHEMATICAL DOUBLE-STRUCK SMALL U")
(120167 . "MATHEMATICAL DOUBLE-STRUCK SMALL V")
(120168 . "MATHEMATICAL DOUBLE-STRUCK SMALL W")
(120169 . "MATHEMATICAL DOUBLE-STRUCK SMALL X")
(120170 . "MATHEMATICAL DOUBLE-STRUCK SMALL Y")
(120171 . "MATHEMATICAL DOUBLE-STRUCK SMALL Z")
(120172 . "MATHEMATICAL BOLD FRAKTUR CAPITAL A")
(120173 . "MATHEMATICAL BOLD FRAKTUR CAPITAL B")
(120174 . "MATHEMATICAL BOLD FRAKTUR CAPITAL C")
(120175 . "MATHEMATICAL BOLD FRAKTUR CAPITAL D")
(120176 . "MATHEMATICAL BOLD FRAKTUR CAPITAL E")
(120177 . "MATHEMATICAL BOLD FRAKTUR CAPITAL F")
(120178 . "MATHEMATICAL BOLD FRAKTUR CAPITAL G")
(120179 . "MATHEMATICAL BOLD FRAKTUR CAPITAL H")
(120180 . "MATHEMATICAL BOLD FRAKTUR CAPITAL I")
(120181 . "MATHEMATICAL BOLD FRAKTUR CAPITAL J")
(120182 . "MATHEMATICAL BOLD FRAKTUR CAPITAL K")
(120183 . "MATHEMATICAL BOLD FRAKTUR CAPITAL L")
(120184 . "MATHEMATICAL BOLD FRAKTUR CAPITAL M")
(120185 . "MATHEMATICAL BOLD FRAKTUR CAPITAL N")
(120186 . "MATHEMATICAL BOLD FRAKTUR CAPITAL O")
(120187 . "MATHEMATICAL BOLD FRAKTUR CAPITAL P")
(120188 . "MATHEMATICAL BOLD FRAKTUR CAPITAL Q")
(120189 . "MATHEMATICAL BOLD FRAKTUR CAPITAL R")
(120190 . "MATHEMATICAL BOLD FRAKTUR CAPITAL S")
(120191 . "MATHEMATICAL BOLD FRAKTUR CAPITAL T")
(120192 . "MATHEMATICAL BOLD FRAKTUR CAPITAL U")
(120193 . "MATHEMATICAL BOLD FRAKTUR CAPITAL V")
(120194 . "MATHEMATICAL BOLD FRAKTUR CAPITAL W")
(120195 . "MATHEMATICAL BOLD FRAKTUR CAPITAL X")
(120196 . "MATHEMATICAL BOLD FRAKTUR CAPITAL Y")
(120197 . "MATHEMATICAL BOLD FRAKTUR CAPITAL Z")
(120198 . "MATHEMATICAL BOLD FRAKTUR SMALL A")
(120199 . "MATHEMATICAL BOLD FRAKTUR SMALL B")
(120200 . "MATHEMATICAL BOLD FRAKTUR SMALL C")
(120201 . "MATHEMATICAL BOLD FRAKTUR SMALL D")
(120202 . "MATHEMATICAL BOLD FRAKTUR SMALL E")
(120203 . "MATHEMATICAL BOLD FRAKTUR SMALL F")
(120204 . "MATHEMATICAL BOLD FRAKTUR SMALL G")
(120205 . "MATHEMATICAL BOLD FRAKTUR SMALL H")
(120206 . "MATHEMATICAL BOLD FRAKTUR SMALL I")
(120207 . "MATHEMATICAL BOLD FRAKTUR SMALL J")
(120208 . "MATHEMATICAL BOLD FRAKTUR SMALL K")
(120209 . "MATHEMATICAL BOLD FRAKTUR SMALL L")
(120210 . "MATHEMATICAL BOLD FRAKTUR SMALL M")
(120211 . "MATHEMATICAL BOLD FRAKTUR SMALL N")
(120212 . "MATHEMATICAL BOLD FRAKTUR SMALL O")
(120213 . "MATHEMATICAL BOLD FRAKTUR SMALL P")
(120214 . "MATHEMATICAL BOLD FRAKTUR SMALL Q")
(120215 . "MATHEMATICAL BOLD FRAKTUR SMALL R")
(120216 . "MATHEMATICAL BOLD FRAKTUR SMALL S")
(120217 . "MATHEMATICAL BOLD FRAKTUR SMALL T")
(120218 . "MATHEMATICAL BOLD FRAKTUR SMALL U")
(120219 . "MATHEMATICAL BOLD FRAKTUR SMALL V")
(120220 . "MATHEMATICAL BOLD FRAKTUR SMALL W")
(120221 . "MATHEMATICAL BOLD FRAKTUR SMALL X")
(120222 . "MATHEMATICAL BOLD FRAKTUR SMALL Y")
(120223 . "MATHEMATICAL BOLD FRAKTUR SMALL Z")
(120224 . "MATHEMATICAL SANS-SERIF CAPITAL A")
(120225 . "MATHEMATICAL SANS-SERIF CAPITAL B")
(120226 . "MATHEMATICAL SANS-SERIF CAPITAL C")
(120227 . "MATHEMATICAL SANS-SERIF CAPITAL D")
(120228 . "MATHEMATICAL SANS-SERIF CAPITAL E")
(120229 . "MATHEMATICAL SANS-SERIF CAPITAL F")
(120230 . "MATHEMATICAL SANS-SERIF CAPITAL G")
(120231 . "MATHEMATICAL SANS-SERIF CAPITAL H")
(120232 . "MATHEMATICAL SANS-SERIF CAPITAL I")
(120233 . "MATHEMATICAL SANS-SERIF CAPITAL J")
(120234 . "MATHEMATICAL SANS-SERIF CAPITAL K")
(120235 . "MATHEMATICAL SANS-SERIF CAPITAL L")
(120236 . "MATHEMATICAL SANS-SERIF CAPITAL M")
(120237 . "MATHEMATICAL SANS-SERIF CAPITAL N")
(120238 . "MATHEMATICAL SANS-SERIF CAPITAL O")
(120239 . "MATHEMATICAL SANS-SERIF CAPITAL P")
(120240 . "MATHEMATICAL SANS-SERIF CAPITAL Q")
(120241 . "MATHEMATICAL SANS-SERIF CAPITAL R")
(120242 . "MATHEMATICAL SANS-SERIF CAPITAL S")
(120243 . "MATHEMATICAL SANS-SERIF CAPITAL T")
(120244 . "MATHEMATICAL SANS-SERIF CAPITAL U")
(120245 . "MATHEMATICAL SANS-SERIF CAPITAL V")
(120246 . "MATHEMATICAL SANS-SERIF CAPITAL W")
(120247 . "MATHEMATICAL SANS-SERIF CAPITAL X")
(120248 . "MATHEMATICAL SANS-SERIF CAPITAL Y")
(120249 . "MATHEMATICAL SANS-SERIF CAPITAL Z")
(120250 . "MATHEMATICAL SANS-SERIF SMALL A")
(120251 . "MATHEMATICAL SANS-SERIF SMALL B")
(120252 . "MATHEMATICAL SANS-SERIF SMALL C")
(120253 . "MATHEMATICAL SANS-SERIF SMALL D")
(120254 . "MATHEMATICAL SANS-SERIF SMALL E")
(120255 . "MATHEMATICAL SANS-SERIF SMALL F")
(120256 . "MATHEMATICAL SANS-SERIF SMALL G")
(120257 . "MATHEMATICAL SANS-SERIF SMALL H")
(120258 . "MATHEMATICAL SANS-SERIF SMALL I")
(120259 . "MATHEMATICAL SANS-SERIF SMALL J")
(120260 . "MATHEMATICAL SANS-SERIF SMALL K")
(120261 . "MATHEMATICAL SANS-SERIF SMALL L")
(120262 . "MATHEMATICAL SANS-SERIF SMALL M")
(120263 . "MATHEMATICAL SANS-SERIF SMALL N")
(120264 . "MATHEMATICAL SANS-SERIF SMALL O")
(120265 . "MATHEMATICAL SANS-SERIF SMALL P")
(120266 . "MATHEMATICAL SANS-SERIF SMALL Q")
(120267 . "MATHEMATICAL SANS-SERIF SMALL R")
(120268 . "MATHEMATICAL SANS-SERIF SMALL S")
(120269 . "MATHEMATICAL SANS-SERIF SMALL T")
(120270 . "MATHEMATICAL SANS-SERIF SMALL U")
(120271 . "MATHEMATICAL SANS-SERIF SMALL V")
(120272 . "MATHEMATICAL SANS-SERIF SMALL W")
(120273 . "MATHEMATICAL SANS-SERIF SMALL X")
(120274 . "MATHEMATICAL SANS-SERIF SMALL Y")
(120275 . "MATHEMATICAL SANS-SERIF SMALL Z")
(120276 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL A")
(120277 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL B")
(120278 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL C")
(120279 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL D")
(120280 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL E")
(120281 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL F")
(120282 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL G")
(120283 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL H")
(120284 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL I")
(120285 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL J")
(120286 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL K")
(120287 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL L")
(120288 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL M")
(120289 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL N")
(120290 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL O")
(120291 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL P")
(120292 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL Q")
(120293 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL R")
(120294 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL S")
(120295 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL T")
(120296 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL U")
(120297 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL V")
(120298 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL W")
(120299 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL X")
(120300 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL Y")
(120301 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL Z")
(120302 . "MATHEMATICAL SANS-SERIF BOLD SMALL A")
(120303 . "MATHEMATICAL SANS-SERIF BOLD SMALL B")
(120304 . "MATHEMATICAL SANS-SERIF BOLD SMALL C")
(120305 . "MATHEMATICAL SANS-SERIF BOLD SMALL D")
(120306 . "MATHEMATICAL SANS-SERIF BOLD SMALL E")
(120307 . "MATHEMATICAL SANS-SERIF BOLD SMALL F")
(120308 . "MATHEMATICAL SANS-SERIF BOLD SMALL G")
(120309 . "MATHEMATICAL SANS-SERIF BOLD SMALL H")
(120310 . "MATHEMATICAL SANS-SERIF BOLD SMALL I")
(120311 . "MATHEMATICAL SANS-SERIF BOLD SMALL J")
(120312 . "MATHEMATICAL SANS-SERIF BOLD SMALL K")
(120313 . "MATHEMATICAL SANS-SERIF BOLD SMALL L")
(120314 . "MATHEMATICAL SANS-SERIF BOLD SMALL M")
(120315 . "MATHEMATICAL SANS-SERIF BOLD SMALL N")
(120316 . "MATHEMATICAL SANS-SERIF BOLD SMALL O")
(120317 . "MATHEMATICAL SANS-SERIF BOLD SMALL P")
(120318 . "MATHEMATICAL SANS-SERIF BOLD SMALL Q")
(120319 . "MATHEMATICAL SANS-SERIF BOLD SMALL R")
(120320 . "MATHEMATICAL SANS-SERIF BOLD SMALL S")
(120321 . "MATHEMATICAL SANS-SERIF BOLD SMALL T")
(120322 . "MATHEMATICAL SANS-SERIF BOLD SMALL U")
(120323 . "MATHEMATICAL SANS-SERIF BOLD SMALL V")
(120324 . "MATHEMATICAL SANS-SERIF BOLD SMALL W")
(120325 . "MATHEMATICAL SANS-SERIF BOLD SMALL X")
(120326 . "MATHEMATICAL SANS-SERIF BOLD SMALL Y")
(120327 . "MATHEMATICAL SANS-SERIF BOLD SMALL Z")
(120328 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL A")
(120329 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL B")
(120330 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL C")
(120331 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL D")
(120332 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL E")
(120333 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL F")
(120334 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL G")
(120335 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL H")
(120336 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL I")
(120337 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL J")
(120338 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL K")
(120339 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL L")
(120340 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL M")
(120341 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL N")
(120342 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL O")
(120343 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL P")
(120344 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL Q")
(120345 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL R")
(120346 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL S")
(120347 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL T")
(120348 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL U")
(120349 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL V")
(120350 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL W")
(120351 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL X")
(120352 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL Y")
(120353 . "MATHEMATICAL SANS-SERIF ITALIC CAPITAL Z")
(120354 . "MATHEMATICAL SANS-SERIF ITALIC SMALL A")
(120355 . "MATHEMATICAL SANS-SERIF ITALIC SMALL B")
(120356 . "MATHEMATICAL SANS-SERIF ITALIC SMALL C")
(120357 . "MATHEMATICAL SANS-SERIF ITALIC SMALL D")
(120358 . "MATHEMATICAL SANS-SERIF ITALIC SMALL E")
(120359 . "MATHEMATICAL SANS-SERIF ITALIC SMALL F")
(120360 . "MATHEMATICAL SANS-SERIF ITALIC SMALL G")
(120361 . "MATHEMATICAL SANS-SERIF ITALIC SMALL H")
(120362 . "MATHEMATICAL SANS-SERIF ITALIC SMALL I")
(120363 . "MATHEMATICAL SANS-SERIF ITALIC SMALL J")
(120364 . "MATHEMATICAL SANS-SERIF ITALIC SMALL K")
(120365 . "MATHEMATICAL SANS-SERIF ITALIC SMALL L")
(120366 . "MATHEMATICAL SANS-SERIF ITALIC SMALL M")
(120367 . "MATHEMATICAL SANS-SERIF ITALIC SMALL N")
(120368 . "MATHEMATICAL SANS-SERIF ITALIC SMALL O")
(120369 . "MATHEMATICAL SANS-SERIF ITALIC SMALL P")
(120370 . "MATHEMATICAL SANS-SERIF ITALIC SMALL Q")
(120371 . "MATHEMATICAL SANS-SERIF ITALIC SMALL R")
(120372 . "MATHEMATICAL SANS-SERIF ITALIC SMALL S")
(120373 . "MATHEMATICAL SANS-SERIF ITALIC SMALL T")
(120374 . "MATHEMATICAL SANS-SERIF ITALIC SMALL U")
(120375 . "MATHEMATICAL SANS-SERIF ITALIC SMALL V")
(120376 . "MATHEMATICAL SANS-SERIF ITALIC SMALL W")
(120377 . "MATHEMATICAL SANS-SERIF ITALIC SMALL X")
(120378 . "MATHEMATICAL SANS-SERIF ITALIC SMALL Y")
(120379 . "MATHEMATICAL SANS-SERIF ITALIC SMALL Z")
(120380 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL A")
(120381 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL B")
(120382 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL C")
(120383 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL D")
(120384 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL E")
(120385 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL F")
(120386 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL G")
(120387 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL H")
(120388 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL I")
(120389 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL J")
(120390 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL K")
(120391 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL L")
(120392 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL M")
(120393 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL N")
(120394 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL O")
(120395 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL P")
(120396 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Q")
(120397 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL R")
(120398 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL S")
(120399 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL T")
(120400 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL U")
(120401 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL V")
(120402 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL W")
(120403 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL X")
(120404 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Y")
(120405 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Z")
(120406 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL A")
(120407 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL B")
(120408 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL C")
(120409 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL D")
(120410 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL E")
(120411 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL F")
(120412 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL G")
(120413 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL H")
(120414 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL I")
(120415 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL J")
(120416 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL K")
(120417 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL L")
(120418 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL M")
(120419 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL N")
(120420 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL O")
(120421 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL P")
(120422 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Q")
(120423 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL R")
(120424 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL S")
(120425 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL T")
(120426 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL U")
(120427 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL V")
(120428 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL W")
(120429 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL X")
(120430 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Y")
(120431 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Z")
(120432 . "MATHEMATICAL MONOSPACE CAPITAL A")
(120433 . "MATHEMATICAL MONOSPACE CAPITAL B")
(120434 . "MATHEMATICAL MONOSPACE CAPITAL C")
(120435 . "MATHEMATICAL MONOSPACE CAPITAL D")
(120436 . "MATHEMATICAL MONOSPACE CAPITAL E")
(120437 . "MATHEMATICAL MONOSPACE CAPITAL F")
(120438 . "MATHEMATICAL MONOSPACE CAPITAL G")
(120439 . "MATHEMATICAL MONOSPACE CAPITAL H")
(120440 . "MATHEMATICAL MONOSPACE CAPITAL I")
(120441 . "MATHEMATICAL MONOSPACE CAPITAL J")
(120442 . "MATHEMATICAL MONOSPACE CAPITAL K")
(120443 . "MATHEMATICAL MONOSPACE CAPITAL L")
(120444 . "MATHEMATICAL MONOSPACE CAPITAL M")
(120445 . "MATHEMATICAL MONOSPACE CAPITAL N")
(120446 . "MATHEMATICAL MONOSPACE CAPITAL O")
(120447 . "MATHEMATICAL MONOSPACE CAPITAL P")
(120448 . "MATHEMATICAL MONOSPACE CAPITAL Q")
(120449 . "MATHEMATICAL MONOSPACE CAPITAL R")
(120450 . "MATHEMATICAL MONOSPACE CAPITAL S")
(120451 . "MATHEMATICAL MONOSPACE CAPITAL T")
(120452 . "MATHEMATICAL MONOSPACE CAPITAL U")
(120453 . "MATHEMATICAL MONOSPACE CAPITAL V")
(120454 . "MATHEMATICAL MONOSPACE CAPITAL W")
(120455 . "MATHEMATICAL MONOSPACE CAPITAL X")
(120456 . "MATHEMATICAL MONOSPACE CAPITAL Y")
(120457 . "MATHEMATICAL MONOSPACE CAPITAL Z")
(120458 . "MATHEMATICAL MONOSPACE SMALL A")
(120459 . "MATHEMATICAL MONOSPACE SMALL B")
(120460 . "MATHEMATICAL MONOSPACE SMALL C")
(120461 . "MATHEMATICAL MONOSPACE SMALL D")
(120462 . "MATHEMATICAL MONOSPACE SMALL E")
(120463 . "MATHEMATICAL MONOSPACE SMALL F")
(120464 . "MATHEMATICAL MONOSPACE SMALL G")
(120465 . "MATHEMATICAL MONOSPACE SMALL H")
(120466 . "MATHEMATICAL MONOSPACE SMALL I")
(120467 . "MATHEMATICAL MONOSPACE SMALL J")
(120468 . "MATHEMATICAL MONOSPACE SMALL K")
(120469 . "MATHEMATICAL MONOSPACE SMALL L")
(120470 . "MATHEMATICAL MONOSPACE SMALL M")
(120471 . "MATHEMATICAL MONOSPACE SMALL N")
(120472 . "MATHEMATICAL MONOSPACE SMALL O")
(120473 . "MATHEMATICAL MONOSPACE SMALL P")
(120474 . "MATHEMATICAL MONOSPACE SMALL Q")
(120475 . "MATHEMATICAL MONOSPACE SMALL R")
(120476 . "MATHEMATICAL MONOSPACE SMALL S")
(120477 . "MATHEMATICAL MONOSPACE SMALL T")
(120478 . "MATHEMATICAL MONOSPACE SMALL U")
(120479 . "MATHEMATICAL MONOSPACE SMALL V")
(120480 . "MATHEMATICAL MONOSPACE SMALL W")
(120481 . "MATHEMATICAL MONOSPACE SMALL X")
(120482 . "MATHEMATICAL MONOSPACE SMALL Y")
(120483 . "MATHEMATICAL MONOSPACE SMALL Z")
(120484 . "MATHEMATICAL ITALIC SMALL DOTLESS I")
(120485 . "MATHEMATICAL ITALIC SMALL DOTLESS J")
((120486 . 120488) . #f)
(120488 . "MATHEMATICAL BOLD CAPITAL ALPHA")
(120489 . "MATHEMATICAL BOLD CAPITAL BETA")
(120490 . "MATHEMATICAL BOLD CAPITAL GAMMA")
(120491 . "MATHEMATICAL BOLD CAPITAL DELTA")
(120492 . "MATHEMATICAL BOLD CAPITAL EPSILON")
(120493 . "MATHEMATICAL BOLD CAPITAL ZETA")
(120494 . "MATHEMATICAL BOLD CAPITAL ETA")
(120495 . "MATHEMATICAL BOLD CAPITAL THETA")
(120496 . "MATHEMATICAL BOLD CAPITAL IOTA")
(120497 . "MATHEMATICAL BOLD CAPITAL KAPPA")
(120498 . "MATHEMATICAL BOLD CAPITAL LAMDA")
(120499 . "MATHEMATICAL BOLD CAPITAL MU")
(120500 . "MATHEMATICAL BOLD CAPITAL NU")
(120501 . "MATHEMATICAL BOLD CAPITAL XI")
(120502 . "MATHEMATICAL BOLD CAPITAL OMICRON")
(120503 . "MATHEMATICAL BOLD CAPITAL PI")
(120504 . "MATHEMATICAL BOLD CAPITAL RHO")
(120505 . "MATHEMATICAL BOLD CAPITAL THETA SYMBOL")
(120506 . "MATHEMATICAL BOLD CAPITAL SIGMA")
(120507 . "MATHEMATICAL BOLD CAPITAL TAU")
(120508 . "MATHEMATICAL BOLD CAPITAL UPSILON")
(120509 . "MATHEMATICAL BOLD CAPITAL PHI")
(120510 . "MATHEMATICAL BOLD CAPITAL CHI")
(120511 . "MATHEMATICAL BOLD CAPITAL PSI")
(120512 . "MATHEMATICAL BOLD CAPITAL OMEGA")
(120513 . "MATHEMATICAL BOLD NABLA")
(120514 . "MATHEMATICAL BOLD SMALL ALPHA")
(120515 . "MATHEMATICAL BOLD SMALL BETA")
(120516 . "MATHEMATICAL BOLD SMALL GAMMA")
(120517 . "MATHEMATICAL BOLD SMALL DELTA")
(120518 . "MATHEMATICAL BOLD SMALL EPSILON")
(120519 . "MATHEMATICAL BOLD SMALL ZETA")
(120520 . "MATHEMATICAL BOLD SMALL ETA")
(120521 . "MATHEMATICAL BOLD SMALL THETA")
(120522 . "MATHEMATICAL BOLD SMALL IOTA")
(120523 . "MATHEMATICAL BOLD SMALL KAPPA")
(120524 . "MATHEMATICAL BOLD SMALL LAMDA")
(120525 . "MATHEMATICAL BOLD SMALL MU")
(120526 . "MATHEMATICAL BOLD SMALL NU")
(120527 . "MATHEMATICAL BOLD SMALL XI")
(120528 . "MATHEMATICAL BOLD SMALL OMICRON")
(120529 . "MATHEMATICAL BOLD SMALL PI")
(120530 . "MATHEMATICAL BOLD SMALL RHO")
(120531 . "MATHEMATICAL BOLD SMALL FINAL SIGMA")
(120532 . "MATHEMATICAL BOLD SMALL SIGMA")
(120533 . "MATHEMATICAL BOLD SMALL TAU")
(120534 . "MATHEMATICAL BOLD SMALL UPSILON")
(120535 . "MATHEMATICAL BOLD SMALL PHI")
(120536 . "MATHEMATICAL BOLD SMALL CHI")
(120537 . "MATHEMATICAL BOLD SMALL PSI")
(120538 . "MATHEMATICAL BOLD SMALL OMEGA")
(120539 . "MATHEMATICAL BOLD PARTIAL DIFFERENTIAL")
(120540 . "MATHEMATICAL BOLD EPSILON SYMBOL")
(120541 . "MATHEMATICAL BOLD THETA SYMBOL")
(120542 . "MATHEMATICAL BOLD KAPPA SYMBOL")
(120543 . "MATHEMATICAL BOLD PHI SYMBOL")
(120544 . "MATHEMATICAL BOLD RHO SYMBOL")
(120545 . "MATHEMATICAL BOLD PI SYMBOL")
(120546 . "MATHEMATICAL ITALIC CAPITAL ALPHA")
(120547 . "MATHEMATICAL ITALIC CAPITAL BETA")
(120548 . "MATHEMATICAL ITALIC CAPITAL GAMMA")
(120549 . "MATHEMATICAL ITALIC CAPITAL DELTA")
(120550 . "MATHEMATICAL ITALIC CAPITAL EPSILON")
(120551 . "MATHEMATICAL ITALIC CAPITAL ZETA")
(120552 . "MATHEMATICAL ITALIC CAPITAL ETA")
(120553 . "MATHEMATICAL ITALIC CAPITAL THETA")
(120554 . "MATHEMATICAL ITALIC CAPITAL IOTA")
(120555 . "MATHEMATICAL ITALIC CAPITAL KAPPA")
(120556 . "MATHEMATICAL ITALIC CAPITAL LAMDA")
(120557 . "MATHEMATICAL ITALIC CAPITAL MU")
(120558 . "MATHEMATICAL ITALIC CAPITAL NU")
(120559 . "MATHEMATICAL ITALIC CAPITAL XI")
(120560 . "MATHEMATICAL ITALIC CAPITAL OMICRON")
(120561 . "MATHEMATICAL ITALIC CAPITAL PI")
(120562 . "MATHEMATICAL ITALIC CAPITAL RHO")
(120563 . "MATHEMATICAL ITALIC CAPITAL THETA SYMBOL")
(120564 . "MATHEMATICAL ITALIC CAPITAL SIGMA")
(120565 . "MATHEMATICAL ITALIC CAPITAL TAU")
(120566 . "MATHEMATICAL ITALIC CAPITAL UPSILON")
(120567 . "MATHEMATICAL ITALIC CAPITAL PHI")
(120568 . "MATHEMATICAL ITALIC CAPITAL CHI")
(120569 . "MATHEMATICAL ITALIC CAPITAL PSI")
(120570 . "MATHEMATICAL ITALIC CAPITAL OMEGA")
(120571 . "MATHEMATICAL ITALIC NABLA")
(120572 . "MATHEMATICAL ITALIC SMALL ALPHA")
(120573 . "MATHEMATICAL ITALIC SMALL BETA")
(120574 . "MATHEMATICAL ITALIC SMALL GAMMA")
(120575 . "MATHEMATICAL ITALIC SMALL DELTA")
(120576 . "MATHEMATICAL ITALIC SMALL EPSILON")
(120577 . "MATHEMATICAL ITALIC SMALL ZETA")
(120578 . "MATHEMATICAL ITALIC SMALL ETA")
(120579 . "MATHEMATICAL ITALIC SMALL THETA")
(120580 . "MATHEMATICAL ITALIC SMALL IOTA")
(120581 . "MATHEMATICAL ITALIC SMALL KAPPA")
(120582 . "MATHEMATICAL ITALIC SMALL LAMDA")
(120583 . "MATHEMATICAL ITALIC SMALL MU")
(120584 . "MATHEMATICAL ITALIC SMALL NU")
(120585 . "MATHEMATICAL ITALIC SMALL XI")
(120586 . "MATHEMATICAL ITALIC SMALL OMICRON")
(120587 . "MATHEMATICAL ITALIC SMALL PI")
(120588 . "MATHEMATICAL ITALIC SMALL RHO")
(120589 . "MATHEMATICAL ITALIC SMALL FINAL SIGMA")
(120590 . "MATHEMATICAL ITALIC SMALL SIGMA")
(120591 . "MATHEMATICAL ITALIC SMALL TAU")
(120592 . "MATHEMATICAL ITALIC SMALL UPSILON")
(120593 . "MATHEMATICAL ITALIC SMALL PHI")
(120594 . "MATHEMATICAL ITALIC SMALL CHI")
(120595 . "MATHEMATICAL ITALIC SMALL PSI")
(120596 . "MATHEMATICAL ITALIC SMALL OMEGA")
(120597 . "MATHEMATICAL ITALIC PARTIAL DIFFERENTIAL")
(120598 . "MATHEMATICAL ITALIC EPSILON SYMBOL")
(120599 . "MATHEMATICAL ITALIC THETA SYMBOL")
(120600 . "MATHEMATICAL ITALIC KAPPA SYMBOL")
(120601 . "MATHEMATICAL ITALIC PHI SYMBOL")
(120602 . "MATHEMATICAL ITALIC RHO SYMBOL")
(120603 . "MATHEMATICAL ITALIC PI SYMBOL")
(120604 . "MATHEMATICAL BOLD ITALIC CAPITAL ALPHA")
(120605 . "MATHEMATICAL BOLD ITALIC CAPITAL BETA")
(120606 . "MATHEMATICAL BOLD ITALIC CAPITAL GAMMA")
(120607 . "MATHEMATICAL BOLD ITALIC CAPITAL DELTA")
(120608 . "MATHEMATICAL BOLD ITALIC CAPITAL EPSILON")
(120609 . "MATHEMATICAL BOLD ITALIC CAPITAL ZETA")
(120610 . "MATHEMATICAL BOLD ITALIC CAPITAL ETA")
(120611 . "MATHEMATICAL BOLD ITALIC CAPITAL THETA")
(120612 . "MATHEMATICAL BOLD ITALIC CAPITAL IOTA")
(120613 . "MATHEMATICAL BOLD ITALIC CAPITAL KAPPA")
(120614 . "MATHEMATICAL BOLD ITALIC CAPITAL LAMDA")
(120615 . "MATHEMATICAL BOLD ITALIC CAPITAL MU")
(120616 . "MATHEMATICAL BOLD ITALIC CAPITAL NU")
(120617 . "MATHEMATICAL BOLD ITALIC CAPITAL XI")
(120618 . "MATHEMATICAL BOLD ITALIC CAPITAL OMICRON")
(120619 . "MATHEMATICAL BOLD ITALIC CAPITAL PI")
(120620 . "MATHEMATICAL BOLD ITALIC CAPITAL RHO")
(120621 . "MATHEMATICAL BOLD ITALIC CAPITAL THETA SYMBOL")
(120622 . "MATHEMATICAL BOLD ITALIC CAPITAL SIGMA")
(120623 . "MATHEMATICAL BOLD ITALIC CAPITAL TAU")
(120624 . "MATHEMATICAL BOLD ITALIC CAPITAL UPSILON")
(120625 . "MATHEMATICAL BOLD ITALIC CAPITAL PHI")
(120626 . "MATHEMATICAL BOLD ITALIC CAPITAL CHI")
(120627 . "MATHEMATICAL BOLD ITALIC CAPITAL PSI")
(120628 . "MATHEMATICAL BOLD ITALIC CAPITAL OMEGA")
(120629 . "MATHEMATICAL BOLD ITALIC NABLA")
(120630 . "MATHEMATICAL BOLD ITALIC SMALL ALPHA")
(120631 . "MATHEMATICAL BOLD ITALIC SMALL BETA")
(120632 . "MATHEMATICAL BOLD ITALIC SMALL GAMMA")
(120633 . "MATHEMATICAL BOLD ITALIC SMALL DELTA")
(120634 . "MATHEMATICAL BOLD ITALIC SMALL EPSILON")
(120635 . "MATHEMATICAL BOLD ITALIC SMALL ZETA")
(120636 . "MATHEMATICAL BOLD ITALIC SMALL ETA")
(120637 . "MATHEMATICAL BOLD ITALIC SMALL THETA")
(120638 . "MATHEMATICAL BOLD ITALIC SMALL IOTA")
(120639 . "MATHEMATICAL BOLD ITALIC SMALL KAPPA")
(120640 . "MATHEMATICAL BOLD ITALIC SMALL LAMDA")
(120641 . "MATHEMATICAL BOLD ITALIC SMALL MU")
(120642 . "MATHEMATICAL BOLD ITALIC SMALL NU")
(120643 . "MATHEMATICAL BOLD ITALIC SMALL XI")
(120644 . "MATHEMATICAL BOLD ITALIC SMALL OMICRON")
(120645 . "MATHEMATICAL BOLD ITALIC SMALL PI")
(120646 . "MATHEMATICAL BOLD ITALIC SMALL RHO")
(120647 . "MATHEMATICAL BOLD ITALIC SMALL FINAL SIGMA")
(120648 . "MATHEMATICAL BOLD ITALIC SMALL SIGMA")
(120649 . "MATHEMATICAL BOLD ITALIC SMALL TAU")
(120650 . "MATHEMATICAL BOLD ITALIC SMALL UPSILON")
(120651 . "MATHEMATICAL BOLD ITALIC SMALL PHI")
(120652 . "MATHEMATICAL BOLD ITALIC SMALL CHI")
(120653 . "MATHEMATICAL BOLD ITALIC SMALL PSI")
(120654 . "MATHEMATICAL BOLD ITALIC SMALL OMEGA")
(120655 . "MATHEMATICAL BOLD ITALIC PARTIAL DIFFERENTIAL")
(120656 . "MATHEMATICAL BOLD ITALIC EPSILON SYMBOL")
(120657 . "MATHEMATICAL BOLD ITALIC THETA SYMBOL")
(120658 . "MATHEMATICAL BOLD ITALIC KAPPA SYMBOL")
(120659 . "MATHEMATICAL BOLD ITALIC PHI SYMBOL")
(120660 . "MATHEMATICAL BOLD ITALIC RHO SYMBOL")
(120661 . "MATHEMATICAL BOLD ITALIC PI SYMBOL")
(120662 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL ALPHA")
(120663 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL BETA")
(120664 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL GAMMA")
(120665 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL DELTA")
(120666 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL EPSILON")
(120667 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL ZETA")
(120668 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL ETA")
(120669 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA")
(120670 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL IOTA")
(120671 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL KAPPA")
(120672 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL LAMDA")
(120673 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL MU")
(120674 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL NU")
(120675 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL XI")
(120676 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL OMICRON")
(120677 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL PI")
(120678 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL RHO")
(120679 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA SYMBOL")
(120680 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL SIGMA")
(120681 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL TAU")
(120682 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL UPSILON")
(120683 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL PHI")
(120684 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL CHI")
(120685 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL PSI")
(120686 . "MATHEMATICAL SANS-SERIF BOLD CAPITAL OMEGA")
(120687 . "MATHEMATICAL SANS-SERIF BOLD NABLA")
(120688 . "MATHEMATICAL SANS-SERIF BOLD SMALL ALPHA")
(120689 . "MATHEMATICAL SANS-SERIF BOLD SMALL BETA")
(120690 . "MATHEMATICAL SANS-SERIF BOLD SMALL GAMMA")
(120691 . "MATHEMATICAL SANS-SERIF BOLD SMALL DELTA")
(120692 . "MATHEMATICAL SANS-SERIF BOLD SMALL EPSILON")
(120693 . "MATHEMATICAL SANS-SERIF BOLD SMALL ZETA")
(120694 . "MATHEMATICAL SANS-SERIF BOLD SMALL ETA")
(120695 . "MATHEMATICAL SANS-SERIF BOLD SMALL THETA")
(120696 . "MATHEMATICAL SANS-SERIF BOLD SMALL IOTA")
(120697 . "MATHEMATICAL SANS-SERIF BOLD SMALL KAPPA")
(120698 . "MATHEMATICAL SANS-SERIF BOLD SMALL LAMDA")
(120699 . "MATHEMATICAL SANS-SERIF BOLD SMALL MU")
(120700 . "MATHEMATICAL SANS-SERIF BOLD SMALL NU")
(120701 . "MATHEMATICAL SANS-SERIF BOLD SMALL XI")
(120702 . "MATHEMATICAL SANS-SERIF BOLD SMALL OMICRON")
(120703 . "MATHEMATICAL SANS-SERIF BOLD SMALL PI")
(120704 . "MATHEMATICAL SANS-SERIF BOLD SMALL RHO")
(120705 . "MATHEMATICAL SANS-SERIF BOLD SMALL FINAL SIGMA")
(120706 . "MATHEMATICAL SANS-SERIF BOLD SMALL SIGMA")
(120707 . "MATHEMATICAL SANS-SERIF BOLD SMALL TAU")
(120708 . "MATHEMATICAL SANS-SERIF BOLD SMALL UPSILON")
(120709 . "MATHEMATICAL SANS-SERIF BOLD SMALL PHI")
(120710 . "MATHEMATICAL SANS-SERIF BOLD SMALL CHI")
(120711 . "MATHEMATICAL SANS-SERIF BOLD SMALL PSI")
(120712 . "MATHEMATICAL SANS-SERIF BOLD SMALL OMEGA")
(120713 . "MATHEMATICAL SANS-SERIF BOLD PARTIAL DIFFERENTIAL")
(120714 . "MATHEMATICAL SANS-SERIF BOLD EPSILON SYMBOL")
(120715 . "MATHEMATICAL SANS-SERIF BOLD THETA SYMBOL")
(120716 . "MATHEMATICAL SANS-SERIF BOLD KAPPA SYMBOL")
(120717 . "MATHEMATICAL SANS-SERIF BOLD PHI SYMBOL")
(120718 . "MATHEMATICAL SANS-SERIF BOLD RHO SYMBOL")
(120719 . "MATHEMATICAL SANS-SERIF BOLD PI SYMBOL")
(120720 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ALPHA")
(120721 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL BETA")
(120722 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL GAMMA")
(120723 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL DELTA")
(120724 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL EPSILON")
(120725 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ZETA")
(120726 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ETA")
(120727 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA")
(120728 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL IOTA")
(120729 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL KAPPA")
(120730 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL LAMDA")
(120731 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL MU")
(120732 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL NU")
(120733 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL XI")
(120734 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMICRON")
(120735 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PI")
(120736 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL RHO")
(120737 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA SYMBOL")
(120738 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL SIGMA")
(120739 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL TAU")
(120740 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL UPSILON")
(120741 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PHI")
(120742 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL CHI")
(120743 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PSI")
(120744 . "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMEGA")
(120745 . "MATHEMATICAL SANS-SERIF BOLD ITALIC NABLA")
(120746 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ALPHA")
(120747 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL BETA")
(120748 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL GAMMA")
(120749 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL DELTA")
(120750 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL EPSILON")
(120751 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ZETA")
(120752 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ETA")
(120753 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL THETA")
(120754 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL IOTA")
(120755 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL KAPPA")
(120756 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL LAMDA")
(120757 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL MU")
(120758 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL NU")
(120759 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL XI")
(120760 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMICRON")
(120761 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PI")
(120762 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL RHO")
(120763 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL FINAL SIGMA")
(120764 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL SIGMA")
(120765 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL TAU")
(120766 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL UPSILON")
(120767 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PHI")
(120768 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL CHI")
(120769 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PSI")
(120770 . "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMEGA")
(120771 . "MATHEMATICAL SANS-SERIF BOLD ITALIC PARTIAL DIFFERENTIAL")
(120772 . "MATHEMATICAL SANS-SERIF BOLD ITALIC EPSILON SYMBOL")
(120773 . "MATHEMATICAL SANS-SERIF BOLD ITALIC THETA SYMBOL")
(120774 . "MATHEMATICAL SANS-SERIF BOLD ITALIC KAPPA SYMBOL")
(120775 . "MATHEMATICAL SANS-SERIF BOLD ITALIC PHI SYMBOL")
(120776 . "MATHEMATICAL SANS-SERIF BOLD ITALIC RHO SYMBOL")
(120777 . "MATHEMATICAL SANS-SERIF BOLD ITALIC PI SYMBOL")
(120778 . "MATHEMATICAL BOLD CAPITAL DIGAMMA")
(120779 . "MATHEMATICAL BOLD SMALL DIGAMMA")
((120780 . 120782) . #f)
(120782 . "MATHEMATICAL BOLD DIGIT ZERO")
(120783 . "MATHEMATICAL BOLD DIGIT ONE")
(120784 . "MATHEMATICAL BOLD DIGIT TWO")
(120785 . "MATHEMATICAL BOLD DIGIT THREE")
(120786 . "MATHEMATICAL BOLD DIGIT FOUR")
(120787 . "MATHEMATICAL BOLD DIGIT FIVE")
(120788 . "MATHEMATICAL BOLD DIGIT SIX")
(120789 . "MATHEMATICAL BOLD DIGIT SEVEN")
(120790 . "MATHEMATICAL BOLD DIGIT EIGHT")
(120791 . "MATHEMATICAL BOLD DIGIT NINE")
(120792 . "MATHEMATICAL DOUBLE-STRUCK DIGIT ZERO")
(120793 . "MATHEMATICAL DOUBLE-STRUCK DIGIT ONE")
(120794 . "MATHEMATICAL DOUBLE-STRUCK DIGIT TWO")
(120795 . "MATHEMATICAL DOUBLE-STRUCK DIGIT THREE")
(120796 . "MATHEMATICAL DOUBLE-STRUCK DIGIT FOUR")
(120797 . "MATHEMATICAL DOUBLE-STRUCK DIGIT FIVE")
(120798 . "MATHEMATICAL DOUBLE-STRUCK DIGIT SIX")
(120799 . "MATHEMATICAL DOUBLE-STRUCK DIGIT SEVEN")
(120800 . "MATHEMATICAL DOUBLE-STRUCK DIGIT EIGHT")
(120801 . "MATHEMATICAL DOUBLE-STRUCK DIGIT NINE")
(120802 . "MATHEMATICAL SANS-SERIF DIGIT ZERO")
(120803 . "MATHEMATICAL SANS-SERIF DIGIT ONE")
(120804 . "MATHEMATICAL SANS-SERIF DIGIT TWO")
(120805 . "MATHEMATICAL SANS-SERIF DIGIT THREE")
(120806 . "MATHEMATICAL SANS-SERIF DIGIT FOUR")
(120807 . "MATHEMATICAL SANS-SERIF DIGIT FIVE")
(120808 . "MATHEMATICAL SANS-SERIF DIGIT SIX")
(120809 . "MATHEMATICAL SANS-SERIF DIGIT SEVEN")
(120810 . "MATHEMATICAL SANS-SERIF DIGIT EIGHT")
(120811 . "MATHEMATICAL SANS-SERIF DIGIT NINE")
(120812 . "MATHEMATICAL SANS-SERIF BOLD DIGIT ZERO")
(120813 . "MATHEMATICAL SANS-SERIF BOLD DIGIT ONE")
(120814 . "MATHEMATICAL SANS-SERIF BOLD DIGIT TWO")
(120815 . "MATHEMATICAL SANS-SERIF BOLD DIGIT THREE")
(120816 . "MATHEMATICAL SANS-SERIF BOLD DIGIT FOUR")
(120817 . "MATHEMATICAL SANS-SERIF BOLD DIGIT FIVE")
(120818 . "MATHEMATICAL SANS-SERIF BOLD DIGIT SIX")
(120819 . "MATHEMATICAL SANS-SERIF BOLD DIGIT SEVEN")
(120820 . "MATHEMATICAL SANS-SERIF BOLD DIGIT EIGHT")
(120821 . "MATHEMATICAL SANS-SERIF BOLD DIGIT NINE")
(120822 . "MATHEMATICAL MONOSPACE DIGIT ZERO")
(120823 . "MATHEMATICAL MONOSPACE DIGIT ONE")
(120824 . "MATHEMATICAL MONOSPACE DIGIT TWO")
(120825 . "MATHEMATICAL MONOSPACE DIGIT THREE")
(120826 . "MATHEMATICAL MONOSPACE DIGIT FOUR")
(120827 . "MATHEMATICAL MONOSPACE DIGIT FIVE")
(120828 . "MATHEMATICAL MONOSPACE DIGIT SIX")
(120829 . "MATHEMATICAL MONOSPACE DIGIT SEVEN")
(120830 . "MATHEMATICAL MONOSPACE DIGIT EIGHT")
(120831 . "MATHEMATICAL MONOSPACE DIGIT NINE")
(120832 . "SIGNWRITING HAND-FIST INDEX")
(120833 . "SIGNWRITING HAND-CIRCLE INDEX")
(120834 . "SIGNWRITING HAND-CUP INDEX")
(120835 . "SIGNWRITING HAND-OVAL INDEX")
(120836 . "SIGNWRITING HAND-HINGE INDEX")
(120837 . "SIGNWRITING HAND-ANGLE INDEX")
(120838 . "SIGNWRITING HAND-FIST INDEX BENT")
(120839 . "SIGNWRITING HAND-CIRCLE INDEX BENT")
(120840 . "SIGNWRITING HAND-FIST THUMB UNDER INDEX BENT")
(120841 . "SIGNWRITING HAND-FIST INDEX RAISED KNUCKLE")
(120842 . "SIGNWRITING HAND-FIST INDEX CUPPED")
(120843 . "SIGNWRITING HAND-FIST INDEX HINGED")
(120844 . "SIGNWRITING HAND-FIST INDEX HINGED LOW")
(120845 . "SIGNWRITING HAND-CIRCLE INDEX HINGE")
(120846 . "SIGNWRITING HAND-FIST INDEX MIDDLE")
(120847 . "SIGNWRITING HAND-CIRCLE INDEX MIDDLE")
(120848 . "SIGNWRITING HAND-FIST INDEX MIDDLE BENT")
(120849 . "SIGNWRITING HAND-FIST INDEX MIDDLE RAISED KNUCKLES")
(120850 . "SIGNWRITING HAND-FIST INDEX MIDDLE HINGED")
(120851 . "SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED")
(120852 . "SIGNWRITING HAND-FIST INDEX HINGED MIDDLE UP")
(120853 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED")
(120854 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED INDEX BENT")
(120855 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED MIDDLE BENT")
(120856 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED CUPPED")
(120857 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED HINGED")
(120858 . "SIGNWRITING HAND-FIST INDEX MIDDLE CROSSED")
(120859 . "SIGNWRITING HAND-CIRCLE INDEX MIDDLE CROSSED")
(120860 . "SIGNWRITING HAND-FIST MIDDLE BENT OVER INDEX")
(120861 . "SIGNWRITING HAND-FIST INDEX BENT OVER MIDDLE")
(120862 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB")
(120863 . "SIGNWRITING HAND-CIRCLE INDEX MIDDLE THUMB")
(120864 . "SIGNWRITING HAND-FIST INDEX MIDDLE STRAIGHT THUMB BENT")
(120865 . "SIGNWRITING HAND-FIST INDEX MIDDLE BENT THUMB STRAIGHT")
(120866 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB BENT")
(120867 . "SIGNWRITING HAND-FIST INDEX MIDDLE HINGED SPREAD THUMB SIDE")
(120868 . "SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED THUMB SIDE")
(120869 . "SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED THUMB CONJOINED")
(120870 . "SIGNWRITING HAND-FIST INDEX HINGED MIDDLE UP THUMB SIDE")
(120871 . "SIGNWRITING HAND-FIST INDEX MIDDLE UP SPREAD THUMB FORWARD")
(120872 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CUPPED")
(120873 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CIRCLED")
(120874 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB HOOKED")
(120875 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB HINGED")
(120876 . "SIGNWRITING HAND-FIST THUMB BETWEEN INDEX MIDDLE STRAIGHT")
(120877 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE")
(120878 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE CONJOINED")
(120879 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE BENT")
(120880 . "SIGNWRITING HAND-FIST MIDDLE THUMB HOOKED INDEX UP")
(120881 . "SIGNWRITING HAND-FIST INDEX THUMB HOOKED MIDDLE UP")
(120882 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED HINGED THUMB SIDE")
(120883 . "SIGNWRITING HAND-FIST INDEX MIDDLE CROSSED THUMB SIDE")
(120884 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB FORWARD")
(120885 . "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED CUPPED THUMB FORWARD")
(120886 . "SIGNWRITING HAND-FIST MIDDLE THUMB CUPPED INDEX UP")
(120887 . "SIGNWRITING HAND-FIST INDEX THUMB CUPPED MIDDLE UP")
(120888 . "SIGNWRITING HAND-FIST MIDDLE THUMB CIRCLED INDEX UP")
(120889 . "SIGNWRITING HAND-FIST MIDDLE THUMB CIRCLED INDEX HINGED")
(120890 . "SIGNWRITING HAND-FIST INDEX THUMB ANGLED OUT MIDDLE UP")
(120891 . "SIGNWRITING HAND-FIST INDEX THUMB ANGLED IN MIDDLE UP")
(120892 . "SIGNWRITING HAND-FIST INDEX THUMB CIRCLED MIDDLE UP")
(120893 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CONJOINED HINGED")
(120894 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB ANGLED OUT")
(120895 . "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB ANGLED")
(120896 . "SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED OUT INDEX UP")
(120897 . "SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED OUT INDEX CROSSED")
(120898 . "SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED INDEX UP")
(120899 . "SIGNWRITING HAND-FIST INDEX THUMB HOOKED MIDDLE HINGED")
(120900 . "SIGNWRITING HAND-FLAT FOUR FINGERS")
(120901 . "SIGNWRITING HAND-FLAT FOUR FINGERS BENT")
(120902 . "SIGNWRITING HAND-FLAT FOUR FINGERS HINGED")
(120903 . "SIGNWRITING HAND-FLAT FOUR FINGERS CONJOINED")
(120904 . "SIGNWRITING HAND-FLAT FOUR FINGERS CONJOINED SPLIT")
(120905 . "SIGNWRITING HAND-CLAW FOUR FINGERS CONJOINED")
(120906 . "SIGNWRITING HAND-FIST FOUR FINGERS CONJOINED BENT")
(120907 . "SIGNWRITING HAND-HINGE FOUR FINGERS CONJOINED")
(120908 . "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD")
(120909 . "SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD")
(120910 . "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD FOUR BENT")
(120911 . "SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD FOUR BENT")
(120912 . "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD BENT")
(120913 . "SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD BENT")
(120914 . "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD THUMB FORWARD")
(120915 . "SIGNWRITING HAND-CUP FIVE FINGERS SPREAD")
(120916 . "SIGNWRITING HAND-CUP FIVE FINGERS SPREAD OPEN")
(120917 . "SIGNWRITING HAND-HINGE FIVE FINGERS SPREAD OPEN")
(120918 . "SIGNWRITING HAND-OVAL FIVE FINGERS SPREAD")
(120919 . "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED")
(120920 . "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED THUMB SIDE")
(120921 . "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED NO THUMB")
(120922 . "SIGNWRITING HAND-FLAT")
(120923 . "SIGNWRITING HAND-FLAT BETWEEN PALM FACINGS")
(120924 . "SIGNWRITING HAND-FLAT HEEL")
(120925 . "SIGNWRITING HAND-FLAT THUMB SIDE")
(120926 . "SIGNWRITING HAND-FLAT HEEL THUMB SIDE")
(120927 . "SIGNWRITING HAND-FLAT THUMB BENT")
(120928 . "SIGNWRITING HAND-FLAT THUMB FORWARD")
(120929 . "SIGNWRITING HAND-FLAT SPLIT INDEX THUMB SIDE")
(120930 . "SIGNWRITING HAND-FLAT SPLIT CENTRE")
(120931 . "SIGNWRITING HAND-FLAT SPLIT CENTRE THUMB SIDE")
(120932 . "SIGNWRITING HAND-FLAT SPLIT CENTRE THUMB SIDE BENT")
(120933 . "SIGNWRITING HAND-FLAT SPLIT LITTLE")
(120934 . "SIGNWRITING HAND-CLAW")
(120935 . "SIGNWRITING HAND-CLAW THUMB SIDE")
(120936 . "SIGNWRITING HAND-CLAW NO THUMB")
(120937 . "SIGNWRITING HAND-CLAW THUMB FORWARD")
(120938 . "SIGNWRITING HAND-HOOK CURLICUE")
(120939 . "SIGNWRITING HAND-HOOK")
(120940 . "SIGNWRITING HAND-CUP OPEN")
(120941 . "SIGNWRITING HAND-CUP")
(120942 . "SIGNWRITING HAND-CUP OPEN THUMB SIDE")
(120943 . "SIGNWRITING HAND-CUP THUMB SIDE")
(120944 . "SIGNWRITING HAND-CUP OPEN NO THUMB")
(120945 . "SIGNWRITING HAND-CUP NO THUMB")
(120946 . "SIGNWRITING HAND-CUP OPEN THUMB FORWARD")
(120947 . "SIGNWRITING HAND-CUP THUMB FORWARD")
(120948 . "SIGNWRITING HAND-CURLICUE OPEN")
(120949 . "SIGNWRITING HAND-CURLICUE")
(120950 . "SIGNWRITING HAND-CIRCLE")
(120951 . "SIGNWRITING HAND-OVAL")
(120952 . "SIGNWRITING HAND-OVAL THUMB SIDE")
(120953 . "SIGNWRITING HAND-OVAL NO THUMB")
(120954 . "SIGNWRITING HAND-OVAL THUMB FORWARD")
(120955 . "SIGNWRITING HAND-HINGE OPEN")
(120956 . "SIGNWRITING HAND-HINGE OPEN THUMB FORWARD")
(120957 . "SIGNWRITING HAND-HINGE")
(120958 . "SIGNWRITING HAND-HINGE SMALL")
(120959 . "SIGNWRITING HAND-HINGE OPEN THUMB SIDE")
(120960 . "SIGNWRITING HAND-HINGE THUMB SIDE")
(120961 . "SIGNWRITING HAND-HINGE OPEN NO THUMB")
(120962 . "SIGNWRITING HAND-HINGE NO THUMB")
(120963 . "SIGNWRITING HAND-HINGE THUMB SIDE TOUCHING INDEX")
(120964 . "SIGNWRITING HAND-HINGE THUMB BETWEEN MIDDLE RING")
(120965 . "SIGNWRITING HAND-ANGLE")
(120966 . "SIGNWRITING HAND-FIST INDEX MIDDLE RING")
(120967 . "SIGNWRITING HAND-CIRCLE INDEX MIDDLE RING")
(120968 . "SIGNWRITING HAND-HINGE INDEX MIDDLE RING")
(120969 . "SIGNWRITING HAND-ANGLE INDEX MIDDLE RING")
(120970 . "SIGNWRITING HAND-HINGE LITTLE")
(120971 . "SIGNWRITING HAND-FIST INDEX MIDDLE RING BENT")
(120972 . "SIGNWRITING HAND-FIST INDEX MIDDLE RING CONJOINED")
(120973 . "SIGNWRITING HAND-HINGE INDEX MIDDLE RING CONJOINED")
(120974 . "SIGNWRITING HAND-FIST LITTLE DOWN")
(120975 . "SIGNWRITING HAND-FIST LITTLE DOWN RIPPLE STRAIGHT")
(120976 . "SIGNWRITING HAND-FIST LITTLE DOWN RIPPLE CURVED")
(120977 . "SIGNWRITING HAND-FIST LITTLE DOWN OTHERS CIRCLED")
(120978 . "SIGNWRITING HAND-FIST LITTLE UP")
(120979 . "SIGNWRITING HAND-FIST THUMB UNDER LITTLE UP")
(120980 . "SIGNWRITING HAND-CIRCLE LITTLE UP")
(120981 . "SIGNWRITING HAND-OVAL LITTLE UP")
(120982 . "SIGNWRITING HAND-ANGLE LITTLE UP")
(120983 . "SIGNWRITING HAND-FIST LITTLE RAISED KNUCKLE")
(120984 . "SIGNWRITING HAND-FIST LITTLE BENT")
(120985 . "SIGNWRITING HAND-FIST LITTLE TOUCHES THUMB")
(120986 . "SIGNWRITING HAND-FIST LITTLE THUMB")
(120987 . "SIGNWRITING HAND-HINGE LITTLE THUMB")
(120988 . "SIGNWRITING HAND-FIST LITTLE INDEX THUMB")
(120989 . "SIGNWRITING HAND-HINGE LITTLE INDEX THUMB")
(120990 . "SIGNWRITING HAND-ANGLE LITTLE INDEX THUMB INDEX THUMB OUT")
(120991 . "SIGNWRITING HAND-ANGLE LITTLE INDEX THUMB INDEX THUMB")
(120992 . "SIGNWRITING HAND-FIST LITTLE INDEX")
(120993 . "SIGNWRITING HAND-CIRCLE LITTLE INDEX")
(120994 . "SIGNWRITING HAND-HINGE LITTLE INDEX")
(120995 . "SIGNWRITING HAND-ANGLE LITTLE INDEX")
(120996 . "SIGNWRITING HAND-FIST INDEX MIDDLE LITTLE")
(120997 . "SIGNWRITING HAND-CIRCLE INDEX MIDDLE LITTLE")
(120998 . "SIGNWRITING HAND-HINGE INDEX MIDDLE LITTLE")
(120999 . "SIGNWRITING HAND-HINGE RING")
(121000 . "SIGNWRITING HAND-ANGLE INDEX MIDDLE LITTLE")
(121001 . "SIGNWRITING HAND-FIST INDEX MIDDLE CROSS LITTLE")
(121002 . "SIGNWRITING HAND-CIRCLE INDEX MIDDLE CROSS LITTLE")
(121003 . "SIGNWRITING HAND-FIST RING DOWN")
(121004 . "SIGNWRITING HAND-HINGE RING DOWN INDEX THUMB HOOK MIDDLE")
(121005 . "SIGNWRITING HAND-ANGLE RING DOWN MIDDLE THUMB INDEX CROSS")
(121006 . "SIGNWRITING HAND-FIST RING UP")
(121007 . "SIGNWRITING HAND-FIST RING RAISED KNUCKLE")
(121008 . "SIGNWRITING HAND-FIST RING LITTLE")
(121009 . "SIGNWRITING HAND-CIRCLE RING LITTLE")
(121010 . "SIGNWRITING HAND-OVAL RING LITTLE")
(121011 . "SIGNWRITING HAND-ANGLE RING LITTLE")
(121012 . "SIGNWRITING HAND-FIST RING MIDDLE")
(121013 . "SIGNWRITING HAND-FIST RING MIDDLE CONJOINED")
(121014 . "SIGNWRITING HAND-FIST RING MIDDLE RAISED KNUCKLES")
(121015 . "SIGNWRITING HAND-FIST RING INDEX")
(121016 . "SIGNWRITING HAND-FIST RING THUMB")
(121017 . "SIGNWRITING HAND-HOOK RING THUMB")
(121018 . "SIGNWRITING HAND-FIST INDEX RING LITTLE")
(121019 . "SIGNWRITING HAND-CIRCLE INDEX RING LITTLE")
(121020 . "SIGNWRITING HAND-CURLICUE INDEX RING LITTLE ON")
(121021 . "SIGNWRITING HAND-HOOK INDEX RING LITTLE OUT")
(121022 . "SIGNWRITING HAND-HOOK INDEX RING LITTLE IN")
(121023 . "SIGNWRITING HAND-HOOK INDEX RING LITTLE UNDER")
(121024 . "SIGNWRITING HAND-CUP INDEX RING LITTLE")
(121025 . "SIGNWRITING HAND-HINGE INDEX RING LITTLE")
(121026 . "SIGNWRITING HAND-ANGLE INDEX RING LITTLE OUT")
(121027 . "SIGNWRITING HAND-ANGLE INDEX RING LITTLE")
(121028 . "SIGNWRITING HAND-FIST MIDDLE DOWN")
(121029 . "SIGNWRITING HAND-HINGE MIDDLE")
(121030 . "SIGNWRITING HAND-FIST MIDDLE UP")
(121031 . "SIGNWRITING HAND-CIRCLE MIDDLE UP")
(121032 . "SIGNWRITING HAND-FIST MIDDLE RAISED KNUCKLE")
(121033 . "SIGNWRITING HAND-FIST MIDDLE UP THUMB SIDE")
(121034 . "SIGNWRITING HAND-HOOK MIDDLE THUMB")
(121035 . "SIGNWRITING HAND-FIST MIDDLE THUMB LITTLE")
(121036 . "SIGNWRITING HAND-FIST MIDDLE LITTLE")
(121037 . "SIGNWRITING HAND-FIST MIDDLE RING LITTLE")
(121038 . "SIGNWRITING HAND-CIRCLE MIDDLE RING LITTLE")
(121039 . "SIGNWRITING HAND-CURLICUE MIDDLE RING LITTLE ON")
(121040 . "SIGNWRITING HAND-CUP MIDDLE RING LITTLE")
(121041 . "SIGNWRITING HAND-HINGE MIDDLE RING LITTLE")
(121042 . "SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE OUT")
(121043 . "SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE IN")
(121044 . "SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE")
(121045 . "SIGNWRITING HAND-CIRCLE MIDDLE RING LITTLE BENT")
(121046 . "SIGNWRITING HAND-CLAW MIDDLE RING LITTLE CONJOINED")
(121047 . "SIGNWRITING HAND-CLAW MIDDLE RING LITTLE CONJOINED SIDE")
(121048 . "SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED OUT")
(121049 . "SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED IN")
(121050 . "SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED")
(121051 . "SIGNWRITING HAND-HINGE INDEX HINGED")
(121052 . "SIGNWRITING HAND-FIST INDEX THUMB SIDE")
(121053 . "SIGNWRITING HAND-HINGE INDEX THUMB SIDE")
(121054 . "SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB DIAGONAL")
(121055 . "SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB CONJOINED")
(121056 . "SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB BENT")
(121057 . "SIGNWRITING HAND-FIST INDEX THUMB SIDE INDEX BENT")
(121058 . "SIGNWRITING HAND-FIST INDEX THUMB SIDE BOTH BENT")
(121059 . "SIGNWRITING HAND-FIST INDEX THUMB SIDE INDEX HINGE")
(121060 . "SIGNWRITING HAND-FIST INDEX THUMB FORWARD INDEX STRAIGHT")
(121061 . "SIGNWRITING HAND-FIST INDEX THUMB FORWARD INDEX BENT")
(121062 . "SIGNWRITING HAND-FIST INDEX THUMB HOOK")
(121063 . "SIGNWRITING HAND-FIST INDEX THUMB CURLICUE")
(121064 . "SIGNWRITING HAND-FIST INDEX THUMB CURVE THUMB INSIDE")
(121065 . "SIGNWRITING HAND-CLAW INDEX THUMB CURVE THUMB INSIDE")
(121066 . "SIGNWRITING HAND-FIST INDEX THUMB CURVE THUMB UNDER")
(121067 . "SIGNWRITING HAND-FIST INDEX THUMB CIRCLE")
(121068 . "SIGNWRITING HAND-CUP INDEX THUMB")
(121069 . "SIGNWRITING HAND-CUP INDEX THUMB OPEN")
(121070 . "SIGNWRITING HAND-HINGE INDEX THUMB OPEN")
(121071 . "SIGNWRITING HAND-HINGE INDEX THUMB LARGE")
(121072 . "SIGNWRITING HAND-HINGE INDEX THUMB")
(121073 . "SIGNWRITING HAND-HINGE INDEX THUMB SMALL")
(121074 . "SIGNWRITING HAND-ANGLE INDEX THUMB OUT")
(121075 . "SIGNWRITING HAND-ANGLE INDEX THUMB IN")
(121076 . "SIGNWRITING HAND-ANGLE INDEX THUMB")
(121077 . "SIGNWRITING HAND-FIST THUMB")
(121078 . "SIGNWRITING HAND-FIST THUMB HEEL")
(121079 . "SIGNWRITING HAND-FIST THUMB SIDE DIAGONAL")
(121080 . "SIGNWRITING HAND-FIST THUMB SIDE CONJOINED")
(121081 . "SIGNWRITING HAND-FIST THUMB SIDE BENT")
(121082 . "SIGNWRITING HAND-FIST THUMB FORWARD")
(121083 . "SIGNWRITING HAND-FIST THUMB BETWEEN INDEX MIDDLE")
(121084 . "SIGNWRITING HAND-FIST THUMB BETWEEN MIDDLE RING")
(121085 . "SIGNWRITING HAND-FIST THUMB BETWEEN RING LITTLE")
(121086 . "SIGNWRITING HAND-FIST THUMB UNDER TWO FINGERS")
(121087 . "SIGNWRITING HAND-FIST THUMB OVER TWO FINGERS")
(121088 . "SIGNWRITING HAND-FIST THUMB UNDER THREE FINGERS")
(121089 . "SIGNWRITING HAND-FIST THUMB UNDER FOUR FINGERS")
(121090 . "SIGNWRITING HAND-FIST THUMB OVER FOUR RAISED KNUCKLES")
(121091 . "SIGNWRITING HAND-FIST")
(121092 . "SIGNWRITING HAND-FIST HEEL")
(121093 . "SIGNWRITING TOUCH SINGLE")
(121094 . "SIGNWRITING TOUCH MULTIPLE")
(121095 . "SIGNWRITING TOUCH BETWEEN")
(121096 . "SIGNWRITING GRASP SINGLE")
(121097 . "SIGNWRITING GRASP MULTIPLE")
(121098 . "SIGNWRITING GRASP BETWEEN")
(121099 . "SIGNWRITING STRIKE SINGLE")
(121100 . "SIGNWRITING STRIKE MULTIPLE")
(121101 . "SIGNWRITING STRIKE BETWEEN")
(121102 . "SIGNWRITING BRUSH SINGLE")
(121103 . "SIGNWRITING BRUSH MULTIPLE")
(121104 . "SIGNWRITING BRUSH BETWEEN")
(121105 . "SIGNWRITING RUB SINGLE")
(121106 . "SIGNWRITING RUB MULTIPLE")
(121107 . "SIGNWRITING RUB BETWEEN")
(121108 . "SIGNWRITING SURFACE SYMBOLS")
(121109 . "SIGNWRITING SURFACE BETWEEN")
(121110 . "SIGNWRITING SQUEEZE LARGE SINGLE")
(121111 . "SIGNWRITING SQUEEZE SMALL SINGLE")
(121112 . "SIGNWRITING SQUEEZE LARGE MULTIPLE")
(121113 . "SIGNWRITING SQUEEZE SMALL MULTIPLE")
(121114 . "SIGNWRITING SQUEEZE SEQUENTIAL")
(121115 . "SIGNWRITING FLICK LARGE SINGLE")
(121116 . "SIGNWRITING FLICK SMALL SINGLE")
(121117 . "SIGNWRITING FLICK LARGE MULTIPLE")
(121118 . "SIGNWRITING FLICK SMALL MULTIPLE")
(121119 . "SIGNWRITING FLICK SEQUENTIAL")
(121120 . "SIGNWRITING SQUEEZE FLICK ALTERNATING")
(121121 . "SIGNWRITING MOVEMENT-HINGE UP DOWN LARGE")
(121122 . "SIGNWRITING MOVEMENT-HINGE UP DOWN SMALL")
(121123 . "SIGNWRITING MOVEMENT-HINGE UP SEQUENTIAL")
(121124 . "SIGNWRITING MOVEMENT-HINGE DOWN SEQUENTIAL")
(121125 . "SIGNWRITING MOVEMENT-HINGE UP DOWN ALTERNATING LARGE")
(121126 . "SIGNWRITING MOVEMENT-HINGE UP DOWN ALTERNATING SMALL")
(121127 . "SIGNWRITING MOVEMENT-HINGE SIDE TO SIDE SCISSORS")
(121128 . "SIGNWRITING MOVEMENT-WALLPLANE FINGER CONTACT")
(121129 . "SIGNWRITING MOVEMENT-FLOORPLANE FINGER CONTACT")
(121130 . "SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT SMALL")
(121131 . "SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT MEDIUM")
(121132 . "SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT LARGE")
(121133 . "SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT LARGEST")
(121134 . "SIGNWRITING MOVEMENT-WALLPLANE SINGLE WRIST FLEX")
(121135 . "SIGNWRITING MOVEMENT-WALLPLANE DOUBLE STRAIGHT")
(121136 . "SIGNWRITING MOVEMENT-WALLPLANE DOUBLE WRIST FLEX")
(121137 . "SIGNWRITING MOVEMENT-WALLPLANE DOUBLE ALTERNATING")
(121138 . "SIGNWRITING MOVEMENT-WALLPLANE DOUBLE ALTERNATING WRIST FLEX")
(121139 . "SIGNWRITING MOVEMENT-WALLPLANE CROSS")
(121140 . "SIGNWRITING MOVEMENT-WALLPLANE TRIPLE STRAIGHT MOVEMENT")
(121141 . "SIGNWRITING MOVEMENT-WALLPLANE TRIPLE WRIST FLEX")
(121142 . "SIGNWRITING MOVEMENT-WALLPLANE TRIPLE ALTERNATING")
(121143 . "SIGNWRITING MOVEMENT-WALLPLANE TRIPLE ALTERNATING WRIST FLEX")
(121144 . "SIGNWRITING MOVEMENT-WALLPLANE BEND SMALL")
(121145 . "SIGNWRITING MOVEMENT-WALLPLANE BEND MEDIUM")
(121146 . "SIGNWRITING MOVEMENT-WALLPLANE BEND LARGE")
(121147 . "SIGNWRITING MOVEMENT-WALLPLANE CORNER SMALL")
(121148 . "SIGNWRITING MOVEMENT-WALLPLANE CORNER MEDIUM")
(121149 . "SIGNWRITING MOVEMENT-WALLPLANE CORNER LARGE")
(121150 . "SIGNWRITING MOVEMENT-WALLPLANE CORNER ROTATION")
(121151 . "SIGNWRITING MOVEMENT-WALLPLANE CHECK SMALL")
(121152 . "SIGNWRITING MOVEMENT-WALLPLANE CHECK MEDIUM")
(121153 . "SIGNWRITING MOVEMENT-WALLPLANE CHECK LARGE")
(121154 . "SIGNWRITING MOVEMENT-WALLPLANE BOX SMALL")
(121155 . "SIGNWRITING MOVEMENT-WALLPLANE BOX MEDIUM")
(121156 . "SIGNWRITING MOVEMENT-WALLPLANE BOX LARGE")
(121157 . "SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG SMALL")
(121158 . "SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG MEDIUM")
(121159 . "SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG LARGE")
(121160 . "SIGNWRITING MOVEMENT-WALLPLANE PEAKS SMALL")
(121161 . "SIGNWRITING MOVEMENT-WALLPLANE PEAKS MEDIUM")
(121162 . "SIGNWRITING MOVEMENT-WALLPLANE PEAKS LARGE")
(121163 . "SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE SINGLE")
(121164 . "SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE DOUBLE")
(121165 . "SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE ALTERNATING")
(121166 . "SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE SINGLE")
(121167 . "SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE DOUBLE")
(121168 . "SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE ALTERNATING")
(121169 . "SIGNWRITING TRAVEL-WALLPLANE SHAKING")
(121170 . "SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL SINGLE")
(121171 . "SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL DOUBLE")
(121172 . "SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL TRIPLE")
(121173 . "SIGNWRITING MOVEMENT-DIAGONAL AWAY SMALL")
(121174 . "SIGNWRITING MOVEMENT-DIAGONAL AWAY MEDIUM")
(121175 . "SIGNWRITING MOVEMENT-DIAGONAL AWAY LARGE")
(121176 . "SIGNWRITING MOVEMENT-DIAGONAL AWAY LARGEST")
(121177 . "SIGNWRITING MOVEMENT-DIAGONAL TOWARDS SMALL")
(121178 . "SIGNWRITING MOVEMENT-DIAGONAL TOWARDS MEDIUM")
(121179 . "SIGNWRITING MOVEMENT-DIAGONAL TOWARDS LARGE")
(121180 . "SIGNWRITING MOVEMENT-DIAGONAL TOWARDS LARGEST")
(121181 . "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY SMALL")
(121182 . "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY MEDIUM")
(121183 . "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY LARGE")
(121184 . "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY LARGEST")
(121185 . "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS SMALL")
(121186 . "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS MEDIUM")
(121187 . "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS LARGE")
(121188 . "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS LARGEST")
(121189 . "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT SMALL")
(121190 . "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT MEDIUM")
(121191 . "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT LARGE")
(121192 . "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT LARGEST")
(121193 . "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE WRIST FLEX")
(121194 . "SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE STRAIGHT")
(121195 . "SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE WRIST FLEX")
(121196 . "SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE ALTERNATING")
(121197 . "SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE ALTERNATING WRIST FLEX")
(121198 . "SIGNWRITING MOVEMENT-FLOORPLANE CROSS")
(121199 . "SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE STRAIGHT MOVEMENT")
(121200 . "SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE WRIST FLEX")
(121201 . "SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE ALTERNATING MOVEMENT")
(121202 . "SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE ALTERNATING WRIST FLEX")
(121203 . "SIGNWRITING MOVEMENT-FLOORPLANE BEND")
(121204 . "SIGNWRITING MOVEMENT-FLOORPLANE CORNER SMALL")
(121205 . "SIGNWRITING MOVEMENT-FLOORPLANE CORNER MEDIUM")
(121206 . "SIGNWRITING MOVEMENT-FLOORPLANE CORNER LARGE")
(121207 . "SIGNWRITING MOVEMENT-FLOORPLANE CHECK")
(121208 . "SIGNWRITING MOVEMENT-FLOORPLANE BOX SMALL")
(121209 . "SIGNWRITING MOVEMENT-FLOORPLANE BOX MEDIUM")
(121210 . "SIGNWRITING MOVEMENT-FLOORPLANE BOX LARGE")
(121211 . "SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG SMALL")
(121212 . "SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG MEDIUM")
(121213 . "SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG LARGE")
(121214 . "SIGNWRITING MOVEMENT-FLOORPLANE PEAKS SMALL")
(121215 . "SIGNWRITING MOVEMENT-FLOORPLANE PEAKS MEDIUM")
(121216 . "SIGNWRITING MOVEMENT-FLOORPLANE PEAKS LARGE")
(121217 . "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE SINGLE")
(121218 . "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE DOUBLE")
(121219 . "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE ALTERNATING")
(121220 . "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE SINGLE")
(121221 . "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE DOUBLE")
(121222 . "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE ALTERNATING")
(121223 . "SIGNWRITING TRAVEL-FLOORPLANE SHAKING")
(121224 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER SMALL")
(121225 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER MEDIUM")
(121226 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER LARGE")
(121227 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER LARGEST")
(121228 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE SMALL")
(121229 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE MEDIUM")
(121230 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE LARGE")
(121231 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE LARGEST")
(121232 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE THREE-QUARTER CIRCLE SMALL")
(121233 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE THREE-QUARTER CIRCLE MEDIUM")
(121234 . "SIGNWRITING MOVEMENT-WALLPLANE HUMP SMALL")
(121235 . "SIGNWRITING MOVEMENT-WALLPLANE HUMP MEDIUM")
(121236 . "SIGNWRITING MOVEMENT-WALLPLANE HUMP LARGE")
(121237 . "SIGNWRITING MOVEMENT-WALLPLANE LOOP SMALL")
(121238 . "SIGNWRITING MOVEMENT-WALLPLANE LOOP MEDIUM")
(121239 . "SIGNWRITING MOVEMENT-WALLPLANE LOOP LARGE")
(121240 . "SIGNWRITING MOVEMENT-WALLPLANE LOOP SMALL DOUBLE")
(121241 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE SMALL")
(121242 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE MEDIUM")
(121243 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE LARGE")
(121244 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE SMALL")
(121245 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE MEDIUM")
(121246 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE LARGE")
(121247 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE THEN STRAIGHT")
(121248 . "SIGNWRITING MOVEMENT-WALLPLANE CURVED CROSS SMALL")
(121249 . "SIGNWRITING MOVEMENT-WALLPLANE CURVED CROSS MEDIUM")
(121250 . "SIGNWRITING ROTATION-WALLPLANE SINGLE")
(121251 . "SIGNWRITING ROTATION-WALLPLANE DOUBLE")
(121252 . "SIGNWRITING ROTATION-WALLPLANE ALTERNATE")
(121253 . "SIGNWRITING MOVEMENT-WALLPLANE SHAKING")
(121254 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE HITTING FRONT WALL")
(121255 . "SIGNWRITING MOVEMENT-WALLPLANE HUMP HITTING FRONT WALL")
(121256 . "SIGNWRITING MOVEMENT-WALLPLANE LOOP HITTING FRONT WALL")
(121257 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE HITTING FRONT WALL")
(121258 . "SIGNWRITING ROTATION-WALLPLANE SINGLE HITTING FRONT WALL")
(121259 . "SIGNWRITING ROTATION-WALLPLANE DOUBLE HITTING FRONT WALL")
(121260 . "SIGNWRITING ROTATION-WALLPLANE ALTERNATING HITTING FRONT WALL")
(121261 . "SIGNWRITING MOVEMENT-WALLPLANE CURVE HITTING CHEST")
(121262 . "SIGNWRITING MOVEMENT-WALLPLANE HUMP HITTING CHEST")
(121263 . "SIGNWRITING MOVEMENT-WALLPLANE LOOP HITTING CHEST")
(121264 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE HITTING CHEST")
(121265 . "SIGNWRITING ROTATION-WALLPLANE SINGLE HITTING CHEST")
(121266 . "SIGNWRITING ROTATION-WALLPLANE DOUBLE HITTING CHEST")
(121267 . "SIGNWRITING ROTATION-WALLPLANE ALTERNATING HITTING CHEST")
(121268 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH SMALL")
(121269 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH MEDIUM")
(121270 . "SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH LARGE")
(121271 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING CEILING SMALL")
(121272 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING CEILING LARGE")
(121273 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING SMALL DOUBLE")
(121274 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING LARGE DOUBLE")
(121275 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING SMALL TRIPLE")
(121276 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING LARGE TRIPLE")
(121277 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING SMALL SINGLE")
(121278 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING LARGE SINGLE")
(121279 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING SMALL DOUBLE")
(121280 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING LARGE DOUBLE")
(121281 . "SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING CEILING SMALL")
(121282 . "SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING CEILING LARGE")
(121283 . "SIGNWRITING ROTATION-FLOORPLANE SINGLE HITTING CEILING")
(121284 . "SIGNWRITING ROTATION-FLOORPLANE DOUBLE HITTING CEILING")
(121285 . "SIGNWRITING ROTATION-FLOORPLANE ALTERNATING HITTING CEILING")
(121286 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING FLOOR SMALL")
(121287 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING FLOOR LARGE")
(121288 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR SMALL DOUBLE")
(121289 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR LARGE DOUBLE")
(121290 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR TRIPLE SMALL TRIPLE")
(121291 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR TRIPLE LARGE TRIPLE")
(121292 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR SMALL SINGLE")
(121293 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR LARGE SINGLE")
(121294 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR SMALL DOUBLE")
(121295 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR LARGE DOUBLE")
(121296 . "SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING FLOOR SMALL")
(121297 . "SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING FLOOR LARGE")
(121298 . "SIGNWRITING ROTATION-FLOORPLANE SINGLE HITTING FLOOR")
(121299 . "SIGNWRITING ROTATION-FLOORPLANE DOUBLE HITTING FLOOR")
(121300 . "SIGNWRITING ROTATION-FLOORPLANE ALTERNATING HITTING FLOOR")
(121301 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE SMALL")
(121302 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE MEDIUM")
(121303 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE LARGE")
(121304 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE LARGEST")
(121305 . "SIGNWRITING MOVEMENT-FLOORPLANE CURVE COMBINED")
(121306 . "SIGNWRITING MOVEMENT-FLOORPLANE HUMP SMALL")
(121307 . "SIGNWRITING MOVEMENT-FLOORPLANE LOOP SMALL")
(121308 . "SIGNWRITING MOVEMENT-FLOORPLANE WAVE SNAKE")
(121309 . "SIGNWRITING MOVEMENT-FLOORPLANE WAVE SMALL")
(121310 . "SIGNWRITING MOVEMENT-FLOORPLANE WAVE LARGE")
(121311 . "SIGNWRITING ROTATION-FLOORPLANE SINGLE")
(121312 . "SIGNWRITING ROTATION-FLOORPLANE DOUBLE")
(121313 . "SIGNWRITING ROTATION-FLOORPLANE ALTERNATING")
(121314 . "SIGNWRITING MOVEMENT-FLOORPLANE SHAKING PARALLEL")
(121315 . "SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE SMALL SINGLE")
(121316 . "SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE MEDIUM SINGLE")
(121317 . "SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE SMALL DOUBLE")
(121318 . "SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE MEDIUM DOUBLE")
(121319 . "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL SMALL SINGLE")
(121320 . "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL MEDIUM SINGLE")
(121321 . "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL LARGE SINGLE")
(121322 . "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL SMALL DOUBLE")
(121323 . "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL MEDIUM DOUBLE")
(121324 . "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL LARGE DOUBLE")
(121325 . "SIGNWRITING MOVEMENT-WALLPLANE WRIST CIRCLE FRONT SINGLE")
(121326 . "SIGNWRITING MOVEMENT-WALLPLANE WRIST CIRCLE FRONT DOUBLE")
(121327 . "SIGNWRITING MOVEMENT-FLOORPLANE WRIST CIRCLE HITTING WALL SINGLE")
(121328 . "SIGNWRITING MOVEMENT-FLOORPLANE WRIST CIRCLE HITTING WALL DOUBLE")
(121329 . "SIGNWRITING MOVEMENT-WALLPLANE FINGER CIRCLES SINGLE")
(121330 . "SIGNWRITING MOVEMENT-WALLPLANE FINGER CIRCLES DOUBLE")
(121331 . "SIGNWRITING MOVEMENT-FLOORPLANE FINGER CIRCLES HITTING WALL SINGLE")
(121332 . "SIGNWRITING MOVEMENT-FLOORPLANE FINGER CIRCLES HITTING WALL DOUBLE")
(121333 . "SIGNWRITING DYNAMIC ARROWHEAD SMALL")
(121334 . "SIGNWRITING DYNAMIC ARROWHEAD LARGE")
(121335 . "SIGNWRITING DYNAMIC FAST")
(121336 . "SIGNWRITING DYNAMIC SLOW")
(121337 . "SIGNWRITING DYNAMIC TENSE")
(121338 . "SIGNWRITING DYNAMIC RELAXED")
(121339 . "SIGNWRITING DYNAMIC SIMULTANEOUS")
(121340 . "SIGNWRITING DYNAMIC SIMULTANEOUS ALTERNATING")
(121341 . "SIGNWRITING DYNAMIC EVERY OTHER TIME")
(121342 . "SIGNWRITING DYNAMIC GRADUAL")
(121343 . "SIGNWRITING HEAD")
(121344 . "SIGNWRITING HEAD RIM")
(121345 . "SIGNWRITING HEAD MOVEMENT-WALLPLANE STRAIGHT")
(121346 . "SIGNWRITING HEAD MOVEMENT-WALLPLANE TILT")
(121347 . "SIGNWRITING HEAD MOVEMENT-FLOORPLANE STRAIGHT")
(121348 . "SIGNWRITING HEAD MOVEMENT-WALLPLANE CURVE")
(121349 . "SIGNWRITING HEAD MOVEMENT-FLOORPLANE CURVE")
(121350 . "SIGNWRITING HEAD MOVEMENT CIRCLE")
(121351 . "SIGNWRITING FACE DIRECTION POSITION NOSE FORWARD TILTING")
(121352 . "SIGNWRITING FACE DIRECTION POSITION NOSE UP OR DOWN")
(121353 . "SIGNWRITING FACE DIRECTION POSITION NOSE UP OR DOWN TILTING")
(121354 . "SIGNWRITING EYEBROWS STRAIGHT UP")
(121355 . "SIGNWRITING EYEBROWS STRAIGHT NEUTRAL")
(121356 . "SIGNWRITING EYEBROWS STRAIGHT DOWN")
(121357 . "SIGNWRITING DREAMY EYEBROWS NEUTRAL DOWN")
(121358 . "SIGNWRITING DREAMY EYEBROWS DOWN NEUTRAL")
(121359 . "SIGNWRITING DREAMY EYEBROWS UP NEUTRAL")
(121360 . "SIGNWRITING DREAMY EYEBROWS NEUTRAL UP")
(121361 . "SIGNWRITING FOREHEAD NEUTRAL")
(121362 . "SIGNWRITING FOREHEAD CONTACT")
(121363 . "SIGNWRITING FOREHEAD WRINKLED")
(121364 . "SIGNWRITING EYES OPEN")
(121365 . "SIGNWRITING EYES SQUEEZED")
(121366 . "SIGNWRITING EYES CLOSED")
(121367 . "SIGNWRITING EYE BLINK SINGLE")
(121368 . "SIGNWRITING EYE BLINK MULTIPLE")
(121369 . "SIGNWRITING EYES HALF OPEN")
(121370 . "SIGNWRITING EYES WIDE OPEN")
(121371 . "SIGNWRITING EYES HALF CLOSED")
(121372 . "SIGNWRITING EYES WIDENING MOVEMENT")
(121373 . "SIGNWRITING EYE WINK")
(121374 . "SIGNWRITING EYELASHES UP")
(121375 . "SIGNWRITING EYELASHES DOWN")
(121376 . "SIGNWRITING EYELASHES FLUTTERING")
(121377 . "SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT")
(121378 . "SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT DOUBLE")
(121379 . "SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT ALTERNATING")
(121380 . "SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT")
(121381 . "SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT DOUBLE")
(121382 . "SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT ALTERNATING")
(121383 . "SIGNWRITING EYEGAZE-WALLPLANE CURVED")
(121384 . "SIGNWRITING EYEGAZE-FLOORPLANE CURVED")
(121385 . "SIGNWRITING EYEGAZE-WALLPLANE CIRCLING")
(121386 . "SIGNWRITING CHEEKS PUFFED")
(121387 . "SIGNWRITING CHEEKS NEUTRAL")
(121388 . "SIGNWRITING CHEEKS SUCKED")
(121389 . "SIGNWRITING TENSE CHEEKS HIGH")
(121390 . "SIGNWRITING TENSE CHEEKS MIDDLE")
(121391 . "SIGNWRITING TENSE CHEEKS LOW")
(121392 . "SIGNWRITING EARS")
(121393 . "SIGNWRITING NOSE NEUTRAL")
(121394 . "SIGNWRITING NOSE CONTACT")
(121395 . "SIGNWRITING NOSE WRINKLES")
(121396 . "SIGNWRITING NOSE WIGGLES")
(121397 . "SIGNWRITING AIR BLOWING OUT")
(121398 . "SIGNWRITING AIR SUCKING IN")
(121399 . "SIGNWRITING AIR BLOW SMALL ROTATIONS")
(121400 . "SIGNWRITING AIR SUCK SMALL ROTATIONS")
(121401 . "SIGNWRITING BREATH INHALE")
(121402 . "SIGNWRITING BREATH EXHALE")
(121403 . "SIGNWRITING MOUTH CLOSED NEUTRAL")
(121404 . "SIGNWRITING MOUTH CLOSED FORWARD")
(121405 . "SIGNWRITING MOUTH CLOSED CONTACT")
(121406 . "SIGNWRITING MOUTH SMILE")
(121407 . "SIGNWRITING MOUTH SMILE WRINKLED")
(121408 . "SIGNWRITING MOUTH SMILE OPEN")
(121409 . "SIGNWRITING MOUTH FROWN")
(121410 . "SIGNWRITING MOUTH FROWN WRINKLED")
(121411 . "SIGNWRITING MOUTH FROWN OPEN")
(121412 . "SIGNWRITING MOUTH OPEN CIRCLE")
(121413 . "SIGNWRITING MOUTH OPEN FORWARD")
(121414 . "SIGNWRITING MOUTH OPEN WRINKLED")
(121415 . "SIGNWRITING MOUTH OPEN OVAL")
(121416 . "SIGNWRITING MOUTH OPEN OVAL WRINKLED")
(121417 . "SIGNWRITING MOUTH OPEN OVAL YAWN")
(121418 . "SIGNWRITING MOUTH OPEN RECTANGLE")
(121419 . "SIGNWRITING MOUTH OPEN RECTANGLE WRINKLED")
(121420 . "SIGNWRITING MOUTH OPEN RECTANGLE YAWN")
(121421 . "SIGNWRITING MOUTH KISS")
(121422 . "SIGNWRITING MOUTH KISS FORWARD")
(121423 . "SIGNWRITING MOUTH KISS WRINKLED")
(121424 . "SIGNWRITING MOUTH TENSE")
(121425 . "SIGNWRITING MOUTH TENSE FORWARD")
(121426 . "SIGNWRITING MOUTH TENSE SUCKED")
(121427 . "SIGNWRITING LIPS PRESSED TOGETHER")
(121428 . "SIGNWRITING LIP LOWER OVER UPPER")
(121429 . "SIGNWRITING LIP UPPER OVER LOWER")
(121430 . "SIGNWRITING MOUTH CORNERS")
(121431 . "SIGNWRITING MOUTH WRINKLES SINGLE")
(121432 . "SIGNWRITING MOUTH WRINKLES DOUBLE")
(121433 . "SIGNWRITING TONGUE STICKING OUT FAR")
(121434 . "SIGNWRITING TONGUE LICKING LIPS")
(121435 . "SIGNWRITING TONGUE TIP BETWEEN LIPS")
(121436 . "SIGNWRITING TONGUE TIP TOUCHING INSIDE MOUTH")
(121437 . "SIGNWRITING TONGUE INSIDE MOUTH RELAXED")
(121438 . "SIGNWRITING TONGUE MOVES AGAINST CHEEK")
(121439 . "SIGNWRITING TONGUE CENTRE STICKING OUT")
(121440 . "SIGNWRITING TONGUE CENTRE INSIDE MOUTH")
(121441 . "SIGNWRITING TEETH")
(121442 . "SIGNWRITING TEETH MOVEMENT")
(121443 . "SIGNWRITING TEETH ON TONGUE")
(121444 . "SIGNWRITING TEETH ON TONGUE MOVEMENT")
(121445 . "SIGNWRITING TEETH ON LIPS")
(121446 . "SIGNWRITING TEETH ON LIPS MOVEMENT")
(121447 . "SIGNWRITING TEETH BITE LIPS")
(121448 . "SIGNWRITING MOVEMENT-WALLPLANE JAW")
(121449 . "SIGNWRITING MOVEMENT-FLOORPLANE JAW")
(121450 . "SIGNWRITING NECK")
(121451 . "SIGNWRITING HAIR")
(121452 . "SIGNWRITING EXCITEMENT")
(121453 . "SIGNWRITING SHOULDER HIP SPINE")
(121454 . "SIGNWRITING SHOULDER HIP POSITIONS")
(121455 . "SIGNWRITING WALLPLANE SHOULDER HIP MOVE")
(121456 . "SIGNWRITING FLOORPLANE SHOULDER HIP MOVE")
(121457 . "SIGNWRITING SHOULDER TILTING FROM WAIST")
(121458 . "SIGNWRITING TORSO-WALLPLANE STRAIGHT STRETCH")
(121459 . "SIGNWRITING TORSO-WALLPLANE CURVED BEND")
(121460 . "SIGNWRITING TORSO-FLOORPLANE TWISTING")
(121461 . "SIGNWRITING UPPER BODY TILTING FROM HIP JOINTS")
(121462 . "SIGNWRITING LIMB COMBINATION")
(121463 . "SIGNWRITING LIMB LENGTH-1")
(121464 . "SIGNWRITING LIMB LENGTH-2")
(121465 . "SIGNWRITING LIMB LENGTH-3")
(121466 . "SIGNWRITING LIMB LENGTH-4")
(121467 . "SIGNWRITING LIMB LENGTH-5")
(121468 . "SIGNWRITING LIMB LENGTH-6")
(121469 . "SIGNWRITING LIMB LENGTH-7")
(121470 . "SIGNWRITING FINGER")
(121471 . "SIGNWRITING LOCATION-WALLPLANE SPACE")
(121472 . "SIGNWRITING LOCATION-FLOORPLANE SPACE")
(121473 . "SIGNWRITING LOCATION HEIGHT")
(121474 . "SIGNWRITING LOCATION WIDTH")
(121475 . "SIGNWRITING LOCATION DEPTH")
(121476 . "SIGNWRITING LOCATION HEAD NECK")
(121477 . "SIGNWRITING LOCATION TORSO")
(121478 . "SIGNWRITING LOCATION LIMBS DIGITS")
(121479 . "SIGNWRITING COMMA")
(121480 . "SIGNWRITING FULL STOP")
(121481 . "SIGNWRITING SEMICOLON")
(121482 . "SIGNWRITING COLON")
(121483 . "SIGNWRITING PARENTHESIS")
((121484 . 121499) . #f)
(121499 . "SIGNWRITING FILL MODIFIER-2")
(121500 . "SIGNWRITING FILL MODIFIER-3")
(121501 . "SIGNWRITING FILL MODIFIER-4")
(121502 . "SIGNWRITING FILL MODIFIER-5")
(121503 . "SIGNWRITING FILL MODIFIER-6")
(121504 . #f)
(121505 . "SIGNWRITING ROTATION MODIFIER-2")
(121506 . "SIGNWRITING ROTATION MODIFIER-3")
(121507 . "SIGNWRITING ROTATION MODIFIER-4")
(121508 . "SIGNWRITING ROTATION MODIFIER-5")
(121509 . "SIGNWRITING ROTATION MODIFIER-6")
(121510 . "SIGNWRITING ROTATION MODIFIER-7")
(121511 . "SIGNWRITING ROTATION MODIFIER-8")
(121512 . "SIGNWRITING ROTATION MODIFIER-9")
(121513 . "SIGNWRITING ROTATION MODIFIER-10")
(121514 . "SIGNWRITING ROTATION MODIFIER-11")
(121515 . "SIGNWRITING ROTATION MODIFIER-12")
(121516 . "SIGNWRITING ROTATION MODIFIER-13")
(121517 . "SIGNWRITING ROTATION MODIFIER-14")
(121518 . "SIGNWRITING ROTATION MODIFIER-15")
(121519 . "SIGNWRITING ROTATION MODIFIER-16")
((121520 . 122880) . #f)
(122880 . "COMBINING GLAGOLITIC LETTER AZU")
(122881 . "COMBINING GLAGOLITIC LETTER BUKY")
(122882 . "COMBINING GLAGOLITIC LETTER VEDE")
(122883 . "COMBINING GLAGOLITIC LETTER GLAGOLI")
(122884 . "COMBINING GLAGOLITIC LETTER DOBRO")
(122885 . "COMBINING GLAGOLITIC LETTER YESTU")
(122886 . "COMBINING GLAGOLITIC LETTER ZHIVETE")
(122887 . #f)
(122888 . "COMBINING GLAGOLITIC LETTER ZEMLJA")
(122889 . "COMBINING GLAGOLITIC LETTER IZHE")
(122890 . "COMBINING GLAGOLITIC LETTER INITIAL IZHE")
(122891 . "COMBINING GLAGOLITIC LETTER I")
(122892 . "COMBINING GLAGOLITIC LETTER DJERVI")
(122893 . "COMBINING GLAGOLITIC LETTER KAKO")
(122894 . "COMBINING GLAGOLITIC LETTER LJUDIJE")
(122895 . "COMBINING GLAGOLITIC LETTER MYSLITE")
(122896 . "COMBINING GLAGOLITIC LETTER NASHI")
(122897 . "COMBINING GLAGOLITIC LETTER ONU")
(122898 . "COMBINING GLAGOLITIC LETTER POKOJI")
(122899 . "COMBINING GLAGOLITIC LETTER RITSI")
(122900 . "COMBINING GLAGOLITIC LETTER SLOVO")
(122901 . "COMBINING GLAGOLITIC LETTER TVRIDO")
(122902 . "COMBINING GLAGOLITIC LETTER UKU")
(122903 . "COMBINING GLAGOLITIC LETTER FRITU")
(122904 . "COMBINING GLAGOLITIC LETTER HERU")
((122905 . 122907) . #f)
(122907 . "COMBINING GLAGOLITIC LETTER SHTA")
(122908 . "COMBINING GLAGOLITIC LETTER TSI")
(122909 . "COMBINING GLAGOLITIC LETTER CHRIVI")
(122910 . "COMBINING GLAGOLITIC LETTER SHA")
(122911 . "COMBINING GLAGOLITIC LETTER YERU")
(122912 . "COMBINING GLAGOLITIC LETTER YERI")
(122913 . "COMBINING GLAGOLITIC LETTER YATI")
(122914 . #f)
(122915 . "COMBINING GLAGOLITIC LETTER YU")
(122916 . "COMBINING GLAGOLITIC LETTER SMALL YUS")
(122917 . #f)
(122918 . "COMBINING GLAGOLITIC LETTER YO")
(122919 . "COMBINING GLAGOLITIC LETTER IOTATED SMALL YUS")
(122920 . "COMBINING GLAGOLITIC LETTER BIG YUS")
(122921 . "COMBINING GLAGOLITIC LETTER IOTATED BIG YUS")
(122922 . "COMBINING GLAGOLITIC LETTER FITA")
((122923 . 124928) . #f)
(124928 . "MENDE KIKAKUI SYLLABLE M001 KI")
(124929 . "MENDE KIKAKUI SYLLABLE M002 KA")
(124930 . "MENDE KIKAKUI SYLLABLE M003 KU")
(124931 . "MENDE KIKAKUI SYLLABLE M065 KEE")
(124932 . "MENDE KIKAKUI SYLLABLE M095 KE")
(124933 . "MENDE KIKAKUI SYLLABLE M076 KOO")
(124934 . "MENDE KIKAKUI SYLLABLE M048 KO")
(124935 . "MENDE KIKAKUI SYLLABLE M179 KUA")
(124936 . "MENDE KIKAKUI SYLLABLE M004 WI")
(124937 . "MENDE KIKAKUI SYLLABLE M005 WA")
(124938 . "MENDE KIKAKUI SYLLABLE M006 WU")
(124939 . "MENDE KIKAKUI SYLLABLE M126 WEE")
(124940 . "MENDE KIKAKUI SYLLABLE M118 WE")
(124941 . "MENDE KIKAKUI SYLLABLE M114 WOO")
(124942 . "MENDE KIKAKUI SYLLABLE M045 WO")
(124943 . "MENDE KIKAKUI SYLLABLE M194 WUI")
(124944 . "MENDE KIKAKUI SYLLABLE M143 WEI")
(124945 . "MENDE KIKAKUI SYLLABLE M061 WVI")
(124946 . "MENDE KIKAKUI SYLLABLE M049 WVA")
(124947 . "MENDE KIKAKUI SYLLABLE M139 WVE")
(124948 . "MENDE KIKAKUI SYLLABLE M007 MIN")
(124949 . "MENDE KIKAKUI SYLLABLE M008 MAN")
(124950 . "MENDE KIKAKUI SYLLABLE M009 MUN")
(124951 . "MENDE KIKAKUI SYLLABLE M059 MEN")
(124952 . "MENDE KIKAKUI SYLLABLE M094 MON")
(124953 . "MENDE KIKAKUI SYLLABLE M154 MUAN")
(124954 . "MENDE KIKAKUI SYLLABLE M189 MUEN")
(124955 . "MENDE KIKAKUI SYLLABLE M010 BI")
(124956 . "MENDE KIKAKUI SYLLABLE M011 BA")
(124957 . "MENDE KIKAKUI SYLLABLE M012 BU")
(124958 . "MENDE KIKAKUI SYLLABLE M150 BEE")
(124959 . "MENDE KIKAKUI SYLLABLE M097 BE")
(124960 . "MENDE KIKAKUI SYLLABLE M103 BOO")
(124961 . "MENDE KIKAKUI SYLLABLE M138 BO")
(124962 . "MENDE KIKAKUI SYLLABLE M013 I")
(124963 . "MENDE KIKAKUI SYLLABLE M014 A")
(124964 . "MENDE KIKAKUI SYLLABLE M015 U")
(124965 . "MENDE KIKAKUI SYLLABLE M163 EE")
(124966 . "MENDE KIKAKUI SYLLABLE M100 E")
(124967 . "MENDE KIKAKUI SYLLABLE M165 OO")
(124968 . "MENDE KIKAKUI SYLLABLE M147 O")
(124969 . "MENDE KIKAKUI SYLLABLE M137 EI")
(124970 . "MENDE KIKAKUI SYLLABLE M131 IN")
(124971 . "MENDE KIKAKUI SYLLABLE M135 IN")
(124972 . "MENDE KIKAKUI SYLLABLE M195 AN")
(124973 . "MENDE KIKAKUI SYLLABLE M178 EN")
(124974 . "MENDE KIKAKUI SYLLABLE M019 SI")
(124975 . "MENDE KIKAKUI SYLLABLE M020 SA")
(124976 . "MENDE KIKAKUI SYLLABLE M021 SU")
(124977 . "MENDE KIKAKUI SYLLABLE M162 SEE")
(124978 . "MENDE KIKAKUI SYLLABLE M116 SE")
(124979 . "MENDE KIKAKUI SYLLABLE M136 SOO")
(124980 . "MENDE KIKAKUI SYLLABLE M079 SO")
(124981 . "MENDE KIKAKUI SYLLABLE M196 SIA")
(124982 . "MENDE KIKAKUI SYLLABLE M025 LI")
(124983 . "MENDE KIKAKUI SYLLABLE M026 LA")
(124984 . "MENDE KIKAKUI SYLLABLE M027 LU")
(124985 . "MENDE KIKAKUI SYLLABLE M084 LEE")
(124986 . "MENDE KIKAKUI SYLLABLE M073 LE")
(124987 . "MENDE KIKAKUI SYLLABLE M054 LOO")
(124988 . "MENDE KIKAKUI SYLLABLE M153 LO")
(124989 . "MENDE KIKAKUI SYLLABLE M110 LONG LE")
(124990 . "MENDE KIKAKUI SYLLABLE M016 DI")
(124991 . "MENDE KIKAKUI SYLLABLE M017 DA")
(124992 . "MENDE KIKAKUI SYLLABLE M018 DU")
(124993 . "MENDE KIKAKUI SYLLABLE M089 DEE")
(124994 . "MENDE KIKAKUI SYLLABLE M180 DOO")
(124995 . "MENDE KIKAKUI SYLLABLE M181 DO")
(124996 . "MENDE KIKAKUI SYLLABLE M022 TI")
(124997 . "MENDE KIKAKUI SYLLABLE M023 TA")
(124998 . "MENDE KIKAKUI SYLLABLE M024 TU")
(124999 . "MENDE KIKAKUI SYLLABLE M091 TEE")
(125000 . "MENDE KIKAKUI SYLLABLE M055 TE")
(125001 . "MENDE KIKAKUI SYLLABLE M104 TOO")
(125002 . "MENDE KIKAKUI SYLLABLE M069 TO")
(125003 . "MENDE KIKAKUI SYLLABLE M028 JI")
(125004 . "MENDE KIKAKUI SYLLABLE M029 JA")
(125005 . "MENDE KIKAKUI SYLLABLE M030 JU")
(125006 . "MENDE KIKAKUI SYLLABLE M157 JEE")
(125007 . "MENDE KIKAKUI SYLLABLE M113 JE")
(125008 . "MENDE KIKAKUI SYLLABLE M160 JOO")
(125009 . "MENDE KIKAKUI SYLLABLE M063 JO")
(125010 . "MENDE KIKAKUI SYLLABLE M175 LONG JO")
(125011 . "MENDE KIKAKUI SYLLABLE M031 YI")
(125012 . "MENDE KIKAKUI SYLLABLE M032 YA")
(125013 . "MENDE KIKAKUI SYLLABLE M033 YU")
(125014 . "MENDE KIKAKUI SYLLABLE M109 YEE")
(125015 . "MENDE KIKAKUI SYLLABLE M080 YE")
(125016 . "MENDE KIKAKUI SYLLABLE M141 YOO")
(125017 . "MENDE KIKAKUI SYLLABLE M121 YO")
(125018 . "MENDE KIKAKUI SYLLABLE M034 FI")
(125019 . "MENDE KIKAKUI SYLLABLE M035 FA")
(125020 . "MENDE KIKAKUI SYLLABLE M036 FU")
(125021 . "MENDE KIKAKUI SYLLABLE M078 FEE")
(125022 . "MENDE KIKAKUI SYLLABLE M075 FE")
(125023 . "MENDE KIKAKUI SYLLABLE M133 FOO")
(125024 . "MENDE KIKAKUI SYLLABLE M088 FO")
(125025 . "MENDE KIKAKUI SYLLABLE M197 FUA")
(125026 . "MENDE KIKAKUI SYLLABLE M101 FAN")
(125027 . "MENDE KIKAKUI SYLLABLE M037 NIN")
(125028 . "MENDE KIKAKUI SYLLABLE M038 NAN")
(125029 . "MENDE KIKAKUI SYLLABLE M039 NUN")
(125030 . "MENDE KIKAKUI SYLLABLE M117 NEN")
(125031 . "MENDE KIKAKUI SYLLABLE M169 NON")
(125032 . "MENDE KIKAKUI SYLLABLE M176 HI")
(125033 . "MENDE KIKAKUI SYLLABLE M041 HA")
(125034 . "MENDE KIKAKUI SYLLABLE M186 HU")
(125035 . "MENDE KIKAKUI SYLLABLE M040 HEE")
(125036 . "MENDE KIKAKUI SYLLABLE M096 HE")
(125037 . "MENDE KIKAKUI SYLLABLE M042 HOO")
(125038 . "MENDE KIKAKUI SYLLABLE M140 HO")
(125039 . "MENDE KIKAKUI SYLLABLE M083 HEEI")
(125040 . "MENDE KIKAKUI SYLLABLE M128 HOOU")
(125041 . "MENDE KIKAKUI SYLLABLE M053 HIN")
(125042 . "MENDE KIKAKUI SYLLABLE M130 HAN")
(125043 . "MENDE KIKAKUI SYLLABLE M087 HUN")
(125044 . "MENDE KIKAKUI SYLLABLE M052 HEN")
(125045 . "MENDE KIKAKUI SYLLABLE M193 HON")
(125046 . "MENDE KIKAKUI SYLLABLE M046 HUAN")
(125047 . "MENDE KIKAKUI SYLLABLE M090 NGGI")
(125048 . "MENDE KIKAKUI SYLLABLE M043 NGGA")
(125049 . "MENDE KIKAKUI SYLLABLE M082 NGGU")
(125050 . "MENDE KIKAKUI SYLLABLE M115 NGGEE")
(125051 . "MENDE KIKAKUI SYLLABLE M146 NGGE")
(125052 . "MENDE KIKAKUI SYLLABLE M156 NGGOO")
(125053 . "MENDE KIKAKUI SYLLABLE M120 NGGO")
(125054 . "MENDE KIKAKUI SYLLABLE M159 NGGAA")
(125055 . "MENDE KIKAKUI SYLLABLE M127 NGGUA")
(125056 . "MENDE KIKAKUI SYLLABLE M086 LONG NGGE")
(125057 . "MENDE KIKAKUI SYLLABLE M106 LONG NGGOO")
(125058 . "MENDE KIKAKUI SYLLABLE M183 LONG NGGO")
(125059 . "MENDE KIKAKUI SYLLABLE M155 GI")
(125060 . "MENDE KIKAKUI SYLLABLE M111 GA")
(125061 . "MENDE KIKAKUI SYLLABLE M168 GU")
(125062 . "MENDE KIKAKUI SYLLABLE M190 GEE")
(125063 . "MENDE KIKAKUI SYLLABLE M166 GUEI")
(125064 . "MENDE KIKAKUI SYLLABLE M167 GUAN")
(125065 . "MENDE KIKAKUI SYLLABLE M184 NGEN")
(125066 . "MENDE KIKAKUI SYLLABLE M057 NGON")
(125067 . "MENDE KIKAKUI SYLLABLE M177 NGUAN")
(125068 . "MENDE KIKAKUI SYLLABLE M068 PI")
(125069 . "MENDE KIKAKUI SYLLABLE M099 PA")
(125070 . "MENDE KIKAKUI SYLLABLE M050 PU")
(125071 . "MENDE KIKAKUI SYLLABLE M081 PEE")
(125072 . "MENDE KIKAKUI SYLLABLE M051 PE")
(125073 . "MENDE KIKAKUI SYLLABLE M102 POO")
(125074 . "MENDE KIKAKUI SYLLABLE M066 PO")
(125075 . "MENDE KIKAKUI SYLLABLE M145 MBI")
(125076 . "MENDE KIKAKUI SYLLABLE M062 MBA")
(125077 . "MENDE KIKAKUI SYLLABLE M122 MBU")
(125078 . "MENDE KIKAKUI SYLLABLE M047 MBEE")
(125079 . "MENDE KIKAKUI SYLLABLE M188 MBEE")
(125080 . "MENDE KIKAKUI SYLLABLE M072 MBE")
(125081 . "MENDE KIKAKUI SYLLABLE M172 MBOO")
(125082 . "MENDE KIKAKUI SYLLABLE M174 MBO")
(125083 . "MENDE KIKAKUI SYLLABLE M187 MBUU")
(125084 . "MENDE KIKAKUI SYLLABLE M161 LONG MBE")
(125085 . "MENDE KIKAKUI SYLLABLE M105 LONG MBOO")
(125086 . "MENDE KIKAKUI SYLLABLE M142 LONG MBO")
(125087 . "MENDE KIKAKUI SYLLABLE M132 KPI")
(125088 . "MENDE KIKAKUI SYLLABLE M092 KPA")
(125089 . "MENDE KIKAKUI SYLLABLE M074 KPU")
(125090 . "MENDE KIKAKUI SYLLABLE M044 KPEE")
(125091 . "MENDE KIKAKUI SYLLABLE M108 KPE")
(125092 . "MENDE KIKAKUI SYLLABLE M112 KPOO")
(125093 . "MENDE KIKAKUI SYLLABLE M158 KPO")
(125094 . "MENDE KIKAKUI SYLLABLE M124 GBI")
(125095 . "MENDE KIKAKUI SYLLABLE M056 GBA")
(125096 . "MENDE KIKAKUI SYLLABLE M148 GBU")
(125097 . "MENDE KIKAKUI SYLLABLE M093 GBEE")
(125098 . "MENDE KIKAKUI SYLLABLE M107 GBE")
(125099 . "MENDE KIKAKUI SYLLABLE M071 GBOO")
(125100 . "MENDE KIKAKUI SYLLABLE M070 GBO")
(125101 . "MENDE KIKAKUI SYLLABLE M171 RA")
(125102 . "MENDE KIKAKUI SYLLABLE M123 NDI")
(125103 . "MENDE KIKAKUI SYLLABLE M129 NDA")
(125104 . "MENDE KIKAKUI SYLLABLE M125 NDU")
(125105 . "MENDE KIKAKUI SYLLABLE M191 NDEE")
(125106 . "MENDE KIKAKUI SYLLABLE M119 NDE")
(125107 . "MENDE KIKAKUI SYLLABLE M067 NDOO")
(125108 . "MENDE KIKAKUI SYLLABLE M064 NDO")
(125109 . "MENDE KIKAKUI SYLLABLE M152 NJA")
(125110 . "MENDE KIKAKUI SYLLABLE M192 NJU")
(125111 . "MENDE KIKAKUI SYLLABLE M149 NJEE")
(125112 . "MENDE KIKAKUI SYLLABLE M134 NJOO")
(125113 . "MENDE KIKAKUI SYLLABLE M182 VI")
(125114 . "MENDE KIKAKUI SYLLABLE M185 VA")
(125115 . "MENDE KIKAKUI SYLLABLE M151 VU")
(125116 . "MENDE KIKAKUI SYLLABLE M173 VEE")
(125117 . "MENDE KIKAKUI SYLLABLE M085 VE")
(125118 . "MENDE KIKAKUI SYLLABLE M144 VOO")
(125119 . "MENDE KIKAKUI SYLLABLE M077 VO")
(125120 . "MENDE KIKAKUI SYLLABLE M164 NYIN")
(125121 . "MENDE KIKAKUI SYLLABLE M058 NYAN")
(125122 . "MENDE KIKAKUI SYLLABLE M170 NYUN")
(125123 . "MENDE KIKAKUI SYLLABLE M098 NYEN")
(125124 . "MENDE KIKAKUI SYLLABLE M060 NYON")
((125125 . 125127) . #f)
(125127 . "MENDE KIKAKUI DIGIT ONE")
(125128 . "MENDE KIKAKUI DIGIT TWO")
(125129 . "MENDE KIKAKUI DIGIT THREE")
(125130 . "MENDE KIKAKUI DIGIT FOUR")
(125131 . "MENDE KIKAKUI DIGIT FIVE")
(125132 . "MENDE KIKAKUI DIGIT SIX")
(125133 . "MENDE KIKAKUI DIGIT SEVEN")
(125134 . "MENDE KIKAKUI DIGIT EIGHT")
(125135 . "MENDE KIKAKUI DIGIT NINE")
(125136 . "MENDE KIKAKUI COMBINING NUMBER TEENS")
(125137 . "MENDE KIKAKUI COMBINING NUMBER TENS")
(125138 . "MENDE KIKAKUI COMBINING NUMBER HUNDREDS")
(125139 . "MENDE KIKAKUI COMBINING NUMBER THOUSANDS")
(125140 . "MENDE KIKAKUI COMBINING NUMBER TEN THOUSANDS")
(125141 . "MENDE KIKAKUI COMBINING NUMBER HUNDRED THOUSANDS")
(125142 . "MENDE KIKAKUI COMBINING NUMBER MILLIONS")
((125143 . 125184) . #f)
(125184 . "ADLAM CAPITAL LETTER ALIF")
(125185 . "ADLAM CAPITAL LETTER DAALI")
(125186 . "ADLAM CAPITAL LETTER LAAM")
(125187 . "ADLAM CAPITAL LETTER MIIM")
(125188 . "ADLAM CAPITAL LETTER BA")
(125189 . "ADLAM CAPITAL LETTER SINNYIIYHE")
(125190 . "ADLAM CAPITAL LETTER PE")
(125191 . "ADLAM CAPITAL LETTER BHE")
(125192 . "ADLAM CAPITAL LETTER RA")
(125193 . "ADLAM CAPITAL LETTER E")
(125194 . "ADLAM CAPITAL LETTER FA")
(125195 . "ADLAM CAPITAL LETTER I")
(125196 . "ADLAM CAPITAL LETTER O")
(125197 . "ADLAM CAPITAL LETTER DHA")
(125198 . "ADLAM CAPITAL LETTER YHE")
(125199 . "ADLAM CAPITAL LETTER WAW")
(125200 . "ADLAM CAPITAL LETTER NUN")
(125201 . "ADLAM CAPITAL LETTER KAF")
(125202 . "ADLAM CAPITAL LETTER YA")
(125203 . "ADLAM CAPITAL LETTER U")
(125204 . "ADLAM CAPITAL LETTER JIIM")
(125205 . "ADLAM CAPITAL LETTER CHI")
(125206 . "ADLAM CAPITAL LETTER HA")
(125207 . "ADLAM CAPITAL LETTER QAAF")
(125208 . "ADLAM CAPITAL LETTER GA")
(125209 . "ADLAM CAPITAL LETTER NYA")
(125210 . "ADLAM CAPITAL LETTER TU")
(125211 . "ADLAM CAPITAL LETTER NHA")
(125212 . "ADLAM CAPITAL LETTER VA")
(125213 . "ADLAM CAPITAL LETTER KHA")
(125214 . "ADLAM CAPITAL LETTER GBE")
(125215 . "ADLAM CAPITAL LETTER ZAL")
(125216 . "ADLAM CAPITAL LETTER KPO")
(125217 . "ADLAM CAPITAL LETTER SHA")
(125218 . "ADLAM SMALL LETTER ALIF")
(125219 . "ADLAM SMALL LETTER DAALI")
(125220 . "ADLAM SMALL LETTER LAAM")
(125221 . "ADLAM SMALL LETTER MIIM")
(125222 . "ADLAM SMALL LETTER BA")
(125223 . "ADLAM SMALL LETTER SINNYIIYHE")
(125224 . "ADLAM SMALL LETTER PE")
(125225 . "ADLAM SMALL LETTER BHE")
(125226 . "ADLAM SMALL LETTER RA")
(125227 . "ADLAM SMALL LETTER E")
(125228 . "ADLAM SMALL LETTER FA")
(125229 . "ADLAM SMALL LETTER I")
(125230 . "ADLAM SMALL LETTER O")
(125231 . "ADLAM SMALL LETTER DHA")
(125232 . "ADLAM SMALL LETTER YHE")
(125233 . "ADLAM SMALL LETTER WAW")
(125234 . "ADLAM SMALL LETTER NUN")
(125235 . "ADLAM SMALL LETTER KAF")
(125236 . "ADLAM SMALL LETTER YA")
(125237 . "ADLAM SMALL LETTER U")
(125238 . "ADLAM SMALL LETTER JIIM")
(125239 . "ADLAM SMALL LETTER CHI")
(125240 . "ADLAM SMALL LETTER HA")
(125241 . "ADLAM SMALL LETTER QAAF")
(125242 . "ADLAM SMALL LETTER GA")
(125243 . "ADLAM SMALL LETTER NYA")
(125244 . "ADLAM SMALL LETTER TU")
(125245 . "ADLAM SMALL LETTER NHA")
(125246 . "ADLAM SMALL LETTER VA")
(125247 . "ADLAM SMALL LETTER KHA")
(125248 . "ADLAM SMALL LETTER GBE")
(125249 . "ADLAM SMALL LETTER ZAL")
(125250 . "ADLAM SMALL LETTER KPO")
(125251 . "ADLAM SMALL LETTER SHA")
(125252 . "ADLAM ALIF LENGTHENER")
(125253 . "ADLAM VOWEL LENGTHENER")
(125254 . "ADLAM GEMINATION MARK")
(125255 . "ADLAM HAMZA")
(125256 . "ADLAM CONSONANT MODIFIER")
(125257 . "ADLAM GEMINATE CONSONANT MODIFIER")
(125258 . "ADLAM NUKTA")
((125259 . 125264) . #f)
(125264 . "ADLAM DIGIT ZERO")
(125265 . "ADLAM DIGIT ONE")
(125266 . "ADLAM DIGIT TWO")
(125267 . "ADLAM DIGIT THREE")
(125268 . "ADLAM DIGIT FOUR")
(125269 . "ADLAM DIGIT FIVE")
(125270 . "ADLAM DIGIT SIX")
(125271 . "ADLAM DIGIT SEVEN")
(125272 . "ADLAM DIGIT EIGHT")
(125273 . "ADLAM DIGIT NINE")
((125274 . 125278) . #f)
(125278 . "ADLAM INITIAL EXCLAMATION MARK")
(125279 . "ADLAM INITIAL QUESTION MARK")
((125280 . 126464) . #f)
(126464 . "ARABIC MATHEMATICAL ALEF")
(126465 . "ARABIC MATHEMATICAL BEH")
(126466 . "ARABIC MATHEMATICAL JEEM")
(126467 . "ARABIC MATHEMATICAL DAL")
(126468 . #f)
(126469 . "ARABIC MATHEMATICAL WAW")
(126470 . "ARABIC MATHEMATICAL ZAIN")
(126471 . "ARABIC MATHEMATICAL HAH")
(126472 . "ARABIC MATHEMATICAL TAH")
(126473 . "ARABIC MATHEMATICAL YEH")
(126474 . "ARABIC MATHEMATICAL KAF")
(126475 . "ARABIC MATHEMATICAL LAM")
(126476 . "ARABIC MATHEMATICAL MEEM")
(126477 . "ARABIC MATHEMATICAL NOON")
(126478 . "ARABIC MATHEMATICAL SEEN")
(126479 . "ARABIC MATHEMATICAL AIN")
(126480 . "ARABIC MATHEMATICAL FEH")
(126481 . "ARABIC MATHEMATICAL SAD")
(126482 . "ARABIC MATHEMATICAL QAF")
(126483 . "ARABIC MATHEMATICAL REH")
(126484 . "ARABIC MATHEMATICAL SHEEN")
(126485 . "ARABIC MATHEMATICAL TEH")
(126486 . "ARABIC MATHEMATICAL THEH")
(126487 . "ARABIC MATHEMATICAL KHAH")
(126488 . "ARABIC MATHEMATICAL THAL")
(126489 . "ARABIC MATHEMATICAL DAD")
(126490 . "ARABIC MATHEMATICAL ZAH")
(126491 . "ARABIC MATHEMATICAL GHAIN")
(126492 . "ARABIC MATHEMATICAL DOTLESS BEH")
(126493 . "ARABIC MATHEMATICAL DOTLESS NOON")
(126494 . "ARABIC MATHEMATICAL DOTLESS FEH")
(126495 . "ARABIC MATHEMATICAL DOTLESS QAF")
(126496 . #f)
(126497 . "ARABIC MATHEMATICAL INITIAL BEH")
(126498 . "ARABIC MATHEMATICAL INITIAL JEEM")
(126499 . #f)
(126500 . "ARABIC MATHEMATICAL INITIAL HEH")
((126501 . 126503) . #f)
(126503 . "ARABIC MATHEMATICAL INITIAL HAH")
(126504 . #f)
(126505 . "ARABIC MATHEMATICAL INITIAL YEH")
(126506 . "ARABIC MATHEMATICAL INITIAL KAF")
(126507 . "ARABIC MATHEMATICAL INITIAL LAM")
(126508 . "ARABIC MATHEMATICAL INITIAL MEEM")
(126509 . "ARABIC MATHEMATICAL INITIAL NOON")
(126510 . "ARABIC MATHEMATICAL INITIAL SEEN")
(126511 . "ARABIC MATHEMATICAL INITIAL AIN")
(126512 . "ARABIC MATHEMATICAL INITIAL FEH")
(126513 . "ARABIC MATHEMATICAL INITIAL SAD")
(126514 . "ARABIC MATHEMATICAL INITIAL QAF")
(126515 . #f)
(126516 . "ARABIC MATHEMATICAL INITIAL SHEEN")
(126517 . "ARABIC MATHEMATICAL INITIAL TEH")
(126518 . "ARABIC MATHEMATICAL INITIAL THEH")
(126519 . "ARABIC MATHEMATICAL INITIAL KHAH")
(126520 . #f)
(126521 . "ARABIC MATHEMATICAL INITIAL DAD")
(126522 . #f)
(126523 . "ARABIC MATHEMATICAL INITIAL GHAIN")
((126524 . 126530) . #f)
(126530 . "ARABIC MATHEMATICAL TAILED JEEM")
((126531 . 126535) . #f)
(126535 . "ARABIC MATHEMATICAL TAILED HAH")
(126536 . #f)
(126537 . "ARABIC MATHEMATICAL TAILED YEH")
(126538 . #f)
(126539 . "ARABIC MATHEMATICAL TAILED LAM")
(126540 . #f)
(126541 . "ARABIC MATHEMATICAL TAILED NOON")
(126542 . "ARABIC MATHEMATICAL TAILED SEEN")
(126543 . "ARABIC MATHEMATICAL TAILED AIN")
(126544 . #f)
(126545 . "ARABIC MATHEMATICAL TAILED SAD")
(126546 . "ARABIC MATHEMATICAL TAILED QAF")
(126547 . #f)
(126548 . "ARABIC MATHEMATICAL TAILED SHEEN")
((126549 . 126551) . #f)
(126551 . "ARABIC MATHEMATICAL TAILED KHAH")
(126552 . #f)
(126553 . "ARABIC MATHEMATICAL TAILED DAD")
(126554 . #f)
(126555 . "ARABIC MATHEMATICAL TAILED GHAIN")
(126556 . #f)
(126557 . "ARABIC MATHEMATICAL TAILED DOTLESS NOON")
(126558 . #f)
(126559 . "ARABIC MATHEMATICAL TAILED DOTLESS QAF")
(126560 . #f)
(126561 . "ARABIC MATHEMATICAL STRETCHED BEH")
(126562 . "ARABIC MATHEMATICAL STRETCHED JEEM")
(126563 . #f)
(126564 . "ARABIC MATHEMATICAL STRETCHED HEH")
((126565 . 126567) . #f)
(126567 . "ARABIC MATHEMATICAL STRETCHED HAH")
(126568 . "ARABIC MATHEMATICAL STRETCHED TAH")
(126569 . "ARABIC MATHEMATICAL STRETCHED YEH")
(126570 . "ARABIC MATHEMATICAL STRETCHED KAF")
(126571 . #f)
(126572 . "ARABIC MATHEMATICAL STRETCHED MEEM")
(126573 . "ARABIC MATHEMATICAL STRETCHED NOON")
(126574 . "ARABIC MATHEMATICAL STRETCHED SEEN")
(126575 . "ARABIC MATHEMATICAL STRETCHED AIN")
(126576 . "ARABIC MATHEMATICAL STRETCHED FEH")
(126577 . "ARABIC MATHEMATICAL STRETCHED SAD")
(126578 . "ARABIC MATHEMATICAL STRETCHED QAF")
(126579 . #f)
(126580 . "ARABIC MATHEMATICAL STRETCHED SHEEN")
(126581 . "ARABIC MATHEMATICAL STRETCHED TEH")
(126582 . "ARABIC MATHEMATICAL STRETCHED THEH")
(126583 . "ARABIC MATHEMATICAL STRETCHED KHAH")
(126584 . #f)
(126585 . "ARABIC MATHEMATICAL STRETCHED DAD")
(126586 . "ARABIC MATHEMATICAL STRETCHED ZAH")
(126587 . "ARABIC MATHEMATICAL STRETCHED GHAIN")
(126588 . "ARABIC MATHEMATICAL STRETCHED DOTLESS BEH")
(126589 . #f)
(126590 . "ARABIC MATHEMATICAL STRETCHED DOTLESS FEH")
(126591 . #f)
(126592 . "ARABIC MATHEMATICAL LOOPED ALEF")
(126593 . "ARABIC MATHEMATICAL LOOPED BEH")
(126594 . "ARABIC MATHEMATICAL LOOPED JEEM")
(126595 . "ARABIC MATHEMATICAL LOOPED DAL")
(126596 . "ARABIC MATHEMATICAL LOOPED HEH")
(126597 . "ARABIC MATHEMATICAL LOOPED WAW")
(126598 . "ARABIC MATHEMATICAL LOOPED ZAIN")
(126599 . "ARABIC MATHEMATICAL LOOPED HAH")
(126600 . "ARABIC MATHEMATICAL LOOPED TAH")
(126601 . "ARABIC MATHEMATICAL LOOPED YEH")
(126602 . #f)
(126603 . "ARABIC MATHEMATICAL LOOPED LAM")
(126604 . "ARABIC MATHEMATICAL LOOPED MEEM")
(126605 . "ARABIC MATHEMATICAL LOOPED NOON")
(126606 . "ARABIC MATHEMATICAL LOOPED SEEN")
(126607 . "ARABIC MATHEMATICAL LOOPED AIN")
(126608 . "ARABIC MATHEMATICAL LOOPED FEH")
(126609 . "ARABIC MATHEMATICAL LOOPED SAD")
(126610 . "ARABIC MATHEMATICAL LOOPED QAF")
(126611 . "ARABIC MATHEMATICAL LOOPED REH")
(126612 . "ARABIC MATHEMATICAL LOOPED SHEEN")
(126613 . "ARABIC MATHEMATICAL LOOPED TEH")
(126614 . "ARABIC MATHEMATICAL LOOPED THEH")
(126615 . "ARABIC MATHEMATICAL LOOPED KHAH")
(126616 . "ARABIC MATHEMATICAL LOOPED THAL")
(126617 . "ARABIC MATHEMATICAL LOOPED DAD")
(126618 . "ARABIC MATHEMATICAL LOOPED ZAH")
(126619 . "ARABIC MATHEMATICAL LOOPED GHAIN")
((126620 . 126625) . #f)
(126625 . "ARABIC MATHEMATICAL DOUBLE-STRUCK BEH")
(126626 . "ARABIC MATHEMATICAL DOUBLE-STRUCK JEEM")
(126627 . "ARABIC MATHEMATICAL DOUBLE-STRUCK DAL")
(126628 . #f)
(126629 . "ARABIC MATHEMATICAL DOUBLE-STRUCK WAW")
(126630 . "ARABIC MATHEMATICAL DOUBLE-STRUCK ZAIN")
(126631 . "ARABIC MATHEMATICAL DOUBLE-STRUCK HAH")
(126632 . "ARABIC MATHEMATICAL DOUBLE-STRUCK TAH")
(126633 . "ARABIC MATHEMATICAL DOUBLE-STRUCK YEH")
(126634 . #f)
(126635 . "ARABIC MATHEMATICAL DOUBLE-STRUCK LAM")
(126636 . "ARABIC MATHEMATICAL DOUBLE-STRUCK MEEM")
(126637 . "ARABIC MATHEMATICAL DOUBLE-STRUCK NOON")
(126638 . "ARABIC MATHEMATICAL DOUBLE-STRUCK SEEN")
(126639 . "ARABIC MATHEMATICAL DOUBLE-STRUCK AIN")
(126640 . "ARABIC MATHEMATICAL DOUBLE-STRUCK FEH")
(126641 . "ARABIC MATHEMATICAL DOUBLE-STRUCK SAD")
(126642 . "ARABIC MATHEMATICAL DOUBLE-STRUCK QAF")
(126643 . "ARABIC MATHEMATICAL DOUBLE-STRUCK REH")
(126644 . "ARABIC MATHEMATICAL DOUBLE-STRUCK SHEEN")
(126645 . "ARABIC MATHEMATICAL DOUBLE-STRUCK TEH")
(126646 . "ARABIC MATHEMATICAL DOUBLE-STRUCK THEH")
(126647 . "ARABIC MATHEMATICAL DOUBLE-STRUCK KHAH")
(126648 . "ARABIC MATHEMATICAL DOUBLE-STRUCK THAL")
(126649 . "ARABIC MATHEMATICAL DOUBLE-STRUCK DAD")
(126650 . "ARABIC MATHEMATICAL DOUBLE-STRUCK ZAH")
(126651 . "ARABIC MATHEMATICAL DOUBLE-STRUCK GHAIN")
((126652 . 126704) . #f)
(126704 . "ARABIC MATHEMATICAL OPERATOR MEEM WITH HAH WITH TATWEEL")
(126705 . "ARABIC MATHEMATICAL OPERATOR HAH WITH DAL")
((126706 . 126976) . #f)
(126976 . "MAHJONG TILE EAST WIND")
(126977 . "MAHJONG TILE SOUTH WIND")
(126978 . "MAHJONG TILE WEST WIND")
(126979 . "MAHJONG TILE NORTH WIND")
(126980 . "MAHJONG TILE RED DRAGON")
(126981 . "MAHJONG TILE GREEN DRAGON")
(126982 . "MAHJONG TILE WHITE DRAGON")
(126983 . "MAHJONG TILE ONE OF CHARACTERS")
(126984 . "MAHJONG TILE TWO OF CHARACTERS")
(126985 . "MAHJONG TILE THREE OF CHARACTERS")
(126986 . "MAHJONG TILE FOUR OF CHARACTERS")
(126987 . "MAHJONG TILE FIVE OF CHARACTERS")
(126988 . "MAHJONG TILE SIX OF CHARACTERS")
(126989 . "MAHJONG TILE SEVEN OF CHARACTERS")
(126990 . "MAHJONG TILE EIGHT OF CHARACTERS")
(126991 . "MAHJONG TILE NINE OF CHARACTERS")
(126992 . "MAHJONG TILE ONE OF BAMBOOS")
(126993 . "MAHJONG TILE TWO OF BAMBOOS")
(126994 . "MAHJONG TILE THREE OF BAMBOOS")
(126995 . "MAHJONG TILE FOUR OF BAMBOOS")
(126996 . "MAHJONG TILE FIVE OF BAMBOOS")
(126997 . "MAHJONG TILE SIX OF BAMBOOS")
(126998 . "MAHJONG TILE SEVEN OF BAMBOOS")
(126999 . "MAHJONG TILE EIGHT OF BAMBOOS")
(127000 . "MAHJONG TILE NINE OF BAMBOOS")
(127001 . "MAHJONG TILE ONE OF CIRCLES")
(127002 . "MAHJONG TILE TWO OF CIRCLES")
(127003 . "MAHJONG TILE THREE OF CIRCLES")
(127004 . "MAHJONG TILE FOUR OF CIRCLES")
(127005 . "MAHJONG TILE FIVE OF CIRCLES")
(127006 . "MAHJONG TILE SIX OF CIRCLES")
(127007 . "MAHJONG TILE SEVEN OF CIRCLES")
(127008 . "MAHJONG TILE EIGHT OF CIRCLES")
(127009 . "MAHJONG TILE NINE OF CIRCLES")
(127010 . "MAHJONG TILE PLUM")
(127011 . "MAHJONG TILE ORCHID")
(127012 . "MAHJONG TILE BAMBOO")
(127013 . "MAHJONG TILE CHRYSANTHEMUM")
(127014 . "MAHJONG TILE SPRING")
(127015 . "MAHJONG TILE SUMMER")
(127016 . "MAHJONG TILE AUTUMN")
(127017 . "MAHJONG TILE WINTER")
(127018 . "MAHJONG TILE JOKER")
(127019 . "MAHJONG TILE BACK")
((127020 . 127024) . #f)
(127024 . "DOMINO TILE HORIZONTAL BACK")
(127025 . "DOMINO TILE HORIZONTAL-00-00")
(127026 . "DOMINO TILE HORIZONTAL-00-01")
(127027 . "DOMINO TILE HORIZONTAL-00-02")
(127028 . "DOMINO TILE HORIZONTAL-00-03")
(127029 . "DOMINO TILE HORIZONTAL-00-04")
(127030 . "DOMINO TILE HORIZONTAL-00-05")
(127031 . "DOMINO TILE HORIZONTAL-00-06")
(127032 . "DOMINO TILE HORIZONTAL-01-00")
(127033 . "DOMINO TILE HORIZONTAL-01-01")
(127034 . "DOMINO TILE HORIZONTAL-01-02")
(127035 . "DOMINO TILE HORIZONTAL-01-03")
(127036 . "DOMINO TILE HORIZONTAL-01-04")
(127037 . "DOMINO TILE HORIZONTAL-01-05")
(127038 . "DOMINO TILE HORIZONTAL-01-06")
(127039 . "DOMINO TILE HORIZONTAL-02-00")
(127040 . "DOMINO TILE HORIZONTAL-02-01")
(127041 . "DOMINO TILE HORIZONTAL-02-02")
(127042 . "DOMINO TILE HORIZONTAL-02-03")
(127043 . "DOMINO TILE HORIZONTAL-02-04")
(127044 . "DOMINO TILE HORIZONTAL-02-05")
(127045 . "DOMINO TILE HORIZONTAL-02-06")
(127046 . "DOMINO TILE HORIZONTAL-03-00")
(127047 . "DOMINO TILE HORIZONTAL-03-01")
(127048 . "DOMINO TILE HORIZONTAL-03-02")
(127049 . "DOMINO TILE HORIZONTAL-03-03")
(127050 . "DOMINO TILE HORIZONTAL-03-04")
(127051 . "DOMINO TILE HORIZONTAL-03-05")
(127052 . "DOMINO TILE HORIZONTAL-03-06")
(127053 . "DOMINO TILE HORIZONTAL-04-00")
(127054 . "DOMINO TILE HORIZONTAL-04-01")
(127055 . "DOMINO TILE HORIZONTAL-04-02")
(127056 . "DOMINO TILE HORIZONTAL-04-03")
(127057 . "DOMINO TILE HORIZONTAL-04-04")
(127058 . "DOMINO TILE HORIZONTAL-04-05")
(127059 . "DOMINO TILE HORIZONTAL-04-06")
(127060 . "DOMINO TILE HORIZONTAL-05-00")
(127061 . "DOMINO TILE HORIZONTAL-05-01")
(127062 . "DOMINO TILE HORIZONTAL-05-02")
(127063 . "DOMINO TILE HORIZONTAL-05-03")
(127064 . "DOMINO TILE HORIZONTAL-05-04")
(127065 . "DOMINO TILE HORIZONTAL-05-05")
(127066 . "DOMINO TILE HORIZONTAL-05-06")
(127067 . "DOMINO TILE HORIZONTAL-06-00")
(127068 . "DOMINO TILE HORIZONTAL-06-01")
(127069 . "DOMINO TILE HORIZONTAL-06-02")
(127070 . "DOMINO TILE HORIZONTAL-06-03")
(127071 . "DOMINO TILE HORIZONTAL-06-04")
(127072 . "DOMINO TILE HORIZONTAL-06-05")
(127073 . "DOMINO TILE HORIZONTAL-06-06")
(127074 . "DOMINO TILE VERTICAL BACK")
(127075 . "DOMINO TILE VERTICAL-00-00")
(127076 . "DOMINO TILE VERTICAL-00-01")
(127077 . "DOMINO TILE VERTICAL-00-02")
(127078 . "DOMINO TILE VERTICAL-00-03")
(127079 . "DOMINO TILE VERTICAL-00-04")
(127080 . "DOMINO TILE VERTICAL-00-05")
(127081 . "DOMINO TILE VERTICAL-00-06")
(127082 . "DOMINO TILE VERTICAL-01-00")
(127083 . "DOMINO TILE VERTICAL-01-01")
(127084 . "DOMINO TILE VERTICAL-01-02")
(127085 . "DOMINO TILE VERTICAL-01-03")
(127086 . "DOMINO TILE VERTICAL-01-04")
(127087 . "DOMINO TILE VERTICAL-01-05")
(127088 . "DOMINO TILE VERTICAL-01-06")
(127089 . "DOMINO TILE VERTICAL-02-00")
(127090 . "DOMINO TILE VERTICAL-02-01")
(127091 . "DOMINO TILE VERTICAL-02-02")
(127092 . "DOMINO TILE VERTICAL-02-03")
(127093 . "DOMINO TILE VERTICAL-02-04")
(127094 . "DOMINO TILE VERTICAL-02-05")
(127095 . "DOMINO TILE VERTICAL-02-06")
(127096 . "DOMINO TILE VERTICAL-03-00")
(127097 . "DOMINO TILE VERTICAL-03-01")
(127098 . "DOMINO TILE VERTICAL-03-02")
(127099 . "DOMINO TILE VERTICAL-03-03")
(127100 . "DOMINO TILE VERTICAL-03-04")
(127101 . "DOMINO TILE VERTICAL-03-05")
(127102 . "DOMINO TILE VERTICAL-03-06")
(127103 . "DOMINO TILE VERTICAL-04-00")
(127104 . "DOMINO TILE VERTICAL-04-01")
(127105 . "DOMINO TILE VERTICAL-04-02")
(127106 . "DOMINO TILE VERTICAL-04-03")
(127107 . "DOMINO TILE VERTICAL-04-04")
(127108 . "DOMINO TILE VERTICAL-04-05")
(127109 . "DOMINO TILE VERTICAL-04-06")
(127110 . "DOMINO TILE VERTICAL-05-00")
(127111 . "DOMINO TILE VERTICAL-05-01")
(127112 . "DOMINO TILE VERTICAL-05-02")
(127113 . "DOMINO TILE VERTICAL-05-03")
(127114 . "DOMINO TILE VERTICAL-05-04")
(127115 . "DOMINO TILE VERTICAL-05-05")
(127116 . "DOMINO TILE VERTICAL-05-06")
(127117 . "DOMINO TILE VERTICAL-06-00")
(127118 . "DOMINO TILE VERTICAL-06-01")
(127119 . "DOMINO TILE VERTICAL-06-02")
(127120 . "DOMINO TILE VERTICAL-06-03")
(127121 . "DOMINO TILE VERTICAL-06-04")
(127122 . "DOMINO TILE VERTICAL-06-05")
(127123 . "DOMINO TILE VERTICAL-06-06")
((127124 . 127136) . #f)
(127136 . "PLAYING CARD BACK")
(127137 . "PLAYING CARD ACE OF SPADES")
(127138 . "PLAYING CARD TWO OF SPADES")
(127139 . "PLAYING CARD THREE OF SPADES")
(127140 . "PLAYING CARD FOUR OF SPADES")
(127141 . "PLAYING CARD FIVE OF SPADES")
(127142 . "PLAYING CARD SIX OF SPADES")
(127143 . "PLAYING CARD SEVEN OF SPADES")
(127144 . "PLAYING CARD EIGHT OF SPADES")
(127145 . "PLAYING CARD NINE OF SPADES")
(127146 . "PLAYING CARD TEN OF SPADES")
(127147 . "PLAYING CARD JACK OF SPADES")
(127148 . "PLAYING CARD KNIGHT OF SPADES")
(127149 . "PLAYING CARD QUEEN OF SPADES")
(127150 . "PLAYING CARD KING OF SPADES")
((127151 . 127153) . #f)
(127153 . "PLAYING CARD ACE OF HEARTS")
(127154 . "PLAYING CARD TWO OF HEARTS")
(127155 . "PLAYING CARD THREE OF HEARTS")
(127156 . "PLAYING CARD FOUR OF HEARTS")
(127157 . "PLAYING CARD FIVE OF HEARTS")
(127158 . "PLAYING CARD SIX OF HEARTS")
(127159 . "PLAYING CARD SEVEN OF HEARTS")
(127160 . "PLAYING CARD EIGHT OF HEARTS")
(127161 . "PLAYING CARD NINE OF HEARTS")
(127162 . "PLAYING CARD TEN OF HEARTS")
(127163 . "PLAYING CARD JACK OF HEARTS")
(127164 . "PLAYING CARD KNIGHT OF HEARTS")
(127165 . "PLAYING CARD QUEEN OF HEARTS")
(127166 . "PLAYING CARD KING OF HEARTS")
(127167 . "PLAYING CARD RED JOKER")
(127168 . #f)
(127169 . "PLAYING CARD ACE OF DIAMONDS")
(127170 . "PLAYING CARD TWO OF DIAMONDS")
(127171 . "PLAYING CARD THREE OF DIAMONDS")
(127172 . "PLAYING CARD FOUR OF DIAMONDS")
(127173 . "PLAYING CARD FIVE OF DIAMONDS")
(127174 . "PLAYING CARD SIX OF DIAMONDS")
(127175 . "PLAYING CARD SEVEN OF DIAMONDS")
(127176 . "PLAYING CARD EIGHT OF DIAMONDS")
(127177 . "PLAYING CARD NINE OF DIAMONDS")
(127178 . "PLAYING CARD TEN OF DIAMONDS")
(127179 . "PLAYING CARD JACK OF DIAMONDS")
(127180 . "PLAYING CARD KNIGHT OF DIAMONDS")
(127181 . "PLAYING CARD QUEEN OF DIAMONDS")
(127182 . "PLAYING CARD KING OF DIAMONDS")
(127183 . "PLAYING CARD BLACK JOKER")
(127184 . #f)
(127185 . "PLAYING CARD ACE OF CLUBS")
(127186 . "PLAYING CARD TWO OF CLUBS")
(127187 . "PLAYING CARD THREE OF CLUBS")
(127188 . "PLAYING CARD FOUR OF CLUBS")
(127189 . "PLAYING CARD FIVE OF CLUBS")
(127190 . "PLAYING CARD SIX OF CLUBS")
(127191 . "PLAYING CARD SEVEN OF CLUBS")
(127192 . "PLAYING CARD EIGHT OF CLUBS")
(127193 . "PLAYING CARD NINE OF CLUBS")
(127194 . "PLAYING CARD TEN OF CLUBS")
(127195 . "PLAYING CARD JACK OF CLUBS")
(127196 . "PLAYING CARD KNIGHT OF CLUBS")
(127197 . "PLAYING CARD QUEEN OF CLUBS")
(127198 . "PLAYING CARD KING OF CLUBS")
(127199 . "PLAYING CARD WHITE JOKER")
(127200 . "PLAYING CARD FOOL")
(127201 . "PLAYING CARD TRUMP-1")
(127202 . "PLAYING CARD TRUMP-2")
(127203 . "PLAYING CARD TRUMP-3")
(127204 . "PLAYING CARD TRUMP-4")
(127205 . "PLAYING CARD TRUMP-5")
(127206 . "PLAYING CARD TRUMP-6")
(127207 . "PLAYING CARD TRUMP-7")
(127208 . "PLAYING CARD TRUMP-8")
(127209 . "PLAYING CARD TRUMP-9")
(127210 . "PLAYING CARD TRUMP-10")
(127211 . "PLAYING CARD TRUMP-11")
(127212 . "PLAYING CARD TRUMP-12")
(127213 . "PLAYING CARD TRUMP-13")
(127214 . "PLAYING CARD TRUMP-14")
(127215 . "PLAYING CARD TRUMP-15")
(127216 . "PLAYING CARD TRUMP-16")
(127217 . "PLAYING CARD TRUMP-17")
(127218 . "PLAYING CARD TRUMP-18")
(127219 . "PLAYING CARD TRUMP-19")
(127220 . "PLAYING CARD TRUMP-20")
(127221 . "PLAYING CARD TRUMP-21")
((127222 . 127232) . #f)
(127232 . "DIGIT ZERO FULL STOP")
(127233 . "DIGIT ZERO COMMA")
(127234 . "DIGIT ONE COMMA")
(127235 . "DIGIT TWO COMMA")
(127236 . "DIGIT THREE COMMA")
(127237 . "DIGIT FOUR COMMA")
(127238 . "DIGIT FIVE COMMA")
(127239 . "DIGIT SIX COMMA")
(127240 . "DIGIT SEVEN COMMA")
(127241 . "DIGIT EIGHT COMMA")
(127242 . "DIGIT NINE COMMA")
(127243 . "DINGBAT CIRCLED SANS-SERIF DIGIT ZERO")
(127244 . "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ZERO")
((127245 . 127248) . #f)
(127248 . "PARENTHESIZED LATIN CAPITAL LETTER A")
(127249 . "PARENTHESIZED LATIN CAPITAL LETTER B")
(127250 . "PARENTHESIZED LATIN CAPITAL LETTER C")
(127251 . "PARENTHESIZED LATIN CAPITAL LETTER D")
(127252 . "PARENTHESIZED LATIN CAPITAL LETTER E")
(127253 . "PARENTHESIZED LATIN CAPITAL LETTER F")
(127254 . "PARENTHESIZED LATIN CAPITAL LETTER G")
(127255 . "PARENTHESIZED LATIN CAPITAL LETTER H")
(127256 . "PARENTHESIZED LATIN CAPITAL LETTER I")
(127257 . "PARENTHESIZED LATIN CAPITAL LETTER J")
(127258 . "PARENTHESIZED LATIN CAPITAL LETTER K")
(127259 . "PARENTHESIZED LATIN CAPITAL LETTER L")
(127260 . "PARENTHESIZED LATIN CAPITAL LETTER M")
(127261 . "PARENTHESIZED LATIN CAPITAL LETTER N")
(127262 . "PARENTHESIZED LATIN CAPITAL LETTER O")
(127263 . "PARENTHESIZED LATIN CAPITAL LETTER P")
(127264 . "PARENTHESIZED LATIN CAPITAL LETTER Q")
(127265 . "PARENTHESIZED LATIN CAPITAL LETTER R")
(127266 . "PARENTHESIZED LATIN CAPITAL LETTER S")
(127267 . "PARENTHESIZED LATIN CAPITAL LETTER T")
(127268 . "PARENTHESIZED LATIN CAPITAL LETTER U")
(127269 . "PARENTHESIZED LATIN CAPITAL LETTER V")
(127270 . "PARENTHESIZED LATIN CAPITAL LETTER W")
(127271 . "PARENTHESIZED LATIN CAPITAL LETTER X")
(127272 . "PARENTHESIZED LATIN CAPITAL LETTER Y")
(127273 . "PARENTHESIZED LATIN CAPITAL LETTER Z")
(127274 . "TORTOISE SHELL BRACKETED LATIN CAPITAL LETTER S")
(127275 . "CIRCLED ITALIC LATIN CAPITAL LETTER C")
(127276 . "CIRCLED ITALIC LATIN CAPITAL LETTER R")
(127277 . "CIRCLED CD")
(127278 . "CIRCLED WZ")
(127279 . #f)
(127280 . "SQUARED LATIN CAPITAL LETTER A")
(127281 . "SQUARED LATIN CAPITAL LETTER B")
(127282 . "SQUARED LATIN CAPITAL LETTER C")
(127283 . "SQUARED LATIN CAPITAL LETTER D")
(127284 . "SQUARED LATIN CAPITAL LETTER E")
(127285 . "SQUARED LATIN CAPITAL LETTER F")
(127286 . "SQUARED LATIN CAPITAL LETTER G")
(127287 . "SQUARED LATIN CAPITAL LETTER H")
(127288 . "SQUARED LATIN CAPITAL LETTER I")
(127289 . "SQUARED LATIN CAPITAL LETTER J")
(127290 . "SQUARED LATIN CAPITAL LETTER K")
(127291 . "SQUARED LATIN CAPITAL LETTER L")
(127292 . "SQUARED LATIN CAPITAL LETTER M")
(127293 . "SQUARED LATIN CAPITAL LETTER N")
(127294 . "SQUARED LATIN CAPITAL LETTER O")
(127295 . "SQUARED LATIN CAPITAL LETTER P")
(127296 . "SQUARED LATIN CAPITAL LETTER Q")
(127297 . "SQUARED LATIN CAPITAL LETTER R")
(127298 . "SQUARED LATIN CAPITAL LETTER S")
(127299 . "SQUARED LATIN CAPITAL LETTER T")
(127300 . "SQUARED LATIN CAPITAL LETTER U")
(127301 . "SQUARED LATIN CAPITAL LETTER V")
(127302 . "SQUARED LATIN CAPITAL LETTER W")
(127303 . "SQUARED LATIN CAPITAL LETTER X")
(127304 . "SQUARED LATIN CAPITAL LETTER Y")
(127305 . "SQUARED LATIN CAPITAL LETTER Z")
(127306 . "SQUARED HV")
(127307 . "SQUARED MV")
(127308 . "SQUARED SD")
(127309 . "SQUARED SS")
(127310 . "SQUARED PPV")
(127311 . "SQUARED WC")
(127312 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER A")
(127313 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER B")
(127314 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER C")
(127315 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER D")
(127316 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER E")
(127317 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER F")
(127318 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER G")
(127319 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER H")
(127320 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER I")
(127321 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER J")
(127322 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER K")
(127323 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER L")
(127324 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER M")
(127325 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER N")
(127326 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER O")
(127327 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER P")
(127328 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER Q")
(127329 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER R")
(127330 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER S")
(127331 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER T")
(127332 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER U")
(127333 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER V")
(127334 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER W")
(127335 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER X")
(127336 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER Y")
(127337 . "NEGATIVE CIRCLED LATIN CAPITAL LETTER Z")
(127338 . "RAISED MC SIGN")
(127339 . "RAISED MD SIGN")
((127340 . 127344) . #f)
(127344 . "NEGATIVE SQUARED LATIN CAPITAL LETTER A")
(127345 . "NEGATIVE SQUARED LATIN CAPITAL LETTER B")
(127346 . "NEGATIVE SQUARED LATIN CAPITAL LETTER C")
(127347 . "NEGATIVE SQUARED LATIN CAPITAL LETTER D")
(127348 . "NEGATIVE SQUARED LATIN CAPITAL LETTER E")
(127349 . "NEGATIVE SQUARED LATIN CAPITAL LETTER F")
(127350 . "NEGATIVE SQUARED LATIN CAPITAL LETTER G")
(127351 . "NEGATIVE SQUARED LATIN CAPITAL LETTER H")
(127352 . "NEGATIVE SQUARED LATIN CAPITAL LETTER I")
(127353 . "NEGATIVE SQUARED LATIN CAPITAL LETTER J")
(127354 . "NEGATIVE SQUARED LATIN CAPITAL LETTER K")
(127355 . "NEGATIVE SQUARED LATIN CAPITAL LETTER L")
(127356 . "NEGATIVE SQUARED LATIN CAPITAL LETTER M")
(127357 . "NEGATIVE SQUARED LATIN CAPITAL LETTER N")
(127358 . "NEGATIVE SQUARED LATIN CAPITAL LETTER O")
(127359 . "NEGATIVE SQUARED LATIN CAPITAL LETTER P")
(127360 . "NEGATIVE SQUARED LATIN CAPITAL LETTER Q")
(127361 . "NEGATIVE SQUARED LATIN CAPITAL LETTER R")
(127362 . "NEGATIVE SQUARED LATIN CAPITAL LETTER S")
(127363 . "NEGATIVE SQUARED LATIN CAPITAL LETTER T")
(127364 . "NEGATIVE SQUARED LATIN CAPITAL LETTER U")
(127365 . "NEGATIVE SQUARED LATIN CAPITAL LETTER V")
(127366 . "NEGATIVE SQUARED LATIN CAPITAL LETTER W")
(127367 . "NEGATIVE SQUARED LATIN CAPITAL LETTER X")
(127368 . "NEGATIVE SQUARED LATIN CAPITAL LETTER Y")
(127369 . "NEGATIVE SQUARED LATIN CAPITAL LETTER Z")
(127370 . "CROSSED NEGATIVE SQUARED LATIN CAPITAL LETTER P")
(127371 . "NEGATIVE SQUARED IC")
(127372 . "NEGATIVE SQUARED PA")
(127373 . "NEGATIVE SQUARED SA")
(127374 . "NEGATIVE SQUARED AB")
(127375 . "NEGATIVE SQUARED WC")
(127376 . "SQUARE DJ")
(127377 . "SQUARED CL")
(127378 . "SQUARED COOL")
(127379 . "SQUARED FREE")
(127380 . "SQUARED ID")
(127381 . "SQUARED NEW")
(127382 . "SQUARED NG")
(127383 . "SQUARED OK")
(127384 . "SQUARED SOS")
(127385 . "SQUARED UP WITH EXCLAMATION MARK")
(127386 . "SQUARED VS")
(127387 . "SQUARED THREE D")
(127388 . "SQUARED SECOND SCREEN")
(127389 . "SQUARED TWO K")
(127390 . "SQUARED FOUR K")
(127391 . "SQUARED EIGHT K")
(127392 . "SQUARED FIVE POINT ONE")
(127393 . "SQUARED SEVEN POINT ONE")
(127394 . "SQUARED TWENTY-TWO POINT TWO")
(127395 . "SQUARED SIXTY P")
(127396 . "SQUARED ONE HUNDRED TWENTY P")
(127397 . "SQUARED LATIN SMALL LETTER D")
(127398 . "SQUARED HC")
(127399 . "SQUARED HDR")
(127400 . "SQUARED HI-RES")
(127401 . "SQUARED LOSSLESS")
(127402 . "SQUARED SHV")
(127403 . "SQUARED UHD")
(127404 . "SQUARED VOD")
((127405 . 127462) . #f)
(127462 . "REGIONAL INDICATOR SYMBOL LETTER A")
(127463 . "REGIONAL INDICATOR SYMBOL LETTER B")
(127464 . "REGIONAL INDICATOR SYMBOL LETTER C")
(127465 . "REGIONAL INDICATOR SYMBOL LETTER D")
(127466 . "REGIONAL INDICATOR SYMBOL LETTER E")
(127467 . "REGIONAL INDICATOR SYMBOL LETTER F")
(127468 . "REGIONAL INDICATOR SYMBOL LETTER G")
(127469 . "REGIONAL INDICATOR SYMBOL LETTER H")
(127470 . "REGIONAL INDICATOR SYMBOL LETTER I")
(127471 . "REGIONAL INDICATOR SYMBOL LETTER J")
(127472 . "REGIONAL INDICATOR SYMBOL LETTER K")
(127473 . "REGIONAL INDICATOR SYMBOL LETTER L")
(127474 . "REGIONAL INDICATOR SYMBOL LETTER M")
(127475 . "REGIONAL INDICATOR SYMBOL LETTER N")
(127476 . "REGIONAL INDICATOR SYMBOL LETTER O")
(127477 . "REGIONAL INDICATOR SYMBOL LETTER P")
(127478 . "REGIONAL INDICATOR SYMBOL LETTER Q")
(127479 . "REGIONAL INDICATOR SYMBOL LETTER R")
(127480 . "REGIONAL INDICATOR SYMBOL LETTER S")
(127481 . "REGIONAL INDICATOR SYMBOL LETTER T")
(127482 . "REGIONAL INDICATOR SYMBOL LETTER U")
(127483 . "REGIONAL INDICATOR SYMBOL LETTER V")
(127484 . "REGIONAL INDICATOR SYMBOL LETTER W")
(127485 . "REGIONAL INDICATOR SYMBOL LETTER X")
(127486 . "REGIONAL INDICATOR SYMBOL LETTER Y")
(127487 . "REGIONAL INDICATOR SYMBOL LETTER Z")
(127488 . "SQUARE HIRAGANA HOKA")
(127489 . "SQUARED KATAKANA KOKO")
(127490 . "SQUARED KATAKANA SA")
((127491 . 127504) . #f)
(127504 . "SQUARED CJK UNIFIED IDEOGRAPH-624B")
(127505 . "SQUARED CJK UNIFIED IDEOGRAPH-5B57")
(127506 . "SQUARED CJK UNIFIED IDEOGRAPH-53CC")
(127507 . "SQUARED KATAKANA DE")
(127508 . "SQUARED CJK UNIFIED IDEOGRAPH-4E8C")
(127509 . "SQUARED CJK UNIFIED IDEOGRAPH-591A")
(127510 . "SQUARED CJK UNIFIED IDEOGRAPH-89E3")
(127511 . "SQUARED CJK UNIFIED IDEOGRAPH-5929")
(127512 . "SQUARED CJK UNIFIED IDEOGRAPH-4EA4")
(127513 . "SQUARED CJK UNIFIED IDEOGRAPH-6620")
(127514 . "SQUARED CJK UNIFIED IDEOGRAPH-7121")
(127515 . "SQUARED CJK UNIFIED IDEOGRAPH-6599")
(127516 . "SQUARED CJK UNIFIED IDEOGRAPH-524D")
(127517 . "SQUARED CJK UNIFIED IDEOGRAPH-5F8C")
(127518 . "SQUARED CJK UNIFIED IDEOGRAPH-518D")
(127519 . "SQUARED CJK UNIFIED IDEOGRAPH-65B0")
(127520 . "SQUARED CJK UNIFIED IDEOGRAPH-521D")
(127521 . "SQUARED CJK UNIFIED IDEOGRAPH-7D42")
(127522 . "SQUARED CJK UNIFIED IDEOGRAPH-751F")
(127523 . "SQUARED CJK UNIFIED IDEOGRAPH-8CA9")
(127524 . "SQUARED CJK UNIFIED IDEOGRAPH-58F0")
(127525 . "SQUARED CJK UNIFIED IDEOGRAPH-5439")
(127526 . "SQUARED CJK UNIFIED IDEOGRAPH-6F14")
(127527 . "SQUARED CJK UNIFIED IDEOGRAPH-6295")
(127528 . "SQUARED CJK UNIFIED IDEOGRAPH-6355")
(127529 . "SQUARED CJK UNIFIED IDEOGRAPH-4E00")
(127530 . "SQUARED CJK UNIFIED IDEOGRAPH-4E09")
(127531 . "SQUARED CJK UNIFIED IDEOGRAPH-904A")
(127532 . "SQUARED CJK UNIFIED IDEOGRAPH-5DE6")
(127533 . "SQUARED CJK UNIFIED IDEOGRAPH-4E2D")
(127534 . "SQUARED CJK UNIFIED IDEOGRAPH-53F3")
(127535 . "SQUARED CJK UNIFIED IDEOGRAPH-6307")
(127536 . "SQUARED CJK UNIFIED IDEOGRAPH-8D70")
(127537 . "SQUARED CJK UNIFIED IDEOGRAPH-6253")
(127538 . "SQUARED CJK UNIFIED IDEOGRAPH-7981")
(127539 . "SQUARED CJK UNIFIED IDEOGRAPH-7A7A")
(127540 . "SQUARED CJK UNIFIED IDEOGRAPH-5408")
(127541 . "SQUARED CJK UNIFIED IDEOGRAPH-6E80")
(127542 . "SQUARED CJK UNIFIED IDEOGRAPH-6709")
(127543 . "SQUARED CJK UNIFIED IDEOGRAPH-6708")
(127544 . "SQUARED CJK UNIFIED IDEOGRAPH-7533")
(127545 . "SQUARED CJK UNIFIED IDEOGRAPH-5272")
(127546 . "SQUARED CJK UNIFIED IDEOGRAPH-55B6")
(127547 . "SQUARED CJK UNIFIED IDEOGRAPH-914D")
((127548 . 127552) . #f)
(127552 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-672C")
(127553 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E09")
(127554 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E8C")
(127555 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-5B89")
(127556 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-70B9")
(127557 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6253")
(127558 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-76D7")
(127559 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-52DD")
(127560 . "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6557")
((127561 . 127568) . #f)
(127568 . "CIRCLED IDEOGRAPH ADVANTAGE")
(127569 . "CIRCLED IDEOGRAPH ACCEPT")
((127570 . 127744) . #f)
(127744 . "CYCLONE")
(127745 . "FOGGY")
(127746 . "CLOSED UMBRELLA")
(127747 . "NIGHT WITH STARS")
(127748 . "SUNRISE OVER MOUNTAINS")
(127749 . "SUNRISE")
(127750 . "CITYSCAPE AT DUSK")
(127751 . "SUNSET OVER BUILDINGS")
(127752 . "RAINBOW")
(127753 . "BRIDGE AT NIGHT")
(127754 . "WATER WAVE")
(127755 . "VOLCANO")
(127756 . "MILKY WAY")
(127757 . "EARTH GLOBE EUROPE-AFRICA")
(127758 . "EARTH GLOBE AMERICAS")
(127759 . "EARTH GLOBE ASIA-AUSTRALIA")
(127760 . "GLOBE WITH MERIDIANS")
(127761 . "NEW MOON SYMBOL")
(127762 . "WAXING CRESCENT MOON SYMBOL")
(127763 . "FIRST QUARTER MOON SYMBOL")
(127764 . "WAXING GIBBOUS MOON SYMBOL")
(127765 . "FULL MOON SYMBOL")
(127766 . "WANING GIBBOUS MOON SYMBOL")
(127767 . "LAST QUARTER MOON SYMBOL")
(127768 . "WANING CRESCENT MOON SYMBOL")
(127769 . "CRESCENT MOON")
(127770 . "NEW MOON WITH FACE")
(127771 . "FIRST QUARTER MOON WITH FACE")
(127772 . "LAST QUARTER MOON WITH FACE")
(127773 . "FULL MOON WITH FACE")
(127774 . "SUN WITH FACE")
(127775 . "GLOWING STAR")
(127776 . "SHOOTING STAR")
(127777 . "THERMOMETER")
(127778 . "BLACK DROPLET")
(127779 . "WHITE SUN")
(127780 . "WHITE SUN WITH SMALL CLOUD")
(127781 . "WHITE SUN BEHIND CLOUD")
(127782 . "WHITE SUN BEHIND CLOUD WITH RAIN")
(127783 . "CLOUD WITH RAIN")
(127784 . "CLOUD WITH SNOW")
(127785 . "CLOUD WITH LIGHTNING")
(127786 . "CLOUD WITH TORNADO")
(127787 . "FOG")
(127788 . "WIND BLOWING FACE")
(127789 . "HOT DOG")
(127790 . "TACO")
(127791 . "BURRITO")
(127792 . "CHESTNUT")
(127793 . "SEEDLING")
(127794 . "EVERGREEN TREE")
(127795 . "DECIDUOUS TREE")
(127796 . "PALM TREE")
(127797 . "CACTUS")
(127798 . "HOT PEPPER")
(127799 . "TULIP")
(127800 . "CHERRY BLOSSOM")
(127801 . "ROSE")
(127802 . "HIBISCUS")
(127803 . "SUNFLOWER")
(127804 . "BLOSSOM")
(127805 . "EAR OF MAIZE")
(127806 . "EAR OF RICE")
(127807 . "HERB")
(127808 . "FOUR LEAF CLOVER")
(127809 . "MAPLE LEAF")
(127810 . "FALLEN LEAF")
(127811 . "LEAF FLUTTERING IN WIND")
(127812 . "MUSHROOM")
(127813 . "TOMATO")
(127814 . "AUBERGINE")
(127815 . "GRAPES")
(127816 . "MELON")
(127817 . "WATERMELON")
(127818 . "TANGERINE")
(127819 . "LEMON")
(127820 . "BANANA")
(127821 . "PINEAPPLE")
(127822 . "RED APPLE")
(127823 . "GREEN APPLE")
(127824 . "PEAR")
(127825 . "PEACH")
(127826 . "CHERRIES")
(127827 . "STRAWBERRY")
(127828 . "HAMBURGER")
(127829 . "SLICE OF PIZZA")
(127830 . "MEAT ON BONE")
(127831 . "POULTRY LEG")
(127832 . "RICE CRACKER")
(127833 . "RICE BALL")
(127834 . "COOKED RICE")
(127835 . "CURRY AND RICE")
(127836 . "STEAMING BOWL")
(127837 . "SPAGHETTI")
(127838 . "BREAD")
(127839 . "FRENCH FRIES")
(127840 . "ROASTED SWEET POTATO")
(127841 . "DANGO")
(127842 . "ODEN")
(127843 . "SUSHI")
(127844 . "FRIED SHRIMP")
(127845 . "FISH CAKE WITH SWIRL DESIGN")
(127846 . "SOFT ICE CREAM")
(127847 . "SHAVED ICE")
(127848 . "ICE CREAM")
(127849 . "DOUGHNUT")
(127850 . "COOKIE")
(127851 . "CHOCOLATE BAR")
(127852 . "CANDY")
(127853 . "LOLLIPOP")
(127854 . "CUSTARD")
(127855 . "HONEY POT")
(127856 . "SHORTCAKE")
(127857 . "BENTO BOX")
(127858 . "POT OF FOOD")
(127859 . "COOKING")
(127860 . "FORK AND KNIFE")
(127861 . "TEACUP WITHOUT HANDLE")
(127862 . "SAKE BOTTLE AND CUP")
(127863 . "WINE GLASS")
(127864 . "COCKTAIL GLASS")
(127865 . "TROPICAL DRINK")
(127866 . "BEER MUG")
(127867 . "CLINKING BEER MUGS")
(127868 . "BABY BOTTLE")
(127869 . "FORK AND KNIFE WITH PLATE")
(127870 . "BOTTLE WITH POPPING CORK")
(127871 . "POPCORN")
(127872 . "RIBBON")
(127873 . "WRAPPED PRESENT")
(127874 . "BIRTHDAY CAKE")
(127875 . "JACK-O-LANTERN")
(127876 . "CHRISTMAS TREE")
(127877 . "FATHER CHRISTMAS")
(127878 . "FIREWORKS")
(127879 . "FIREWORK SPARKLER")
(127880 . "BALLOON")
(127881 . "PARTY POPPER")
(127882 . "CONFETTI BALL")
(127883 . "TANABATA TREE")
(127884 . "CROSSED FLAGS")
(127885 . "PINE DECORATION")
(127886 . "JAPANESE DOLLS")
(127887 . "CARP STREAMER")
(127888 . "WIND CHIME")
(127889 . "MOON VIEWING CEREMONY")
(127890 . "SCHOOL SATCHEL")
(127891 . "GRADUATION CAP")
(127892 . "HEART WITH TIP ON THE LEFT")
(127893 . "BOUQUET OF FLOWERS")
(127894 . "MILITARY MEDAL")
(127895 . "REMINDER RIBBON")
(127896 . "MUSICAL KEYBOARD WITH JACKS")
(127897 . "STUDIO MICROPHONE")
(127898 . "LEVEL SLIDER")
(127899 . "CONTROL KNOBS")
(127900 . "BEAMED ASCENDING MUSICAL NOTES")
(127901 . "BEAMED DESCENDING MUSICAL NOTES")
(127902 . "FILM FRAMES")
(127903 . "ADMISSION TICKETS")
(127904 . "CAROUSEL HORSE")
(127905 . "FERRIS WHEEL")
(127906 . "ROLLER COASTER")
(127907 . "FISHING POLE AND FISH")
(127908 . "MICROPHONE")
(127909 . "MOVIE CAMERA")
(127910 . "CINEMA")
(127911 . "HEADPHONE")
(127912 . "ARTIST PALETTE")
(127913 . "TOP HAT")
(127914 . "CIRCUS TENT")
(127915 . "TICKET")
(127916 . "CLAPPER BOARD")
(127917 . "PERFORMING ARTS")
(127918 . "VIDEO GAME")
(127919 . "DIRECT HIT")
(127920 . "SLOT MACHINE")
(127921 . "BILLIARDS")
(127922 . "GAME DIE")
(127923 . "BOWLING")
(127924 . "FLOWER PLAYING CARDS")
(127925 . "MUSICAL NOTE")
(127926 . "MULTIPLE MUSICAL NOTES")
(127927 . "SAXOPHONE")
(127928 . "GUITAR")
(127929 . "MUSICAL KEYBOARD")
(127930 . "TRUMPET")
(127931 . "VIOLIN")
(127932 . "MUSICAL SCORE")
(127933 . "RUNNING SHIRT WITH SASH")
(127934 . "TENNIS RACQUET AND BALL")
(127935 . "SKI AND SKI BOOT")
(127936 . "BASKETBALL AND HOOP")
(127937 . "CHEQUERED FLAG")
(127938 . "SNOWBOARDER")
(127939 . "RUNNER")
(127940 . "SURFER")
(127941 . "SPORTS MEDAL")
(127942 . "TROPHY")
(127943 . "HORSE RACING")
(127944 . "AMERICAN FOOTBALL")
(127945 . "RUGBY FOOTBALL")
(127946 . "SWIMMER")
(127947 . "WEIGHT LIFTER")
(127948 . "GOLFER")
(127949 . "RACING MOTORCYCLE")
(127950 . "RACING CAR")
(127951 . "CRICKET BAT AND BALL")
(127952 . "VOLLEYBALL")
(127953 . "FIELD HOCKEY STICK AND BALL")
(127954 . "ICE HOCKEY STICK AND PUCK")
(127955 . "TABLE TENNIS PADDLE AND BALL")
(127956 . "SNOW CAPPED MOUNTAIN")
(127957 . "CAMPING")
(127958 . "BEACH WITH UMBRELLA")
(127959 . "BUILDING CONSTRUCTION")
(127960 . "HOUSE BUILDINGS")
(127961 . "CITYSCAPE")
(127962 . "DERELICT HOUSE BUILDING")
(127963 . "CLASSICAL BUILDING")
(127964 . "DESERT")
(127965 . "DESERT ISLAND")
(127966 . "NATIONAL PARK")
(127967 . "STADIUM")
(127968 . "HOUSE BUILDING")
(127969 . "HOUSE WITH GARDEN")
(127970 . "OFFICE BUILDING")
(127971 . "JAPANESE POST OFFICE")
(127972 . "EUROPEAN POST OFFICE")
(127973 . "HOSPITAL")
(127974 . "BANK")
(127975 . "AUTOMATED TELLER MACHINE")
(127976 . "HOTEL")
(127977 . "LOVE HOTEL")
(127978 . "CONVENIENCE STORE")
(127979 . "SCHOOL")
(127980 . "DEPARTMENT STORE")
(127981 . "FACTORY")
(127982 . "IZAKAYA LANTERN")
(127983 . "JAPANESE CASTLE")
(127984 . "EUROPEAN CASTLE")
(127985 . "WHITE PENNANT")
(127986 . "BLACK PENNANT")
(127987 . "WAVING WHITE FLAG")
(127988 . "WAVING BLACK FLAG")
(127989 . "ROSETTE")
(127990 . "BLACK ROSETTE")
(127991 . "LABEL")
(127992 . "BADMINTON RACQUET AND SHUTTLECOCK")
(127993 . "BOW AND ARROW")
(127994 . "AMPHORA")
(127995 . "EMOJI MODIFIER FITZPATRICK TYPE-1-2")
(127996 . "EMOJI MODIFIER FITZPATRICK TYPE-3")
(127997 . "EMOJI MODIFIER FITZPATRICK TYPE-4")
(127998 . "EMOJI MODIFIER FITZPATRICK TYPE-5")
(127999 . "EMOJI MODIFIER FITZPATRICK TYPE-6")
(128000 . "RAT")
(128001 . "MOUSE")
(128002 . "OX")
(128003 . "WATER BUFFALO")
(128004 . "COW")
(128005 . "TIGER")
(128006 . "LEOPARD")
(128007 . "RABBIT")
(128008 . "CAT")
(128009 . "DRAGON")
(128010 . "CROCODILE")
(128011 . "WHALE")
(128012 . "SNAIL")
(128013 . "SNAKE")
(128014 . "HORSE")
(128015 . "RAM")
(128016 . "GOAT")
(128017 . "SHEEP")
(128018 . "MONKEY")
(128019 . "ROOSTER")
(128020 . "CHICKEN")
(128021 . "DOG")
(128022 . "PIG")
(128023 . "BOAR")
(128024 . "ELEPHANT")
(128025 . "OCTOPUS")
(128026 . "SPIRAL SHELL")
(128027 . "BUG")
(128028 . "ANT")
(128029 . "HONEYBEE")
(128030 . "LADY BEETLE")
(128031 . "FISH")
(128032 . "TROPICAL FISH")
(128033 . "BLOWFISH")
(128034 . "TURTLE")
(128035 . "HATCHING CHICK")
(128036 . "BABY CHICK")
(128037 . "FRONT-FACING BABY CHICK")
(128038 . "BIRD")
(128039 . "PENGUIN")
(128040 . "KOALA")
(128041 . "POODLE")
(128042 . "DROMEDARY CAMEL")
(128043 . "BACTRIAN CAMEL")
(128044 . "DOLPHIN")
(128045 . "MOUSE FACE")
(128046 . "COW FACE")
(128047 . "TIGER FACE")
(128048 . "RABBIT FACE")
(128049 . "CAT FACE")
(128050 . "DRAGON FACE")
(128051 . "SPOUTING WHALE")
(128052 . "HORSE FACE")
(128053 . "MONKEY FACE")
(128054 . "DOG FACE")
(128055 . "PIG FACE")
(128056 . "FROG FACE")
(128057 . "HAMSTER FACE")
(128058 . "WOLF FACE")
(128059 . "BEAR FACE")
(128060 . "PANDA FACE")
(128061 . "PIG NOSE")
(128062 . "PAW PRINTS")
(128063 . "CHIPMUNK")
(128064 . "EYES")
(128065 . "EYE")
(128066 . "EAR")
(128067 . "NOSE")
(128068 . "MOUTH")
(128069 . "TONGUE")
(128070 . "WHITE UP POINTING BACKHAND INDEX")
(128071 . "WHITE DOWN POINTING BACKHAND INDEX")
(128072 . "WHITE LEFT POINTING BACKHAND INDEX")
(128073 . "WHITE RIGHT POINTING BACKHAND INDEX")
(128074 . "FISTED HAND SIGN")
(128075 . "WAVING HAND SIGN")
(128076 . "OK HAND SIGN")
(128077 . "THUMBS UP SIGN")
(128078 . "THUMBS DOWN SIGN")
(128079 . "CLAPPING HANDS SIGN")
(128080 . "OPEN HANDS SIGN")
(128081 . "CROWN")
(128082 . "WOMANS HAT")
(128083 . "EYEGLASSES")
(128084 . "NECKTIE")
(128085 . "T-SHIRT")
(128086 . "JEANS")
(128087 . "DRESS")
(128088 . "KIMONO")
(128089 . "BIKINI")
(128090 . "WOMANS CLOTHES")
(128091 . "PURSE")
(128092 . "HANDBAG")
(128093 . "POUCH")
(128094 . "MANS SHOE")
(128095 . "ATHLETIC SHOE")
(128096 . "HIGH-HEELED SHOE")
(128097 . "WOMANS SANDAL")
(128098 . "WOMANS BOOTS")
(128099 . "FOOTPRINTS")
(128100 . "BUST IN SILHOUETTE")
(128101 . "BUSTS IN SILHOUETTE")
(128102 . "BOY")
(128103 . "GIRL")
(128104 . "MAN")
(128105 . "WOMAN")
(128106 . "FAMILY")
(128107 . "MAN AND WOMAN HOLDING HANDS")
(128108 . "TWO MEN HOLDING HANDS")
(128109 . "TWO WOMEN HOLDING HANDS")
(128110 . "POLICE OFFICER")
(128111 . "WOMAN WITH BUNNY EARS")
(128112 . "BRIDE WITH VEIL")
(128113 . "PERSON WITH BLOND HAIR")
(128114 . "MAN WITH GUA PI MAO")
(128115 . "MAN WITH TURBAN")
(128116 . "OLDER MAN")
(128117 . "OLDER WOMAN")
(128118 . "BABY")
(128119 . "CONSTRUCTION WORKER")
(128120 . "PRINCESS")
(128121 . "JAPANESE OGRE")
(128122 . "JAPANESE GOBLIN")
(128123 . "GHOST")
(128124 . "BABY ANGEL")
(128125 . "EXTRATERRESTRIAL ALIEN")
(128126 . "ALIEN MONSTER")
(128127 . "IMP")
(128128 . "SKULL")
(128129 . "INFORMATION DESK PERSON")
(128130 . "GUARDSMAN")
(128131 . "DANCER")
(128132 . "LIPSTICK")
(128133 . "NAIL POLISH")
(128134 . "FACE MASSAGE")
(128135 . "HAIRCUT")
(128136 . "BARBER POLE")
(128137 . "SYRINGE")
(128138 . "PILL")
(128139 . "KISS MARK")
(128140 . "LOVE LETTER")
(128141 . "RING")
(128142 . "GEM STONE")
(128143 . "KISS")
(128144 . "BOUQUET")
(128145 . "COUPLE WITH HEART")
(128146 . "WEDDING")
(128147 . "BEATING HEART")
(128148 . "BROKEN HEART")
(128149 . "TWO HEARTS")
(128150 . "SPARKLING HEART")
(128151 . "GROWING HEART")
(128152 . "HEART WITH ARROW")
(128153 . "BLUE HEART")
(128154 . "GREEN HEART")
(128155 . "YELLOW HEART")
(128156 . "PURPLE HEART")
(128157 . "HEART WITH RIBBON")
(128158 . "REVOLVING HEARTS")
(128159 . "HEART DECORATION")
(128160 . "DIAMOND SHAPE WITH A DOT INSIDE")
(128161 . "ELECTRIC LIGHT BULB")
(128162 . "ANGER SYMBOL")
(128163 . "BOMB")
(128164 . "SLEEPING SYMBOL")
(128165 . "COLLISION SYMBOL")
(128166 . "SPLASHING SWEAT SYMBOL")
(128167 . "DROPLET")
(128168 . "DASH SYMBOL")
(128169 . "PILE OF POO")
(128170 . "FLEXED BICEPS")
(128171 . "DIZZY SYMBOL")
(128172 . "SPEECH BALLOON")
(128173 . "THOUGHT BALLOON")
(128174 . "WHITE FLOWER")
(128175 . "HUNDRED POINTS SYMBOL")
(128176 . "MONEY BAG")
(128177 . "CURRENCY EXCHANGE")
(128178 . "HEAVY DOLLAR SIGN")
(128179 . "CREDIT CARD")
(128180 . "BANKNOTE WITH YEN SIGN")
(128181 . "BANKNOTE WITH DOLLAR SIGN")
(128182 . "BANKNOTE WITH EURO SIGN")
(128183 . "BANKNOTE WITH POUND SIGN")
(128184 . "MONEY WITH WINGS")
(128185 . "CHART WITH UPWARDS TREND AND YEN SIGN")
(128186 . "SEAT")
(128187 . "PERSONAL COMPUTER")
(128188 . "BRIEFCASE")
(128189 . "MINIDISC")
(128190 . "FLOPPY DISK")
(128191 . "OPTICAL DISC")
(128192 . "DVD")
(128193 . "FILE FOLDER")
(128194 . "OPEN FILE FOLDER")
(128195 . "PAGE WITH CURL")
(128196 . "PAGE FACING UP")
(128197 . "CALENDAR")
(128198 . "TEAR-OFF CALENDAR")
(128199 . "CARD INDEX")
(128200 . "CHART WITH UPWARDS TREND")
(128201 . "CHART WITH DOWNWARDS TREND")
(128202 . "BAR CHART")
(128203 . "CLIPBOARD")
(128204 . "PUSHPIN")
(128205 . "ROUND PUSHPIN")
(128206 . "PAPERCLIP")
(128207 . "STRAIGHT RULER")
(128208 . "TRIANGULAR RULER")
(128209 . "BOOKMARK TABS")
(128210 . "LEDGER")
(128211 . "NOTEBOOK")
(128212 . "NOTEBOOK WITH DECORATIVE COVER")
(128213 . "CLOSED BOOK")
(128214 . "OPEN BOOK")
(128215 . "GREEN BOOK")
(128216 . "BLUE BOOK")
(128217 . "ORANGE BOOK")
(128218 . "BOOKS")
(128219 . "NAME BADGE")
(128220 . "SCROLL")
(128221 . "MEMO")
(128222 . "TELEPHONE RECEIVER")
(128223 . "PAGER")
(128224 . "FAX MACHINE")
(128225 . "SATELLITE ANTENNA")
(128226 . "PUBLIC ADDRESS LOUDSPEAKER")
(128227 . "CHEERING MEGAPHONE")
(128228 . "OUTBOX TRAY")
(128229 . "INBOX TRAY")
(128230 . "PACKAGE")
(128231 . "E-MAIL SYMBOL")
(128232 . "INCOMING ENVELOPE")
(128233 . "ENVELOPE WITH DOWNWARDS ARROW ABOVE")
(128234 . "CLOSED MAILBOX WITH LOWERED FLAG")
(128235 . "CLOSED MAILBOX WITH RAISED FLAG")
(128236 . "OPEN MAILBOX WITH RAISED FLAG")
(128237 . "OPEN MAILBOX WITH LOWERED FLAG")
(128238 . "POSTBOX")
(128239 . "POSTAL HORN")
(128240 . "NEWSPAPER")
(128241 . "MOBILE PHONE")
(128242 . "MOBILE PHONE WITH RIGHTWARDS ARROW AT LEFT")
(128243 . "VIBRATION MODE")
(128244 . "MOBILE PHONE OFF")
(128245 . "NO MOBILE PHONES")
(128246 . "ANTENNA WITH BARS")
(128247 . "CAMERA")
(128248 . "CAMERA WITH FLASH")
(128249 . "VIDEO CAMERA")
(128250 . "TELEVISION")
(128251 . "RADIO")
(128252 . "VIDEOCASSETTE")
(128253 . "FILM PROJECTOR")
(128254 . "PORTABLE STEREO")
(128255 . "PRAYER BEADS")
(128256 . "TWISTED RIGHTWARDS ARROWS")
(128257 . "CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS")
(128258 . "CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS WITH CIRCLED ONE OVERLAY")
(128259 . "CLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS")
(128260 . "ANTICLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS")
(128261 . "LOW BRIGHTNESS SYMBOL")
(128262 . "HIGH BRIGHTNESS SYMBOL")
(128263 . "SPEAKER WITH CANCELLATION STROKE")
(128264 . "SPEAKER")
(128265 . "SPEAKER WITH ONE SOUND WAVE")
(128266 . "SPEAKER WITH THREE SOUND WAVES")
(128267 . "BATTERY")
(128268 . "ELECTRIC PLUG")
(128269 . "LEFT-POINTING MAGNIFYING GLASS")
(128270 . "RIGHT-POINTING MAGNIFYING GLASS")
(128271 . "LOCK WITH INK PEN")
(128272 . "CLOSED LOCK WITH KEY")
(128273 . "KEY")
(128274 . "LOCK")
(128275 . "OPEN LOCK")
(128276 . "BELL")
(128277 . "BELL WITH CANCELLATION STROKE")
(128278 . "BOOKMARK")
(128279 . "LINK SYMBOL")
(128280 . "RADIO BUTTON")
(128281 . "BACK WITH LEFTWARDS ARROW ABOVE")
(128282 . "END WITH LEFTWARDS ARROW ABOVE")
(128283 . "ON WITH EXCLAMATION MARK WITH LEFT RIGHT ARROW ABOVE")
(128284 . "SOON WITH RIGHTWARDS ARROW ABOVE")
(128285 . "TOP WITH UPWARDS ARROW ABOVE")
(128286 . "NO ONE UNDER EIGHTEEN SYMBOL")
(128287 . "KEYCAP TEN")
(128288 . "INPUT SYMBOL FOR LATIN CAPITAL LETTERS")
(128289 . "INPUT SYMBOL FOR LATIN SMALL LETTERS")
(128290 . "INPUT SYMBOL FOR NUMBERS")
(128291 . "INPUT SYMBOL FOR SYMBOLS")
(128292 . "INPUT SYMBOL FOR LATIN LETTERS")
(128293 . "FIRE")
(128294 . "ELECTRIC TORCH")
(128295 . "WRENCH")
(128296 . "HAMMER")
(128297 . "NUT AND BOLT")
(128298 . "HOCHO")
(128299 . "PISTOL")
(128300 . "MICROSCOPE")
(128301 . "TELESCOPE")
(128302 . "CRYSTAL BALL")
(128303 . "SIX POINTED STAR WITH MIDDLE DOT")
(128304 . "JAPANESE SYMBOL FOR BEGINNER")
(128305 . "TRIDENT EMBLEM")
(128306 . "BLACK SQUARE BUTTON")
(128307 . "WHITE SQUARE BUTTON")
(128308 . "LARGE RED CIRCLE")
(128309 . "LARGE BLUE CIRCLE")
(128310 . "LARGE ORANGE DIAMOND")
(128311 . "LARGE BLUE DIAMOND")
(128312 . "SMALL ORANGE DIAMOND")
(128313 . "SMALL BLUE DIAMOND")
(128314 . "UP-POINTING RED TRIANGLE")
(128315 . "DOWN-POINTING RED TRIANGLE")
(128316 . "UP-POINTING SMALL RED TRIANGLE")
(128317 . "DOWN-POINTING SMALL RED TRIANGLE")
(128318 . "LOWER RIGHT SHADOWED WHITE CIRCLE")
(128319 . "UPPER RIGHT SHADOWED WHITE CIRCLE")
(128320 . "CIRCLED CROSS POMMEE")
(128321 . "CROSS POMMEE WITH HALF-CIRCLE BELOW")
(128322 . "CROSS POMMEE")
(128323 . "NOTCHED LEFT SEMICIRCLE WITH THREE DOTS")
(128324 . "NOTCHED RIGHT SEMICIRCLE WITH THREE DOTS")
(128325 . "SYMBOL FOR MARKS CHAPTER")
(128326 . "WHITE LATIN CROSS")
(128327 . "HEAVY LATIN CROSS")
(128328 . "CELTIC CROSS")
(128329 . "OM SYMBOL")
(128330 . "DOVE OF PEACE")
(128331 . "KAABA")
(128332 . "MOSQUE")
(128333 . "SYNAGOGUE")
(128334 . "MENORAH WITH NINE BRANCHES")
(128335 . "BOWL OF HYGIEIA")
(128336 . "CLOCK FACE ONE OCLOCK")
(128337 . "CLOCK FACE TWO OCLOCK")
(128338 . "CLOCK FACE THREE OCLOCK")
(128339 . "CLOCK FACE FOUR OCLOCK")
(128340 . "CLOCK FACE FIVE OCLOCK")
(128341 . "CLOCK FACE SIX OCLOCK")
(128342 . "CLOCK FACE SEVEN OCLOCK")
(128343 . "CLOCK FACE EIGHT OCLOCK")
(128344 . "CLOCK FACE NINE OCLOCK")
(128345 . "CLOCK FACE TEN OCLOCK")
(128346 . "CLOCK FACE ELEVEN OCLOCK")
(128347 . "CLOCK FACE TWELVE OCLOCK")
(128348 . "CLOCK FACE ONE-THIRTY")
(128349 . "CLOCK FACE TWO-THIRTY")
(128350 . "CLOCK FACE THREE-THIRTY")
(128351 . "CLOCK FACE FOUR-THIRTY")
(128352 . "CLOCK FACE FIVE-THIRTY")
(128353 . "CLOCK FACE SIX-THIRTY")
(128354 . "CLOCK FACE SEVEN-THIRTY")
(128355 . "CLOCK FACE EIGHT-THIRTY")
(128356 . "CLOCK FACE NINE-THIRTY")
(128357 . "CLOCK FACE TEN-THIRTY")
(128358 . "CLOCK FACE ELEVEN-THIRTY")
(128359 . "CLOCK FACE TWELVE-THIRTY")
(128360 . "RIGHT SPEAKER")
(128361 . "RIGHT SPEAKER WITH ONE SOUND WAVE")
(128362 . "RIGHT SPEAKER WITH THREE SOUND WAVES")
(128363 . "BULLHORN")
(128364 . "BULLHORN WITH SOUND WAVES")
(128365 . "RINGING BELL")
(128366 . "BOOK")
(128367 . "CANDLE")
(128368 . "MANTELPIECE CLOCK")
(128369 . "BLACK SKULL AND CROSSBONES")
(128370 . "NO PIRACY")
(128371 . "HOLE")
(128372 . "MAN IN BUSINESS SUIT LEVITATING")
(128373 . "SLEUTH OR SPY")
(128374 . "DARK SUNGLASSES")
(128375 . "SPIDER")
(128376 . "SPIDER WEB")
(128377 . "JOYSTICK")
(128378 . "MAN DANCING")
(128379 . "LEFT HAND TELEPHONE RECEIVER")
(128380 . "TELEPHONE RECEIVER WITH PAGE")
(128381 . "RIGHT HAND TELEPHONE RECEIVER")
(128382 . "WHITE TOUCHTONE TELEPHONE")
(128383 . "BLACK TOUCHTONE TELEPHONE")
(128384 . "TELEPHONE ON TOP OF MODEM")
(128385 . "CLAMSHELL MOBILE PHONE")
(128386 . "BACK OF ENVELOPE")
(128387 . "STAMPED ENVELOPE")
(128388 . "ENVELOPE WITH LIGHTNING")
(128389 . "FLYING ENVELOPE")
(128390 . "PEN OVER STAMPED ENVELOPE")
(128391 . "LINKED PAPERCLIPS")
(128392 . "BLACK PUSHPIN")
(128393 . "LOWER LEFT PENCIL")
(128394 . "LOWER LEFT BALLPOINT PEN")
(128395 . "LOWER LEFT FOUNTAIN PEN")
(128396 . "LOWER LEFT PAINTBRUSH")
(128397 . "LOWER LEFT CRAYON")
(128398 . "LEFT WRITING HAND")
(128399 . "TURNED OK HAND SIGN")
(128400 . "RAISED HAND WITH FINGERS SPLAYED")
(128401 . "REVERSED RAISED HAND WITH FINGERS SPLAYED")
(128402 . "REVERSED THUMBS UP SIGN")
(128403 . "REVERSED THUMBS DOWN SIGN")
(128404 . "REVERSED VICTORY HAND")
(128405 . "REVERSED HAND WITH MIDDLE FINGER EXTENDED")
(128406 . "RAISED HAND WITH PART BETWEEN MIDDLE AND RING FINGERS")
(128407 . "WHITE DOWN POINTING LEFT HAND INDEX")
(128408 . "SIDEWAYS WHITE LEFT POINTING INDEX")
(128409 . "SIDEWAYS WHITE RIGHT POINTING INDEX")
(128410 . "SIDEWAYS BLACK LEFT POINTING INDEX")
(128411 . "SIDEWAYS BLACK RIGHT POINTING INDEX")
(128412 . "BLACK LEFT POINTING BACKHAND INDEX")
(128413 . "BLACK RIGHT POINTING BACKHAND INDEX")
(128414 . "SIDEWAYS WHITE UP POINTING INDEX")
(128415 . "SIDEWAYS WHITE DOWN POINTING INDEX")
(128416 . "SIDEWAYS BLACK UP POINTING INDEX")
(128417 . "SIDEWAYS BLACK DOWN POINTING INDEX")
(128418 . "BLACK UP POINTING BACKHAND INDEX")
(128419 . "BLACK DOWN POINTING BACKHAND INDEX")
(128420 . "BLACK HEART")
(128421 . "DESKTOP COMPUTER")
(128422 . "KEYBOARD AND MOUSE")
(128423 . "THREE NETWORKED COMPUTERS")
(128424 . "PRINTER")
(128425 . "POCKET CALCULATOR")
(128426 . "BLACK HARD SHELL FLOPPY DISK")
(128427 . "WHITE HARD SHELL FLOPPY DISK")
(128428 . "SOFT SHELL FLOPPY DISK")
(128429 . "TAPE CARTRIDGE")
(128430 . "WIRED KEYBOARD")
(128431 . "ONE BUTTON MOUSE")
(128432 . "TWO BUTTON MOUSE")
(128433 . "THREE BUTTON MOUSE")
(128434 . "TRACKBALL")
(128435 . "OLD PERSONAL COMPUTER")
(128436 . "HARD DISK")
(128437 . "SCREEN")
(128438 . "PRINTER ICON")
(128439 . "FAX ICON")
(128440 . "OPTICAL DISC ICON")
(128441 . "DOCUMENT WITH TEXT")
(128442 . "DOCUMENT WITH TEXT AND PICTURE")
(128443 . "DOCUMENT WITH PICTURE")
(128444 . "FRAME WITH PICTURE")
(128445 . "FRAME WITH TILES")
(128446 . "FRAME WITH AN X")
(128447 . "BLACK FOLDER")
(128448 . "FOLDER")
(128449 . "OPEN FOLDER")
(128450 . "CARD INDEX DIVIDERS")
(128451 . "CARD FILE BOX")
(128452 . "FILE CABINET")
(128453 . "EMPTY NOTE")
(128454 . "EMPTY NOTE PAGE")
(128455 . "EMPTY NOTE PAD")
(128456 . "NOTE")
(128457 . "NOTE PAGE")
(128458 . "NOTE PAD")
(128459 . "EMPTY DOCUMENT")
(128460 . "EMPTY PAGE")
(128461 . "EMPTY PAGES")
(128462 . "DOCUMENT")
(128463 . "PAGE")
(128464 . "PAGES")
(128465 . "WASTEBASKET")
(128466 . "SPIRAL NOTE PAD")
(128467 . "SPIRAL CALENDAR PAD")
(128468 . "DESKTOP WINDOW")
(128469 . "MINIMIZE")
(128470 . "MAXIMIZE")
(128471 . "OVERLAP")
(128472 . "CLOCKWISE RIGHT AND LEFT SEMICIRCLE ARROWS")
(128473 . "CANCELLATION X")
(128474 . "INCREASE FONT SIZE SYMBOL")
(128475 . "DECREASE FONT SIZE SYMBOL")
(128476 . "COMPRESSION")
(128477 . "OLD KEY")
(128478 . "ROLLED-UP NEWSPAPER")
(128479 . "PAGE WITH CIRCLED TEXT")
(128480 . "STOCK CHART")
(128481 . "DAGGER KNIFE")
(128482 . "LIPS")
(128483 . "SPEAKING HEAD IN SILHOUETTE")
(128484 . "THREE RAYS ABOVE")
(128485 . "THREE RAYS BELOW")
(128486 . "THREE RAYS LEFT")
(128487 . "THREE RAYS RIGHT")
(128488 . "LEFT SPEECH BUBBLE")
(128489 . "RIGHT SPEECH BUBBLE")
(128490 . "TWO SPEECH BUBBLES")
(128491 . "THREE SPEECH BUBBLES")
(128492 . "LEFT THOUGHT BUBBLE")
(128493 . "RIGHT THOUGHT BUBBLE")
(128494 . "LEFT ANGER BUBBLE")
(128495 . "RIGHT ANGER BUBBLE")
(128496 . "MOOD BUBBLE")
(128497 . "LIGHTNING MOOD BUBBLE")
(128498 . "LIGHTNING MOOD")
(128499 . "BALLOT BOX WITH BALLOT")
(128500 . "BALLOT SCRIPT X")
(128501 . "BALLOT BOX WITH SCRIPT X")
(128502 . "BALLOT BOLD SCRIPT X")
(128503 . "BALLOT BOX WITH BOLD SCRIPT X")
(128504 . "LIGHT CHECK MARK")
(128505 . "BALLOT BOX WITH BOLD CHECK")
(128506 . "WORLD MAP")
(128507 . "MOUNT FUJI")
(128508 . "TOKYO TOWER")
(128509 . "STATUE OF LIBERTY")
(128510 . "SILHOUETTE OF JAPAN")
(128511 . "MOYAI")
(128512 . "GRINNING FACE")
(128513 . "GRINNING FACE WITH SMILING EYES")
(128514 . "FACE WITH TEARS OF JOY")
(128515 . "SMILING FACE WITH OPEN MOUTH")
(128516 . "SMILING FACE WITH OPEN MOUTH AND SMILING EYES")
(128517 . "SMILING FACE WITH OPEN MOUTH AND COLD SWEAT")
(128518 . "SMILING FACE WITH OPEN MOUTH AND TIGHTLY-CLOSED EYES")
(128519 . "SMILING FACE WITH HALO")
(128520 . "SMILING FACE WITH HORNS")
(128521 . "WINKING FACE")
(128522 . "SMILING FACE WITH SMILING EYES")
(128523 . "FACE SAVOURING DELICIOUS FOOD")
(128524 . "RELIEVED FACE")
(128525 . "SMILING FACE WITH HEART-SHAPED EYES")
(128526 . "SMILING FACE WITH SUNGLASSES")
(128527 . "SMIRKING FACE")
(128528 . "NEUTRAL FACE")
(128529 . "EXPRESSIONLESS FACE")
(128530 . "UNAMUSED FACE")
(128531 . "FACE WITH COLD SWEAT")
(128532 . "PENSIVE FACE")
(128533 . "CONFUSED FACE")
(128534 . "CONFOUNDED FACE")
(128535 . "KISSING FACE")
(128536 . "FACE THROWING A KISS")
(128537 . "KISSING FACE WITH SMILING EYES")
(128538 . "KISSING FACE WITH CLOSED EYES")
(128539 . "FACE WITH STUCK-OUT TONGUE")
(128540 . "FACE WITH STUCK-OUT TONGUE AND WINKING EYE")
(128541 . "FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES")
(128542 . "DISAPPOINTED FACE")
(128543 . "WORRIED FACE")
(128544 . "ANGRY FACE")
(128545 . "POUTING FACE")
(128546 . "CRYING FACE")
(128547 . "PERSEVERING FACE")
(128548 . "FACE WITH LOOK OF TRIUMPH")
(128549 . "DISAPPOINTED BUT RELIEVED FACE")
(128550 . "FROWNING FACE WITH OPEN MOUTH")
(128551 . "ANGUISHED FACE")
(128552 . "FEARFUL FACE")
(128553 . "WEARY FACE")
(128554 . "SLEEPY FACE")
(128555 . "TIRED FACE")
(128556 . "GRIMACING FACE")
(128557 . "LOUDLY CRYING FACE")
(128558 . "FACE WITH OPEN MOUTH")
(128559 . "HUSHED FACE")
(128560 . "FACE WITH OPEN MOUTH AND COLD SWEAT")
(128561 . "FACE SCREAMING IN FEAR")
(128562 . "ASTONISHED FACE")
(128563 . "FLUSHED FACE")
(128564 . "SLEEPING FACE")
(128565 . "DIZZY FACE")
(128566 . "FACE WITHOUT MOUTH")
(128567 . "FACE WITH MEDICAL MASK")
(128568 . "GRINNING CAT FACE WITH SMILING EYES")
(128569 . "CAT FACE WITH TEARS OF JOY")
(128570 . "SMILING CAT FACE WITH OPEN MOUTH")
(128571 . "SMILING CAT FACE WITH HEART-SHAPED EYES")
(128572 . "CAT FACE WITH WRY SMILE")
(128573 . "KISSING CAT FACE WITH CLOSED EYES")
(128574 . "POUTING CAT FACE")
(128575 . "CRYING CAT FACE")
(128576 . "WEARY CAT FACE")
(128577 . "SLIGHTLY FROWNING FACE")
(128578 . "SLIGHTLY SMILING FACE")
(128579 . "UPSIDE-DOWN FACE")
(128580 . "FACE WITH ROLLING EYES")
(128581 . "FACE WITH NO GOOD GESTURE")
(128582 . "FACE WITH OK GESTURE")
(128583 . "PERSON BOWING DEEPLY")
(128584 . "SEE-NO-EVIL MONKEY")
(128585 . "HEAR-NO-EVIL MONKEY")
(128586 . "SPEAK-NO-EVIL MONKEY")
(128587 . "HAPPY PERSON RAISING ONE HAND")
(128588 . "PERSON RAISING BOTH HANDS IN CELEBRATION")
(128589 . "PERSON FROWNING")
(128590 . "PERSON WITH POUTING FACE")
(128591 . "PERSON WITH FOLDED HANDS")
(128592 . "NORTH WEST POINTING LEAF")
(128593 . "SOUTH WEST POINTING LEAF")
(128594 . "NORTH EAST POINTING LEAF")
(128595 . "SOUTH EAST POINTING LEAF")
(128596 . "TURNED NORTH WEST POINTING LEAF")
(128597 . "TURNED SOUTH WEST POINTING LEAF")
(128598 . "TURNED NORTH EAST POINTING LEAF")
(128599 . "TURNED SOUTH EAST POINTING LEAF")
(128600 . "NORTH WEST POINTING VINE LEAF")
(128601 . "SOUTH WEST POINTING VINE LEAF")
(128602 . "NORTH EAST POINTING VINE LEAF")
(128603 . "SOUTH EAST POINTING VINE LEAF")
(128604 . "HEAVY NORTH WEST POINTING VINE LEAF")
(128605 . "HEAVY SOUTH WEST POINTING VINE LEAF")
(128606 . "HEAVY NORTH EAST POINTING VINE LEAF")
(128607 . "HEAVY SOUTH EAST POINTING VINE LEAF")
(128608 . "NORTH WEST POINTING BUD")
(128609 . "SOUTH WEST POINTING BUD")
(128610 . "NORTH EAST POINTING BUD")
(128611 . "SOUTH EAST POINTING BUD")
(128612 . "HEAVY NORTH WEST POINTING BUD")
(128613 . "HEAVY SOUTH WEST POINTING BUD")
(128614 . "HEAVY NORTH EAST POINTING BUD")
(128615 . "HEAVY SOUTH EAST POINTING BUD")
(128616 . "HOLLOW QUILT SQUARE ORNAMENT")
(128617 . "HOLLOW QUILT SQUARE ORNAMENT IN BLACK SQUARE")
(128618 . "SOLID QUILT SQUARE ORNAMENT")
(128619 . "SOLID QUILT SQUARE ORNAMENT IN BLACK SQUARE")
(128620 . "LEFTWARDS ROCKET")
(128621 . "UPWARDS ROCKET")
(128622 . "RIGHTWARDS ROCKET")
(128623 . "DOWNWARDS ROCKET")
(128624 . "SCRIPT LIGATURE ET ORNAMENT")
(128625 . "HEAVY SCRIPT LIGATURE ET ORNAMENT")
(128626 . "LIGATURE OPEN ET ORNAMENT")
(128627 . "HEAVY LIGATURE OPEN ET ORNAMENT")
(128628 . "HEAVY AMPERSAND ORNAMENT")
(128629 . "SWASH AMPERSAND ORNAMENT")
(128630 . "SANS-SERIF HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT")
(128631 . "SANS-SERIF HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT")
(128632 . "SANS-SERIF HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT")
(128633 . "HEAVY INTERROBANG ORNAMENT")
(128634 . "SANS-SERIF INTERROBANG ORNAMENT")
(128635 . "HEAVY SANS-SERIF INTERROBANG ORNAMENT")
(128636 . "VERY HEAVY SOLIDUS")
(128637 . "VERY HEAVY REVERSE SOLIDUS")
(128638 . "CHECKER BOARD")
(128639 . "REVERSE CHECKER BOARD")
(128640 . "ROCKET")
(128641 . "HELICOPTER")
(128642 . "STEAM LOCOMOTIVE")
(128643 . "RAILWAY CAR")
(128644 . "HIGH-SPEED TRAIN")
(128645 . "HIGH-SPEED TRAIN WITH BULLET NOSE")
(128646 . "TRAIN")
(128647 . "METRO")
(128648 . "LIGHT RAIL")
(128649 . "STATION")
(128650 . "TRAM")
(128651 . "TRAM CAR")
(128652 . "BUS")
(128653 . "ONCOMING BUS")
(128654 . "TROLLEYBUS")
(128655 . "BUS STOP")
(128656 . "MINIBUS")
(128657 . "AMBULANCE")
(128658 . "FIRE ENGINE")
(128659 . "POLICE CAR")
(128660 . "ONCOMING POLICE CAR")
(128661 . "TAXI")
(128662 . "ONCOMING TAXI")
(128663 . "AUTOMOBILE")
(128664 . "ONCOMING AUTOMOBILE")
(128665 . "RECREATIONAL VEHICLE")
(128666 . "DELIVERY TRUCK")
(128667 . "ARTICULATED LORRY")
(128668 . "TRACTOR")
(128669 . "MONORAIL")
(128670 . "MOUNTAIN RAILWAY")
(128671 . "SUSPENSION RAILWAY")
(128672 . "MOUNTAIN CABLEWAY")
(128673 . "AERIAL TRAMWAY")
(128674 . "SHIP")
(128675 . "ROWBOAT")
(128676 . "SPEEDBOAT")
(128677 . "HORIZONTAL TRAFFIC LIGHT")
(128678 . "VERTICAL TRAFFIC LIGHT")
(128679 . "CONSTRUCTION SIGN")
(128680 . "POLICE CARS REVOLVING LIGHT")
(128681 . "TRIANGULAR FLAG ON POST")
(128682 . "DOOR")
(128683 . "NO ENTRY SIGN")
(128684 . "SMOKING SYMBOL")
(128685 . "NO SMOKING SYMBOL")
(128686 . "PUT LITTER IN ITS PLACE SYMBOL")
(128687 . "DO NOT LITTER SYMBOL")
(128688 . "POTABLE WATER SYMBOL")
(128689 . "NON-POTABLE WATER SYMBOL")
(128690 . "BICYCLE")
(128691 . "NO BICYCLES")
(128692 . "BICYCLIST")
(128693 . "MOUNTAIN BICYCLIST")
(128694 . "PEDESTRIAN")
(128695 . "NO PEDESTRIANS")
(128696 . "CHILDREN CROSSING")
(128697 . "MENS SYMBOL")
(128698 . "WOMENS SYMBOL")
(128699 . "RESTROOM")
(128700 . "BABY SYMBOL")
(128701 . "TOILET")
(128702 . "WATER CLOSET")
(128703 . "SHOWER")
(128704 . "BATH")
(128705 . "BATHTUB")
(128706 . "PASSPORT CONTROL")
(128707 . "CUSTOMS")
(128708 . "BAGGAGE CLAIM")
(128709 . "LEFT LUGGAGE")
(128710 . "TRIANGLE WITH ROUNDED CORNERS")
(128711 . "PROHIBITED SIGN")
(128712 . "CIRCLED INFORMATION SOURCE")
(128713 . "BOYS SYMBOL")
(128714 . "GIRLS SYMBOL")
(128715 . "COUCH AND LAMP")
(128716 . "SLEEPING ACCOMMODATION")
(128717 . "SHOPPING BAGS")
(128718 . "BELLHOP BELL")
(128719 . "BED")
(128720 . "PLACE OF WORSHIP")
(128721 . "OCTAGONAL SIGN")
(128722 . "SHOPPING TROLLEY")
((128723 . 128736) . #f)
(128736 . "HAMMER AND WRENCH")
(128737 . "SHIELD")
(128738 . "OIL DRUM")
(128739 . "MOTORWAY")
(128740 . "RAILWAY TRACK")
(128741 . "MOTOR BOAT")
(128742 . "UP-POINTING MILITARY AIRPLANE")
(128743 . "UP-POINTING AIRPLANE")
(128744 . "UP-POINTING SMALL AIRPLANE")
(128745 . "SMALL AIRPLANE")
(128746 . "NORTHEAST-POINTING AIRPLANE")
(128747 . "AIRPLANE DEPARTURE")
(128748 . "AIRPLANE ARRIVING")
((128749 . 128752) . #f)
(128752 . "SATELLITE")
(128753 . "ONCOMING FIRE ENGINE")
(128754 . "DIESEL LOCOMOTIVE")
(128755 . "PASSENGER SHIP")
(128756 . "SCOOTER")
(128757 . "MOTOR SCOOTER")
(128758 . "CANOE")
((128759 . 128768) . #f)
(128768 . "ALCHEMICAL SYMBOL FOR QUINTESSENCE")
(128769 . "ALCHEMICAL SYMBOL FOR AIR")
(128770 . "ALCHEMICAL SYMBOL FOR FIRE")
(128771 . "ALCHEMICAL SYMBOL FOR EARTH")
(128772 . "ALCHEMICAL SYMBOL FOR WATER")
(128773 . "ALCHEMICAL SYMBOL FOR AQUAFORTIS")
(128774 . "ALCHEMICAL SYMBOL FOR AQUA REGIA")
(128775 . "ALCHEMICAL SYMBOL FOR AQUA REGIA-2")
(128776 . "ALCHEMICAL SYMBOL FOR AQUA VITAE")
(128777 . "ALCHEMICAL SYMBOL FOR AQUA VITAE-2")
(128778 . "ALCHEMICAL SYMBOL FOR VINEGAR")
(128779 . "ALCHEMICAL SYMBOL FOR VINEGAR-2")
(128780 . "ALCHEMICAL SYMBOL FOR VINEGAR-3")
(128781 . "ALCHEMICAL SYMBOL FOR SULFUR")
(128782 . "ALCHEMICAL SYMBOL FOR PHILOSOPHERS SULFUR")
(128783 . "ALCHEMICAL SYMBOL FOR BLACK SULFUR")
(128784 . "ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE")
(128785 . "ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-2")
(128786 . "ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-3")
(128787 . "ALCHEMICAL SYMBOL FOR CINNABAR")
(128788 . "ALCHEMICAL SYMBOL FOR SALT")
(128789 . "ALCHEMICAL SYMBOL FOR NITRE")
(128790 . "ALCHEMICAL SYMBOL FOR VITRIOL")
(128791 . "ALCHEMICAL SYMBOL FOR VITRIOL-2")
(128792 . "ALCHEMICAL SYMBOL FOR ROCK SALT")
(128793 . "ALCHEMICAL SYMBOL FOR ROCK SALT-2")
(128794 . "ALCHEMICAL SYMBOL FOR GOLD")
(128795 . "ALCHEMICAL SYMBOL FOR SILVER")
(128796 . "ALCHEMICAL SYMBOL FOR IRON ORE")
(128797 . "ALCHEMICAL SYMBOL FOR IRON ORE-2")
(128798 . "ALCHEMICAL SYMBOL FOR CROCUS OF IRON")
(128799 . "ALCHEMICAL SYMBOL FOR REGULUS OF IRON")
(128800 . "ALCHEMICAL SYMBOL FOR COPPER ORE")
(128801 . "ALCHEMICAL SYMBOL FOR IRON-COPPER ORE")
(128802 . "ALCHEMICAL SYMBOL FOR SUBLIMATE OF COPPER")
(128803 . "ALCHEMICAL SYMBOL FOR CROCUS OF COPPER")
(128804 . "ALCHEMICAL SYMBOL FOR CROCUS OF COPPER-2")
(128805 . "ALCHEMICAL SYMBOL FOR COPPER ANTIMONIATE")
(128806 . "ALCHEMICAL SYMBOL FOR SALT OF COPPER ANTIMONIATE")
(128807 . "ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF COPPER")
(128808 . "ALCHEMICAL SYMBOL FOR VERDIGRIS")
(128809 . "ALCHEMICAL SYMBOL FOR TIN ORE")
(128810 . "ALCHEMICAL SYMBOL FOR LEAD ORE")
(128811 . "ALCHEMICAL SYMBOL FOR ANTIMONY ORE")
(128812 . "ALCHEMICAL SYMBOL FOR SUBLIMATE OF ANTIMONY")
(128813 . "ALCHEMICAL SYMBOL FOR SALT OF ANTIMONY")
(128814 . "ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF ANTIMONY")
(128815 . "ALCHEMICAL SYMBOL FOR VINEGAR OF ANTIMONY")
(128816 . "ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY")
(128817 . "ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY-2")
(128818 . "ALCHEMICAL SYMBOL FOR REGULUS")
(128819 . "ALCHEMICAL SYMBOL FOR REGULUS-2")
(128820 . "ALCHEMICAL SYMBOL FOR REGULUS-3")
(128821 . "ALCHEMICAL SYMBOL FOR REGULUS-4")
(128822 . "ALCHEMICAL SYMBOL FOR ALKALI")
(128823 . "ALCHEMICAL SYMBOL FOR ALKALI-2")
(128824 . "ALCHEMICAL SYMBOL FOR MARCASITE")
(128825 . "ALCHEMICAL SYMBOL FOR SAL-AMMONIAC")
(128826 . "ALCHEMICAL SYMBOL FOR ARSENIC")
(128827 . "ALCHEMICAL SYMBOL FOR REALGAR")
(128828 . "ALCHEMICAL SYMBOL FOR REALGAR-2")
(128829 . "ALCHEMICAL SYMBOL FOR AURIPIGMENT")
(128830 . "ALCHEMICAL SYMBOL FOR BISMUTH ORE")
(128831 . "ALCHEMICAL SYMBOL FOR TARTAR")
(128832 . "ALCHEMICAL SYMBOL FOR TARTAR-2")
(128833 . "ALCHEMICAL SYMBOL FOR QUICK LIME")
(128834 . "ALCHEMICAL SYMBOL FOR BORAX")
(128835 . "ALCHEMICAL SYMBOL FOR BORAX-2")
(128836 . "ALCHEMICAL SYMBOL FOR BORAX-3")
(128837 . "ALCHEMICAL SYMBOL FOR ALUM")
(128838 . "ALCHEMICAL SYMBOL FOR OIL")
(128839 . "ALCHEMICAL SYMBOL FOR SPIRIT")
(128840 . "ALCHEMICAL SYMBOL FOR TINCTURE")
(128841 . "ALCHEMICAL SYMBOL FOR GUM")
(128842 . "ALCHEMICAL SYMBOL FOR WAX")
(128843 . "ALCHEMICAL SYMBOL FOR POWDER")
(128844 . "ALCHEMICAL SYMBOL FOR CALX")
(128845 . "ALCHEMICAL SYMBOL FOR TUTTY")
(128846 . "ALCHEMICAL SYMBOL FOR CAPUT MORTUUM")
(128847 . "ALCHEMICAL SYMBOL FOR SCEPTER OF JOVE")
(128848 . "ALCHEMICAL SYMBOL FOR CADUCEUS")
(128849 . "ALCHEMICAL SYMBOL FOR TRIDENT")
(128850 . "ALCHEMICAL SYMBOL FOR STARRED TRIDENT")
(128851 . "ALCHEMICAL SYMBOL FOR LODESTONE")
(128852 . "ALCHEMICAL SYMBOL FOR SOAP")
(128853 . "ALCHEMICAL SYMBOL FOR URINE")
(128854 . "ALCHEMICAL SYMBOL FOR HORSE DUNG")
(128855 . "ALCHEMICAL SYMBOL FOR ASHES")
(128856 . "ALCHEMICAL SYMBOL FOR POT ASHES")
(128857 . "ALCHEMICAL SYMBOL FOR BRICK")
(128858 . "ALCHEMICAL SYMBOL FOR POWDERED BRICK")
(128859 . "ALCHEMICAL SYMBOL FOR AMALGAM")
(128860 . "ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM")
(128861 . "ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM-2")
(128862 . "ALCHEMICAL SYMBOL FOR SUBLIMATION")
(128863 . "ALCHEMICAL SYMBOL FOR PRECIPITATE")
(128864 . "ALCHEMICAL SYMBOL FOR DISTILL")
(128865 . "ALCHEMICAL SYMBOL FOR DISSOLVE")
(128866 . "ALCHEMICAL SYMBOL FOR DISSOLVE-2")
(128867 . "ALCHEMICAL SYMBOL FOR PURIFY")
(128868 . "ALCHEMICAL SYMBOL FOR PUTREFACTION")
(128869 . "ALCHEMICAL SYMBOL FOR CRUCIBLE")
(128870 . "ALCHEMICAL SYMBOL FOR CRUCIBLE-2")
(128871 . "ALCHEMICAL SYMBOL FOR CRUCIBLE-3")
(128872 . "ALCHEMICAL SYMBOL FOR CRUCIBLE-4")
(128873 . "ALCHEMICAL SYMBOL FOR CRUCIBLE-5")
(128874 . "ALCHEMICAL SYMBOL FOR ALEMBIC")
(128875 . "ALCHEMICAL SYMBOL FOR BATH OF MARY")
(128876 . "ALCHEMICAL SYMBOL FOR BATH OF VAPOURS")
(128877 . "ALCHEMICAL SYMBOL FOR RETORT")
(128878 . "ALCHEMICAL SYMBOL FOR HOUR")
(128879 . "ALCHEMICAL SYMBOL FOR NIGHT")
(128880 . "ALCHEMICAL SYMBOL FOR DAY-NIGHT")
(128881 . "ALCHEMICAL SYMBOL FOR MONTH")
(128882 . "ALCHEMICAL SYMBOL FOR HALF DRAM")
(128883 . "ALCHEMICAL SYMBOL FOR HALF OUNCE")
((128884 . 128896) . #f)
(128896 . "BLACK LEFT-POINTING ISOSCELES RIGHT TRIANGLE")
(128897 . "BLACK UP-POINTING ISOSCELES RIGHT TRIANGLE")
(128898 . "BLACK RIGHT-POINTING ISOSCELES RIGHT TRIANGLE")
(128899 . "BLACK DOWN-POINTING ISOSCELES RIGHT TRIANGLE")
(128900 . "BLACK SLIGHTLY SMALL CIRCLE")
(128901 . "MEDIUM BOLD WHITE CIRCLE")
(128902 . "BOLD WHITE CIRCLE")
(128903 . "HEAVY WHITE CIRCLE")
(128904 . "VERY HEAVY WHITE CIRCLE")
(128905 . "EXTREMELY HEAVY WHITE CIRCLE")
(128906 . "WHITE CIRCLE CONTAINING BLACK SMALL CIRCLE")
(128907 . "ROUND TARGET")
(128908 . "BLACK TINY SQUARE")
(128909 . "BLACK SLIGHTLY SMALL SQUARE")
(128910 . "LIGHT WHITE SQUARE")
(128911 . "MEDIUM WHITE SQUARE")
(128912 . "BOLD WHITE SQUARE")
(128913 . "HEAVY WHITE SQUARE")
(128914 . "VERY HEAVY WHITE SQUARE")
(128915 . "EXTREMELY HEAVY WHITE SQUARE")
(128916 . "WHITE SQUARE CONTAINING BLACK VERY SMALL SQUARE")
(128917 . "WHITE SQUARE CONTAINING BLACK MEDIUM SQUARE")
(128918 . "SQUARE TARGET")
(128919 . "BLACK TINY DIAMOND")
(128920 . "BLACK VERY SMALL DIAMOND")
(128921 . "BLACK MEDIUM SMALL DIAMOND")
(128922 . "WHITE DIAMOND CONTAINING BLACK VERY SMALL DIAMOND")
(128923 . "WHITE DIAMOND CONTAINING BLACK MEDIUM DIAMOND")
(128924 . "DIAMOND TARGET")
(128925 . "BLACK TINY LOZENGE")
(128926 . "BLACK VERY SMALL LOZENGE")
(128927 . "BLACK MEDIUM SMALL LOZENGE")
(128928 . "WHITE LOZENGE CONTAINING BLACK SMALL LOZENGE")
(128929 . "THIN GREEK CROSS")
(128930 . "LIGHT GREEK CROSS")
(128931 . "MEDIUM GREEK CROSS")
(128932 . "BOLD GREEK CROSS")
(128933 . "VERY BOLD GREEK CROSS")
(128934 . "VERY HEAVY GREEK CROSS")
(128935 . "EXTREMELY HEAVY GREEK CROSS")
(128936 . "THIN SALTIRE")
(128937 . "LIGHT SALTIRE")
(128938 . "MEDIUM SALTIRE")
(128939 . "BOLD SALTIRE")
(128940 . "HEAVY SALTIRE")
(128941 . "VERY HEAVY SALTIRE")
(128942 . "EXTREMELY HEAVY SALTIRE")
(128943 . "LIGHT FIVE SPOKED ASTERISK")
(128944 . "MEDIUM FIVE SPOKED ASTERISK")
(128945 . "BOLD FIVE SPOKED ASTERISK")
(128946 . "HEAVY FIVE SPOKED ASTERISK")
(128947 . "VERY HEAVY FIVE SPOKED ASTERISK")
(128948 . "EXTREMELY HEAVY FIVE SPOKED ASTERISK")
(128949 . "LIGHT SIX SPOKED ASTERISK")
(128950 . "MEDIUM SIX SPOKED ASTERISK")
(128951 . "BOLD SIX SPOKED ASTERISK")
(128952 . "HEAVY SIX SPOKED ASTERISK")
(128953 . "VERY HEAVY SIX SPOKED ASTERISK")
(128954 . "EXTREMELY HEAVY SIX SPOKED ASTERISK")
(128955 . "LIGHT EIGHT SPOKED ASTERISK")
(128956 . "MEDIUM EIGHT SPOKED ASTERISK")
(128957 . "BOLD EIGHT SPOKED ASTERISK")
(128958 . "HEAVY EIGHT SPOKED ASTERISK")
(128959 . "VERY HEAVY EIGHT SPOKED ASTERISK")
(128960 . "LIGHT THREE POINTED BLACK STAR")
(128961 . "MEDIUM THREE POINTED BLACK STAR")
(128962 . "THREE POINTED BLACK STAR")
(128963 . "MEDIUM THREE POINTED PINWHEEL STAR")
(128964 . "LIGHT FOUR POINTED BLACK STAR")
(128965 . "MEDIUM FOUR POINTED BLACK STAR")
(128966 . "FOUR POINTED BLACK STAR")
(128967 . "MEDIUM FOUR POINTED PINWHEEL STAR")
(128968 . "REVERSE LIGHT FOUR POINTED PINWHEEL STAR")
(128969 . "LIGHT FIVE POINTED BLACK STAR")
(128970 . "HEAVY FIVE POINTED BLACK STAR")
(128971 . "MEDIUM SIX POINTED BLACK STAR")
(128972 . "HEAVY SIX POINTED BLACK STAR")
(128973 . "SIX POINTED PINWHEEL STAR")
(128974 . "MEDIUM EIGHT POINTED BLACK STAR")
(128975 . "HEAVY EIGHT POINTED BLACK STAR")
(128976 . "VERY HEAVY EIGHT POINTED BLACK STAR")
(128977 . "HEAVY EIGHT POINTED PINWHEEL STAR")
(128978 . "LIGHT TWELVE POINTED BLACK STAR")
(128979 . "HEAVY TWELVE POINTED BLACK STAR")
(128980 . "HEAVY TWELVE POINTED PINWHEEL STAR")
((128981 . 129024) . #f)
(129024 . "LEFTWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD")
(129025 . "UPWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD")
(129026 . "RIGHTWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD")
(129027 . "DOWNWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD")
(129028 . "LEFTWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD")
(129029 . "UPWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD")
(129030 . "RIGHTWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD")
(129031 . "DOWNWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD")
(129032 . "LEFTWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD")
(129033 . "UPWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD")
(129034 . "RIGHTWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD")
(129035 . "DOWNWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD")
((129036 . 129040) . #f)
(129040 . "LEFTWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD")
(129041 . "UPWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD")
(129042 . "RIGHTWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD")
(129043 . "DOWNWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD")
(129044 . "LEFTWARDS ARROW WITH EQUILATERAL ARROWHEAD")
(129045 . "UPWARDS ARROW WITH EQUILATERAL ARROWHEAD")
(129046 . "RIGHTWARDS ARROW WITH EQUILATERAL ARROWHEAD")
(129047 . "DOWNWARDS ARROW WITH EQUILATERAL ARROWHEAD")
(129048 . "HEAVY LEFTWARDS ARROW WITH EQUILATERAL ARROWHEAD")
(129049 . "HEAVY UPWARDS ARROW WITH EQUILATERAL ARROWHEAD")
(129050 . "HEAVY RIGHTWARDS ARROW WITH EQUILATERAL ARROWHEAD")
(129051 . "HEAVY DOWNWARDS ARROW WITH EQUILATERAL ARROWHEAD")
(129052 . "HEAVY LEFTWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD")
(129053 . "HEAVY UPWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD")
(129054 . "HEAVY RIGHTWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD")
(129055 . "HEAVY DOWNWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD")
(129056 . "LEFTWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT")
(129057 . "UPWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT")
(129058 . "RIGHTWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT")
(129059 . "DOWNWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT")
(129060 . "LEFTWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT")
(129061 . "UPWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT")
(129062 . "RIGHTWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT")
(129063 . "DOWNWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT")
(129064 . "LEFTWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT")
(129065 . "UPWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT")
(129066 . "RIGHTWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT")
(129067 . "DOWNWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT")
(129068 . "LEFTWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT")
(129069 . "UPWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT")
(129070 . "RIGHTWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT")
(129071 . "DOWNWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT")
(129072 . "LEFTWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT")
(129073 . "UPWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT")
(129074 . "RIGHTWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT")
(129075 . "DOWNWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT")
(129076 . "LEFTWARDS FINGER-POST ARROW")
(129077 . "UPWARDS FINGER-POST ARROW")
(129078 . "RIGHTWARDS FINGER-POST ARROW")
(129079 . "DOWNWARDS FINGER-POST ARROW")
(129080 . "LEFTWARDS SQUARED ARROW")
(129081 . "UPWARDS SQUARED ARROW")
(129082 . "RIGHTWARDS SQUARED ARROW")
(129083 . "DOWNWARDS SQUARED ARROW")
(129084 . "LEFTWARDS COMPRESSED ARROW")
(129085 . "UPWARDS COMPRESSED ARROW")
(129086 . "RIGHTWARDS COMPRESSED ARROW")
(129087 . "DOWNWARDS COMPRESSED ARROW")
(129088 . "LEFTWARDS HEAVY COMPRESSED ARROW")
(129089 . "UPWARDS HEAVY COMPRESSED ARROW")
(129090 . "RIGHTWARDS HEAVY COMPRESSED ARROW")
(129091 . "DOWNWARDS HEAVY COMPRESSED ARROW")
(129092 . "LEFTWARDS HEAVY ARROW")
(129093 . "UPWARDS HEAVY ARROW")
(129094 . "RIGHTWARDS HEAVY ARROW")
(129095 . "DOWNWARDS HEAVY ARROW")
((129096 . 129104) . #f)
(129104 . "LEFTWARDS SANS-SERIF ARROW")
(129105 . "UPWARDS SANS-SERIF ARROW")
(129106 . "RIGHTWARDS SANS-SERIF ARROW")
(129107 . "DOWNWARDS SANS-SERIF ARROW")
(129108 . "NORTH WEST SANS-SERIF ARROW")
(129109 . "NORTH EAST SANS-SERIF ARROW")
(129110 . "SOUTH EAST SANS-SERIF ARROW")
(129111 . "SOUTH WEST SANS-SERIF ARROW")
(129112 . "LEFT RIGHT SANS-SERIF ARROW")
(129113 . "UP DOWN SANS-SERIF ARROW")
((129114 . 129120) . #f)
(129120 . "WIDE-HEADED LEFTWARDS LIGHT BARB ARROW")
(129121 . "WIDE-HEADED UPWARDS LIGHT BARB ARROW")
(129122 . "WIDE-HEADED RIGHTWARDS LIGHT BARB ARROW")
(129123 . "WIDE-HEADED DOWNWARDS LIGHT BARB ARROW")
(129124 . "WIDE-HEADED NORTH WEST LIGHT BARB ARROW")
(129125 . "WIDE-HEADED NORTH EAST LIGHT BARB ARROW")
(129126 . "WIDE-HEADED SOUTH EAST LIGHT BARB ARROW")
(129127 . "WIDE-HEADED SOUTH WEST LIGHT BARB ARROW")
(129128 . "WIDE-HEADED LEFTWARDS BARB ARROW")
(129129 . "WIDE-HEADED UPWARDS BARB ARROW")
(129130 . "WIDE-HEADED RIGHTWARDS BARB ARROW")
(129131 . "WIDE-HEADED DOWNWARDS BARB ARROW")
(129132 . "WIDE-HEADED NORTH WEST BARB ARROW")
(129133 . "WIDE-HEADED NORTH EAST BARB ARROW")
(129134 . "WIDE-HEADED SOUTH EAST BARB ARROW")
(129135 . "WIDE-HEADED SOUTH WEST BARB ARROW")
(129136 . "WIDE-HEADED LEFTWARDS MEDIUM BARB ARROW")
(129137 . "WIDE-HEADED UPWARDS MEDIUM BARB ARROW")
(129138 . "WIDE-HEADED RIGHTWARDS MEDIUM BARB ARROW")
(129139 . "WIDE-HEADED DOWNWARDS MEDIUM BARB ARROW")
(129140 . "WIDE-HEADED NORTH WEST MEDIUM BARB ARROW")
(129141 . "WIDE-HEADED NORTH EAST MEDIUM BARB ARROW")
(129142 . "WIDE-HEADED SOUTH EAST MEDIUM BARB ARROW")
(129143 . "WIDE-HEADED SOUTH WEST MEDIUM BARB ARROW")
(129144 . "WIDE-HEADED LEFTWARDS HEAVY BARB ARROW")
(129145 . "WIDE-HEADED UPWARDS HEAVY BARB ARROW")
(129146 . "WIDE-HEADED RIGHTWARDS HEAVY BARB ARROW")
(129147 . "WIDE-HEADED DOWNWARDS HEAVY BARB ARROW")
(129148 . "WIDE-HEADED NORTH WEST HEAVY BARB ARROW")
(129149 . "WIDE-HEADED NORTH EAST HEAVY BARB ARROW")
(129150 . "WIDE-HEADED SOUTH EAST HEAVY BARB ARROW")
(129151 . "WIDE-HEADED SOUTH WEST HEAVY BARB ARROW")
(129152 . "WIDE-HEADED LEFTWARDS VERY HEAVY BARB ARROW")
(129153 . "WIDE-HEADED UPWARDS VERY HEAVY BARB ARROW")
(129154 . "WIDE-HEADED RIGHTWARDS VERY HEAVY BARB ARROW")
(129155 . "WIDE-HEADED DOWNWARDS VERY HEAVY BARB ARROW")
(129156 . "WIDE-HEADED NORTH WEST VERY HEAVY BARB ARROW")
(129157 . "WIDE-HEADED NORTH EAST VERY HEAVY BARB ARROW")
(129158 . "WIDE-HEADED SOUTH EAST VERY HEAVY BARB ARROW")
(129159 . "WIDE-HEADED SOUTH WEST VERY HEAVY BARB ARROW")
((129160 . 129168) . #f)
(129168 . "LEFTWARDS TRIANGLE ARROWHEAD")
(129169 . "UPWARDS TRIANGLE ARROWHEAD")
(129170 . "RIGHTWARDS TRIANGLE ARROWHEAD")
(129171 . "DOWNWARDS TRIANGLE ARROWHEAD")
(129172 . "LEFTWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD")
(129173 . "UPWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD")
(129174 . "RIGHTWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD")
(129175 . "DOWNWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD")
(129176 . "LEFTWARDS ARROW WITH NOTCHED TAIL")
(129177 . "UPWARDS ARROW WITH NOTCHED TAIL")
(129178 . "RIGHTWARDS ARROW WITH NOTCHED TAIL")
(129179 . "DOWNWARDS ARROW WITH NOTCHED TAIL")
(129180 . "HEAVY ARROW SHAFT WIDTH ONE")
(129181 . "HEAVY ARROW SHAFT WIDTH TWO THIRDS")
(129182 . "HEAVY ARROW SHAFT WIDTH ONE HALF")
(129183 . "HEAVY ARROW SHAFT WIDTH ONE THIRD")
(129184 . "LEFTWARDS BOTTOM-SHADED WHITE ARROW")
(129185 . "RIGHTWARDS BOTTOM SHADED WHITE ARROW")
(129186 . "LEFTWARDS TOP SHADED WHITE ARROW")
(129187 . "RIGHTWARDS TOP SHADED WHITE ARROW")
(129188 . "LEFTWARDS LEFT-SHADED WHITE ARROW")
(129189 . "RIGHTWARDS RIGHT-SHADED WHITE ARROW")
(129190 . "LEFTWARDS RIGHT-SHADED WHITE ARROW")
(129191 . "RIGHTWARDS LEFT-SHADED WHITE ARROW")
(129192 . "LEFTWARDS BACK-TILTED SHADOWED WHITE ARROW")
(129193 . "RIGHTWARDS BACK-TILTED SHADOWED WHITE ARROW")
(129194 . "LEFTWARDS FRONT-TILTED SHADOWED WHITE ARROW")
(129195 . "RIGHTWARDS FRONT-TILTED SHADOWED WHITE ARROW")
(129196 . "WHITE ARROW SHAFT WIDTH ONE")
(129197 . "WHITE ARROW SHAFT WIDTH TWO THIRDS")
((129198 . 129296) . #f)
(129296 . "ZIPPER-MOUTH FACE")
(129297 . "MONEY-MOUTH FACE")
(129298 . "FACE WITH THERMOMETER")
(129299 . "NERD FACE")
(129300 . "THINKING FACE")
(129301 . "FACE WITH HEAD-BANDAGE")
(129302 . "ROBOT FACE")
(129303 . "HUGGING FACE")
(129304 . "SIGN OF THE HORNS")
(129305 . "CALL ME HAND")
(129306 . "RAISED BACK OF HAND")
(129307 . "LEFT-FACING FIST")
(129308 . "RIGHT-FACING FIST")
(129309 . "HANDSHAKE")
(129310 . "HAND WITH INDEX AND MIDDLE FINGERS CROSSED")
(129311 . #f)
(129312 . "FACE WITH COWBOY HAT")
(129313 . "CLOWN FACE")
(129314 . "NAUSEATED FACE")
(129315 . "ROLLING ON THE FLOOR LAUGHING")
(129316 . "DROOLING FACE")
(129317 . "LYING FACE")
(129318 . "FACE PALM")
(129319 . "SNEEZING FACE")
((129320 . 129328) . #f)
(129328 . "PREGNANT WOMAN")
((129329 . 129331) . #f)
(129331 . "SELFIE")
(129332 . "PRINCE")
(129333 . "MAN IN TUXEDO")
(129334 . "MOTHER CHRISTMAS")
(129335 . "SHRUG")
(129336 . "PERSON DOING CARTWHEEL")
(129337 . "JUGGLING")
(129338 . "FENCER")
(129339 . "MODERN PENTATHLON")
(129340 . "WRESTLERS")
(129341 . "WATER POLO")
(129342 . "HANDBALL")
(129343 . #f)
(129344 . "WILTED FLOWER")
(129345 . "DRUM WITH DRUMSTICKS")
(129346 . "CLINKING GLASSES")
(129347 . "TUMBLER GLASS")
(129348 . "SPOON")
(129349 . "GOAL NET")
(129350 . "RIFLE")
(129351 . "FIRST PLACE MEDAL")
(129352 . "SECOND PLACE MEDAL")
(129353 . "THIRD PLACE MEDAL")
(129354 . "BOXING GLOVE")
(129355 . "MARTIAL ARTS UNIFORM")
((129356 . 129360) . #f)
(129360 . "CROISSANT")
(129361 . "AVOCADO")
(129362 . "CUCUMBER")
(129363 . "BACON")
(129364 . "POTATO")
(129365 . "CARROT")
(129366 . "BAGUETTE BREAD")
(129367 . "GREEN SALAD")
(129368 . "SHALLOW PAN OF FOOD")
(129369 . "STUFFED FLATBREAD")
(129370 . "EGG")
(129371 . "GLASS OF MILK")
(129372 . "PEANUTS")
(129373 . "KIWIFRUIT")
(129374 . "PANCAKES")
((129375 . 129408) . #f)
(129408 . "CRAB")
(129409 . "LION FACE")
(129410 . "SCORPION")
(129411 . "TURKEY")
(129412 . "UNICORN FACE")
(129413 . "EAGLE")
(129414 . "DUCK")
(129415 . "BAT")
(129416 . "SHARK")
(129417 . "OWL")
(129418 . "FOX FACE")
(129419 . "BUTTERFLY")
(129420 . "DEER")
(129421 . "GORILLA")
(129422 . "LIZARD")
(129423 . "RHINOCEROS")
(129424 . "SHRIMP")
(129425 . "SQUID")
((129426 . 129472) . #f)
(129472 . "CHEESE WEDGE")
((129473 . 131072) . #f)
((131072 . 173792) . "CJK UNIFIED IDEOGRAPH-#")
((173792 . 173824) . #f)
((173824 . 183984) . "CJK UNIFIED IDEOGRAPH-#")
((183984 . 194560) . #f)
((194560 . 195104) . "CJK COMPATIBILITY IDEOGRAPH-#")
((195104 . 917505) . #f)
(917505 . "LANGUAGE TAG")
((917506 . 917536) . #f)
(917536 . "TAG SPACE")
(917537 . "TAG EXCLAMATION MARK")
(917538 . "TAG QUOTATION MARK")
(917539 . "TAG NUMBER SIGN")
(917540 . "TAG DOLLAR SIGN")
(917541 . "TAG PERCENT SIGN")
(917542 . "TAG AMPERSAND")
(917543 . "TAG APOSTROPHE")
(917544 . "TAG LEFT PARENTHESIS")
(917545 . "TAG RIGHT PARENTHESIS")
(917546 . "TAG ASTERISK")
(917547 . "TAG PLUS SIGN")
(917548 . "TAG COMMA")
(917549 . "TAG HYPHEN-MINUS")
(917550 . "TAG FULL STOP")
(917551 . "TAG SOLIDUS")
(917552 . "TAG DIGIT ZERO")
(917553 . "TAG DIGIT ONE")
(917554 . "TAG DIGIT TWO")
(917555 . "TAG DIGIT THREE")
(917556 . "TAG DIGIT FOUR")
(917557 . "TAG DIGIT FIVE")
(917558 . "TAG DIGIT SIX")
(917559 . "TAG DIGIT SEVEN")
(917560 . "TAG DIGIT EIGHT")
(917561 . "TAG DIGIT NINE")
(917562 . "TAG COLON")
(917563 . "TAG SEMICOLON")
(917564 . "TAG LESS-THAN SIGN")
(917565 . "TAG EQUALS SIGN")
(917566 . "TAG GREATER-THAN SIGN")
(917567 . "TAG QUESTION MARK")
(917568 . "TAG COMMERCIAL AT")
(917569 . "TAG LATIN CAPITAL LETTER A")
(917570 . "TAG LATIN CAPITAL LETTER B")
(917571 . "TAG LATIN CAPITAL LETTER C")
(917572 . "TAG LATIN CAPITAL LETTER D")
(917573 . "TAG LATIN CAPITAL LETTER E")
(917574 . "TAG LATIN CAPITAL LETTER F")
(917575 . "TAG LATIN CAPITAL LETTER G")
(917576 . "TAG LATIN CAPITAL LETTER H")
(917577 . "TAG LATIN CAPITAL LETTER I")
(917578 . "TAG LATIN CAPITAL LETTER J")
(917579 . "TAG LATIN CAPITAL LETTER K")
(917580 . "TAG LATIN CAPITAL LETTER L")
(917581 . "TAG LATIN CAPITAL LETTER M")
(917582 . "TAG LATIN CAPITAL LETTER N")
(917583 . "TAG LATIN CAPITAL LETTER O")
(917584 . "TAG LATIN CAPITAL LETTER P")
(917585 . "TAG LATIN CAPITAL LETTER Q")
(917586 . "TAG LATIN CAPITAL LETTER R")
(917587 . "TAG LATIN CAPITAL LETTER S")
(917588 . "TAG LATIN CAPITAL LETTER T")
(917589 . "TAG LATIN CAPITAL LETTER U")
(917590 . "TAG LATIN CAPITAL LETTER V")
(917591 . "TAG LATIN CAPITAL LETTER W")
(917592 . "TAG LATIN CAPITAL LETTER X")
(917593 . "TAG LATIN CAPITAL LETTER Y")
(917594 . "TAG LATIN CAPITAL LETTER Z")
(917595 . "TAG LEFT SQUARE BRACKET")
(917596 . "TAG REVERSE SOLIDUS")
(917597 . "TAG RIGHT SQUARE BRACKET")
(917598 . "TAG CIRCUMFLEX ACCENT")
(917599 . "TAG LOW LINE")
(917600 . "TAG GRAVE ACCENT")
(917601 . "TAG LATIN SMALL LETTER A")
(917602 . "TAG LATIN SMALL LETTER B")
(917603 . "TAG LATIN SMALL LETTER C")
(917604 . "TAG LATIN SMALL LETTER D")
(917605 . "TAG LATIN SMALL LETTER E")
(917606 . "TAG LATIN SMALL LETTER F")
(917607 . "TAG LATIN SMALL LETTER G")
(917608 . "TAG LATIN SMALL LETTER H")
(917609 . "TAG LATIN SMALL LETTER I")
(917610 . "TAG LATIN SMALL LETTER J")
(917611 . "TAG LATIN SMALL LETTER K")
(917612 . "TAG LATIN SMALL LETTER L")
(917613 . "TAG LATIN SMALL LETTER M")
(917614 . "TAG LATIN SMALL LETTER N")
(917615 . "TAG LATIN SMALL LETTER O")
(917616 . "TAG LATIN SMALL LETTER P")
(917617 . "TAG LATIN SMALL LETTER Q")
(917618 . "TAG LATIN SMALL LETTER R")
(917619 . "TAG LATIN SMALL LETTER S")
(917620 . "TAG LATIN SMALL LETTER T")
(917621 . "TAG LATIN SMALL LETTER U")
(917622 . "TAG LATIN SMALL LETTER V")
(917623 . "TAG LATIN SMALL LETTER W")
(917624 . "TAG LATIN SMALL LETTER X")
(917625 . "TAG LATIN SMALL LETTER Y")
(917626 . "TAG LATIN SMALL LETTER Z")
(917627 . "TAG LEFT CURLY BRACKET")
(917628 . "TAG VERTICAL LINE")
(917629 . "TAG RIGHT CURLY BRACKET")
(917630 . "TAG TILDE")
(917631 . "CANCEL TAG")
((917632 . 917760) . #f)
(917760 . "VARIATION SELECTOR-17")
(917761 . "VARIATION SELECTOR-18")
(917762 . "VARIATION SELECTOR-19")
(917763 . "VARIATION SELECTOR-20")
(917764 . "VARIATION SELECTOR-21")
(917765 . "VARIATION SELECTOR-22")
(917766 . "VARIATION SELECTOR-23")
(917767 . "VARIATION SELECTOR-24")
(917768 . "VARIATION SELECTOR-25")
(917769 . "VARIATION SELECTOR-26")
(917770 . "VARIATION SELECTOR-27")
(917771 . "VARIATION SELECTOR-28")
(917772 . "VARIATION SELECTOR-29")
(917773 . "VARIATION SELECTOR-30")
(917774 . "VARIATION SELECTOR-31")
(917775 . "VARIATION SELECTOR-32")
(917776 . "VARIATION SELECTOR-33")
(917777 . "VARIATION SELECTOR-34")
(917778 . "VARIATION SELECTOR-35")
(917779 . "VARIATION SELECTOR-36")
(917780 . "VARIATION SELECTOR-37")
(917781 . "VARIATION SELECTOR-38")
(917782 . "VARIATION SELECTOR-39")
(917783 . "VARIATION SELECTOR-40")
(917784 . "VARIATION SELECTOR-41")
(917785 . "VARIATION SELECTOR-42")
(917786 . "VARIATION SELECTOR-43")
(917787 . "VARIATION SELECTOR-44")
(917788 . "VARIATION SELECTOR-45")
(917789 . "VARIATION SELECTOR-46")
(917790 . "VARIATION SELECTOR-47")
(917791 . "VARIATION SELECTOR-48")
(917792 . "VARIATION SELECTOR-49")
(917793 . "VARIATION SELECTOR-50")
(917794 . "VARIATION SELECTOR-51")
(917795 . "VARIATION SELECTOR-52")
(917796 . "VARIATION SELECTOR-53")
(917797 . "VARIATION SELECTOR-54")
(917798 . "VARIATION SELECTOR-55")
(917799 . "VARIATION SELECTOR-56")
(917800 . "VARIATION SELECTOR-57")
(917801 . "VARIATION SELECTOR-58")
(917802 . "VARIATION SELECTOR-59")
(917803 . "VARIATION SELECTOR-60")
(917804 . "VARIATION SELECTOR-61")
(917805 . "VARIATION SELECTOR-62")
(917806 . "VARIATION SELECTOR-63")
(917807 . "VARIATION SELECTOR-64")
(917808 . "VARIATION SELECTOR-65")
(917809 . "VARIATION SELECTOR-66")
(917810 . "VARIATION SELECTOR-67")
(917811 . "VARIATION SELECTOR-68")
(917812 . "VARIATION SELECTOR-69")
(917813 . "VARIATION SELECTOR-70")
(917814 . "VARIATION SELECTOR-71")
(917815 . "VARIATION SELECTOR-72")
(917816 . "VARIATION SELECTOR-73")
(917817 . "VARIATION SELECTOR-74")
(917818 . "VARIATION SELECTOR-75")
(917819 . "VARIATION SELECTOR-76")
(917820 . "VARIATION SELECTOR-77")
(917821 . "VARIATION SELECTOR-78")
(917822 . "VARIATION SELECTOR-79")
(917823 . "VARIATION SELECTOR-80")
(917824 . "VARIATION SELECTOR-81")
(917825 . "VARIATION SELECTOR-82")
(917826 . "VARIATION SELECTOR-83")
(917827 . "VARIATION SELECTOR-84")
(917828 . "VARIATION SELECTOR-85")
(917829 . "VARIATION SELECTOR-86")
(917830 . "VARIATION SELECTOR-87")
(917831 . "VARIATION SELECTOR-88")
(917832 . "VARIATION SELECTOR-89")
(917833 . "VARIATION SELECTOR-90")
(917834 . "VARIATION SELECTOR-91")
(917835 . "VARIATION SELECTOR-92")
(917836 . "VARIATION SELECTOR-93")
(917837 . "VARIATION SELECTOR-94")
(917838 . "VARIATION SELECTOR-95")
(917839 . "VARIATION SELECTOR-96")
(917840 . "VARIATION SELECTOR-97")
(917841 . "VARIATION SELECTOR-98")
(917842 . "VARIATION SELECTOR-99")
(917843 . "VARIATION SELECTOR-100")
(917844 . "VARIATION SELECTOR-101")
(917845 . "VARIATION SELECTOR-102")
(917846 . "VARIATION SELECTOR-103")
(917847 . "VARIATION SELECTOR-104")
(917848 . "VARIATION SELECTOR-105")
(917849 . "VARIATION SELECTOR-106")
(917850 . "VARIATION SELECTOR-107")
(917851 . "VARIATION SELECTOR-108")
(917852 . "VARIATION SELECTOR-109")
(917853 . "VARIATION SELECTOR-110")
(917854 . "VARIATION SELECTOR-111")
(917855 . "VARIATION SELECTOR-112")
(917856 . "VARIATION SELECTOR-113")
(917857 . "VARIATION SELECTOR-114")
(917858 . "VARIATION SELECTOR-115")
(917859 . "VARIATION SELECTOR-116")
(917860 . "VARIATION SELECTOR-117")
(917861 . "VARIATION SELECTOR-118")
(917862 . "VARIATION SELECTOR-119")
(917863 . "VARIATION SELECTOR-120")
(917864 . "VARIATION SELECTOR-121")
(917865 . "VARIATION SELECTOR-122")
(917866 . "VARIATION SELECTOR-123")
(917867 . "VARIATION SELECTOR-124")
(917868 . "VARIATION SELECTOR-125")
(917869 . "VARIATION SELECTOR-126")
(917870 . "VARIATION SELECTOR-127")
(917871 . "VARIATION SELECTOR-128")
(917872 . "VARIATION SELECTOR-129")
(917873 . "VARIATION SELECTOR-130")
(917874 . "VARIATION SELECTOR-131")
(917875 . "VARIATION SELECTOR-132")
(917876 . "VARIATION SELECTOR-133")
(917877 . "VARIATION SELECTOR-134")
(917878 . "VARIATION SELECTOR-135")
(917879 . "VARIATION SELECTOR-136")
(917880 . "VARIATION SELECTOR-137")
(917881 . "VARIATION SELECTOR-138")
(917882 . "VARIATION SELECTOR-139")
(917883 . "VARIATION SELECTOR-140")
(917884 . "VARIATION SELECTOR-141")
(917885 . "VARIATION SELECTOR-142")
(917886 . "VARIATION SELECTOR-143")
(917887 . "VARIATION SELECTOR-144")
(917888 . "VARIATION SELECTOR-145")
(917889 . "VARIATION SELECTOR-146")
(917890 . "VARIATION SELECTOR-147")
(917891 . "VARIATION SELECTOR-148")
(917892 . "VARIATION SELECTOR-149")
(917893 . "VARIATION SELECTOR-150")
(917894 . "VARIATION SELECTOR-151")
(917895 . "VARIATION SELECTOR-152")
(917896 . "VARIATION SELECTOR-153")
(917897 . "VARIATION SELECTOR-154")
(917898 . "VARIATION SELECTOR-155")
(917899 . "VARIATION SELECTOR-156")
(917900 . "VARIATION SELECTOR-157")
(917901 . "VARIATION SELECTOR-158")
(917902 . "VARIATION SELECTOR-159")
(917903 . "VARIATION SELECTOR-160")
(917904 . "VARIATION SELECTOR-161")
(917905 . "VARIATION SELECTOR-162")
(917906 . "VARIATION SELECTOR-163")
(917907 . "VARIATION SELECTOR-164")
(917908 . "VARIATION SELECTOR-165")
(917909 . "VARIATION SELECTOR-166")
(917910 . "VARIATION SELECTOR-167")
(917911 . "VARIATION SELECTOR-168")
(917912 . "VARIATION SELECTOR-169")
(917913 . "VARIATION SELECTOR-170")
(917914 . "VARIATION SELECTOR-171")
(917915 . "VARIATION SELECTOR-172")
(917916 . "VARIATION SELECTOR-173")
(917917 . "VARIATION SELECTOR-174")
(917918 . "VARIATION SELECTOR-175")
(917919 . "VARIATION SELECTOR-176")
(917920 . "VARIATION SELECTOR-177")
(917921 . "VARIATION SELECTOR-178")
(917922 . "VARIATION SELECTOR-179")
(917923 . "VARIATION SELECTOR-180")
(917924 . "VARIATION SELECTOR-181")
(917925 . "VARIATION SELECTOR-182")
(917926 . "VARIATION SELECTOR-183")
(917927 . "VARIATION SELECTOR-184")
(917928 . "VARIATION SELECTOR-185")
(917929 . "VARIATION SELECTOR-186")
(917930 . "VARIATION SELECTOR-187")
(917931 . "VARIATION SELECTOR-188")
(917932 . "VARIATION SELECTOR-189")
(917933 . "VARIATION SELECTOR-190")
(917934 . "VARIATION SELECTOR-191")
(917935 . "VARIATION SELECTOR-192")
(917936 . "VARIATION SELECTOR-193")
(917937 . "VARIATION SELECTOR-194")
(917938 . "VARIATION SELECTOR-195")
(917939 . "VARIATION SELECTOR-196")
(917940 . "VARIATION SELECTOR-197")
(917941 . "VARIATION SELECTOR-198")
(917942 . "VARIATION SELECTOR-199")
(917943 . "VARIATION SELECTOR-200")
(917944 . "VARIATION SELECTOR-201")
(917945 . "VARIATION SELECTOR-202")
(917946 . "VARIATION SELECTOR-203")
(917947 . "VARIATION SELECTOR-204")
(917948 . "VARIATION SELECTOR-205")
(917949 . "VARIATION SELECTOR-206")
(917950 . "VARIATION SELECTOR-207")
(917951 . "VARIATION SELECTOR-208")
(917952 . "VARIATION SELECTOR-209")
(917953 . "VARIATION SELECTOR-210")
(917954 . "VARIATION SELECTOR-211")
(917955 . "VARIATION SELECTOR-212")
(917956 . "VARIATION SELECTOR-213")
(917957 . "VARIATION SELECTOR-214")
(917958 . "VARIATION SELECTOR-215")
(917959 . "VARIATION SELECTOR-216")
(917960 . "VARIATION SELECTOR-217")
(917961 . "VARIATION SELECTOR-218")
(917962 . "VARIATION SELECTOR-219")
(917963 . "VARIATION SELECTOR-220")
(917964 . "VARIATION SELECTOR-221")
(917965 . "VARIATION SELECTOR-222")
(917966 . "VARIATION SELECTOR-223")
(917967 . "VARIATION SELECTOR-224")
(917968 . "VARIATION SELECTOR-225")
(917969 . "VARIATION SELECTOR-226")
(917970 . "VARIATION SELECTOR-227")
(917971 . "VARIATION SELECTOR-228")
(917972 . "VARIATION SELECTOR-229")
(917973 . "VARIATION SELECTOR-230")
(917974 . "VARIATION SELECTOR-231")
(917975 . "VARIATION SELECTOR-232")
(917976 . "VARIATION SELECTOR-233")
(917977 . "VARIATION SELECTOR-234")
(917978 . "VARIATION SELECTOR-235")
(917979 . "VARIATION SELECTOR-236")
(917980 . "VARIATION SELECTOR-237")
(917981 . "VARIATION SELECTOR-238")
(917982 . "VARIATION SELECTOR-239")
(917983 . "VARIATION SELECTOR-240")
(917984 . "VARIATION SELECTOR-241")
(917985 . "VARIATION SELECTOR-242")
(917986 . "VARIATION SELECTOR-243")
(917987 . "VARIATION SELECTOR-244")
(917988 . "VARIATION SELECTOR-245")
(917989 . "VARIATION SELECTOR-246")
(917990 . "VARIATION SELECTOR-247")
(917991 . "VARIATION SELECTOR-248")
(917992 . "VARIATION SELECTOR-249")
(917993 . "VARIATION SELECTOR-250")
(917994 . "VARIATION SELECTOR-251")
(917995 . "VARIATION SELECTOR-252")
(917996 . "VARIATION SELECTOR-253")
(917997 . "VARIATION SELECTOR-254")
(917998 . "VARIATION SELECTOR-255")
(917999 . "VARIATION SELECTOR-256")
((918000 . 1114112) . #f)
